/*
 * JSUnzip
 *
 * Copyright (c) 2011 by Erik Moller
 * All Rights Reserved
 *
 * This software is provided 'as-is', without any express
 * or implied warranty.  In no event will the authors be
 * held liable for any damages arising from the use of
 * this software.
 *
 * Permission is granted to anyone to use this software
 * for any purpose, including commercial applications,
 * and to alter it and redistribute it freely, subject to
 * the following restrictions:
 *
 * 1. The origin of this software must not be
 *    misrepresented; you must not claim that you
 *    wrote the original software. If you use this
 *    software in a product, an acknowledgment in
 *    the product documentation would be appreciated
 *    but is not required.
 *
 * 2. Altered source versions must be plainly marked
 *    as such, and must not be misrepresented as
 *    being the original software.
 *
 * 3. This notice may not be removed or altered from
 *    any source distribution.
 */
 
var tinf;

function JSUnzip() {

    this.getInt = function(offset, size) {
        switch (size) {
        case 4:
            return  (this.data.charCodeAt(offset + 3) & 0xff) << 24 | 
                    (this.data.charCodeAt(offset + 2) & 0xff) << 16 | 
                    (this.data.charCodeAt(offset + 1) & 0xff) << 8 | 
                    (this.data.charCodeAt(offset + 0) & 0xff);
            break;
        case 2:
            return  (this.data.charCodeAt(offset + 1) & 0xff) << 8 | 
                    (this.data.charCodeAt(offset + 0) & 0xff);
            break;
        default:
            return this.data.charCodeAt(offset) & 0xff;
            break;
        }
    };

    this.getDOSDate = function(dosdate, dostime) {
        var day = dosdate & 0x1f;
        var month = ((dosdate >> 5) & 0xf) - 1;
        var year = 1980 + ((dosdate >> 9) & 0x7f)
        var second = (dostime & 0x1f) * 2;
        var minute = (dostime >> 5) & 0x3f;
        hour = (dostime >> 11) & 0x1f;
        return new Date(year, month, day, hour, minute, second);
    }

    this.open = function(data) {
        this.data = data;
        this.files = [];

        if (this.data.length < 22)
            return { 'status' : false, 'error' : 'Invalid data' };
        var endOfCentralDirectory = this.data.length - 22;
        while (endOfCentralDirectory >= 0 && this.getInt(endOfCentralDirectory, 4) != 0x06054b50)
            --endOfCentralDirectory;
        if (endOfCentralDirectory < 0)
            return { 'status' : false, 'error' : 'Invalid data' };
        if (this.getInt(endOfCentralDirectory + 4, 2) != 0 || this.getInt(endOfCentralDirectory + 6, 2) != 0)
            return { 'status' : false, 'error' : 'No multidisk support' };

        var entriesInThisDisk = this.getInt(endOfCentralDirectory + 8, 2);
        var centralDirectoryOffset = this.getInt(endOfCentralDirectory + 16, 4);
        var globalCommentLength = this.getInt(endOfCentralDirectory + 20, 2);
        this.comment = this.data.slice(endOfCentralDirectory + 22, endOfCentralDirectory + 22 + globalCommentLength);

        var fileOffset = centralDirectoryOffset;

        for (var i = 0; i < entriesInThisDisk; ++i) {
            if (this.getInt(fileOffset + 0, 4) != 0x02014b50)
                return { 'status' : false, 'error' : 'Invalid data' };
            if (this.getInt(fileOffset + 6, 2) > 20)
                return { 'status' : false, 'error' : 'Unsupported version' };
            if (this.getInt(fileOffset + 8, 2) & 1)
                return { 'status' : false, 'error' : 'Encryption not implemented' };

            var compressionMethod = this.getInt(fileOffset + 10, 2);
            if (compressionMethod != 0 && compressionMethod != 8)
                return { 'status' : false, 'error' : 'Unsupported compression method' };

            var lastModFileTime = this.getInt(fileOffset + 12, 2);
            var lastModFileDate = this.getInt(fileOffset + 14, 2);
            var lastModifiedDate = this.getDOSDate(lastModFileDate, lastModFileTime);

            var crc = this.getInt(fileOffset + 16, 4);
            // TODO: crc

            var compressedSize = this.getInt(fileOffset + 20, 4);
            var uncompressedSize = this.getInt(fileOffset + 24, 4);

            var fileNameLength = this.getInt(fileOffset + 28, 2);
            var extraFieldLength = this.getInt(fileOffset + 30, 2);
            var fileCommentLength = this.getInt(fileOffset + 32, 2);

            var relativeOffsetOfLocalHeader = this.getInt(fileOffset + 42, 4);

            var fileName = this.data.slice(fileOffset + 46, fileOffset + 46 + fileNameLength);
            var fileComment = this.data.slice(fileOffset + 46 + fileNameLength + extraFieldLength, fileOffset + 46 + fileNameLength + extraFieldLength + fileCommentLength);

            if (this.getInt(relativeOffsetOfLocalHeader + 0, 4) != 0x04034b50)
                return { 'status' : false, 'error' : 'Invalid data' };
            var localFileNameLength = this.getInt(relativeOffsetOfLocalHeader + 26, 2);
            var localExtraFieldLength = this.getInt(relativeOffsetOfLocalHeader + 28, 2);
            var localFileContent = relativeOffsetOfLocalHeader + 30 + localFileNameLength + localExtraFieldLength;

            this.files[fileName] = 
            {
                'fileComment' : fileComment,
                'compressionMethod' : compressionMethod,
                'compressedSize' : compressedSize,
                'uncompressedSize' : uncompressedSize,
                'localFileContent' : localFileContent,
                'lastModifiedDate' : lastModifiedDate
            };

            fileOffset += 46 + fileNameLength + extraFieldLength + fileCommentLength;
        }
        return { 'status' : true }
    };     
    

    this.read = function(fileName) {
        var fileInfo = this.files[fileName];
        if (fileInfo) {
            if (fileInfo.compressionMethod == 8) {
                if (!tinf) {
                    tinf = new TINF();
                    tinf.init();
                }
                var result = tinf.uncompress(this.data, fileInfo.localFileContent);
                if (result.status == tinf.OK)
                    return { 'status' : true, 'data' : result.data };
                else
                    return { 'status' : false, 'error' : result.error };
            } else {
                return { 'status' : true, 'data' : this.data.slice(fileInfo.localFileContent, fileInfo.localFileContent + fileInfo.uncompressedSize) };
            }
        }
        return { 'status' : false, 'error' : "File '" + fileName + "' doesn't exist in zip" };
    };
    
};



/*
 * tinflate  -  tiny inflate
 *
 * Copyright (c) 2003 by Joergen Ibsen / Jibz
 * All Rights Reserved
 *
 * http://www.ibsensoftware.com/
 *
 * This software is provided 'as-is', without any express
 * or implied warranty.  In no event will the authors be
 * held liable for any damages arising from the use of
 * this software.
 *
 * Permission is granted to anyone to use this software
 * for any purpose, including commercial applications,
 * and to alter it and redistribute it freely, subject to
 * the following restrictions:
 *
 * 1. The origin of this software must not be
 *    misrepresented; you must not claim that you
 *    wrote the original software. If you use this
 *    software in a product, an acknowledgment in
 *    the product documentation would be appreciated
 *    but is not required.
 *
 * 2. Altered source versions must be plainly marked
 *    as such, and must not be misrepresented as
 *    being the original software.
 *
 * 3. This notice may not be removed or altered from
 *    any source distribution.
 */

/*
 * tinflate javascript port by Erik Moller in May 2011.
 * emoller@opera.com
 */

function TINF() {

this.OK = 0;
this.DATA_ERROR = (-3);

/* ------------------------------ *
 * -- internal data structures -- *
 * ------------------------------ */

this.TREE = function() {
   this.table = new Array(16);  /* table of code length counts */
   this.trans = new Array(288); /* code -> symbol translation table */
};

this.DATA = function(that) {
   this.source = '';
   this.sourceIndex = 0;
   this.tag = 0;
   this.bitcount = 0;

   this.dest = [];

   this.ltree = new that.TREE(); /* dynamic length/symbol tree */
   this.dtree = new that.TREE(); /* dynamic distance tree */
};

/* --------------------------------------------------- *
 * -- uninitialized global data (static structures) -- *
 * --------------------------------------------------- */

this.sltree = new this.TREE(); /* fixed length/symbol tree */
this.sdtree = new this.TREE(); /* fixed distance tree */

/* extra bits and base tables for length codes */
this.length_bits = new Array(30);
this.length_base = new Array(30);

/* extra bits and base tables for distance codes */
this.dist_bits = new Array(30);
this.dist_base = new Array(30);

/* special ordering of code length codes */
this.clcidx = [
   16, 17, 18, 0, 8, 7, 9, 6,
   10, 5, 11, 4, 12, 3, 13, 2,
   14, 1, 15
];

/* ----------------------- *
 * -- utility functions -- *
 * ----------------------- */

/* build extra bits and base tables */
this.build_bits_base = function(bits, base, delta, first)
{
   var i, sum;

   /* build bits table */
   for (i = 0; i < delta; ++i) bits[i] = 0;
   for (i = 0; i < 30 - delta; ++i) bits[i + delta] = Math.floor(i / delta);

   /* build base table */
   for (sum = first, i = 0; i < 30; ++i)
   {
      base[i] = sum;
      sum += 1 << bits[i];
   }
}

/* build the fixed huffman trees */
this.build_fixed_trees = function(lt, dt)
{
   var i;

   /* build fixed length tree */
   for (i = 0; i < 7; ++i) lt.table[i] = 0;

   lt.table[7] = 24;
   lt.table[8] = 152;
   lt.table[9] = 112;

   for (i = 0; i < 24; ++i) lt.trans[i] = 256 + i;
   for (i = 0; i < 144; ++i) lt.trans[24 + i] = i;
   for (i = 0; i < 8; ++i) lt.trans[24 + 144 + i] = 280 + i;
   for (i = 0; i < 112; ++i) lt.trans[24 + 144 + 8 + i] = 144 + i;

   /* build fixed distance tree */
   for (i = 0; i < 5; ++i) dt.table[i] = 0;

   dt.table[5] = 32;

   for (i = 0; i < 32; ++i) dt.trans[i] = i;
}

/* given an array of code lengths, build a tree */
this.build_tree = function(t, lengths, loffset, num)
{
   var offs = new Array(16);
   var i, sum;

   /* clear code length count table */
   for (i = 0; i < 16; ++i) t.table[i] = 0;

   /* scan symbol lengths, and sum code length counts */
   for (i = 0; i < num; ++i) t.table[lengths[loffset + i]]++;

   t.table[0] = 0;

   /* compute offset table for distribution sort */
   for (sum = 0, i = 0; i < 16; ++i)
   {
      offs[i] = sum;
      sum += t.table[i];
   }

   /* create code->symbol translation table (symbols sorted by code) */
   for (i = 0; i < num; ++i)
   {
      if (lengths[loffset + i]) t.trans[offs[lengths[loffset + i]]++] = i;
   }
}

/* ---------------------- *
 * -- decode functions -- *
 * ---------------------- */

/* get one bit from source stream */
this.getbit = function(d)
{
   var bit;

   /* check if tag is empty */
   if (!d.bitcount--)
   {
      /* load next tag */
      d.tag = d.source.charCodeAt(d.sourceIndex++) & 0xff;
      d.bitcount = 7;
   }

   /* shift bit out of tag */
   bit = d.tag & 0x01;
   d.tag >>= 1;

   return bit;
}

/* read a num bit value from a stream and add base */
this.read_bits = function(d, num, base)
{
    if (!num)
        return base;

    var val = 0;
    while (d.bitcount < 24) {
        d.tag = d.tag | (d.source.charCodeAt(d.sourceIndex++) & 0xff) << d.bitcount;
        d.bitcount += 8;
    }
    val = d.tag & (0xff >> (8 - num));
    d.tag >>= num;
    d.bitcount -= num;
    return val + base;
}

/* given a data stream and a tree, decode a symbol */
this.decode_symbol = function(d, t)
{
    while (d.bitcount < 24) {
        d.tag = d.tag | (d.source.charCodeAt(d.sourceIndex++) & 0xff) << d.bitcount;
        d.bitcount += 8;
    }
    
    var sum = 0, cur = 0, len = 0;
    do {
        cur = 2 * cur + ((d.tag & (1 << len)) >> len);

        ++len;

        sum += t.table[len];
        cur -= t.table[len];

    } while (cur >= 0);

    d.tag >>= len;
    d.bitcount -= len;

    return t.trans[sum + cur];
}

/* given a data stream, decode dynamic trees from it */
this.decode_trees = function(d, lt, dt)
{
   var code_tree = new this.TREE();
   lengths = new Array(288+32);
   var hlit, hdist, hclen;
   var i, num, length;

   /* get 5 bits HLIT (257-286) */
   hlit = this.read_bits(d, 5, 257);

   /* get 5 bits HDIST (1-32) */
   hdist = this.read_bits(d, 5, 1);

   /* get 4 bits HCLEN (4-19) */
   hclen = this.read_bits(d, 4, 4);

   for (i = 0; i < 19; ++i) lengths[i] = 0;

   /* read code lengths for code length alphabet */
   for (i = 0; i < hclen; ++i)
   {
      /* get 3 bits code length (0-7) */
      var clen = this.read_bits(d, 3, 0);

      lengths[this.clcidx[i]] = clen;
   }

   /* build code length tree */
   this.build_tree(code_tree, lengths, 0, 19);

   /* decode code lengths for the dynamic trees */
   for (num = 0; num < hlit + hdist; )
   {
      var sym = this.decode_symbol(d, code_tree);

      switch (sym)
      {
      case 16:
         /* copy previous code length 3-6 times (read 2 bits) */
         {
            var prev = lengths[num - 1];
            for (length = this.read_bits(d, 2, 3); length; --length)
            {
               lengths[num++] = prev;
            }
         }
         break;
      case 17:
         /* repeat code length 0 for 3-10 times (read 3 bits) */
         for (length = this.read_bits(d, 3, 3); length; --length)
         {
            lengths[num++] = 0;
         }
         break;
      case 18:
         /* repeat code length 0 for 11-138 times (read 7 bits) */
         for (length = this.read_bits(d, 7, 11); length; --length)
         {
            lengths[num++] = 0;
         }
         break;
      default:
         /* values 0-15 represent the actual code lengths */
         lengths[num++] = sym;
         break;
      }
   }

   /* build dynamic trees */
   this.build_tree(lt, lengths, 0, hlit);
   this.build_tree(dt, lengths, hlit, hdist);
}

/* ----------------------------- *
 * -- block inflate functions -- *
 * ----------------------------- */

/* given a stream and two trees, inflate a block of data */
this.inflate_block_data = function(d, lt, dt)
{
   // js optimization.
   var ddest = d.dest;
   var ddestlength = ddest.length;

   while (1)
   {
      var sym = this.decode_symbol(d, lt);

      /* check for end of block */
      if (sym == 256)
      {
         return this.OK;
      }

      if (sym < 256)
      {
         ddest[ddestlength++] = String.fromCharCode(sym);
      } else {

         var length, dist, offs;
         var i;

         sym -= 257;

         /* possibly get more bits from length code */
         length = this.read_bits(d, this.length_bits[sym], this.length_base[sym]);

         dist = this.decode_symbol(d, dt);

         /* possibly get more bits from distance code */
         offs = ddestlength - this.read_bits(d, this.dist_bits[dist], this.dist_base[dist]);

         /* copy match */
         for (i = offs; i < offs + length; ++i) {
            ddest[ddestlength++] = ddest[i];
         }
      }
   }
}

/* inflate an uncompressed block of data */
this.inflate_uncompressed_block = function(d)
{
   var length, invlength;
   var i;

   /* get length */
   length = d.source[d.sourceIndex+1];
   length = 256*length + d.source[d.sourceIndex];

   /* get one's complement of length */
   invlength = d.source[d.sourceIndex+3];
   invlength = 256*invlength + d.source[d.sourceIndex+2];

   /* check length */
   if (length != (~invlength & 0x0000ffff)) return this.DATA_ERROR;

   d.sourceIndex += 4;

   /* copy block */
   for (i = length; i; --i)
       d.dest[d.dest.length] = d.source[d.sourceIndex++];

   /* make sure we start next block on a byte boundary */
   d.bitcount = 0;

   return this.OK;
}

/* inflate a block of data compressed with fixed huffman trees */
this.inflate_fixed_block = function(d)
{
   /* decode block using fixed trees */
   return this.inflate_block_data(d, this.sltree, this.sdtree);
}

/* inflate a block of data compressed with dynamic huffman trees */
this.inflate_dynamic_block = function(d)
{
   /* decode trees from stream */
   this.decode_trees(d, d.ltree, d.dtree);

   /* decode block using decoded trees */
   return this.inflate_block_data(d, d.ltree, d.dtree);
}

/* ---------------------- *
 * -- public functions -- *
 * ---------------------- */

/* initialize global (static) data */
this.init = function()
{
   /* build fixed huffman trees */
   this.build_fixed_trees(this.sltree, this.sdtree);

   /* build extra bits and base tables */
   this.build_bits_base(this.length_bits, this.length_base, 4, 3);
   this.build_bits_base(this.dist_bits, this.dist_base, 2, 1);

   /* fix a special case */
   this.length_bits[28] = 0;
   this.length_base[28] = 258;
}

/* inflate stream from source to dest */
this.uncompress = function(source, offset)
{
   var d = new this.DATA(this);
   var bfinal;

   /* initialise data */
   d.source = source;
   d.sourceIndex = offset;
   d.bitcount = 0;

   d.dest = [];

   do {

      var btype;
      var res;

      /* read final block flag */
      bfinal = this.getbit(d);

      /* read block type (2 bits) */
      btype = this.read_bits(d, 2, 0);

      /* decompress block */
      switch (btype)
      {
      case 0:
         /* decompress uncompressed block */
         res = this.inflate_uncompressed_block(d);
         break;
      case 1:
         /* decompress block with fixed huffman trees */
         res = this.inflate_fixed_block(d);
         break;
      case 2:
         /* decompress block with dynamic huffman trees */
         res = this.inflate_dynamic_block(d);
         break;
      default:
         return { 'status' : this.DATA_ERROR };
      }

      if (res != this.OK) return { 'status' : this.DATA_ERROR };

   } while (!bfinal);
   d.dest = d.dest.join('');

   return { 'status' : this.OK, 'data' : d.dest };
}

};

var data = [80,75,3,4,20,0,0,0,8,0,112,134,58,33,186,125,0,102,84,212,0,0,25,82,2,0,11,0,0,0,97,108,105,99,101,50,57,46,116,120,116,213,253,91,115,27,215,178,53,10,190,43,66,127,160,159,64,189,208,62,1,240,161,223,218,122,80,200,22,109,241,91,186,120,139,244,82,187,59,78,124,44,2,69,162,76,0,133,93,85,16,13,255,250,147,99,140,204,57,103,1,160,215,90,251,60,116,180,246,142,101,137,4,234,50,103,206,188,142,28,249,242,197,75,254,223,228,224,207,219,15,87,63,93,158,95,79,222,190,251,231,229,167,155,223,190,92,94,79,174,62,77,190,126,254,244,238,242,203,135,183,159,222,157,250,78,254,243,161,126,106,250,201,79,85,215,181,171,213,137,143,222,188,191,156,124,188,250,240,225,242,211,167,171,223,62,78,126,254,237,195,79,95,236,191,151,239,174,110,174,62,127,154,252,63,47,254,95,47,95,188,124,230,201,202,63,63,189,127,251,235,205,229,151,201,213,243,31,124,215,62,109,38,195,178,158,124,169,238,238,154,97,246,190,93,213,113,225,183,171,102,94,79,158,170,126,114,87,63,52,155,77,179,121,152,12,237,228,161,30,38,223,234,110,63,25,154,174,94,76,218,251,73,223,12,3,126,121,183,159,44,235,206,254,217,15,117,247,242,69,171,43,223,85,155,199,233,164,218,240,163,203,234,27,62,185,105,135,165,95,110,209,254,48,153,180,27,187,83,219,77,134,39,220,178,183,111,45,171,197,203,23,219,186,222,218,45,154,141,125,142,151,106,219,199,226,22,124,182,174,174,22,118,169,233,228,110,55,76,154,1,95,180,203,219,119,155,249,176,235,234,30,151,157,183,27,123,226,190,26,154,118,211,219,229,236,115,211,201,45,30,233,105,89,217,183,122,94,125,215,215,120,196,138,183,153,158,191,124,49,44,219,221,195,114,240,133,184,125,106,240,131,97,242,220,149,223,156,107,221,174,91,190,1,30,206,126,221,55,139,186,195,187,218,109,241,232,88,240,117,99,183,254,206,126,255,84,175,86,19,251,47,62,63,111,119,171,197,244,229,139,123,172,3,86,160,29,38,139,106,63,89,87,139,154,223,188,175,235,149,86,190,95,217,194,236,185,166,253,176,219,54,139,239,167,246,38,181,125,171,195,83,215,147,237,170,174,122,123,70,188,207,186,122,196,237,43,187,88,211,239,103,243,101,101,79,242,132,155,217,190,218,95,186,97,201,251,13,93,187,187,195,238,219,119,108,143,185,163,187,45,111,98,111,204,107,224,99,184,74,83,247,188,225,102,210,239,22,139,122,179,178,103,153,124,93,54,131,125,91,130,52,193,98,217,247,54,143,147,122,111,75,213,85,155,201,124,213,218,10,75,72,46,180,84,55,246,87,173,84,72,68,223,78,254,121,249,229,119,219,214,117,213,61,86,246,64,88,184,193,182,233,181,125,166,155,44,154,133,246,3,47,138,203,219,189,226,59,235,221,124,57,193,14,217,27,12,220,129,61,36,108,89,87,93,33,227,147,158,63,126,249,162,25,250,122,117,111,130,240,121,57,89,216,103,206,38,147,252,183,43,219,147,202,54,199,150,104,85,13,245,217,249,100,242,157,222,24,75,37,193,192,37,38,173,237,200,164,186,55,113,124,170,186,133,173,11,126,54,159,239,58,28,14,222,189,227,227,243,139,146,39,252,180,250,102,111,240,212,110,76,56,236,115,246,107,123,155,94,66,204,127,216,77,154,117,141,139,225,41,250,186,94,219,199,254,123,103,75,60,217,84,38,126,213,234,251,215,47,95,224,227,124,170,226,245,42,147,78,251,206,126,114,243,249,243,63,38,111,39,95,223,222,252,244,126,242,249,183,155,201,231,159,39,87,55,215,246,131,171,235,155,159,62,191,189,153,189,124,241,235,231,159,254,113,121,163,227,185,50,177,215,179,224,120,224,39,3,46,189,180,87,105,112,208,55,83,63,9,253,80,117,3,223,238,229,11,23,76,251,2,228,214,110,127,191,170,236,77,237,50,243,174,237,123,190,62,197,61,173,1,15,104,253,13,162,122,87,219,151,106,188,221,198,4,168,43,36,167,110,32,204,246,195,39,19,183,97,222,86,195,108,219,206,31,113,159,86,63,30,108,175,241,0,67,245,88,199,166,199,115,223,237,58,106,43,94,202,182,162,105,77,69,237,167,188,61,36,209,159,205,110,97,199,173,169,237,36,112,3,211,247,237,169,134,157,45,115,109,171,8,225,252,99,215,15,20,67,108,137,237,158,61,48,94,117,219,110,95,190,88,224,64,87,38,36,221,67,237,175,48,91,154,22,157,236,176,183,58,201,245,226,161,118,137,191,178,15,67,214,177,44,237,186,222,216,25,199,5,158,240,55,173,110,126,20,174,18,117,227,203,23,165,38,89,182,79,58,20,60,190,246,244,161,110,92,59,99,53,170,7,59,230,249,148,141,158,140,55,235,135,174,106,32,141,166,166,87,141,173,97,53,177,119,222,152,138,193,70,246,246,108,56,63,166,143,146,32,44,154,45,180,113,58,242,120,240,41,14,95,250,9,247,88,111,33,53,108,207,241,242,133,191,39,117,56,78,108,117,135,7,236,135,118,187,229,219,152,254,180,115,56,9,97,176,135,189,111,109,241,226,23,182,69,38,206,248,164,47,53,85,224,194,52,32,213,167,191,227,165,4,134,107,2,165,138,229,72,31,164,208,240,194,248,149,171,208,246,105,181,151,212,246,144,3,60,176,169,205,205,176,167,250,192,78,187,98,126,74,187,100,175,128,67,226,111,64,1,221,232,24,232,36,203,156,224,214,15,173,155,183,101,101,139,182,177,173,252,115,184,152,76,126,110,186,126,144,28,14,60,84,126,197,16,35,187,218,58,228,249,41,14,140,12,201,90,23,76,118,78,251,109,246,211,212,36,31,1,66,89,109,246,84,163,175,181,99,248,118,62,213,88,27,200,80,159,244,163,173,6,5,254,229,11,219,42,219,53,63,165,246,59,147,123,104,230,251,102,181,178,159,250,57,218,222,181,80,113,58,98,118,217,153,93,127,245,173,238,95,83,13,212,161,50,124,19,251,234,201,94,102,219,135,5,145,205,92,238,104,86,76,232,182,245,67,111,75,114,141,197,31,176,170,190,189,127,152,182,190,239,218,181,9,102,29,79,234,55,138,29,217,86,125,95,47,94,251,50,188,124,177,170,238,106,62,232,237,231,47,111,63,253,98,222,211,219,47,31,223,126,120,251,238,242,92,235,229,122,248,193,156,5,219,202,166,183,77,177,13,26,40,151,141,233,113,44,102,189,222,14,123,243,69,112,3,88,25,72,47,15,6,156,148,174,221,242,65,248,112,45,84,158,253,197,30,238,177,161,104,218,234,155,144,223,181,139,61,15,196,186,218,84,15,218,221,173,118,139,46,76,241,66,197,98,246,146,63,138,166,189,24,62,238,50,125,251,213,126,102,150,103,236,135,232,93,220,116,73,89,244,48,124,213,4,231,4,215,147,41,49,175,79,38,76,167,46,12,44,30,96,183,190,203,7,202,180,185,73,165,153,188,247,166,86,238,58,51,76,20,128,115,184,166,249,235,56,14,38,242,246,150,246,201,175,75,123,207,43,57,17,155,115,89,212,16,61,63,28,166,191,94,190,48,253,101,190,214,189,125,148,111,215,222,235,229,237,228,199,58,216,155,245,48,174,223,153,247,96,239,144,78,45,22,126,181,55,193,232,118,245,197,247,90,142,119,212,55,139,244,191,38,60,95,233,198,224,66,124,247,79,151,230,7,224,172,112,149,76,209,215,155,133,61,238,237,85,58,160,80,157,182,59,230,85,53,43,147,167,171,243,111,250,170,61,231,221,158,11,199,163,255,230,220,69,216,228,160,90,181,187,133,237,200,237,149,57,24,182,61,230,17,132,123,132,77,127,162,192,111,194,199,152,155,72,117,105,155,237,167,195,242,2,30,191,9,217,154,150,206,36,140,135,44,121,96,166,236,58,110,113,207,227,207,231,210,75,94,105,237,103,51,91,31,19,58,91,208,125,187,195,53,166,133,146,53,79,175,131,58,135,173,168,180,91,15,126,194,237,101,122,179,100,238,121,218,49,169,251,222,29,96,30,170,249,178,109,87,93,219,174,195,218,67,204,244,61,119,201,76,168,232,89,61,180,173,41,9,83,216,52,140,102,75,93,111,182,79,18,169,123,30,175,199,141,233,84,216,186,169,164,48,251,118,20,125,40,169,21,28,247,141,203,176,157,149,193,206,79,104,51,220,100,178,237,204,127,113,49,135,88,185,135,245,253,228,118,54,51,71,114,10,183,175,26,206,123,23,51,188,71,71,51,102,167,122,168,204,84,206,102,119,250,249,134,18,154,213,242,7,115,210,135,221,2,14,110,55,249,208,110,30,248,47,137,192,67,11,29,241,6,78,94,105,190,38,166,45,171,241,183,241,164,211,131,75,200,89,113,77,227,103,53,235,208,13,174,247,208,49,218,104,113,226,169,172,171,125,136,245,175,166,22,77,104,204,124,66,228,44,212,130,131,66,235,13,201,141,87,224,41,210,121,166,168,243,165,95,190,184,121,255,229,243,111,191,188,207,194,230,231,248,222,76,57,22,239,220,157,71,44,39,207,5,125,131,117,43,103,30,17,86,107,70,207,37,178,90,61,74,213,219,175,154,14,126,243,66,162,8,207,246,76,126,196,219,205,208,108,43,147,145,90,42,38,75,104,152,170,174,162,37,126,88,85,97,13,190,190,189,14,25,208,254,51,94,131,156,217,247,237,180,81,92,26,108,161,180,9,173,127,37,207,55,111,48,22,143,98,128,101,246,181,128,217,254,166,195,222,63,226,179,107,237,22,190,181,169,214,89,221,218,37,7,83,43,208,139,56,67,144,84,59,210,191,34,76,178,219,127,172,206,43,59,4,141,84,231,228,83,253,52,249,255,212,213,138,49,107,55,121,187,131,175,180,106,42,147,143,239,24,115,133,249,134,225,130,127,105,129,196,62,108,83,191,53,123,59,155,221,155,44,238,39,63,253,246,229,230,250,242,247,171,79,191,224,215,118,231,243,78,250,134,54,99,88,118,126,226,76,185,54,136,58,222,181,124,60,169,92,252,141,65,161,219,19,91,162,55,223,155,76,188,245,184,21,174,217,164,121,176,168,168,218,192,84,13,131,237,228,67,211,173,240,28,231,165,230,198,97,181,5,178,155,218,61,62,181,83,9,134,89,125,58,152,139,214,23,208,84,211,182,238,150,176,217,33,107,238,233,62,117,118,117,59,81,22,15,38,157,119,113,254,172,90,62,14,235,234,85,47,67,218,210,64,122,28,209,182,27,4,1,144,248,193,132,143,214,35,36,255,93,179,169,150,120,139,117,99,174,186,189,4,237,2,67,188,161,157,109,32,18,110,227,220,6,216,187,50,74,227,23,229,30,97,231,171,225,226,123,30,164,101,187,77,150,13,225,101,189,190,131,82,100,58,161,218,205,107,218,115,83,191,143,244,149,234,106,6,209,180,39,209,245,214,251,28,25,62,53,253,146,187,131,243,237,174,155,222,24,135,135,22,82,43,80,225,248,155,59,128,151,117,165,107,251,108,143,125,190,54,55,223,252,239,5,149,134,244,250,154,82,62,103,96,83,77,238,170,20,131,81,221,37,171,104,191,91,195,104,142,4,249,199,29,60,84,124,217,252,24,123,124,251,118,63,77,250,15,122,237,173,28,234,218,151,222,23,157,241,194,203,23,126,100,149,86,208,109,233,244,154,151,102,138,42,60,217,112,58,26,120,105,11,115,165,108,77,104,95,218,123,120,80,246,197,219,119,7,207,240,134,34,61,254,209,185,242,22,38,70,88,224,158,223,50,41,136,207,204,245,25,216,187,73,50,119,101,138,4,42,162,218,244,182,246,174,120,95,190,248,239,93,221,35,3,51,45,180,8,37,101,93,13,204,19,185,115,33,21,43,151,76,174,39,28,147,65,54,37,249,218,139,246,47,183,106,90,10,216,130,63,100,249,31,118,27,185,131,246,242,41,162,149,251,248,228,2,188,196,87,96,113,185,138,16,8,10,144,46,53,90,77,238,169,57,73,102,191,237,241,17,140,220,126,106,159,166,241,249,1,46,211,186,246,220,204,110,88,218,241,132,95,138,69,225,185,197,106,85,92,57,91,175,81,54,6,202,117,183,222,158,197,127,228,231,241,52,216,5,233,125,87,80,239,91,110,157,45,221,252,81,110,250,2,66,86,155,74,237,83,2,64,230,6,111,8,59,124,113,152,26,148,147,128,184,125,105,122,208,223,18,142,178,221,216,60,96,83,24,109,152,123,230,9,40,61,17,19,186,183,237,33,202,110,59,10,110,112,91,6,55,184,47,108,209,235,8,17,185,231,252,136,71,210,43,216,51,4,5,21,125,15,127,112,38,164,34,43,130,143,187,183,97,58,167,151,250,64,106,99,159,28,97,202,196,72,117,241,172,69,240,138,76,80,219,15,63,152,218,133,36,21,17,187,162,4,72,79,179,89,248,241,57,145,53,96,30,10,209,70,143,179,34,147,103,65,209,6,209,153,137,182,253,165,83,50,202,206,149,125,84,59,98,162,219,63,218,201,155,210,117,69,42,10,89,39,83,8,238,131,66,229,93,71,144,168,4,91,189,68,190,165,241,204,16,141,149,238,66,139,31,55,114,47,169,92,159,77,203,149,68,24,205,215,69,94,198,183,136,17,57,149,37,99,117,170,0,124,118,106,255,251,52,129,169,152,166,83,214,195,22,97,231,239,144,22,236,236,247,166,88,87,213,122,219,195,92,155,211,100,11,206,0,143,182,189,109,239,199,201,64,252,207,162,109,59,73,64,71,103,128,161,2,111,226,143,237,190,21,62,177,66,94,104,241,90,137,10,190,114,118,225,238,152,89,114,55,2,187,198,141,134,35,130,64,152,11,188,219,106,93,90,249,112,131,4,162,86,238,160,133,22,146,94,88,65,68,251,106,225,137,15,94,113,221,44,22,171,122,26,209,69,228,102,66,145,240,148,62,147,147,185,142,156,201,225,177,116,59,110,190,65,93,207,86,245,3,227,72,228,65,167,124,17,102,131,121,106,219,149,41,3,243,178,250,254,245,200,215,246,48,15,242,60,169,255,156,215,91,136,177,137,202,222,188,220,149,221,115,242,88,71,90,135,11,101,178,116,143,180,68,114,93,101,58,153,6,116,163,100,209,117,43,181,149,67,88,216,61,108,82,4,114,246,112,175,177,59,120,204,202,194,201,58,39,100,176,67,189,54,12,25,11,166,202,144,146,81,174,250,177,222,167,100,70,191,78,155,12,229,102,207,108,166,73,30,8,173,60,206,100,139,124,10,126,133,85,128,203,119,65,151,23,139,61,157,120,205,161,175,231,45,196,6,39,143,18,52,61,94,231,246,201,14,131,233,44,164,195,83,94,210,174,31,169,16,41,27,79,40,230,51,5,181,227,155,164,37,240,72,228,190,177,80,28,225,238,102,190,68,158,195,22,206,207,142,103,122,176,16,238,163,165,125,176,179,188,73,75,228,154,107,148,170,168,87,220,0,228,85,225,129,45,206,74,253,139,149,240,43,235,65,152,186,220,69,178,213,190,180,138,234,73,165,165,53,135,63,180,36,94,149,54,146,219,193,28,181,146,176,74,18,250,179,63,110,204,62,78,34,57,101,241,155,103,147,86,30,65,132,214,205,53,154,149,169,235,149,69,7,195,228,193,162,6,123,205,100,175,250,10,174,202,123,63,32,212,52,139,242,120,80,146,240,210,80,250,58,237,82,165,12,128,184,202,38,182,30,187,72,211,45,40,127,119,10,16,238,109,75,107,87,155,250,192,220,226,91,174,8,54,185,119,95,43,57,18,92,2,166,40,240,4,88,116,88,153,28,6,107,85,77,107,188,86,173,200,179,25,102,188,246,250,164,100,242,1,239,77,71,126,154,83,53,91,236,7,119,201,84,122,83,68,251,16,90,247,229,40,11,40,58,69,97,9,254,20,189,89,123,139,11,20,35,164,244,229,112,190,124,113,229,143,221,47,119,84,175,145,181,173,45,174,159,155,44,208,55,149,207,239,31,157,42,108,108,55,72,165,192,85,228,245,168,220,77,11,95,152,233,248,121,228,102,41,117,181,199,110,204,218,251,153,45,193,140,53,20,230,20,148,34,85,62,211,54,110,197,244,248,244,48,231,155,124,36,61,8,127,203,247,189,175,159,20,45,62,32,1,177,168,145,86,132,70,48,57,71,177,162,89,111,219,190,111,76,207,141,172,129,23,62,100,143,204,62,97,185,80,190,170,154,168,56,22,231,202,213,117,235,78,25,12,244,93,53,127,156,184,100,186,22,53,201,186,71,48,192,4,14,149,56,133,7,231,59,252,9,168,36,132,38,141,151,27,10,85,164,234,32,164,174,219,33,83,163,60,200,78,249,32,143,166,125,111,236,117,99,107,122,102,125,60,185,84,164,184,147,186,191,107,249,159,86,165,201,239,110,105,75,77,63,213,212,79,94,134,128,188,114,85,92,53,157,43,65,37,49,251,158,114,159,205,229,166,158,63,178,150,167,194,41,47,47,229,181,173,182,240,153,144,51,157,166,120,223,115,19,183,239,190,92,125,250,199,228,227,229,57,2,179,106,55,52,247,59,108,207,214,140,219,192,34,144,178,153,94,239,88,213,240,175,251,168,109,100,199,141,91,206,68,188,231,113,110,223,117,10,70,237,169,195,245,48,177,174,147,42,29,187,148,41,127,110,81,205,205,251,183,55,242,56,232,175,33,56,68,12,123,117,78,227,143,228,57,237,215,52,231,236,188,184,139,224,213,203,162,19,250,76,40,41,218,75,188,218,182,77,223,110,94,97,111,237,102,231,175,85,116,13,35,128,138,114,202,167,109,228,224,113,249,108,3,135,214,148,121,36,159,230,203,102,101,161,128,137,227,178,213,233,64,30,9,197,39,119,132,77,133,43,104,54,57,125,106,168,0,170,126,144,134,146,164,237,54,44,213,90,0,31,135,67,102,254,174,158,87,144,117,186,58,95,63,255,246,225,29,151,37,194,86,207,229,175,33,109,148,67,90,194,6,137,243,166,222,216,62,226,97,134,42,50,81,107,104,115,230,136,123,63,176,166,232,235,197,12,37,102,164,43,224,78,195,53,198,163,83,27,152,218,192,127,204,16,208,232,209,106,183,40,43,84,201,184,232,19,115,91,6,251,111,135,61,160,231,200,116,33,106,46,144,89,200,86,101,54,164,185,175,25,154,237,122,85,38,237,28,154,234,126,157,130,5,22,251,149,140,176,141,176,69,100,142,112,137,16,216,239,179,144,244,224,29,232,58,86,33,210,218,210,151,47,110,181,167,38,4,13,11,250,213,106,109,206,250,196,15,16,37,169,49,67,213,213,30,165,219,69,167,76,64,32,238,71,110,212,182,42,162,155,228,77,240,200,22,103,231,211,231,155,144,161,124,191,148,206,48,243,128,26,135,178,66,131,109,116,157,11,138,166,93,136,1,112,101,184,161,97,248,78,112,5,70,212,247,213,28,159,101,64,205,99,187,110,254,180,219,220,175,170,111,200,15,219,15,204,173,48,233,159,161,246,58,181,117,71,17,214,190,106,106,172,158,153,78,134,102,235,90,187,169,221,125,215,193,197,179,119,190,191,175,221,129,89,82,48,113,88,169,77,237,115,166,48,176,244,42,134,217,58,224,25,27,84,110,85,213,190,15,175,220,254,252,31,14,22,249,183,255,59,194,155,252,231,223,250,31,222,239,246,171,36,155,5,223,93,79,188,132,34,164,172,38,95,79,138,52,126,210,219,187,45,50,211,99,107,26,233,173,183,76,86,132,235,39,203,229,206,145,148,213,19,237,235,100,24,251,126,94,87,99,216,91,33,225,66,31,133,150,19,160,10,47,241,167,100,113,145,126,192,21,83,214,19,161,234,95,74,224,185,74,204,222,73,97,245,194,253,178,203,208,255,218,187,243,101,123,232,37,199,101,200,180,110,211,64,153,51,45,8,195,140,10,253,110,168,251,84,219,190,143,167,121,249,34,105,226,126,201,51,8,75,120,111,110,179,189,89,196,134,112,17,147,37,179,3,245,13,171,239,254,26,142,144,45,186,131,3,100,107,107,248,227,145,189,26,89,177,113,113,203,142,197,122,31,79,192,0,106,53,180,15,181,2,53,223,175,185,45,243,10,105,186,113,178,255,202,61,41,219,102,223,90,84,4,34,17,54,170,191,42,83,155,210,198,118,226,214,142,3,210,181,39,72,83,235,110,44,182,41,171,232,191,49,85,198,136,114,55,164,82,114,225,92,230,44,35,117,155,131,159,8,119,240,146,29,117,126,36,85,120,121,212,27,26,156,230,208,25,220,213,8,235,214,204,127,184,15,166,205,92,212,115,139,101,23,196,91,105,169,146,47,238,30,120,53,16,68,80,132,103,124,214,236,163,158,49,110,150,107,172,82,72,114,127,167,163,130,60,237,74,169,162,15,98,26,243,50,235,72,32,70,242,225,180,31,230,112,145,242,242,189,210,19,177,120,238,15,238,97,143,109,173,154,200,22,185,19,172,196,180,16,49,219,21,157,164,113,70,157,161,113,78,72,105,191,113,30,239,16,156,32,113,191,106,214,119,202,80,229,160,214,34,238,20,211,186,195,120,80,112,239,87,192,65,116,251,215,227,215,164,13,19,36,46,178,36,172,226,211,191,98,82,97,170,128,9,171,158,130,124,202,67,85,70,88,115,60,103,20,128,127,106,81,29,97,116,127,222,23,254,239,92,89,10,23,236,106,56,59,56,68,41,83,51,141,114,76,191,172,58,179,201,212,127,213,226,27,60,47,86,26,90,229,251,188,54,107,2,45,85,112,102,218,15,105,165,7,147,179,142,54,251,1,159,138,55,163,213,96,189,14,215,162,45,115,197,20,54,5,120,132,213,194,44,245,125,187,66,92,6,63,226,251,233,56,245,43,127,109,14,201,201,139,214,19,202,96,151,128,22,19,166,229,142,153,149,129,57,49,202,54,94,8,176,50,109,1,193,131,132,246,248,113,163,9,238,34,211,122,215,254,153,128,119,188,4,36,207,143,162,169,235,106,40,110,78,47,243,193,20,0,77,240,188,107,255,123,87,103,205,108,98,182,79,53,138,126,200,154,74,144,61,91,60,55,61,182,139,112,13,115,57,251,190,21,252,113,219,213,118,110,22,241,100,182,85,79,173,71,13,112,107,127,164,164,113,167,95,190,192,86,75,63,158,12,42,129,45,208,213,142,46,229,21,122,250,132,20,28,219,123,228,173,234,13,183,8,206,5,92,247,123,158,2,226,77,62,127,186,180,213,235,183,245,156,50,143,186,96,103,222,205,89,66,52,182,155,88,116,47,229,23,169,42,30,52,46,243,16,240,151,21,215,137,8,40,37,121,120,89,63,192,158,182,200,96,171,157,50,230,192,174,185,63,130,92,133,41,217,71,164,137,76,169,40,179,88,68,41,151,22,17,88,140,162,8,178,140,83,220,59,195,17,177,88,193,220,106,196,38,196,81,120,192,80,11,222,54,10,157,20,45,52,247,180,80,118,83,150,155,30,58,230,91,145,27,153,50,246,174,54,174,137,60,105,37,225,59,245,45,62,62,108,148,190,53,55,167,211,28,140,140,7,131,94,125,13,167,194,115,100,136,177,249,112,15,245,112,168,188,181,70,87,72,53,161,170,49,71,73,73,203,33,43,208,167,61,66,113,137,1,106,132,148,177,192,66,49,108,254,132,100,174,246,99,19,251,85,113,166,61,193,27,8,141,151,73,222,156,79,233,251,59,60,75,181,12,79,173,57,120,35,167,75,90,96,87,234,85,81,100,137,122,126,71,120,64,86,193,248,161,20,118,191,235,44,162,236,29,67,120,63,194,7,2,249,217,68,94,171,135,49,134,11,132,0,90,73,233,93,87,187,103,158,148,19,130,47,46,134,212,49,244,121,141,122,146,36,8,250,59,39,40,96,223,144,231,128,253,141,181,230,2,224,173,234,63,113,4,74,132,50,190,124,50,29,146,193,93,142,73,32,18,181,196,105,46,118,128,227,36,140,46,181,196,202,66,33,230,188,90,134,210,155,200,201,175,215,45,178,26,251,139,17,132,184,175,121,68,77,232,61,57,120,236,173,39,80,13,222,245,255,207,92,246,127,137,96,79,0,246,191,65,176,11,150,240,43,50,125,182,129,55,208,240,113,221,219,159,164,142,29,167,55,143,127,153,181,164,149,117,169,72,200,5,23,11,179,63,33,158,30,45,7,36,219,139,65,248,188,182,88,174,80,100,213,76,127,86,143,142,149,185,220,60,172,108,131,190,55,131,11,135,30,21,95,232,189,240,100,83,201,136,26,6,254,72,196,29,188,163,59,140,79,72,164,79,126,177,11,206,238,246,112,9,235,26,166,30,96,160,236,120,120,74,86,30,196,160,226,152,16,185,76,30,140,50,104,30,21,123,182,213,171,96,185,156,146,113,77,0,93,34,234,188,255,30,118,9,153,200,245,126,228,186,232,14,133,211,221,78,152,66,64,113,21,42,27,73,1,248,224,117,239,71,160,37,132,92,214,23,158,7,76,27,75,234,40,18,99,121,136,87,255,223,87,255,27,174,138,169,58,228,159,38,176,26,99,48,118,149,50,227,0,59,181,112,223,59,157,129,54,16,236,246,168,194,141,42,75,99,55,51,229,193,10,59,226,62,199,82,48,43,134,133,199,137,102,38,163,218,188,158,4,184,196,35,68,115,103,27,217,87,36,81,166,7,72,60,83,159,240,162,29,49,161,85,164,146,38,144,38,169,149,43,100,176,7,29,250,51,66,193,38,9,9,38,173,223,8,114,135,172,198,198,130,177,109,213,116,204,19,223,181,237,208,123,41,234,39,139,190,250,97,93,245,163,184,52,220,107,192,41,87,85,106,209,8,119,38,21,163,198,40,18,152,196,27,60,46,95,211,84,145,167,81,205,184,216,177,232,60,145,230,239,234,201,239,229,24,84,68,184,233,218,188,119,247,102,182,2,49,245,94,35,50,159,3,226,72,121,117,236,1,226,228,133,215,32,23,230,38,207,213,140,65,161,129,8,159,29,30,241,232,177,249,114,245,203,251,155,201,207,159,63,223,76,39,151,215,255,117,113,172,8,222,95,190,253,114,243,254,203,111,191,76,79,43,137,79,246,123,54,213,252,124,137,6,157,103,62,133,63,223,125,189,186,121,159,238,252,225,243,63,47,191,167,78,245,190,128,169,194,196,141,61,184,25,155,154,98,235,192,149,48,195,255,107,215,59,250,44,89,200,126,232,118,22,253,132,215,24,85,207,178,114,102,162,128,178,52,146,64,163,60,0,195,61,86,102,108,107,117,232,114,118,129,159,244,216,14,71,225,209,124,140,237,233,58,147,114,64,1,228,247,211,146,3,68,56,36,110,59,126,45,130,194,148,208,237,101,46,75,20,6,145,60,171,92,60,111,105,118,145,174,88,192,60,59,80,58,226,177,195,136,148,81,17,205,244,94,97,105,130,162,196,55,112,95,5,187,166,19,1,92,212,50,224,48,184,27,89,134,77,9,207,130,248,105,63,42,180,222,254,110,135,59,245,93,64,131,152,46,89,171,113,9,74,138,142,208,161,59,40,37,243,242,5,209,84,212,213,200,23,58,200,77,73,12,38,183,123,185,3,253,247,114,200,101,213,61,56,195,134,58,150,114,111,107,121,61,16,66,140,8,139,86,132,240,78,92,195,174,140,34,62,124,255,242,60,179,90,23,46,16,195,228,5,79,218,131,253,2,7,7,210,3,237,57,53,55,123,104,86,69,9,56,154,17,76,93,59,132,183,11,60,253,52,138,149,208,206,158,173,34,146,158,181,3,120,183,130,176,152,238,136,34,55,124,171,132,178,143,20,69,42,99,0,211,80,148,49,182,196,219,56,204,56,224,30,126,228,5,207,156,22,73,95,224,49,246,72,237,122,96,206,78,33,79,65,37,36,189,144,239,118,255,171,168,76,31,32,59,44,8,82,187,135,45,18,0,252,139,134,53,122,83,72,52,224,74,66,163,240,73,173,10,55,213,190,251,200,218,121,11,76,121,35,135,145,62,110,165,154,12,151,239,190,202,14,90,235,233,174,168,33,155,165,145,165,84,33,84,97,35,237,18,75,20,102,45,119,177,16,12,198,155,53,245,113,213,199,21,8,244,56,227,203,188,219,97,27,250,105,249,143,179,9,126,43,107,194,180,8,28,223,234,27,213,247,189,32,171,143,40,236,43,122,104,2,8,34,127,134,249,56,243,101,22,8,232,58,34,70,70,9,70,212,55,246,129,153,92,214,43,250,243,44,251,109,106,132,37,211,195,150,34,59,84,120,105,98,156,151,145,67,228,137,155,6,18,196,108,185,201,132,45,234,183,86,71,232,74,121,251,173,16,150,208,11,29,80,162,116,214,162,15,203,219,136,190,53,237,138,0,216,41,113,246,91,119,253,211,70,217,49,212,78,101,68,146,135,69,253,163,171,52,34,114,146,146,65,1,121,3,149,81,41,244,181,67,160,133,247,122,237,8,196,196,214,3,215,155,216,114,92,87,247,227,61,2,202,76,53,157,2,122,219,210,214,115,87,220,135,123,183,189,97,120,3,114,146,206,73,156,106,183,22,63,152,5,126,71,131,226,160,66,84,197,255,123,87,227,16,224,250,138,61,80,47,108,103,11,170,15,216,80,59,30,38,84,246,239,84,72,141,203,18,106,100,207,198,2,75,153,12,13,105,33,16,102,14,244,13,163,99,105,22,130,40,223,36,151,132,21,91,19,114,188,228,85,142,190,158,4,165,134,159,187,147,6,3,124,139,39,14,158,91,248,148,169,240,204,56,217,203,84,158,130,47,17,19,205,253,189,41,170,13,176,86,76,119,220,211,138,34,225,151,149,157,234,151,127,34,189,39,96,31,129,187,95,205,199,140,71,87,223,83,181,158,92,217,51,188,53,123,136,34,161,153,108,218,24,30,196,237,238,175,191,86,236,219,11,79,137,18,235,136,101,170,40,118,238,249,78,165,90,158,163,30,158,60,153,81,103,48,63,87,195,142,160,139,147,135,208,227,148,185,68,140,160,228,209,146,51,213,94,98,86,220,56,37,199,55,22,225,237,162,26,23,50,153,173,98,12,222,160,6,32,133,213,51,76,161,238,129,146,89,213,131,103,58,215,112,19,22,246,41,104,142,7,172,87,250,128,35,170,149,182,176,219,49,204,169,181,99,231,172,135,124,84,73,24,119,188,98,110,94,189,135,109,55,68,67,129,234,147,90,79,160,224,77,73,105,189,218,167,62,82,218,5,186,193,228,246,199,154,45,71,211,201,245,123,184,84,248,94,60,192,228,74,48,164,217,172,13,247,10,94,34,55,206,139,101,184,127,131,24,136,142,50,17,220,247,229,179,81,57,251,89,184,66,114,148,206,58,65,177,7,158,182,186,44,152,117,188,135,191,141,179,245,132,166,34,135,66,21,191,239,155,63,29,10,222,1,209,147,178,84,233,247,2,130,244,233,185,207,144,31,82,132,162,34,230,131,226,246,225,137,237,100,149,23,120,160,138,207,70,213,69,123,248,143,187,213,208,108,77,19,177,133,120,114,195,220,120,108,160,5,104,155,230,30,77,73,182,129,230,83,99,1,126,169,219,135,174,218,46,145,42,248,96,135,156,135,195,221,247,109,99,250,5,91,245,107,213,53,190,83,252,235,137,143,124,65,106,89,239,142,191,206,102,155,54,157,34,170,186,142,240,62,236,147,23,81,25,136,49,100,72,242,141,68,103,22,112,202,79,185,89,14,121,157,188,130,122,91,180,67,89,183,154,205,94,157,235,246,60,55,104,200,116,55,0,150,184,159,120,198,113,85,109,9,149,244,138,20,49,33,202,194,122,55,139,191,67,2,52,119,245,214,115,124,244,43,137,179,109,133,54,71,6,14,145,136,121,77,181,146,237,0,246,111,74,204,168,242,139,209,254,165,78,162,116,244,61,200,11,49,91,180,63,204,102,135,81,203,237,137,87,197,219,205,219,69,3,253,55,142,55,174,214,219,174,253,70,100,129,189,95,163,248,173,106,86,7,33,10,52,216,86,109,66,48,225,128,92,132,82,250,116,226,170,159,55,30,52,122,0,208,207,43,59,139,39,159,212,188,141,186,83,234,116,41,180,141,186,72,77,105,28,133,73,248,188,249,0,236,84,217,18,36,193,148,247,170,122,234,79,60,175,29,46,46,95,228,11,144,173,234,169,191,199,87,253,10,255,236,193,27,96,214,13,79,254,31,118,201,8,168,178,138,20,166,75,152,250,178,243,135,123,22,46,124,153,35,79,21,88,58,150,101,47,163,106,9,12,19,70,93,158,128,144,23,5,98,10,180,201,151,188,222,0,164,197,89,143,214,147,135,86,237,211,84,43,194,45,0,85,177,79,54,111,41,188,190,176,228,223,220,180,217,23,55,104,188,216,115,193,81,90,224,163,57,83,130,41,86,97,230,204,123,36,36,43,122,183,84,176,233,54,222,200,65,227,78,76,168,217,230,245,94,173,214,209,129,247,218,173,171,105,25,105,118,30,76,115,187,28,194,138,136,129,81,222,185,114,43,94,95,18,146,100,235,181,113,254,11,203,24,205,64,37,144,253,21,10,84,44,104,99,41,221,155,121,149,19,54,172,140,175,34,52,77,234,0,150,28,182,91,69,89,115,10,19,212,29,201,54,21,172,163,237,88,24,54,175,192,222,213,169,34,170,10,133,191,211,92,143,129,48,250,30,210,113,248,170,222,160,74,252,55,229,201,187,53,217,151,242,138,89,159,233,36,180,249,40,59,152,3,8,129,235,129,145,233,135,34,250,50,113,89,180,106,9,41,192,58,91,65,156,162,139,74,77,34,84,160,213,58,241,21,36,2,13,189,22,187,55,87,140,69,176,49,145,231,233,115,43,162,90,250,78,230,252,164,53,19,248,188,200,97,134,135,50,106,192,87,154,174,236,72,149,83,126,222,39,169,61,10,148,88,151,206,189,230,242,100,47,92,145,252,244,246,147,189,28,197,123,193,68,0,110,247,102,148,73,82,63,91,234,161,84,117,192,107,61,138,216,29,203,46,87,211,1,221,169,117,60,10,199,168,89,57,187,69,106,29,223,31,84,147,136,29,162,159,134,160,101,181,31,167,46,30,118,140,183,202,68,139,119,19,62,181,69,142,197,31,32,117,115,163,27,134,24,8,252,195,76,48,226,204,200,69,48,37,207,91,171,43,81,96,2,4,78,206,42,146,186,42,35,206,136,187,123,157,37,199,197,17,3,33,238,242,24,121,122,212,75,80,153,77,91,20,143,195,0,40,195,35,232,94,222,222,224,49,208,124,87,77,54,32,155,121,154,212,102,10,182,245,217,56,221,81,169,146,203,140,234,125,134,169,84,131,231,31,36,247,50,244,50,170,50,46,108,240,107,133,156,76,213,219,212,98,81,255,201,86,63,66,110,240,106,88,229,200,163,43,11,116,118,158,222,25,164,12,58,103,56,181,219,26,21,220,18,50,80,64,93,108,197,11,148,249,33,14,134,105,252,37,129,194,210,72,97,216,143,83,98,185,78,233,149,45,213,49,37,100,56,65,1,0,191,213,53,232,100,178,252,214,118,125,157,211,81,69,90,56,213,247,25,77,152,0,221,202,151,222,68,54,159,224,212,117,209,166,157,80,230,252,136,199,121,87,192,116,172,170,46,90,61,144,230,190,171,162,24,65,124,219,105,237,80,247,225,193,16,119,212,162,212,69,180,130,119,165,52,137,124,34,58,112,152,51,169,122,247,227,241,132,136,241,84,97,71,50,136,193,134,201,149,188,14,32,237,107,41,104,123,52,246,198,70,175,64,40,22,104,86,230,138,213,84,157,98,242,190,174,162,206,186,241,18,199,188,234,61,252,96,14,26,219,125,7,148,109,179,66,51,89,209,129,157,51,218,23,101,131,46,118,168,222,76,242,13,216,211,193,108,168,115,237,172,8,60,140,30,174,232,11,31,50,174,129,188,26,243,213,174,103,243,152,34,62,40,95,108,23,210,23,15,173,18,218,252,142,151,116,236,58,232,210,199,175,33,250,38,105,147,205,142,209,46,52,121,229,56,29,166,210,234,220,107,141,215,39,169,70,10,52,23,205,195,67,206,19,226,85,163,97,236,201,142,35,220,182,109,197,200,137,217,228,220,72,211,46,30,212,104,98,154,165,119,39,199,251,19,188,136,224,75,8,243,135,160,2,253,143,239,75,248,23,181,149,26,73,92,89,9,250,35,128,91,72,241,42,25,57,47,237,198,22,63,33,227,145,225,61,208,160,13,52,126,210,156,41,184,149,89,132,89,96,75,158,204,170,87,217,14,149,144,11,242,147,217,71,42,227,105,137,225,8,29,195,106,141,253,82,166,36,21,133,182,59,47,134,58,204,140,181,37,244,134,238,182,219,22,174,151,201,149,108,172,41,215,167,141,0,2,230,45,49,197,137,55,100,199,38,148,229,213,135,15,170,50,49,25,227,177,229,180,40,61,151,1,220,56,85,163,244,141,18,54,23,71,213,128,156,44,37,252,69,192,31,30,189,130,51,161,88,251,10,30,143,3,79,247,185,23,49,173,17,236,154,186,139,198,132,33,170,189,155,146,196,166,170,175,167,48,193,196,42,184,1,198,225,93,117,59,210,88,45,77,73,180,219,118,168,236,151,169,199,202,1,97,25,85,163,122,18,213,87,97,59,139,7,59,33,87,142,5,160,35,232,157,171,58,103,84,22,82,78,196,147,195,189,139,83,30,120,78,90,235,102,80,223,4,243,39,116,164,199,168,152,2,16,163,2,172,154,15,152,165,178,143,155,123,121,57,218,39,147,191,131,130,126,114,134,93,5,4,120,48,40,166,10,70,10,60,205,220,219,149,185,200,169,51,96,4,211,90,86,221,90,7,155,34,76,199,166,205,73,168,31,80,83,157,124,84,88,176,104,19,22,210,227,187,189,23,104,189,126,0,121,120,227,174,227,1,241,218,83,179,94,103,249,209,43,248,133,97,33,92,87,102,243,132,234,131,111,127,17,63,9,251,192,197,243,243,230,59,245,131,36,32,49,54,209,181,27,65,23,147,253,186,219,37,244,70,146,22,98,172,88,41,220,132,70,190,235,104,126,108,149,64,168,176,153,252,210,85,235,53,50,63,183,111,117,203,217,140,208,75,255,59,30,197,247,113,54,75,63,253,172,191,156,121,58,153,175,91,240,220,224,62,66,189,161,189,234,191,119,77,223,12,205,55,54,171,120,87,192,186,160,230,130,239,190,121,204,21,41,210,72,101,47,24,161,99,130,0,82,97,57,50,36,132,244,87,175,255,162,243,216,211,54,68,250,160,220,177,8,155,113,40,174,128,225,89,76,96,71,88,28,23,224,179,152,252,108,86,1,61,203,18,11,177,53,208,111,192,163,125,5,209,12,155,142,237,161,126,106,237,181,234,174,237,32,88,223,177,135,39,121,79,35,34,14,34,117,216,181,176,47,56,67,64,247,35,73,154,35,150,100,199,27,210,45,0,60,181,196,183,181,153,206,165,108,250,129,37,185,110,163,34,145,136,42,40,206,187,73,205,234,58,28,197,97,168,217,146,28,253,160,244,121,165,139,204,231,168,101,161,21,154,251,75,43,188,157,161,183,230,162,220,85,162,14,171,240,65,87,108,89,78,4,111,168,175,15,44,106,141,182,213,118,60,50,187,121,253,228,216,6,152,225,10,231,208,65,10,91,83,202,128,186,141,48,33,201,241,86,155,254,216,199,65,167,179,238,191,85,219,93,99,58,241,60,1,206,123,89,167,17,66,132,61,12,106,76,167,166,67,151,123,24,137,219,79,109,241,211,244,32,67,44,130,23,89,224,236,35,5,129,142,59,219,46,214,117,152,217,186,72,170,242,247,207,191,229,11,69,235,4,115,102,160,180,41,72,133,166,9,182,128,96,121,4,30,213,189,218,68,208,184,65,246,244,86,232,51,32,34,44,10,64,102,207,83,12,23,81,153,24,38,201,218,71,151,154,137,211,158,181,215,14,207,163,182,246,31,144,42,77,244,22,231,104,82,33,140,91,32,236,161,29,61,185,46,68,211,129,0,86,113,13,2,196,38,37,155,17,176,99,165,107,21,32,30,236,93,188,145,40,210,57,44,102,22,152,55,70,133,201,140,174,170,191,80,131,60,178,191,209,65,132,207,65,29,108,81,104,114,100,12,154,55,208,196,178,15,185,174,129,70,23,67,34,68,122,91,61,245,17,135,47,227,135,104,2,48,21,198,164,227,232,13,54,202,77,222,251,11,48,47,132,170,52,63,76,38,143,244,81,207,222,2,233,45,252,52,201,34,232,110,54,184,122,27,146,61,121,94,176,21,22,5,203,100,116,164,37,89,19,221,39,160,38,171,72,73,180,223,210,17,91,6,95,66,180,213,20,238,132,247,241,161,231,4,105,86,10,101,237,37,76,88,203,17,105,218,158,37,164,218,55,218,196,192,81,202,38,141,23,89,78,189,219,226,212,137,32,222,8,154,197,236,77,193,101,229,222,125,141,101,150,234,99,58,21,15,243,182,87,237,64,88,24,62,81,155,96,248,253,238,238,143,122,14,172,202,231,29,246,106,221,0,84,88,193,139,238,39,239,223,222,92,190,163,96,218,73,216,152,98,216,79,85,241,252,182,91,61,144,246,9,135,158,236,45,60,223,42,59,192,217,243,50,155,234,70,200,160,159,103,207,152,159,77,47,88,186,194,135,213,100,30,11,70,223,82,58,254,176,236,9,42,232,71,249,146,29,145,10,38,59,250,11,129,199,48,169,52,171,139,246,161,135,26,200,234,53,18,221,226,211,40,168,89,162,176,88,87,15,117,199,52,7,16,67,157,154,33,74,201,77,193,247,131,234,195,16,60,134,38,185,5,35,72,212,66,35,156,189,124,241,54,129,84,169,150,103,102,101,109,79,106,193,143,114,107,136,91,101,19,107,222,146,198,105,190,235,176,55,119,29,157,54,209,230,188,101,111,54,50,126,247,53,121,33,189,58,186,244,246,99,128,74,232,92,173,61,94,114,98,36,209,20,120,249,192,131,7,100,255,55,155,16,249,19,5,176,217,236,10,177,43,182,47,213,57,169,100,100,148,214,58,184,77,116,205,247,242,167,238,205,35,244,119,83,43,174,199,165,44,103,244,114,1,122,230,95,239,119,171,169,254,45,110,86,180,61,110,22,112,168,182,72,48,245,182,124,239,211,183,72,64,215,103,166,164,74,221,133,185,52,53,62,253,34,223,176,23,178,245,176,251,80,189,79,149,98,119,67,199,132,114,28,98,150,224,36,184,108,21,246,146,85,82,20,217,255,132,15,201,198,60,158,111,149,221,157,226,34,170,238,190,244,78,71,43,235,8,222,139,245,90,238,199,40,250,225,55,33,132,99,64,236,188,98,14,31,234,18,90,59,49,101,222,186,56,171,152,254,206,185,174,144,82,24,37,130,158,78,40,36,26,28,16,203,218,225,72,76,94,209,117,216,18,136,24,96,205,53,150,225,107,96,35,116,75,197,116,98,220,203,124,30,2,220,80,103,154,149,177,21,39,219,100,234,130,17,152,4,178,198,222,176,140,139,222,86,118,38,190,19,119,174,204,252,52,179,221,210,127,244,30,138,112,70,3,126,81,40,194,64,96,160,252,185,235,189,22,233,41,134,101,98,52,96,80,170,66,157,131,144,16,16,39,95,17,31,129,102,6,8,169,112,103,159,150,123,239,175,68,80,63,184,163,129,223,96,249,66,117,59,82,7,169,128,148,176,196,254,71,250,143,91,204,188,170,227,77,245,242,115,19,74,54,50,165,158,228,187,38,232,38,229,99,245,57,116,44,243,75,108,13,26,50,123,136,137,248,59,34,238,136,230,121,215,2,170,86,77,62,180,94,145,52,183,245,178,66,73,60,28,71,117,250,170,33,55,119,112,64,1,131,178,242,34,144,34,171,0,166,84,251,162,96,72,70,85,51,181,195,94,30,69,32,202,185,214,23,255,17,200,249,25,148,243,219,201,79,213,110,190,235,103,95,32,44,122,41,144,207,77,110,170,76,214,125,147,64,188,222,92,239,41,140,25,226,34,34,52,249,136,106,254,237,123,8,75,29,152,126,228,90,65,226,150,151,156,59,176,232,170,135,7,124,234,190,166,117,118,136,82,108,69,102,138,51,111,2,62,30,164,143,77,53,164,161,9,208,108,82,163,139,174,17,225,235,19,86,158,5,95,87,9,187,141,29,87,112,238,86,163,246,127,15,25,18,6,132,246,14,174,17,57,248,2,116,13,249,94,4,230,79,114,176,87,51,54,148,203,166,223,173,148,5,75,132,129,81,24,247,170,222,168,255,49,65,248,193,41,85,112,45,227,70,169,65,113,148,240,14,222,50,250,12,13,107,13,88,24,161,60,166,69,233,26,79,4,189,191,241,44,157,135,106,72,81,2,176,195,77,155,230,78,178,208,143,10,200,186,135,29,145,231,233,100,124,224,41,133,23,132,150,79,228,35,93,243,216,251,62,6,189,203,83,225,63,147,158,139,41,4,100,192,157,238,131,77,208,132,141,192,137,99,6,226,142,29,253,231,78,167,67,15,209,61,130,212,152,7,0,226,83,34,173,192,183,130,248,198,219,197,69,145,88,130,167,120,246,182,109,4,226,102,56,239,163,138,78,245,3,85,72,86,146,140,98,68,11,148,224,175,202,189,153,182,11,220,86,188,241,216,29,28,3,221,189,62,200,188,209,206,158,180,3,105,37,201,67,98,107,220,150,176,117,243,246,186,17,152,84,221,247,130,134,58,43,118,98,172,36,177,219,213,249,135,15,176,160,204,116,9,23,74,241,83,111,149,167,36,246,242,27,18,64,85,24,221,0,203,1,93,248,242,69,199,196,98,218,80,89,147,166,228,21,74,138,39,65,253,144,140,192,194,70,43,207,61,123,196,157,52,34,218,79,5,255,219,57,11,175,182,45,179,202,161,195,144,219,36,169,12,7,48,78,81,106,48,137,244,198,91,153,189,40,48,68,148,192,108,195,134,172,29,118,108,77,50,201,107,119,27,110,39,65,167,128,25,190,129,183,153,241,39,192,122,246,17,233,92,5,80,231,186,89,49,39,144,160,170,201,0,11,62,104,30,207,171,34,255,49,73,233,15,110,60,120,94,170,240,72,238,217,46,15,246,158,189,155,154,45,196,131,5,209,150,254,254,221,154,68,58,148,147,125,153,215,143,160,130,60,23,118,223,5,53,94,20,15,132,118,33,145,149,157,75,193,161,231,232,194,111,93,232,118,40,184,186,166,65,179,9,159,177,71,128,124,185,120,106,188,185,243,99,219,205,43,65,127,208,139,184,162,91,249,177,238,230,77,197,111,125,130,199,183,91,155,87,92,9,31,195,61,248,237,97,89,110,129,159,125,145,43,88,132,153,105,217,110,79,69,127,227,173,155,194,77,123,18,92,54,74,121,200,99,152,63,94,203,207,127,231,28,115,204,7,190,41,115,20,87,135,79,17,105,146,124,251,200,114,121,190,99,122,120,123,4,41,230,64,79,182,93,59,175,25,37,190,250,159,45,207,52,106,100,74,250,47,155,245,15,82,89,4,103,93,15,205,3,245,15,101,160,26,204,166,15,205,220,244,232,124,121,103,91,173,22,182,159,176,213,221,221,14,171,233,252,102,240,119,209,28,11,67,84,108,192,207,116,231,190,90,32,248,166,120,33,248,24,23,163,79,92,221,48,209,23,167,164,171,183,43,248,222,30,220,210,228,105,141,179,41,75,241,128,210,247,175,154,225,21,202,219,155,156,29,114,184,219,193,175,133,63,151,214,153,6,70,83,36,54,41,19,130,39,149,227,135,71,197,125,157,57,46,122,122,43,8,195,131,51,234,183,221,218,83,111,37,234,18,56,0,114,102,235,157,139,21,196,205,66,60,142,35,74,177,104,201,128,100,122,70,34,178,132,217,93,237,83,142,230,229,139,219,87,179,153,247,129,22,59,224,224,26,74,250,229,2,161,246,91,123,134,149,103,73,214,40,55,185,90,208,214,35,108,161,40,240,81,225,78,146,35,90,31,57,231,52,142,197,110,78,106,49,185,22,212,11,235,118,65,148,180,3,82,241,213,102,211,183,82,73,158,68,48,193,91,219,162,155,72,8,6,229,122,238,229,139,240,96,109,177,24,211,57,77,232,155,115,69,62,27,251,229,142,109,100,62,145,32,249,17,140,112,76,41,129,126,37,233,90,236,42,113,188,94,87,62,76,203,173,235,85,181,153,155,199,185,79,137,185,156,118,86,75,142,232,41,247,206,215,13,228,126,146,35,135,38,161,236,90,158,75,248,199,19,188,239,154,204,145,93,211,251,131,50,62,97,155,23,146,213,235,246,91,157,128,13,92,124,6,126,139,63,76,142,55,217,183,183,128,176,94,52,108,68,93,180,219,240,219,96,200,95,190,128,220,217,130,217,65,68,224,188,48,83,48,155,197,211,93,179,116,227,170,184,212,51,114,213,149,82,85,22,50,85,74,112,16,212,107,192,38,5,132,223,45,43,1,112,50,9,10,19,130,251,73,20,170,107,6,63,113,21,139,206,27,91,102,143,243,236,225,24,250,5,94,56,223,217,62,24,244,255,88,16,239,121,53,169,88,48,49,13,190,238,31,68,255,30,72,26,5,18,114,164,135,198,57,87,170,221,2,100,6,169,180,165,58,211,104,84,64,175,170,247,104,95,168,25,115,60,206,120,221,142,203,83,34,242,161,207,158,109,170,59,196,22,247,65,8,18,235,88,21,33,68,103,33,68,206,176,241,33,174,199,191,125,51,166,75,17,212,46,117,15,208,56,170,73,210,129,182,153,73,146,15,76,112,81,69,231,78,190,111,83,114,98,219,117,174,63,127,188,252,241,243,187,223,205,152,70,83,14,45,141,76,173,211,68,147,46,216,29,186,102,131,200,194,113,76,5,209,124,94,202,163,101,67,53,112,89,244,247,217,55,235,63,73,18,225,209,171,136,165,26,38,27,191,123,235,142,106,38,225,141,140,21,48,172,4,30,113,109,83,183,144,79,199,0,35,86,135,42,142,200,240,155,50,150,94,186,136,114,77,98,28,128,221,207,57,191,73,202,162,198,113,246,171,147,220,100,130,229,159,201,46,68,206,95,244,186,147,121,211,205,65,69,241,221,45,195,181,250,79,53,138,85,219,140,21,22,213,173,248,143,8,29,255,62,199,249,145,30,98,12,8,102,180,142,156,25,243,17,147,95,220,120,60,202,225,128,18,117,114,251,153,18,56,60,181,16,192,46,248,133,42,65,54,18,59,167,170,67,221,78,109,17,209,79,162,42,234,194,195,19,50,16,160,25,237,240,215,72,132,13,185,152,45,158,190,170,223,7,182,27,54,201,147,48,93,228,79,72,78,91,212,230,243,53,19,15,104,60,13,84,5,185,179,151,100,86,234,216,242,162,244,80,23,141,189,41,162,156,22,58,50,40,59,21,57,64,128,7,166,69,245,20,141,30,194,81,77,67,68,1,158,213,240,148,16,28,245,109,5,179,240,224,171,32,94,238,169,200,31,224,129,154,79,133,44,85,54,173,133,5,205,15,147,121,82,156,11,57,226,177,81,131,172,106,200,60,104,69,222,72,13,205,30,91,50,65,147,170,159,206,226,181,85,247,20,185,50,57,40,9,223,168,169,251,190,147,91,141,80,78,73,59,149,249,32,244,65,239,133,98,205,245,18,148,8,91,160,20,166,137,229,50,79,206,130,89,93,115,106,21,48,133,220,73,29,86,18,19,1,116,164,152,0,49,16,50,112,17,239,105,35,212,25,129,97,15,191,67,149,196,146,229,92,67,66,169,155,107,219,53,127,213,217,155,138,85,150,18,136,214,219,137,62,101,186,47,229,37,45,100,220,241,65,153,79,67,216,213,63,102,98,22,78,192,184,126,127,57,205,89,137,99,37,196,25,35,35,171,175,212,64,94,232,215,39,243,72,209,211,57,22,29,36,38,145,120,214,44,28,175,87,49,199,161,88,90,12,220,191,242,69,206,38,254,223,128,137,157,30,106,64,53,152,160,97,232,23,67,147,9,52,253,118,151,81,165,220,62,22,182,124,2,19,62,191,221,69,244,76,46,182,63,181,14,235,251,6,157,40,223,173,204,223,68,93,77,184,38,84,140,88,169,77,28,171,40,137,122,234,238,251,136,177,100,224,144,27,241,236,105,239,187,114,193,138,133,171,32,170,190,21,123,213,38,213,108,219,212,101,220,120,81,108,50,59,53,83,179,66,165,107,229,182,157,67,250,169,28,161,248,53,62,23,251,154,36,47,60,122,1,32,49,43,101,69,62,66,90,82,26,45,9,157,176,99,220,33,5,99,92,57,19,175,101,81,153,60,244,9,211,157,133,149,49,163,131,36,221,216,13,36,1,113,124,240,189,159,104,86,185,9,254,56,16,193,156,75,219,60,167,144,150,62,97,202,189,163,124,30,241,125,178,12,211,47,140,6,111,79,129,198,179,5,14,28,197,186,20,121,90,92,92,111,217,236,153,49,44,245,10,6,97,136,47,158,191,14,207,172,222,196,208,190,196,104,225,40,103,18,225,1,11,58,95,78,139,167,71,195,66,58,135,135,248,150,56,71,50,216,220,165,234,206,2,243,69,65,28,93,121,195,57,52,120,223,106,23,179,139,19,241,11,176,25,4,219,131,68,241,117,234,4,28,241,123,5,62,72,216,164,228,128,49,215,166,202,241,26,52,136,119,160,63,10,114,95,54,69,231,5,20,163,46,61,233,222,157,240,209,109,138,108,168,186,6,120,19,159,245,85,187,255,231,231,46,56,70,231,114,191,232,164,108,218,166,175,101,104,164,40,24,134,121,86,78,125,174,114,84,237,26,116,144,70,51,160,202,55,37,159,33,211,189,5,55,188,192,96,45,128,142,166,48,137,191,241,124,137,210,112,236,7,70,134,74,97,40,234,31,165,145,14,112,24,225,26,202,234,77,179,245,204,249,51,24,98,106,161,106,210,37,172,244,157,115,99,167,208,51,146,137,212,33,25,101,183,142,60,188,247,130,111,187,118,221,148,201,199,117,45,185,77,197,143,147,212,116,112,187,199,37,16,250,121,166,214,102,179,159,248,64,239,28,179,90,45,22,181,87,102,192,222,190,197,155,186,207,81,128,73,198,164,192,238,223,143,26,215,63,162,151,175,233,83,18,152,177,125,79,98,207,85,125,34,177,147,245,137,179,169,122,125,195,92,218,194,93,190,114,151,95,198,31,189,70,209,223,181,218,143,95,120,18,162,169,9,117,52,93,222,86,90,21,217,215,115,213,216,95,79,110,53,141,112,31,136,182,57,187,247,224,112,44,156,120,79,216,7,166,51,193,88,17,141,126,1,38,41,180,79,81,99,116,88,218,148,216,11,213,127,80,245,131,17,75,60,109,171,32,112,137,77,247,146,93,211,159,104,209,74,13,80,63,239,144,236,116,132,113,117,242,67,14,198,186,209,109,79,124,100,93,244,184,31,252,74,109,63,227,31,191,82,85,238,240,179,119,104,24,35,216,248,248,22,171,234,233,135,137,7,24,167,158,209,228,185,175,231,187,225,212,211,217,159,223,63,255,102,71,206,100,84,253,126,167,62,50,137,150,61,36,180,55,39,30,33,254,152,251,219,84,182,211,95,159,185,87,105,112,79,124,98,232,236,219,63,176,146,124,248,91,71,143,8,183,89,94,80,141,198,44,75,151,191,112,16,94,241,35,250,50,23,175,70,223,190,246,19,114,112,183,117,82,23,39,118,109,190,179,227,250,234,154,33,238,209,27,84,122,135,211,235,72,44,210,117,211,253,13,191,8,187,221,158,249,181,121,102,127,236,144,140,61,254,149,121,235,127,236,48,87,235,248,151,161,67,14,127,243,132,204,236,104,129,120,161,221,209,202,223,33,90,88,30,44,28,254,188,186,82,91,216,137,7,210,195,80,104,78,190,140,169,52,188,202,244,248,162,249,207,53,147,147,167,126,51,87,156,246,220,119,81,189,192,201,253,225,153,15,188,122,246,177,38,147,136,232,255,230,185,232,64,252,93,193,150,230,245,239,246,24,127,232,54,63,123,5,40,209,245,81,39,100,250,195,204,226,233,95,157,82,16,254,103,161,125,60,79,236,87,48,118,209,45,9,59,76,166,158,227,90,78,10,78,130,117,145,140,121,172,19,123,53,39,119,204,223,191,57,127,174,210,48,246,83,233,122,33,85,175,124,183,76,165,200,215,2,140,128,129,9,75,100,215,22,105,210,93,113,117,124,250,211,231,155,83,216,47,167,178,204,132,104,128,36,22,85,136,183,48,222,195,97,127,129,176,92,137,251,130,197,187,40,226,6,234,166,138,17,7,180,74,169,204,150,144,107,1,31,93,180,25,229,181,98,191,140,185,210,8,102,10,128,151,154,19,22,237,104,240,34,65,242,221,112,20,116,76,139,137,203,209,118,182,74,141,93,23,190,153,13,171,217,184,45,42,87,254,1,34,163,130,145,168,184,127,140,65,170,81,166,195,106,108,89,211,42,59,100,131,114,210,231,146,129,144,176,234,137,124,11,135,36,251,66,103,71,153,126,214,149,209,197,167,33,19,140,141,210,30,104,178,90,134,225,168,55,143,30,190,132,134,174,214,89,160,53,189,22,203,146,60,242,13,57,46,102,50,85,0,167,63,218,198,91,55,20,156,91,180,251,59,192,217,42,18,218,82,159,49,1,37,233,42,158,209,66,9,243,186,83,242,214,156,242,106,104,156,112,36,150,186,206,36,54,172,189,91,184,214,141,114,181,22,64,162,130,28,94,27,187,243,135,10,111,0,255,170,46,43,115,116,68,218,77,164,248,51,186,167,164,93,123,29,80,20,168,179,159,186,234,46,199,6,229,152,69,78,122,25,13,141,90,144,213,221,254,114,251,118,57,45,198,146,125,168,29,224,207,116,175,240,212,248,14,149,201,38,70,209,16,154,97,46,193,23,115,125,215,91,229,187,111,223,227,25,184,43,131,57,133,59,14,196,43,244,4,195,89,123,0,60,229,52,115,253,244,155,106,187,181,253,92,133,124,66,134,156,98,52,231,78,65,188,131,213,158,123,11,199,164,221,131,196,164,68,66,166,30,33,130,7,53,110,77,173,12,94,250,186,210,222,22,234,133,51,57,145,64,91,144,231,7,203,179,105,217,208,107,210,129,36,74,51,223,89,116,131,7,187,94,214,231,11,111,208,36,56,176,17,27,113,122,2,54,171,43,35,228,147,183,136,19,85,38,216,57,221,131,45,103,40,170,99,80,86,163,106,232,40,38,141,76,129,3,40,115,121,94,19,18,198,202,40,195,209,4,138,223,214,195,15,105,4,94,31,8,234,139,68,101,114,4,9,158,56,34,24,249,161,2,18,28,196,118,231,78,207,226,80,73,225,132,211,20,187,76,168,204,150,137,204,114,205,200,48,198,189,246,154,41,200,161,99,153,98,84,40,191,16,119,117,122,51,184,57,43,211,151,138,226,35,48,173,202,225,238,80,91,94,53,95,231,153,50,221,128,213,188,46,138,42,138,82,75,10,51,207,146,217,66,113,184,40,14,142,189,198,199,234,97,219,36,174,151,167,174,18,230,72,179,222,129,246,84,223,67,5,4,202,138,245,46,62,139,82,176,87,225,135,38,254,191,80,203,24,124,203,49,75,34,205,153,33,79,150,88,58,118,72,228,67,218,187,150,84,204,138,212,126,170,54,21,220,185,140,51,81,76,120,128,212,139,74,91,244,5,78,197,250,172,140,58,249,207,23,222,161,118,133,34,86,6,213,37,108,63,195,172,13,166,225,224,52,127,222,76,190,85,34,192,39,63,240,159,131,134,67,40,241,129,42,222,34,183,147,229,161,27,220,66,102,228,217,130,254,92,11,31,80,72,182,89,118,13,10,231,217,201,46,205,152,241,54,174,86,106,110,7,15,105,226,153,136,174,175,105,217,131,85,141,248,105,36,238,169,156,131,78,130,114,246,249,153,230,228,184,30,244,167,154,76,242,196,223,98,112,170,24,21,106,135,168,96,8,112,219,37,134,32,102,24,179,109,76,115,41,219,201,60,215,2,70,24,27,181,133,217,155,185,47,178,106,159,102,253,182,233,144,194,6,95,89,65,145,236,148,238,35,18,126,177,79,252,13,129,26,64,250,237,96,218,114,155,218,50,143,89,212,210,236,188,172,105,138,1,55,30,48,103,131,200,62,88,167,108,113,182,239,98,98,157,79,25,119,152,42,137,121,177,251,60,194,67,104,184,127,23,206,248,207,83,31,132,251,224,244,95,215,28,84,194,35,241,65,47,255,35,35,220,17,134,20,79,94,178,189,77,51,245,90,137,169,205,24,223,231,253,183,140,41,158,230,210,36,39,40,131,190,42,165,14,94,103,82,26,237,13,123,28,50,155,91,168,18,22,126,18,93,219,164,252,23,249,34,67,34,209,13,66,33,197,79,128,147,84,18,73,83,253,206,72,120,16,212,207,107,150,246,24,203,123,182,17,7,0,168,166,186,235,200,224,132,233,177,250,59,213,50,68,54,19,47,152,166,200,244,105,235,131,241,159,60,232,36,62,136,220,84,76,54,204,133,182,188,118,81,205,15,66,52,105,229,211,4,122,73,22,125,176,21,200,4,102,196,77,18,228,161,99,180,220,169,18,18,244,131,157,63,227,104,156,31,250,210,52,78,123,72,243,7,103,179,162,203,182,104,221,67,142,33,4,217,236,255,220,141,23,16,233,227,62,158,120,124,111,168,208,164,194,64,221,141,90,254,55,14,150,25,77,147,130,128,124,171,60,51,205,36,105,61,212,201,207,253,103,226,99,30,178,96,199,0,185,113,103,51,211,254,163,101,240,2,96,97,31,220,197,83,209,95,141,86,142,208,167,9,254,104,246,196,116,213,198,105,72,223,126,185,84,165,97,145,6,100,96,241,222,76,38,95,118,27,90,172,201,136,111,146,46,56,93,160,53,11,34,65,51,91,176,235,177,17,203,68,235,191,224,1,179,209,54,212,99,105,41,98,14,79,80,69,20,252,130,157,208,10,169,132,149,244,150,19,190,66,210,88,22,227,54,78,163,106,89,246,122,71,165,158,8,15,232,187,199,58,78,42,122,139,83,241,195,169,251,124,188,49,94,148,9,183,117,37,216,217,9,179,228,59,97,207,136,16,151,131,232,18,73,138,78,225,157,211,221,49,60,37,11,149,151,11,129,156,61,19,64,232,234,156,13,247,28,44,203,135,3,224,8,183,31,179,7,2,78,141,147,213,187,63,137,174,225,251,104,210,71,57,242,144,216,229,120,68,33,200,150,210,236,41,133,137,46,105,144,77,162,17,115,143,101,21,99,240,238,58,200,244,150,56,197,36,232,236,65,186,253,122,49,249,242,246,199,31,175,110,206,1,198,97,229,67,53,222,60,15,151,98,218,108,74,120,239,252,49,229,220,221,255,2,155,143,109,12,75,1,246,89,29,173,123,104,187,85,237,13,231,222,251,67,144,150,202,187,230,165,38,1,14,206,174,64,45,231,158,78,111,30,242,73,175,1,156,14,86,151,164,145,66,106,147,52,36,254,68,135,112,247,169,19,240,64,10,212,41,14,2,154,150,6,114,93,115,128,97,239,53,241,142,103,88,156,211,98,15,152,164,73,212,84,73,226,59,134,99,186,41,190,140,226,204,17,215,160,186,26,157,68,41,97,57,188,78,196,238,120,101,239,212,94,11,143,255,213,71,12,187,14,250,93,250,129,212,135,58,63,17,176,194,86,48,118,80,27,31,35,55,4,177,103,175,72,200,36,82,9,104,120,162,218,167,234,39,76,210,155,198,221,99,157,10,7,65,89,209,196,29,168,161,140,23,175,224,81,154,26,15,216,20,227,136,81,151,37,234,217,4,220,120,213,232,124,193,228,136,226,56,115,27,182,161,4,180,179,178,187,90,159,182,211,212,212,52,135,94,230,161,24,107,162,237,253,81,153,225,130,118,54,201,68,144,66,248,148,203,161,89,164,209,138,93,219,174,189,108,81,185,142,15,207,209,206,97,116,96,73,39,125,231,186,129,237,189,173,217,208,239,165,11,101,62,158,204,23,162,201,194,248,48,232,77,181,131,97,166,234,161,53,140,153,159,199,172,162,120,138,176,161,178,61,217,122,166,113,193,9,12,166,169,44,60,57,246,26,170,148,38,50,51,205,224,24,15,140,245,49,101,210,196,118,251,133,250,241,6,247,17,237,178,51,28,26,211,13,135,144,30,78,2,44,22,248,185,145,128,83,204,4,180,237,97,50,193,126,79,86,102,188,44,250,55,52,118,99,112,108,0,61,10,183,102,171,102,235,29,209,194,238,0,0,118,243,254,234,211,47,19,2,168,106,230,169,213,16,43,203,239,83,21,78,234,112,130,223,108,41,232,202,95,49,26,69,239,86,76,166,146,7,7,19,197,228,53,151,52,177,9,171,184,224,235,4,57,39,81,42,48,107,160,221,87,75,32,211,130,163,233,31,133,235,255,242,133,135,135,232,151,83,74,231,128,194,43,168,17,32,25,229,140,159,16,228,43,33,105,49,79,204,27,62,212,125,1,118,21,205,162,99,95,70,72,162,198,81,212,139,31,130,140,40,253,102,209,237,54,143,222,219,188,140,205,31,207,106,114,246,241,173,39,72,188,17,206,113,52,243,154,76,123,25,223,14,117,96,82,179,85,1,91,163,126,56,67,82,109,125,124,61,118,93,62,214,27,55,21,65,224,140,237,78,35,145,211,147,28,206,141,119,62,170,243,72,134,41,83,4,44,56,151,255,202,105,255,181,242,17,156,205,102,111,123,85,91,201,231,162,84,70,26,167,60,36,91,136,203,4,11,91,138,85,181,70,62,112,4,221,36,100,157,137,36,13,216,163,138,169,78,52,151,67,34,114,171,134,179,194,30,98,178,86,49,204,196,206,81,57,218,36,15,229,240,133,124,220,96,30,74,208,162,83,5,172,196,92,133,50,118,12,25,149,118,158,12,197,81,244,113,180,84,92,209,160,125,48,193,74,46,106,125,127,239,29,192,5,5,123,38,85,95,221,97,13,139,237,150,47,235,174,176,211,89,91,52,177,102,55,237,8,11,2,153,193,254,146,199,171,127,102,1,212,68,95,169,13,199,228,203,12,208,220,165,79,196,114,53,47,94,88,245,177,198,173,21,218,134,130,156,155,7,181,137,185,97,135,78,219,237,39,102,0,225,62,49,153,46,160,138,96,233,62,85,141,163,95,128,244,46,40,124,230,158,59,202,196,7,31,28,147,116,159,9,34,11,111,127,93,61,52,243,80,162,130,41,61,241,191,4,191,237,16,152,106,209,243,126,152,219,243,36,253,137,33,65,80,252,34,63,27,242,220,167,81,103,219,184,39,234,196,112,219,132,246,92,86,129,61,119,66,232,40,15,8,115,232,107,74,49,113,237,100,223,246,124,71,74,79,236,54,88,153,125,81,247,127,10,34,255,152,57,170,74,62,34,133,130,160,100,52,101,42,230,233,48,141,141,67,229,169,203,96,239,243,225,209,92,146,152,122,36,215,142,33,9,236,123,189,136,212,230,221,94,89,73,124,64,126,150,84,176,51,72,143,79,239,3,164,200,213,10,92,37,125,129,179,169,213,97,189,175,135,226,47,236,108,136,70,11,245,112,22,64,14,71,33,197,2,163,233,238,204,149,127,57,53,16,177,52,35,203,52,229,88,109,95,47,95,124,85,131,69,52,173,145,253,244,222,140,57,230,113,174,96,197,175,232,236,53,1,159,225,220,144,112,246,34,255,158,231,246,9,234,252,36,231,142,93,121,163,206,47,124,211,94,255,204,13,117,1,149,190,75,19,136,159,58,64,203,163,173,113,93,103,60,56,24,171,241,121,207,246,202,115,184,146,98,221,109,157,26,19,95,135,15,91,251,200,19,179,104,15,108,169,183,51,233,208,151,17,148,229,176,107,28,172,126,224,58,112,96,102,16,31,81,38,73,32,203,155,37,69,254,242,197,251,203,47,151,35,20,166,125,107,115,130,198,73,169,186,171,201,39,192,59,169,235,201,155,157,155,22,205,14,128,255,170,125,122,35,210,46,247,204,217,74,142,163,54,165,254,49,41,157,205,82,217,3,191,87,169,229,169,93,87,27,243,132,102,65,114,101,50,36,145,142,172,194,9,166,85,81,198,40,164,9,10,151,151,47,64,150,156,170,8,248,136,8,23,90,146,196,201,135,247,85,36,66,55,143,153,11,206,204,185,90,48,49,116,208,238,147,110,44,180,37,226,120,70,253,177,186,62,196,45,25,135,223,63,255,22,130,100,167,131,186,64,132,217,193,53,94,112,234,100,32,232,102,225,3,178,11,28,162,58,242,213,18,67,130,39,246,54,4,120,60,85,225,60,106,59,106,224,207,20,20,34,79,42,120,40,53,219,163,232,180,53,43,236,173,182,229,244,8,37,194,77,142,53,61,132,218,100,240,84,86,235,29,152,9,21,229,49,164,109,75,250,107,81,78,77,140,56,63,71,166,99,189,119,87,219,149,128,210,33,222,169,185,81,192,253,55,3,44,162,69,90,241,110,238,201,4,69,124,147,147,148,158,251,241,12,234,224,243,79,156,188,221,189,6,25,113,111,189,78,6,86,229,201,20,32,77,11,226,32,47,62,68,118,69,181,196,76,87,90,241,240,144,55,80,204,228,40,193,200,103,45,31,42,59,121,148,20,59,178,170,12,226,80,8,144,198,109,139,1,48,2,122,58,120,55,94,75,89,137,224,87,41,220,137,152,162,138,225,86,160,28,102,136,144,16,134,228,228,140,121,127,155,167,42,122,114,180,136,231,189,187,42,28,174,40,200,57,58,121,186,69,114,94,152,241,101,253,117,64,193,114,0,218,233,91,173,68,85,179,218,117,185,73,54,146,181,172,151,30,228,105,157,233,224,161,45,136,25,52,107,47,156,72,249,39,73,63,113,228,56,11,44,8,122,143,148,148,204,56,165,58,38,209,199,118,98,136,143,236,64,22,240,98,33,25,145,228,73,128,225,22,81,14,188,189,0,160,87,218,151,160,203,89,86,145,163,39,183,94,133,202,43,11,153,58,155,38,150,238,144,59,118,149,85,43,205,238,46,144,169,153,162,237,160,228,0,94,169,58,200,18,64,171,16,141,9,147,121,87,245,28,23,41,183,63,38,170,50,32,200,148,144,98,208,92,132,229,139,84,50,223,212,103,184,166,4,94,201,218,128,65,205,115,18,103,206,76,10,97,192,216,138,225,105,248,52,186,30,54,219,69,243,19,16,176,58,175,145,30,229,113,23,115,65,16,24,207,102,183,191,194,125,231,255,120,146,156,92,170,182,159,111,114,123,215,38,233,157,49,197,157,86,39,113,191,94,139,121,156,38,244,124,29,148,217,239,156,187,147,170,22,195,183,225,108,224,203,173,69,53,185,184,125,234,99,99,202,159,66,52,2,197,194,220,102,7,167,67,117,64,58,230,171,45,83,78,114,254,44,122,190,134,254,250,238,154,132,48,209,96,55,218,166,232,52,162,251,236,48,215,41,214,36,181,195,105,183,202,132,72,130,223,224,165,157,131,6,43,221,173,199,111,103,119,126,143,150,9,252,115,51,87,220,127,91,117,221,110,125,113,254,125,170,170,251,247,136,132,111,153,127,226,4,15,21,225,170,39,175,218,66,179,53,127,37,99,135,243,123,79,74,155,12,230,214,195,157,29,62,28,67,248,242,193,196,12,92,62,182,22,158,144,224,170,36,150,90,5,195,206,3,59,85,237,107,22,33,107,198,148,42,144,153,214,209,46,234,252,238,158,136,182,195,129,129,78,25,14,147,167,46,161,126,221,71,47,187,87,209,155,82,225,149,140,102,226,135,114,128,176,107,117,151,204,215,158,71,232,167,241,182,145,125,99,102,12,58,113,143,98,135,94,123,234,118,63,254,75,72,199,59,224,21,138,9,83,83,175,244,67,5,71,133,58,250,106,168,124,142,85,78,81,84,115,197,227,129,107,82,63,138,69,165,127,110,74,46,177,32,98,185,249,250,121,172,101,98,74,9,61,194,62,73,239,72,112,51,226,38,211,234,142,53,133,239,19,34,122,150,233,207,14,20,244,69,48,108,37,199,158,121,73,135,99,33,83,75,226,100,102,116,208,199,18,9,221,227,112,245,74,123,149,217,221,127,2,187,251,89,49,176,48,77,102,141,33,127,228,156,119,23,78,110,88,139,78,159,114,76,107,49,126,157,32,253,148,117,211,242,87,157,202,151,251,140,95,119,62,87,110,151,59,44,221,206,81,4,140,103,52,102,162,234,6,243,246,235,85,137,208,23,41,249,61,60,120,210,124,115,154,128,20,31,79,134,195,200,194,99,243,252,101,193,226,234,121,192,31,136,10,148,43,154,92,66,115,55,22,168,48,206,102,60,189,41,120,27,98,104,243,157,210,1,230,22,160,184,235,39,46,125,125,54,195,79,207,50,48,71,199,207,46,122,54,155,189,231,223,145,79,56,175,215,194,197,57,194,105,222,118,27,124,25,3,16,134,166,230,239,227,249,229,198,210,34,236,253,208,104,106,175,16,248,132,79,56,72,137,113,163,79,225,10,233,40,186,234,95,167,70,225,2,81,132,200,65,15,166,39,23,177,70,216,90,62,93,103,254,142,173,71,19,148,92,45,179,131,21,22,233,99,179,137,98,217,10,58,113,210,175,216,63,128,224,129,250,200,221,71,31,22,240,158,51,23,64,35,134,50,220,119,208,48,59,78,8,55,179,252,189,153,185,79,164,72,51,157,186,240,166,2,187,133,135,249,120,186,8,74,247,216,157,246,92,13,111,173,70,17,148,121,23,251,214,39,245,176,42,5,119,70,30,73,225,25,103,179,27,239,84,198,90,104,164,244,230,76,251,22,87,228,227,206,70,203,194,80,22,29,35,157,136,202,28,97,8,76,129,127,190,124,128,34,136,58,3,211,87,41,42,78,229,117,248,149,41,123,254,150,209,173,236,13,15,69,222,72,208,175,125,49,4,21,191,132,52,21,245,100,102,208,249,196,8,144,19,176,239,142,133,2,127,10,246,201,122,113,40,241,228,71,171,13,200,31,245,1,164,150,69,178,95,178,69,43,254,185,130,197,254,244,15,207,98,61,54,0,44,196,132,164,66,45,44,144,79,74,196,237,36,51,233,142,94,124,212,29,228,113,133,235,147,20,81,28,56,120,34,108,210,236,194,121,188,35,161,0,42,231,147,254,27,153,17,185,110,223,79,122,147,48,71,145,49,20,179,127,186,174,25,241,100,198,19,145,239,137,211,86,149,54,22,9,211,230,68,14,24,206,184,200,96,40,159,138,142,73,241,170,217,145,0,246,114,125,162,42,162,247,42,39,2,22,5,51,170,242,35,186,40,71,10,164,101,144,109,118,206,139,162,173,211,249,12,49,81,75,202,137,86,100,52,247,206,118,63,20,165,233,112,59,112,63,233,180,55,238,215,220,57,194,113,9,170,221,248,186,59,0,5,203,90,216,205,212,128,149,187,74,237,154,0,95,114,58,10,43,216,118,226,237,112,117,246,221,61,92,130,217,76,156,146,108,174,194,141,237,152,121,188,4,47,0,106,7,165,32,115,221,144,162,34,190,33,39,174,224,239,250,108,149,157,16,180,209,104,19,82,247,161,176,39,121,174,175,26,251,254,123,231,116,208,206,39,247,93,164,239,181,117,169,175,216,99,162,239,195,175,186,138,68,197,35,159,255,147,39,108,153,187,121,52,157,251,90,216,46,47,160,243,51,145,128,170,138,169,190,171,93,47,226,132,232,210,18,173,37,83,67,170,35,177,98,158,26,126,160,37,56,226,140,35,135,200,41,251,191,170,249,227,172,217,144,230,251,174,253,83,59,98,11,125,229,155,238,31,235,31,247,179,142,253,153,217,197,108,19,129,77,177,198,165,207,46,88,114,66,8,123,171,233,221,174,43,75,157,84,227,71,142,126,72,213,107,29,222,17,0,218,113,74,208,243,7,7,61,6,42,46,218,11,239,214,233,49,46,85,85,214,138,24,238,83,62,233,130,3,104,221,39,69,68,93,101,220,243,65,243,100,203,242,162,151,200,143,221,39,37,214,179,3,117,117,175,31,147,105,13,132,174,4,160,79,163,4,76,111,57,217,191,246,254,30,84,213,49,62,212,75,31,168,112,136,71,0,148,109,42,9,175,219,111,89,209,20,30,104,25,228,23,65,147,120,205,222,130,193,46,178,147,36,98,64,91,51,213,240,131,99,25,146,247,255,118,146,63,106,79,230,164,62,7,236,220,41,84,246,126,101,53,203,209,118,238,238,134,204,118,194,158,76,7,82,129,139,169,125,146,191,26,217,164,250,206,14,83,207,35,134,12,246,32,86,221,195,180,131,103,188,50,218,21,120,146,33,160,64,42,33,179,61,248,150,27,191,101,234,135,149,117,167,186,127,166,86,234,149,138,118,55,56,207,153,93,1,56,237,197,36,157,62,68,81,158,96,113,158,79,5,246,22,220,45,118,228,135,112,229,5,65,194,20,79,117,229,151,72,231,128,59,177,252,196,151,8,84,77,202,72,167,133,8,188,170,105,15,111,86,100,42,32,249,175,143,74,98,81,176,48,17,171,44,159,121,119,191,195,92,124,254,8,149,23,175,81,20,175,112,86,188,54,156,230,27,245,126,121,45,85,193,138,32,78,164,168,61,179,254,139,10,117,48,238,106,80,4,66,84,71,236,11,212,175,74,164,167,55,246,169,108,172,114,200,52,241,34,199,207,83,109,36,15,165,8,129,116,102,211,254,137,180,122,108,150,77,160,103,61,113,66,8,44,234,21,33,87,105,236,78,1,188,210,233,201,3,129,2,49,114,161,25,49,14,208,14,0,58,159,7,24,160,64,235,147,37,212,71,47,231,12,95,66,116,29,192,115,220,239,80,165,57,37,130,209,87,94,8,127,240,68,178,28,36,86,73,207,149,121,162,87,125,253,163,169,242,31,154,191,42,52,107,203,125,45,230,145,168,46,50,245,186,210,178,94,81,147,223,237,201,68,98,206,140,133,239,96,3,192,120,74,178,184,209,180,55,223,4,253,46,204,132,191,73,229,149,62,61,130,67,163,149,92,51,247,128,10,53,180,99,29,231,155,153,252,45,25,45,22,73,67,224,84,59,226,45,147,222,142,253,179,114,56,84,26,147,84,221,7,25,175,61,151,249,131,24,249,18,214,228,208,151,41,33,59,166,215,70,141,16,163,211,222,71,146,120,83,148,221,50,90,186,133,25,113,222,139,78,228,153,38,218,2,141,65,192,165,2,18,243,35,234,147,232,84,155,20,195,104,133,96,179,111,21,243,118,25,204,144,213,81,99,157,46,50,197,187,6,234,52,42,208,16,29,0,120,24,38,213,23,84,177,49,151,17,227,148,254,156,215,72,16,234,51,172,106,186,194,77,117,118,31,64,168,124,186,250,235,77,157,19,7,42,124,62,3,118,76,153,69,192,54,236,39,153,42,169,84,232,74,233,243,84,34,203,12,85,226,124,162,61,42,78,105,128,158,131,117,139,185,103,219,218,33,75,110,162,50,202,56,245,47,12,93,205,99,155,115,31,240,107,205,236,60,42,255,139,126,119,97,121,136,208,160,224,49,152,118,208,208,33,1,120,168,219,13,34,211,110,77,104,191,41,17,31,97,85,54,105,123,115,52,85,177,42,1,76,120,199,24,11,33,64,107,104,172,222,30,210,125,252,214,75,246,219,10,177,75,194,97,14,45,146,80,34,221,191,253,181,56,164,142,104,57,230,44,159,183,213,159,250,242,166,64,168,59,108,129,135,3,0,11,180,217,175,188,237,33,91,90,214,81,64,0,142,135,43,167,144,165,41,175,141,40,205,184,192,37,161,20,116,173,128,143,53,240,181,15,104,193,74,180,52,156,49,213,36,164,221,93,61,26,230,226,28,10,88,50,45,123,191,101,85,244,62,209,179,250,43,249,14,188,207,158,173,104,141,50,105,132,163,31,208,56,70,213,84,244,200,104,148,75,63,164,184,134,234,171,25,2,242,75,3,137,253,124,173,225,83,140,74,211,15,77,100,214,91,44,96,26,165,37,12,153,158,49,56,218,50,199,168,243,66,238,125,174,183,219,12,207,233,67,185,105,72,10,207,119,126,36,202,96,80,162,97,151,90,16,207,99,131,24,194,120,75,196,162,93,0,111,237,211,166,66,70,7,237,40,29,174,71,12,147,15,45,151,145,67,224,94,122,249,2,114,159,59,251,78,168,213,176,247,158,103,100,49,48,45,4,168,195,139,44,100,232,233,131,23,25,118,42,175,241,100,57,49,74,189,210,224,81,182,0,6,163,126,89,35,25,191,231,116,146,26,94,11,44,135,199,11,26,106,131,119,175,228,174,165,201,157,236,198,234,128,80,232,98,218,167,240,91,248,124,173,75,4,230,158,9,130,193,194,234,45,158,85,245,160,76,183,7,147,210,37,196,171,47,175,227,183,94,231,32,85,226,225,115,88,76,111,129,91,149,253,133,160,78,129,255,210,61,40,36,242,250,37,215,40,72,176,70,115,154,169,206,205,167,101,129,110,194,116,153,142,27,119,25,206,47,172,138,122,45,28,223,161,158,41,31,166,187,218,39,138,49,239,116,97,46,34,168,137,69,58,229,137,39,207,162,164,169,86,193,134,165,53,196,34,168,9,17,57,232,135,194,100,55,131,38,58,197,136,84,124,82,242,199,233,174,132,194,97,242,95,74,8,0,239,145,0,54,222,54,168,123,151,13,150,240,228,189,162,77,176,13,7,36,190,38,51,12,221,178,122,40,241,236,83,199,174,108,114,178,37,183,119,10,11,72,132,19,208,46,204,107,163,39,219,5,51,18,130,220,54,115,57,105,15,194,248,121,205,215,54,56,211,73,68,179,79,234,107,22,214,69,106,199,71,159,68,160,65,81,144,180,158,28,172,70,140,193,102,72,117,213,10,138,215,244,237,92,69,93,146,111,141,194,6,76,180,207,136,5,231,100,47,92,83,226,83,129,118,189,77,115,30,132,158,0,131,27,134,170,201,182,0,6,218,153,224,245,222,28,2,248,17,0,241,179,25,71,211,122,45,68,115,252,150,117,233,140,4,69,31,225,23,106,130,99,222,125,17,35,61,53,89,135,220,204,76,81,22,94,82,66,159,48,166,97,111,44,176,218,144,135,217,12,118,254,234,218,1,170,119,117,176,243,189,41,33,223,87,147,132,184,17,196,20,189,53,240,104,10,79,178,147,154,122,157,248,15,37,141,163,145,245,216,170,146,35,245,224,35,137,120,69,94,10,63,157,216,230,125,158,85,112,91,201,97,112,133,119,143,80,161,235,147,46,189,91,97,84,32,246,230,161,99,141,54,204,106,208,25,17,234,157,73,138,60,3,141,27,196,112,3,95,251,196,98,52,130,214,82,67,169,220,3,42,194,221,90,146,57,134,18,59,181,53,34,159,37,241,40,1,18,35,16,217,1,36,119,81,84,224,72,237,101,205,155,50,149,75,65,11,143,171,206,32,216,232,112,211,35,4,156,193,86,143,164,41,156,46,47,253,16,200,51,26,39,252,19,38,118,62,55,133,159,198,125,21,1,211,58,238,204,148,63,93,47,122,44,41,211,200,169,117,210,192,226,11,78,16,137,107,154,28,250,79,249,136,64,222,240,249,102,59,180,174,39,204,85,4,132,133,86,8,215,241,137,92,90,199,88,165,112,9,124,74,117,226,79,69,84,201,160,172,213,0,217,68,28,62,7,147,218,214,180,137,152,146,253,81,251,38,17,209,198,35,39,133,90,117,107,84,187,86,104,232,103,119,123,173,97,219,222,39,167,236,6,80,40,85,232,42,41,196,24,179,157,252,100,133,250,26,173,131,68,71,55,162,190,2,255,217,191,211,33,152,90,4,79,118,8,226,207,219,197,55,28,1,250,15,104,164,77,47,92,76,59,40,127,92,100,136,242,24,56,154,49,249,10,227,74,27,92,1,79,100,104,132,95,98,23,44,47,57,100,84,14,22,230,57,51,228,29,232,146,131,32,120,55,251,69,143,112,101,2,224,197,182,76,38,208,178,141,239,247,207,191,149,92,210,197,157,75,3,22,176,96,196,70,27,208,209,85,50,137,219,122,147,112,5,135,67,128,220,87,243,6,244,105,128,34,251,229,30,137,191,219,43,66,174,179,35,107,143,9,234,118,6,38,213,16,60,111,96,77,74,248,190,196,64,141,62,40,204,19,118,186,233,135,128,240,18,85,213,101,82,113,143,255,16,8,102,70,32,42,249,212,178,231,67,55,132,91,82,3,31,28,155,49,55,173,19,73,145,195,130,201,118,141,148,62,177,104,19,100,139,55,226,46,185,244,6,178,224,107,45,184,6,148,182,137,14,179,143,191,95,95,126,248,121,58,201,227,111,184,24,99,251,121,123,87,179,111,93,248,15,108,198,122,159,41,4,77,93,20,68,221,42,24,218,207,166,127,187,181,163,121,59,254,76,222,51,65,28,7,167,242,145,141,107,204,37,48,230,106,183,71,211,116,97,93,160,152,210,210,196,51,142,83,160,158,112,246,78,133,86,149,96,68,202,166,192,55,178,186,222,143,187,64,116,239,16,102,175,90,96,136,101,70,18,55,192,2,255,139,151,28,207,153,19,3,204,183,26,143,154,152,190,237,33,204,161,25,101,52,68,35,230,12,175,241,37,70,73,200,173,7,112,104,217,237,251,106,213,244,179,25,65,90,244,197,88,38,172,246,197,136,37,193,131,85,131,113,56,70,53,196,53,228,255,220,175,246,25,218,57,201,131,233,144,29,195,56,63,194,25,195,203,98,131,217,212,71,8,17,77,84,144,227,87,136,244,254,211,37,233,210,204,64,219,13,248,65,121,63,198,171,2,242,185,84,251,80,83,97,20,195,248,152,220,170,152,64,59,249,152,145,182,191,163,46,112,250,200,128,158,28,152,186,29,243,23,23,135,202,73,23,248,202,48,250,174,75,12,139,235,162,227,58,162,87,202,216,38,147,220,112,172,242,145,78,18,44,61,173,102,99,193,254,80,13,57,28,45,158,237,188,79,131,162,8,133,1,211,171,199,53,226,107,40,218,34,162,108,26,70,56,154,8,166,209,143,44,154,78,22,53,212,189,230,99,9,221,193,11,14,64,168,55,20,190,193,88,171,252,91,161,140,246,127,175,172,223,39,31,200,163,211,196,109,23,190,94,202,30,151,64,160,35,14,73,197,39,130,104,78,227,27,71,170,174,108,27,96,71,137,214,103,183,9,92,63,39,63,171,253,129,253,253,76,195,168,211,146,124,66,254,90,63,5,59,143,106,151,99,225,40,24,121,130,250,136,46,118,129,208,203,211,63,196,122,57,230,252,240,200,70,116,139,52,13,201,221,253,33,49,119,250,67,177,13,122,60,177,43,30,242,31,200,40,136,156,134,140,53,255,74,181,58,176,205,30,255,205,88,145,123,134,61,229,202,232,78,147,237,56,156,64,78,9,89,142,153,55,237,108,255,253,29,199,85,180,99,207,18,73,239,212,4,238,233,199,228,46,145,69,61,40,120,67,47,56,92,90,173,36,186,24,101,148,86,60,197,31,28,14,135,160,128,112,161,11,205,103,163,18,44,134,25,109,119,166,77,180,233,9,96,148,9,21,169,104,139,32,125,183,145,147,152,156,198,233,223,120,65,19,58,65,163,241,106,206,203,236,213,211,172,76,187,212,170,31,211,142,51,209,87,105,9,171,181,156,145,3,123,16,22,46,77,219,243,241,126,216,46,181,100,72,209,167,249,0,144,152,20,98,48,152,100,189,206,204,64,44,77,160,133,146,107,240,211,248,14,168,10,250,109,254,254,224,71,209,27,39,35,97,161,1,64,126,245,254,243,215,201,187,207,55,239,39,55,239,47,39,31,174,110,110,62,92,78,126,252,237,250,247,201,143,151,151,211,87,142,84,196,140,201,149,68,63,41,254,179,67,179,79,147,172,232,57,51,170,140,156,202,47,22,103,0,217,249,10,250,235,237,151,203,201,231,15,239,166,147,159,223,218,173,191,176,110,123,245,246,227,244,213,191,33,198,190,255,1,1,236,19,211,106,181,41,136,52,19,179,92,139,18,199,207,242,47,125,204,198,84,170,68,140,81,107,148,164,164,138,229,216,43,135,65,178,85,100,49,129,225,241,86,45,190,31,155,105,95,235,195,145,237,128,40,193,61,236,123,150,174,39,114,113,90,39,86,22,96,34,46,255,174,144,188,169,87,197,59,13,150,18,101,43,99,220,16,62,205,196,88,239,241,41,115,231,207,15,222,36,173,63,167,61,64,161,109,242,123,92,177,221,93,208,87,29,209,102,243,135,67,133,209,129,207,58,10,62,249,35,208,240,26,88,81,9,229,96,199,252,158,165,57,7,16,202,195,217,104,178,131,46,239,96,58,230,63,220,210,38,64,230,197,249,201,109,40,54,87,175,51,185,37,0,52,19,246,56,164,57,238,241,118,227,25,27,181,253,176,3,139,237,106,107,166,100,238,171,193,223,224,119,223,132,208,213,84,210,51,104,26,179,239,224,163,203,229,108,181,98,198,29,126,237,224,141,105,42,189,172,152,247,30,208,73,168,158,223,135,244,38,61,183,142,217,1,111,147,192,70,60,116,168,14,183,115,115,2,138,253,32,171,44,235,120,200,106,174,239,220,125,69,70,39,248,28,127,84,79,195,174,175,19,88,15,84,20,107,198,59,108,124,89,54,66,131,114,23,219,63,243,187,188,229,204,51,141,50,236,99,200,3,66,175,157,93,253,205,191,191,37,33,254,127,112,70,48,107,206,168,86,86,143,113,163,159,213,188,19,105,24,51,42,169,41,120,87,31,110,73,65,153,93,11,101,93,112,155,220,145,150,57,101,136,236,30,227,173,97,193,107,225,195,158,148,4,75,73,183,191,223,26,145,93,12,108,108,129,83,69,27,33,79,112,85,61,141,36,12,147,235,200,130,22,181,24,62,30,10,136,205,125,121,210,61,35,66,140,37,115,43,155,7,44,152,138,56,118,8,30,60,10,176,111,254,81,220,226,61,59,94,250,160,37,103,26,19,94,207,94,115,245,254,237,125,97,199,152,39,49,25,25,123,34,48,238,67,16,36,55,14,221,247,116,244,64,137,68,254,54,31,215,115,176,53,119,21,84,181,151,53,205,65,247,188,76,45,48,46,47,181,177,27,228,45,97,192,203,10,7,227,74,115,196,1,81,193,180,137,21,46,95,238,136,51,236,70,87,153,104,9,194,209,76,216,95,29,59,159,16,117,30,183,185,30,111,224,235,24,237,205,73,8,17,49,163,196,4,26,163,67,157,234,8,70,31,137,71,126,75,245,218,208,73,239,7,243,54,222,196,141,126,172,149,223,71,136,10,212,10,97,143,66,48,153,186,81,55,213,89,38,43,189,241,231,101,178,18,207,72,85,253,47,156,61,196,93,255,245,219,213,205,165,127,186,140,228,199,206,223,208,172,27,219,87,123,221,2,102,131,170,32,89,229,42,79,29,87,43,98,206,198,145,238,228,169,67,126,204,139,89,17,232,32,67,186,89,60,243,124,72,87,207,27,179,164,1,181,26,82,146,52,176,88,247,7,222,90,129,99,44,221,240,104,47,115,60,128,207,202,25,49,83,210,193,241,76,73,128,208,239,106,77,160,26,205,172,96,23,163,231,48,50,162,153,17,70,203,171,164,132,67,116,246,187,5,68,244,73,163,160,150,92,17,132,104,206,124,20,105,76,94,91,115,91,55,185,231,182,72,139,188,251,252,233,252,230,104,218,194,115,62,8,63,224,78,178,163,209,115,119,14,147,72,193,64,132,0,182,171,22,205,92,51,67,148,33,199,193,79,237,59,17,35,50,242,44,198,24,161,108,222,71,205,71,113,69,170,178,56,233,45,163,227,205,192,70,211,127,203,5,60,28,119,205,158,84,119,252,2,23,196,84,155,102,27,122,73,154,164,122,205,102,44,175,40,171,232,84,155,231,179,172,251,98,92,252,147,167,157,241,178,77,106,10,62,144,88,119,23,25,76,250,199,142,219,142,70,242,234,205,71,160,67,84,251,65,34,76,236,34,154,65,190,6,211,202,38,223,121,85,52,70,113,240,73,81,159,230,163,2,97,255,125,57,136,35,68,46,122,167,159,33,163,149,155,139,250,59,240,13,131,56,8,131,78,39,194,43,37,158,51,70,209,251,50,38,105,88,239,8,196,13,210,7,49,218,38,134,253,179,34,47,18,180,107,249,193,88,122,107,214,207,165,239,94,123,225,17,93,35,67,25,21,249,40,19,143,137,178,207,156,115,236,69,68,155,59,101,130,83,139,40,231,68,74,107,94,152,29,62,206,143,91,250,32,93,30,250,116,145,171,204,237,227,16,202,255,60,121,205,103,220,87,79,36,95,34,217,0,46,148,103,6,4,101,174,144,244,55,62,166,227,161,141,42,46,106,162,199,85,140,121,87,145,13,184,18,60,200,171,98,44,72,173,73,45,141,180,180,211,109,142,248,248,48,85,74,109,199,204,229,165,201,170,194,41,101,94,1,149,78,50,60,224,212,199,153,38,178,243,156,154,10,226,210,129,246,148,150,45,46,242,12,12,180,132,196,22,83,97,70,175,125,90,80,34,157,94,14,255,245,1,66,234,143,110,119,11,23,166,12,15,119,108,64,204,196,40,184,130,15,136,101,215,26,211,17,192,31,127,102,57,11,193,229,20,37,56,86,8,162,233,186,68,247,112,205,196,110,70,6,177,218,99,23,72,83,81,83,139,180,21,71,99,10,254,20,209,139,79,106,205,148,51,116,168,93,245,36,0,86,242,75,236,37,210,220,143,200,57,244,135,133,52,149,170,98,84,86,244,64,56,34,52,64,60,62,74,94,93,99,170,206,59,202,38,87,217,232,102,122,223,79,158,11,244,214,105,23,220,173,236,245,151,55,127,131,158,221,52,119,132,147,84,128,127,48,109,25,228,27,164,129,93,10,220,168,60,162,15,139,19,77,136,154,32,74,128,176,114,75,158,3,253,214,180,196,185,221,33,172,96,234,30,192,182,165,48,71,75,14,178,246,150,89,91,31,204,50,103,241,18,141,33,103,101,31,89,95,54,165,148,176,169,59,103,204,242,24,8,157,197,158,131,241,180,207,216,42,102,255,100,211,166,145,237,119,168,166,245,57,121,69,247,37,0,166,0,62,110,229,82,21,80,9,33,135,30,19,253,159,215,145,79,77,71,132,84,191,247,183,45,27,192,113,57,118,148,172,246,9,173,16,77,49,211,131,167,21,170,44,72,17,162,11,93,135,105,135,130,71,89,6,111,134,209,140,25,36,152,53,150,15,10,86,185,65,178,98,98,247,51,202,225,126,136,61,190,40,10,155,255,135,23,42,255,237,255,142,42,157,255,249,183,254,135,247,99,134,151,228,184,200,147,156,219,105,130,79,225,171,48,102,212,22,53,177,0,30,112,95,133,26,11,20,157,87,237,84,58,89,161,179,246,72,113,77,83,213,62,128,193,105,86,139,28,35,224,21,168,102,198,36,159,252,44,234,176,142,167,97,242,149,179,76,243,21,163,170,171,9,221,202,179,179,82,190,193,184,79,198,138,216,49,208,85,249,35,107,24,170,147,181,0,138,30,205,30,164,218,78,40,224,94,67,100,30,58,184,149,130,180,56,56,162,2,185,94,213,169,251,206,81,144,217,231,6,81,76,244,21,251,183,25,253,200,241,206,203,122,145,248,197,217,175,250,254,237,63,47,9,39,79,11,34,192,202,155,204,203,109,191,165,79,228,233,183,37,171,61,144,221,68,127,229,4,198,104,101,15,37,224,77,19,172,206,36,178,91,181,245,218,186,169,38,43,238,7,14,16,200,75,115,223,66,236,167,4,222,110,139,218,76,191,84,241,37,97,90,3,141,52,140,214,42,12,211,115,132,70,153,200,40,241,104,71,102,209,217,36,150,66,194,86,81,164,136,20,42,209,121,1,144,85,15,28,189,156,245,9,52,60,147,232,78,173,233,18,71,226,178,128,124,110,2,9,237,190,32,69,119,159,57,73,167,185,21,200,12,184,137,114,226,55,91,56,131,220,110,142,97,213,62,123,96,215,5,172,92,67,97,121,38,64,9,86,205,193,41,62,249,171,121,248,171,122,200,207,153,40,253,22,8,177,155,146,232,92,171,152,69,54,155,82,95,65,165,129,2,96,52,180,219,62,205,60,2,198,216,145,131,137,139,1,250,208,135,93,10,4,46,96,157,200,14,132,66,54,163,208,103,196,241,194,28,54,213,243,4,70,39,58,18,135,209,161,60,219,230,161,118,94,51,64,142,54,185,213,2,29,41,249,29,239,76,203,211,40,224,87,110,219,86,251,140,64,65,213,37,117,75,93,107,149,161,127,224,183,175,61,121,243,43,239,85,150,200,63,125,190,201,155,114,168,174,22,205,195,134,25,97,156,177,15,154,198,65,234,242,220,197,165,47,50,52,171,246,169,193,165,99,178,124,116,83,157,16,103,69,102,107,250,238,110,177,163,36,6,146,89,76,72,142,243,12,118,167,190,189,155,122,89,76,146,235,48,79,82,183,139,154,39,19,23,43,204,6,87,60,228,184,0,37,68,89,220,37,34,240,232,79,158,115,98,227,108,76,3,33,111,240,168,231,53,47,88,46,65,44,217,118,53,72,88,28,140,142,2,73,254,200,93,181,121,44,126,10,254,221,134,46,152,57,79,189,231,240,181,54,153,39,40,77,24,141,89,50,126,128,163,100,47,168,146,111,87,31,228,85,226,133,98,101,50,116,212,120,42,165,20,152,207,156,229,95,88,60,173,23,25,197,86,12,248,75,110,202,203,23,100,19,221,68,151,233,168,95,62,163,45,127,45,36,216,179,165,197,184,109,145,145,58,181,217,96,126,39,184,74,188,43,102,25,61,176,116,234,30,30,250,194,217,127,249,66,215,245,161,103,14,115,193,36,55,5,61,176,87,179,96,186,142,21,209,232,0,249,30,139,106,127,150,242,252,33,0,108,165,195,89,97,57,152,232,33,92,141,141,84,48,220,79,117,157,153,156,120,66,156,122,16,144,102,72,74,160,108,170,205,166,221,215,135,57,48,54,198,192,105,26,101,177,96,78,24,186,106,152,118,233,42,71,16,115,229,253,124,222,219,136,121,39,72,70,41,63,193,159,177,185,228,60,15,60,87,156,22,135,171,171,52,83,28,183,73,51,15,42,167,132,240,172,120,186,151,30,49,33,176,83,90,5,174,2,238,24,29,114,201,151,67,104,160,245,223,152,146,102,15,61,50,123,230,11,63,172,82,177,151,217,59,150,20,30,177,240,191,61,152,169,77,122,232,32,89,49,82,59,211,130,68,227,236,208,180,51,221,56,155,177,161,181,202,179,204,145,16,194,238,162,136,232,51,148,202,20,146,43,186,0,36,133,65,63,239,234,146,6,187,217,124,35,42,39,10,190,121,223,121,195,108,171,31,154,110,117,176,211,14,249,98,239,140,143,185,8,24,112,148,56,93,77,20,20,27,244,241,114,153,250,65,252,44,209,18,6,52,86,70,14,188,141,14,10,142,5,56,145,92,242,99,87,122,149,238,70,0,19,137,174,99,7,159,100,92,1,5,119,146,57,42,138,215,235,213,134,167,38,16,119,103,152,14,252,252,233,210,251,14,149,29,163,221,175,228,195,217,14,128,32,98,211,218,95,124,58,13,88,236,180,173,175,115,90,86,10,138,253,186,245,102,47,57,189,40,193,192,194,3,113,28,8,36,193,217,66,124,28,167,116,180,63,206,160,82,4,82,254,15,197,134,77,232,247,249,47,169,73,158,29,185,232,103,212,195,104,200,131,197,49,240,42,56,30,196,213,205,104,101,136,128,183,107,70,31,158,83,60,18,203,16,138,7,8,131,19,121,217,224,183,80,215,199,24,189,52,210,111,141,247,250,226,58,79,203,189,88,32,248,35,174,106,182,135,113,102,6,181,138,11,178,68,25,55,217,41,209,33,140,37,99,207,158,100,240,2,166,95,180,107,101,112,61,243,230,131,8,175,143,26,136,229,0,61,4,99,178,11,31,163,205,131,89,74,102,198,233,19,197,188,162,114,224,129,118,198,33,86,100,0,27,177,129,136,106,65,176,68,161,43,52,114,93,28,145,240,178,120,232,220,98,143,142,231,68,89,24,95,158,55,69,178,86,151,24,135,241,4,112,141,219,252,60,33,31,230,6,250,70,109,201,135,79,175,164,154,83,162,122,138,233,94,74,117,68,97,200,46,193,129,147,160,174,127,152,140,249,133,168,94,205,49,60,32,76,186,243,130,14,246,254,185,163,110,225,197,99,204,44,240,78,217,190,198,50,44,138,73,174,57,93,186,49,77,144,208,97,243,14,13,103,233,147,57,242,144,171,155,65,58,101,127,165,19,236,233,224,179,4,28,145,134,45,180,41,52,206,105,207,14,247,93,87,49,75,237,237,57,234,40,44,152,151,146,246,19,29,242,86,155,190,219,12,79,13,33,50,23,185,135,61,119,5,142,84,106,21,89,173,134,136,157,149,187,11,28,84,45,166,174,72,205,249,80,237,2,103,113,152,69,145,10,40,102,21,49,27,149,185,26,189,193,57,131,28,11,106,157,49,81,177,204,8,177,182,202,166,166,142,115,7,224,42,103,58,245,220,115,74,89,142,34,31,50,250,120,16,199,226,64,196,101,236,159,195,236,119,47,54,92,140,70,184,244,109,48,99,109,10,178,53,247,83,220,103,75,84,229,185,1,100,234,88,125,19,103,230,169,92,13,12,236,245,196,171,114,13,114,138,231,161,61,204,228,87,128,112,62,69,129,173,128,178,20,164,71,163,238,89,190,195,69,164,77,168,229,156,121,115,197,154,50,154,82,113,80,152,194,0,63,143,73,78,30,98,43,135,179,15,172,19,38,198,147,43,142,245,15,177,158,1,239,241,20,56,144,20,23,222,213,206,169,135,43,7,43,116,155,136,162,207,138,129,201,169,201,197,71,244,140,27,120,139,156,163,60,168,7,34,69,61,156,206,237,186,22,173,237,134,6,86,69,29,187,169,39,70,217,181,150,166,110,193,67,60,154,33,243,252,192,138,224,46,116,78,122,244,250,33,19,71,106,156,212,146,88,78,178,192,254,52,209,104,123,239,64,216,129,190,165,198,79,182,92,177,85,243,45,216,190,166,199,84,177,162,108,215,218,130,198,160,117,223,47,26,40,215,100,202,139,165,121,90,150,80,223,200,149,234,115,185,193,189,233,216,235,132,46,170,104,205,151,204,164,179,231,167,140,223,79,249,223,2,5,183,64,104,6,237,92,204,142,123,104,179,136,235,253,51,89,79,181,72,240,218,212,109,21,39,107,195,17,208,185,176,246,159,12,96,250,231,213,223,126,208,212,54,31,247,215,218,108,69,106,172,248,249,216,188,186,62,131,121,74,163,149,134,252,38,193,65,212,122,190,193,25,67,218,160,10,137,44,94,72,72,197,76,46,144,97,205,134,251,203,113,108,228,199,240,214,196,146,135,13,179,132,102,206,92,180,65,93,130,52,186,205,58,21,88,253,98,8,106,8,211,159,184,215,144,46,142,249,112,16,32,211,224,53,234,50,11,170,176,187,189,131,32,230,234,24,159,42,251,242,148,27,217,28,0,139,123,217,93,26,50,110,169,249,143,188,180,40,225,228,122,139,230,177,80,206,113,217,199,205,110,254,184,210,128,1,47,231,108,35,45,31,89,211,163,85,152,250,5,42,175,127,228,12,139,114,49,108,15,242,68,149,169,139,7,89,119,54,65,241,90,53,18,89,35,74,14,77,47,218,182,79,190,108,128,220,241,136,59,235,59,103,183,123,115,82,227,121,184,222,147,95,121,194,153,179,105,179,187,87,197,147,196,242,153,73,133,92,10,230,221,40,141,200,38,207,241,110,78,14,9,125,81,139,251,217,150,119,246,179,47,136,142,155,173,148,56,72,154,192,94,40,215,197,26,83,183,142,230,99,244,53,14,180,92,222,21,88,82,224,218,222,229,74,14,203,33,60,111,132,37,235,189,219,162,160,24,124,85,222,204,222,183,171,122,189,113,95,230,246,103,39,124,241,17,95,28,197,136,146,247,55,64,216,209,202,151,2,204,255,218,177,153,177,85,99,176,57,53,255,189,171,135,139,115,127,81,219,183,120,81,182,232,48,19,53,141,48,90,128,213,242,198,132,93,36,148,5,159,21,156,234,7,0,150,88,112,60,232,232,57,248,156,147,242,49,199,239,193,212,233,248,65,211,174,200,193,151,128,221,145,153,100,21,84,53,148,23,74,145,50,216,133,175,21,200,218,81,205,114,133,153,165,42,237,40,56,25,220,128,140,120,25,144,170,223,109,34,29,25,123,67,161,193,99,115,190,80,40,233,68,147,184,140,150,242,84,43,96,96,166,214,59,209,229,15,135,18,166,172,108,100,246,114,81,234,184,143,142,14,20,14,99,210,222,78,140,50,232,238,253,176,99,17,76,244,1,142,129,235,31,199,163,64,153,64,115,0,210,73,18,101,206,88,170,75,254,143,136,74,131,176,222,45,102,26,198,84,184,223,254,82,74,163,184,207,116,239,154,91,120,75,72,235,207,112,150,224,195,75,73,194,255,104,75,153,243,50,184,66,116,212,31,42,181,236,152,11,243,218,121,64,224,128,198,247,35,244,43,123,52,44,146,107,155,158,64,16,117,238,219,243,195,163,81,171,67,162,202,193,198,225,210,23,78,197,155,123,96,139,178,94,37,60,170,237,100,87,153,132,55,152,164,169,203,187,219,212,170,165,169,1,125,59,77,3,107,19,230,198,172,196,205,1,239,118,83,215,127,53,49,164,227,132,175,31,252,5,228,83,140,153,128,21,102,44,46,57,238,231,177,78,195,32,232,173,58,75,41,78,12,189,249,241,172,99,5,70,7,225,252,45,28,171,106,141,28,82,56,97,41,250,227,54,103,234,10,49,39,177,162,229,189,107,229,118,23,59,157,134,46,61,155,144,133,107,116,111,31,211,169,114,81,3,231,211,19,94,99,215,171,89,128,27,229,211,36,5,73,82,121,238,234,211,245,213,187,75,37,12,244,116,124,14,79,22,251,118,174,208,81,173,54,154,161,204,45,160,21,102,68,75,114,112,48,18,79,0,226,14,88,28,29,186,212,146,144,52,245,184,173,34,193,233,0,81,110,190,53,43,31,93,141,193,81,106,154,160,39,202,36,42,136,47,148,203,56,46,234,91,0,141,139,211,148,34,51,7,132,16,123,103,194,122,164,66,11,161,70,206,200,119,161,209,89,5,43,48,110,199,181,129,168,1,134,153,225,151,23,162,232,59,220,116,143,20,67,225,19,2,146,135,172,106,232,65,31,12,168,227,253,22,100,6,223,186,85,90,187,93,115,20,67,74,56,190,117,94,212,52,209,49,136,215,203,137,106,109,49,122,34,149,119,64,63,138,8,19,162,247,216,172,215,238,126,77,25,103,41,91,61,148,207,114,174,5,17,58,1,41,91,214,189,254,170,5,41,221,180,65,124,33,104,70,58,41,169,144,95,16,8,48,170,135,219,198,118,109,51,213,177,26,179,89,219,73,137,179,155,111,93,237,239,14,87,36,229,153,71,134,115,16,132,62,96,105,58,207,81,129,225,96,47,39,71,44,135,198,29,237,147,80,58,206,23,33,175,94,93,189,182,97,116,25,242,112,92,116,90,16,27,219,22,108,242,69,227,81,241,200,23,14,113,21,121,46,56,174,17,192,135,208,28,103,231,228,54,102,6,36,78,57,182,151,210,115,69,87,127,1,53,28,64,101,210,183,36,137,227,40,20,77,170,90,128,214,25,179,237,37,128,26,100,90,151,71,130,163,219,228,170,37,174,157,12,167,35,126,251,194,103,15,103,186,176,69,215,136,180,19,202,243,175,146,13,59,237,81,174,5,7,23,84,147,210,92,7,4,28,225,9,113,159,208,165,65,129,247,184,17,195,140,43,157,172,211,71,133,228,38,234,60,106,213,39,193,52,21,108,160,9,144,16,240,248,203,104,248,136,56,52,124,239,23,237,184,104,159,74,32,158,157,192,230,96,169,79,154,221,156,85,16,179,81,81,67,1,224,246,32,197,220,140,147,15,205,122,100,48,76,207,129,13,156,221,255,224,91,230,232,227,140,184,106,22,13,28,251,114,206,160,199,21,233,200,211,19,210,8,199,194,191,230,175,56,231,201,177,160,172,191,72,7,60,54,64,95,109,34,137,10,117,140,108,147,56,139,214,56,198,41,55,81,111,22,225,188,208,97,242,124,131,251,146,135,238,19,185,205,236,144,207,86,245,3,91,190,45,132,92,29,242,185,97,52,161,72,8,238,170,187,189,24,188,230,28,111,195,113,180,170,73,101,6,5,240,237,66,57,161,119,84,212,5,124,7,115,74,86,139,174,13,210,167,36,122,80,47,241,54,104,72,220,30,186,88,133,243,209,186,111,186,101,60,172,231,36,116,105,183,61,59,24,37,89,16,101,158,202,74,170,232,231,222,71,222,5,175,92,158,184,165,166,166,140,198,57,92,126,171,221,1,141,213,229,5,17,184,204,231,21,72,100,113,188,83,83,105,184,245,88,196,105,26,193,16,207,32,134,9,249,70,194,184,111,68,48,145,28,8,55,29,144,54,248,119,130,124,194,199,160,91,198,110,59,127,60,23,23,175,8,5,187,8,159,109,154,81,132,216,194,52,70,34,246,104,40,68,236,128,174,2,78,161,131,82,31,58,175,77,66,236,128,223,237,132,34,235,198,238,150,135,234,84,191,62,221,224,128,247,38,209,149,201,243,246,9,126,81,85,192,99,123,74,81,89,57,101,239,61,174,141,42,212,6,185,249,200,49,99,227,133,196,189,151,55,125,251,180,220,203,83,155,19,6,100,38,46,207,174,44,178,252,168,132,76,126,178,93,92,54,29,23,162,84,36,190,191,94,6,245,194,137,93,248,130,53,230,146,31,58,125,133,216,73,68,126,69,237,203,49,126,194,94,204,157,122,211,169,32,244,158,226,17,203,9,83,204,96,56,134,159,14,101,116,31,220,22,12,19,179,124,57,178,33,121,155,14,0,36,232,88,36,21,1,13,17,116,192,155,68,83,7,33,74,79,13,65,218,143,169,51,174,92,158,62,79,25,51,89,192,51,219,115,222,155,85,39,127,230,209,87,249,13,18,243,243,11,23,133,131,45,155,102,142,225,137,21,127,173,21,103,160,97,39,16,36,242,139,246,168,58,198,219,120,115,182,100,190,157,142,212,1,227,138,196,201,32,214,0,53,126,99,209,137,123,112,123,27,93,38,65,98,80,182,200,103,84,122,121,95,178,37,61,251,228,81,100,227,210,92,140,48,21,113,48,125,34,84,226,248,201,165,216,194,204,234,90,116,180,5,243,141,122,123,40,55,86,163,7,49,194,58,150,147,34,211,239,238,254,208,24,194,163,134,255,175,35,206,196,92,213,190,111,254,196,153,103,240,157,116,61,4,199,201,133,66,145,187,190,78,56,115,41,126,234,19,135,150,22,133,18,26,26,213,57,10,114,119,197,135,60,185,154,0,224,174,108,40,212,212,25,103,50,253,242,133,102,200,224,54,179,198,30,64,156,189,81,99,96,184,40,172,28,59,32,51,209,111,95,217,154,108,45,6,176,157,167,55,221,71,18,216,222,221,233,145,210,29,121,64,204,17,80,122,46,33,25,56,243,81,83,218,152,113,113,238,223,215,163,39,228,58,134,14,79,121,148,21,199,0,79,227,212,106,64,148,36,15,205,249,62,124,199,91,146,67,199,241,146,246,42,36,195,227,97,135,195,221,14,165,219,242,235,135,203,183,215,151,236,76,25,1,145,56,106,220,236,225,156,112,33,87,181,208,44,138,245,164,242,29,23,135,58,120,245,208,98,122,219,61,185,29,91,178,8,36,175,136,52,220,116,248,126,253,114,249,211,213,231,223,174,145,55,239,235,243,215,19,33,60,119,27,86,100,204,6,201,132,196,98,79,238,87,245,147,64,194,200,19,54,5,63,40,70,237,49,146,155,87,156,84,205,183,187,79,240,253,171,123,73,200,93,187,216,243,229,234,72,102,225,145,99,12,140,71,27,201,242,226,248,57,62,142,116,119,236,51,88,133,227,220,118,28,43,39,100,122,12,152,114,64,182,70,32,176,125,179,97,235,68,157,221,80,49,107,232,139,128,156,104,70,93,181,248,86,109,6,104,208,99,96,64,202,201,114,144,111,194,73,130,128,118,84,230,166,124,138,141,227,62,219,65,245,206,136,25,101,5,156,23,54,227,127,237,156,102,246,49,102,1,168,244,152,212,0,251,4,82,79,233,2,176,88,225,226,53,96,240,119,113,224,240,151,178,225,0,10,153,168,67,245,239,103,172,236,44,209,85,24,20,46,24,85,183,83,3,55,89,6,254,4,137,75,210,216,238,26,67,223,254,89,247,167,205,228,124,217,74,47,4,62,116,12,39,123,240,190,75,199,192,20,252,172,67,118,77,18,240,73,237,25,192,62,13,50,114,65,91,110,75,50,100,106,183,112,73,41,34,132,189,184,7,202,224,211,20,85,76,120,147,231,233,198,17,0,122,166,186,153,218,24,143,221,83,108,137,70,175,155,188,84,16,48,91,171,105,76,140,120,141,147,41,248,175,45,232,234,27,198,36,93,229,229,194,73,114,12,135,20,114,134,13,140,173,197,149,23,201,228,158,86,119,205,130,33,232,3,66,188,136,38,124,143,71,116,210,225,157,123,87,194,42,102,2,129,63,75,25,233,42,207,212,52,55,27,122,74,229,87,247,135,53,236,88,199,51,211,49,219,65,138,254,7,0,141,19,173,171,55,199,42,85,103,138,174,254,161,172,96,221,94,211,247,98,169,76,220,173,116,189,210,248,235,253,52,127,86,175,4,84,42,11,56,204,13,99,167,232,167,98,148,77,124,236,125,16,6,59,164,3,150,25,224,185,209,181,126,204,165,37,28,30,125,16,118,189,207,29,198,199,85,184,207,95,126,187,190,136,95,127,119,21,193,73,18,167,145,118,255,163,69,79,207,247,5,201,66,249,231,246,43,234,205,79,241,63,153,154,103,85,31,104,170,16,73,49,55,195,34,167,132,75,223,82,10,241,18,245,150,210,222,7,34,83,207,144,113,187,206,162,35,184,125,60,231,246,144,2,24,210,202,118,47,236,112,246,55,93,202,188,51,99,25,137,115,13,17,26,191,31,194,121,110,42,233,192,156,145,119,189,63,218,204,171,103,183,242,117,254,216,207,116,211,137,54,50,111,38,196,164,222,252,209,238,203,107,193,32,123,140,23,215,146,147,150,144,149,255,114,51,255,245,214,104,130,155,119,214,239,121,142,106,81,73,113,30,163,167,91,225,150,157,29,219,26,42,34,87,251,247,171,38,151,126,184,75,142,112,47,1,254,74,140,16,2,169,89,101,154,0,72,223,224,176,18,149,117,57,11,68,211,243,132,60,1,246,187,241,25,20,65,82,8,160,138,59,49,242,212,44,160,127,98,253,17,14,221,12,182,56,49,4,165,54,33,42,56,78,27,16,201,137,176,157,235,38,88,242,70,197,145,121,21,200,94,119,115,210,20,129,204,225,29,176,38,1,227,200,114,53,227,180,24,22,98,125,118,128,167,172,10,134,101,113,120,59,253,33,235,168,181,226,88,114,223,39,248,63,108,10,159,48,183,136,116,51,20,124,15,17,7,190,16,91,214,122,203,131,160,136,118,99,138,16,255,72,151,169,171,245,172,198,238,213,185,56,229,175,219,4,33,51,33,75,200,240,173,70,77,183,218,20,207,193,138,235,207,127,151,199,98,144,163,214,185,142,162,234,150,39,83,40,193,120,128,147,139,53,20,70,144,67,188,115,214,66,8,10,82,34,39,166,203,131,209,1,203,96,43,143,178,218,22,195,174,58,39,243,77,230,130,111,247,93,14,246,97,87,29,64,149,234,1,217,112,152,74,29,138,105,57,96,239,1,208,147,120,136,196,207,236,212,45,240,49,124,43,239,7,111,9,3,85,2,239,177,237,234,111,234,160,236,129,217,162,171,234,203,54,253,222,87,63,59,133,187,33,23,38,8,86,81,226,229,246,234,231,60,211,205,189,1,140,28,147,245,11,30,165,201,250,20,30,37,170,98,200,40,240,16,63,250,60,240,68,170,167,141,0,24,37,218,148,27,22,127,214,187,78,201,101,181,132,208,89,84,102,60,218,124,142,131,127,245,136,34,45,157,117,244,88,61,63,116,187,141,90,227,217,201,191,103,231,54,41,85,177,122,112,161,82,134,40,250,5,81,150,249,30,203,192,185,67,126,137,145,43,250,26,239,201,192,179,8,48,171,3,73,168,255,100,55,31,159,34,72,37,138,210,178,142,122,60,222,209,148,23,239,246,162,27,144,253,55,149,132,201,146,93,9,66,62,226,106,101,86,81,128,76,111,59,73,228,180,243,8,104,55,49,193,37,165,57,4,185,103,9,8,222,233,140,211,175,81,197,96,124,197,86,130,56,207,155,86,77,14,100,219,70,122,157,159,180,88,101,213,11,205,200,170,146,38,79,4,6,241,79,140,251,37,78,122,237,147,153,81,219,196,219,179,227,45,13,173,59,149,214,95,106,33,82,189,68,243,184,68,25,229,229,175,68,25,22,77,195,112,101,250,246,238,206,107,196,203,84,65,115,32,9,23,214,169,228,211,35,251,250,103,151,216,11,177,49,192,208,20,89,26,117,244,169,157,150,191,70,183,40,127,59,137,1,69,231,93,157,145,109,37,103,227,182,121,48,173,96,198,29,76,206,7,193,13,184,203,185,201,236,166,1,112,82,148,72,101,67,7,210,244,142,144,65,245,120,50,193,48,61,2,241,206,179,94,30,29,0,174,68,200,215,228,59,172,189,139,92,210,132,167,130,100,211,90,223,167,19,181,79,254,186,178,135,237,218,41,206,217,121,114,98,26,14,174,250,135,154,65,138,38,11,47,129,148,69,23,31,222,231,101,8,39,130,11,235,12,141,227,6,45,145,173,214,18,88,123,2,211,9,79,209,145,175,23,74,52,108,38,138,201,141,43,224,21,69,255,100,70,223,242,24,225,53,8,154,99,91,231,137,65,158,233,240,124,250,12,27,78,149,24,243,49,84,7,100,174,121,83,55,158,70,164,88,160,220,192,121,170,60,45,216,251,19,92,28,69,174,41,146,148,213,157,41,207,69,145,114,165,206,38,181,249,253,174,27,178,247,112,93,52,29,103,197,151,22,45,187,174,5,120,180,19,210,93,41,124,245,189,160,233,103,144,94,15,94,228,100,21,56,147,69,130,237,154,66,84,89,22,237,157,43,145,124,212,50,126,155,94,137,18,236,35,101,162,8,7,207,250,129,120,30,51,38,63,36,247,104,205,136,57,226,85,1,130,33,103,92,53,231,172,188,40,106,62,140,205,138,22,25,86,71,124,196,28,174,220,185,175,129,17,229,74,28,168,140,111,226,37,150,181,224,58,212,188,156,232,225,83,171,227,225,200,62,97,9,152,54,132,114,225,216,115,122,134,170,126,63,137,255,199,135,37,33,157,101,225,105,118,119,156,22,220,155,74,205,177,34,20,252,142,3,25,105,28,112,169,148,250,253,137,108,54,185,128,100,113,0,234,141,236,212,101,183,17,71,200,79,246,156,82,144,179,58,56,252,63,49,45,136,25,52,74,25,167,3,130,44,119,120,111,87,137,244,28,249,125,115,33,55,20,150,232,61,149,166,4,229,204,224,118,27,123,78,219,64,0,243,124,69,210,174,77,154,124,193,22,114,232,71,83,226,41,190,31,137,119,34,25,229,184,7,181,29,242,136,119,40,244,205,83,202,45,45,193,175,187,62,166,121,113,155,83,47,79,170,98,20,145,181,12,176,56,4,29,154,151,171,24,5,23,141,125,124,83,173,129,129,93,6,144,184,209,114,65,35,106,189,50,102,15,32,203,4,130,158,112,58,86,100,177,237,21,239,169,188,83,186,56,15,68,47,147,27,228,146,61,170,207,248,101,114,165,113,15,189,151,150,200,66,23,86,26,161,117,10,144,12,82,238,181,249,103,139,113,147,4,139,125,181,115,245,4,237,17,167,88,5,95,167,11,87,53,92,28,164,244,197,29,84,73,181,118,53,4,246,184,248,123,227,242,19,116,71,225,90,164,71,215,96,235,50,223,82,220,106,54,11,212,59,91,218,240,92,24,42,246,245,253,229,151,203,84,62,80,75,169,82,157,164,164,222,140,106,1,200,238,184,65,141,233,100,62,171,237,224,166,58,162,4,227,104,148,192,234,209,226,147,150,61,16,88,221,113,105,160,36,125,224,44,93,39,162,37,249,176,133,26,60,14,109,209,141,237,5,34,104,104,103,242,72,204,83,238,193,111,235,214,182,150,48,86,55,13,163,61,188,218,168,155,38,55,92,39,186,89,167,12,125,170,190,69,127,160,220,252,173,157,90,241,139,188,124,113,43,16,120,53,121,207,45,128,227,36,226,148,163,139,250,101,82,125,154,19,141,138,11,124,172,58,219,188,247,182,243,246,10,255,108,128,33,112,171,21,209,184,42,218,116,226,137,123,52,5,62,130,13,132,8,37,129,107,189,81,101,13,160,45,151,33,109,111,192,118,14,246,179,132,41,157,216,76,100,4,159,106,118,16,105,38,25,215,242,66,236,227,107,98,145,188,117,169,124,54,32,89,156,2,140,138,192,63,124,18,214,128,148,173,183,171,30,11,82,171,181,72,225,137,160,208,176,70,124,140,195,34,147,218,150,211,168,47,11,2,190,213,193,180,97,207,255,58,43,156,66,59,216,142,188,85,65,122,244,204,67,81,102,224,179,199,73,44,57,204,143,159,216,204,107,251,224,209,72,90,31,176,14,109,228,173,23,133,216,212,209,215,143,167,168,141,137,188,6,193,248,66,66,83,251,243,173,243,189,163,180,108,183,84,17,160,15,67,3,198,234,74,195,167,100,80,145,106,192,48,155,170,89,229,207,132,38,189,128,39,253,4,205,128,139,184,139,135,174,46,255,125,186,8,178,97,249,18,236,251,196,77,34,180,1,203,89,108,118,81,186,156,59,121,240,118,199,44,245,148,139,195,91,21,224,209,209,171,255,228,223,136,90,207,17,222,5,202,141,97,33,127,91,102,148,220,41,79,41,37,59,23,51,139,117,203,101,47,136,209,26,71,149,151,165,205,196,180,207,19,22,221,208,192,92,58,196,186,38,21,108,201,105,174,1,168,156,173,56,56,14,104,44,23,44,8,85,163,134,239,236,160,83,86,84,53,215,164,202,69,134,36,135,219,18,49,92,79,224,142,146,114,78,176,46,64,132,208,100,128,120,28,150,59,15,218,36,216,5,67,70,251,174,14,175,2,47,71,43,156,251,34,98,6,214,136,253,250,199,189,198,215,238,107,15,22,128,192,205,100,58,136,36,223,28,239,210,213,249,34,21,194,138,49,57,72,148,60,150,84,113,78,233,90,68,104,161,188,210,144,16,234,231,130,205,74,207,143,122,175,211,117,43,185,65,79,202,204,114,193,46,126,149,242,35,225,142,252,237,38,141,222,123,196,140,150,209,237,108,196,202,67,181,82,247,122,132,176,65,170,156,156,35,174,169,215,141,79,205,158,245,45,91,61,106,246,88,158,188,228,70,37,15,146,195,51,103,251,161,140,159,123,255,48,47,163,54,102,208,112,168,173,211,121,8,159,195,162,30,94,180,241,54,99,202,38,19,26,0,39,216,246,152,228,244,67,2,200,38,162,240,94,54,220,254,255,99,165,241,79,222,209,11,118,38,218,66,211,11,179,89,26,228,65,172,78,75,171,146,51,170,24,132,129,103,184,24,183,120,49,192,240,243,16,35,120,182,135,108,150,161,36,35,250,28,161,191,212,108,153,221,247,16,140,119,206,57,139,112,155,49,14,192,253,205,195,161,28,103,245,129,159,74,56,131,146,57,50,81,130,36,147,6,112,100,182,148,68,212,246,7,0,74,130,230,71,58,142,157,153,91,37,233,31,5,103,84,160,248,208,44,22,169,95,249,246,45,70,48,157,96,35,141,2,125,196,203,80,109,33,204,188,142,5,137,43,211,185,196,205,71,50,32,233,74,47,118,49,181,99,10,222,81,234,130,113,199,135,228,158,135,195,156,152,223,242,40,155,24,107,145,169,111,35,82,45,96,170,78,71,64,241,36,73,103,244,218,19,146,149,32,96,188,213,225,36,100,179,213,119,233,183,197,135,231,236,175,191,114,60,171,228,52,53,10,105,106,41,235,120,128,102,238,125,136,46,152,57,75,60,83,204,226,36,211,0,69,254,190,98,136,239,199,38,183,23,50,215,226,252,143,92,22,135,52,223,31,28,75,167,11,45,244,78,240,114,164,144,213,155,214,114,191,24,235,113,154,100,239,217,187,84,88,120,100,77,59,35,69,56,202,218,233,41,42,113,214,113,167,238,119,221,197,168,221,85,13,72,209,31,151,178,48,174,150,156,110,40,183,5,50,188,43,218,1,131,116,78,252,176,88,137,3,58,50,123,122,241,221,141,233,23,193,179,81,12,164,130,82,215,184,173,167,54,183,87,218,26,33,77,238,61,252,133,254,99,103,138,38,0,218,197,15,195,206,163,196,128,73,198,181,187,83,48,99,137,164,35,43,158,60,200,0,162,98,255,165,148,240,176,210,64,137,97,162,77,248,1,249,247,156,82,158,170,250,255,118,175,227,223,55,59,190,53,33,89,76,110,234,106,246,171,137,216,62,174,123,147,20,153,105,168,10,89,64,206,251,219,249,52,157,72,59,52,108,239,218,28,204,64,206,115,114,11,21,30,63,242,119,161,60,249,200,72,123,169,73,229,89,51,211,142,239,52,201,53,88,129,165,56,163,71,3,137,148,41,225,35,166,168,193,3,115,216,170,100,91,106,30,5,174,190,235,163,170,142,183,152,155,64,16,80,238,6,99,34,116,75,189,186,67,221,154,160,139,116,41,19,129,192,91,124,243,249,147,49,64,251,159,112,209,200,6,111,7,81,43,147,58,199,252,185,145,3,59,152,154,78,146,96,47,214,1,152,230,79,158,253,238,50,158,110,54,139,178,34,160,155,148,99,228,136,17,75,212,87,78,128,227,113,17,103,77,151,237,102,209,11,63,111,205,163,233,164,8,17,74,125,106,89,195,36,23,136,254,118,174,180,46,1,76,234,15,123,74,189,110,41,89,132,144,71,158,93,130,10,255,250,225,242,211,205,239,184,178,95,166,224,96,42,233,168,138,86,254,106,200,80,168,80,10,221,122,54,103,35,166,30,24,51,184,11,59,112,183,74,90,251,125,229,195,86,64,8,20,13,16,133,164,37,84,210,120,52,88,209,159,112,122,142,96,190,83,90,221,196,169,228,147,13,5,86,226,47,235,234,162,200,156,224,164,34,227,229,79,228,228,7,163,40,87,71,138,243,161,240,209,210,100,22,225,247,65,146,197,9,152,212,110,138,246,30,231,72,39,165,35,198,98,20,228,36,142,105,117,194,226,139,236,204,254,221,69,250,96,107,11,11,118,167,244,163,71,23,127,255,148,99,180,170,123,77,96,206,240,101,60,168,142,81,246,87,248,137,147,175,170,203,140,169,66,149,50,150,132,40,116,197,232,176,223,211,72,12,100,22,122,59,198,212,7,229,115,73,163,92,16,178,18,17,4,210,60,41,212,136,9,30,229,168,59,154,39,239,114,131,117,182,117,72,140,228,98,97,49,91,138,62,104,86,139,251,109,93,207,151,101,158,32,34,55,51,82,155,64,53,209,87,50,23,180,7,6,61,141,99,42,49,177,30,17,122,71,155,109,136,221,53,22,134,219,211,237,22,117,121,248,93,91,122,51,67,234,208,82,182,154,173,137,155,212,240,137,7,23,48,139,101,124,251,246,245,219,171,119,234,150,193,160,38,241,95,99,230,211,38,74,119,79,29,231,206,207,22,117,255,152,194,82,165,55,159,106,111,40,89,166,227,118,191,219,120,89,233,176,250,79,190,39,32,239,4,212,20,221,214,195,14,229,113,110,66,199,166,6,116,128,93,37,86,29,209,223,60,236,188,26,226,125,105,36,162,225,169,44,218,192,222,21,211,238,18,177,80,154,162,195,235,144,229,48,138,239,222,121,54,196,192,134,191,17,225,75,239,137,122,38,241,113,19,195,214,124,191,85,8,243,39,192,243,28,171,159,200,244,22,185,213,233,115,244,241,230,167,123,4,82,196,34,87,122,81,220,6,99,124,236,150,128,224,70,135,148,119,116,45,25,243,28,81,23,125,138,193,148,233,67,66,214,156,157,58,47,74,120,209,247,83,199,90,192,154,241,150,92,231,87,87,185,148,108,110,107,53,188,138,129,37,229,13,122,124,142,89,127,255,160,125,231,85,201,39,94,220,100,82,220,3,16,155,133,3,77,139,21,156,170,142,110,23,117,127,208,175,106,246,236,249,219,63,196,248,223,43,202,246,127,124,251,100,188,89,22,26,247,201,132,51,0,204,52,248,230,101,188,227,33,125,150,113,42,71,242,215,241,160,144,189,131,39,21,123,157,127,216,191,155,31,215,212,53,233,70,70,175,24,181,221,99,173,151,102,164,214,186,91,9,54,159,44,186,22,140,12,5,80,13,46,30,173,175,72,163,38,37,103,20,88,22,152,172,25,55,152,210,3,26,81,208,230,97,80,114,162,169,81,122,39,187,40,20,74,95,116,78,69,117,225,226,72,181,29,205,113,192,146,136,162,61,170,200,145,85,39,78,36,134,196,154,215,185,20,2,244,205,249,196,35,243,41,243,54,238,141,199,188,0,15,29,68,211,103,251,135,210,220,48,79,204,239,216,209,45,186,204,135,92,240,43,108,7,135,127,137,30,117,26,228,175,236,5,56,110,155,246,189,104,87,11,247,59,217,199,214,23,29,58,225,65,37,190,142,156,192,201,60,75,216,96,232,29,146,191,12,203,220,180,97,177,10,219,246,56,117,3,7,186,121,136,9,55,249,72,95,169,223,145,131,86,216,210,88,76,83,8,138,77,2,153,1,111,93,70,169,37,189,176,124,135,200,207,241,76,190,124,49,50,249,25,83,242,227,229,245,141,223,228,88,11,174,235,250,49,43,186,100,57,235,152,192,12,123,50,239,118,152,70,148,7,161,170,7,36,206,168,95,84,239,70,132,2,7,216,195,121,205,26,57,165,226,125,76,168,199,226,202,1,162,186,60,123,220,20,3,111,110,198,79,153,166,1,72,36,50,18,196,183,254,193,254,181,110,152,12,25,216,134,192,88,149,52,39,141,163,164,88,42,98,63,6,124,194,233,241,53,2,206,124,199,234,15,142,104,30,168,217,230,54,220,187,58,40,211,92,251,74,217,232,88,68,67,138,45,191,58,25,14,215,255,200,18,132,189,241,14,253,216,96,158,102,42,49,39,90,46,96,133,201,15,18,207,16,146,87,48,249,240,106,177,58,103,7,110,173,39,74,109,163,244,56,58,157,82,67,60,157,222,239,225,97,13,107,157,212,208,237,249,28,51,170,184,130,153,180,19,14,138,27,89,30,233,220,144,59,146,239,119,128,35,211,197,212,150,225,178,234,183,151,89,6,12,142,23,78,238,204,231,123,182,94,245,132,205,76,79,77,142,37,30,84,187,124,43,199,191,98,213,34,18,33,136,226,7,156,188,164,150,121,27,58,148,226,119,96,77,209,217,225,157,229,99,220,204,208,56,138,128,57,149,52,237,233,227,213,167,203,19,158,236,81,81,178,128,73,56,3,236,69,169,67,207,163,99,169,180,91,14,20,74,165,72,103,49,21,189,148,182,102,95,167,134,182,220,123,121,185,121,88,53,61,185,166,34,184,81,234,175,24,163,235,166,40,105,93,112,212,123,159,87,162,211,28,141,138,188,41,44,44,221,80,25,65,37,71,159,53,106,118,81,128,16,0,12,75,12,89,140,188,68,166,69,158,188,182,175,11,155,146,238,145,198,116,136,39,187,89,167,33,34,229,64,70,143,121,196,201,21,117,86,56,216,211,66,108,166,228,0,229,95,95,107,19,221,207,40,41,172,99,124,135,143,23,206,229,199,234,155,15,224,216,137,195,95,233,54,120,195,88,254,55,165,138,59,50,97,17,67,143,234,30,192,153,93,105,40,21,65,163,135,18,205,50,105,246,22,229,10,23,37,167,146,83,185,23,79,184,243,42,63,43,137,118,207,110,114,245,183,161,160,135,56,178,72,79,8,72,68,63,125,85,184,233,9,107,147,71,117,74,233,21,117,178,152,49,147,68,235,150,154,240,9,237,66,129,23,29,133,20,60,172,89,218,245,186,185,149,72,208,59,129,115,110,152,23,206,109,201,238,153,31,9,223,237,120,6,17,121,241,229,233,224,49,152,193,189,137,198,255,247,87,31,79,55,70,30,6,9,199,161,69,214,75,251,232,109,60,59,37,14,222,140,16,148,27,244,241,14,166,19,219,157,149,248,216,23,148,171,108,158,211,92,34,51,42,120,249,164,107,127,245,50,73,169,16,77,213,13,142,39,45,36,73,133,71,85,206,99,224,52,20,35,28,4,134,209,114,99,21,6,155,33,111,230,185,56,176,60,83,16,81,205,237,61,17,187,67,97,142,185,84,179,94,127,95,123,137,134,26,70,183,80,158,137,112,192,18,198,65,100,184,157,127,66,94,236,235,235,94,218,20,156,1,182,68,231,11,226,33,61,169,90,29,82,21,44,178,127,64,51,228,243,97,51,227,75,26,112,199,25,60,192,236,1,167,158,140,150,119,233,199,80,119,105,245,52,23,4,213,120,224,251,204,197,251,129,102,233,124,161,135,142,97,221,160,66,216,10,205,214,8,41,129,157,241,44,53,179,80,236,253,147,51,31,119,172,128,18,223,60,162,70,13,206,195,106,117,63,219,86,34,13,153,234,230,228,116,0,94,41,13,110,253,206,164,66,168,23,164,149,165,230,159,201,149,9,245,136,196,184,122,249,252,25,47,190,47,161,70,169,247,21,0,130,197,115,60,189,147,114,230,206,15,94,35,129,235,132,200,63,123,108,119,104,170,64,185,62,100,226,116,36,27,92,150,105,50,248,177,236,132,144,106,48,25,30,81,21,46,119,191,203,165,34,3,154,35,143,146,52,228,211,235,243,45,228,13,238,57,240,90,115,80,222,36,88,82,49,51,174,136,96,242,252,77,218,26,51,64,221,134,239,127,225,175,113,37,87,59,251,194,183,95,81,79,171,186,174,38,147,30,129,235,220,148,217,204,17,178,172,242,188,191,84,50,97,141,33,16,177,64,108,114,251,110,139,241,156,41,52,100,161,205,204,162,157,246,118,51,114,222,21,80,127,15,220,85,180,56,12,81,63,99,238,11,29,195,157,134,28,110,132,117,15,176,130,89,189,247,104,92,12,50,252,196,254,202,8,104,92,82,120,117,67,249,132,52,198,95,162,251,172,26,206,198,159,125,79,93,34,86,196,81,7,173,125,242,21,46,252,123,198,189,68,111,150,111,127,49,28,249,155,168,17,22,133,49,113,20,197,73,101,123,53,232,92,149,140,50,163,248,34,51,231,0,52,182,137,44,224,254,68,223,217,171,223,182,176,7,78,169,172,46,87,206,28,93,141,123,179,38,147,15,202,178,217,214,204,134,46,15,254,18,13,218,169,106,204,225,50,206,102,175,248,202,239,131,62,226,216,193,73,52,126,62,87,205,187,162,26,249,71,244,179,76,224,142,247,231,240,47,0,251,21,204,4,137,156,86,246,149,69,0,23,128,45,104,55,61,190,101,202,147,254,113,187,45,171,170,32,100,77,157,110,163,97,172,10,104,216,127,119,194,248,218,163,70,209,193,197,80,228,12,209,249,115,167,49,106,100,98,122,245,30,213,7,53,136,120,65,71,60,232,166,35,63,223,223,231,163,193,86,216,87,35,68,88,118,168,251,234,155,157,113,59,161,245,159,243,85,213,172,235,35,174,27,81,164,57,75,175,103,42,71,149,44,45,152,15,201,208,225,15,202,165,219,101,216,181,5,128,36,81,0,54,77,18,69,98,39,116,232,209,254,239,54,166,12,227,192,45,204,138,45,120,192,189,228,27,201,141,243,92,150,42,181,151,207,18,6,131,151,163,112,77,252,124,48,120,167,64,57,35,17,233,106,141,134,97,50,70,247,124,227,41,107,29,164,181,189,74,166,74,94,235,45,64,3,111,247,74,6,237,169,62,151,91,22,6,210,20,144,251,121,122,158,168,234,49,241,212,151,252,20,202,186,114,96,185,207,240,241,169,106,169,102,118,18,194,119,156,206,29,155,10,15,157,253,246,105,198,225,110,123,204,129,228,84,225,114,113,100,94,244,18,76,45,36,216,2,157,243,48,17,47,95,56,181,237,34,48,69,126,213,40,8,63,213,5,34,60,104,34,142,205,50,129,45,221,110,139,10,140,185,17,213,147,163,169,148,103,119,252,213,208,224,62,206,89,65,94,254,111,237,160,11,107,200,248,170,90,236,197,204,15,6,103,118,222,181,93,70,111,140,38,204,151,156,30,155,195,22,251,64,224,163,17,130,121,13,229,224,208,217,212,246,213,106,148,44,63,208,82,168,113,123,97,145,184,81,86,23,153,209,131,230,176,240,37,215,123,163,223,154,31,166,146,241,134,180,141,190,170,225,123,206,114,113,50,232,35,166,228,176,88,34,7,217,115,144,94,121,205,220,88,58,182,98,47,152,2,11,128,98,43,71,113,252,160,112,137,70,70,201,62,18,203,80,211,219,146,182,79,189,215,153,5,0,200,194,139,240,34,47,247,217,223,86,208,120,216,4,109,180,45,40,198,127,30,233,160,59,66,112,230,143,169,197,100,148,190,78,177,139,96,170,154,202,224,111,235,45,48,225,85,240,188,130,195,186,152,3,57,175,157,159,186,236,111,113,206,34,148,151,163,79,1,61,251,157,187,145,69,161,94,166,167,201,196,145,156,150,148,200,88,80,103,7,204,222,81,36,151,171,190,129,110,252,80,205,27,87,20,55,152,46,94,39,94,143,61,145,99,139,240,100,108,247,7,16,109,1,46,133,224,173,152,39,18,92,75,233,75,38,28,111,198,194,139,124,190,43,89,166,251,82,139,66,160,199,240,224,137,164,144,61,122,34,92,99,246,202,135,250,21,34,30,15,7,130,38,208,167,172,70,118,44,215,17,2,129,228,189,40,105,214,164,3,236,70,87,156,143,82,153,36,82,167,161,41,125,21,39,113,96,18,35,210,13,44,33,177,226,230,125,53,76,246,217,98,166,189,189,110,181,54,79,7,80,208,120,78,251,62,251,56,138,239,184,35,31,3,199,238,45,44,218,23,240,22,105,71,37,190,54,7,68,164,50,2,224,60,16,165,65,10,26,8,154,117,20,98,228,176,188,143,73,140,45,35,22,8,240,107,253,144,116,241,254,96,135,159,145,138,12,139,134,102,201,8,161,129,153,141,103,226,30,151,17,81,135,32,136,53,49,40,106,231,116,51,171,60,173,106,95,31,103,16,133,52,136,49,186,65,139,12,235,123,229,136,118,118,134,225,89,202,170,182,138,124,25,246,206,15,125,184,188,190,62,109,184,82,137,152,131,123,185,31,252,198,199,207,95,46,149,45,246,103,44,2,40,114,185,136,181,145,25,211,214,148,170,250,1,78,32,188,151,45,156,41,177,214,30,214,176,125,212,115,225,3,240,170,156,141,101,238,217,82,211,198,14,16,240,5,145,88,206,136,68,122,155,141,127,61,80,105,218,117,128,254,53,186,57,33,180,84,171,7,52,136,180,153,72,229,219,223,102,145,240,78,5,19,135,234,202,48,103,165,228,33,117,140,52,91,22,76,164,23,158,110,62,37,86,47,95,60,39,87,35,83,35,141,234,250,228,96,226,112,52,53,38,69,173,210,88,170,238,76,83,21,165,10,13,50,195,141,74,247,39,209,28,11,239,42,106,161,2,167,157,253,15,239,5,246,33,213,62,110,44,239,211,49,16,139,254,234,237,245,242,204,22,254,236,60,125,34,94,13,163,45,86,143,42,82,39,118,85,79,163,73,82,237,56,19,69,162,38,156,69,84,46,228,229,123,209,147,195,143,238,101,140,70,61,206,204,95,186,193,123,0,13,242,217,49,103,216,18,133,30,152,143,43,247,157,147,59,228,166,140,206,78,74,121,201,90,129,77,194,158,236,243,167,203,114,190,241,244,196,4,166,156,136,30,141,202,75,163,36,188,142,218,215,236,193,22,24,81,66,195,62,67,202,89,127,218,50,146,43,107,239,126,1,147,98,94,140,196,56,193,131,24,254,132,1,195,167,14,172,151,14,16,160,234,197,156,72,115,188,214,77,159,65,10,127,103,134,2,215,19,85,71,175,107,138,209,20,213,80,88,252,12,86,96,255,142,69,26,32,152,68,93,203,46,90,56,163,7,74,105,85,199,44,35,243,209,201,138,232,152,126,172,151,191,226,251,154,191,164,189,4,81,87,26,189,121,40,120,153,70,108,217,172,85,112,123,249,162,172,40,170,131,38,122,80,227,107,108,29,73,3,1,92,53,211,95,5,213,1,128,227,246,198,226,148,84,169,207,31,240,16,33,123,113,170,42,237,68,143,120,47,184,17,168,79,34,162,74,84,84,153,220,94,94,189,183,96,229,115,10,144,83,234,204,51,255,145,216,220,123,41,108,135,192,251,16,231,242,136,166,249,154,187,109,95,251,129,94,55,171,199,217,31,187,135,92,117,36,171,218,73,173,171,233,239,173,27,165,241,42,231,118,232,162,99,214,103,77,68,6,56,108,111,132,5,185,244,195,142,14,8,247,72,102,245,132,174,203,184,38,111,74,75,7,124,14,231,105,62,85,4,51,197,140,89,254,115,230,165,222,3,155,247,58,76,168,215,4,11,180,143,56,57,112,189,184,99,186,98,169,78,103,179,122,9,42,16,18,209,191,41,195,187,228,16,77,174,62,41,135,163,71,24,81,153,30,28,35,162,147,231,203,182,237,253,68,59,85,29,243,68,76,224,73,93,30,103,247,211,221,206,167,39,221,175,25,159,118,146,233,25,217,103,238,16,38,140,124,110,55,247,12,82,217,198,127,56,7,108,229,109,222,89,125,83,91,157,64,187,57,175,135,142,178,138,93,35,31,244,180,206,58,31,75,79,234,249,242,152,84,166,173,219,145,88,161,40,159,41,173,59,106,23,210,68,70,4,36,69,100,64,30,230,39,53,234,138,85,212,3,90,11,207,109,3,51,103,161,143,231,49,171,231,217,126,147,169,143,165,30,221,231,31,159,204,12,224,19,182,103,111,254,117,21,75,176,99,224,99,78,5,153,56,155,36,216,91,100,158,136,146,35,228,96,188,45,188,225,251,232,35,90,180,127,213,68,232,77,25,212,214,244,181,60,208,245,220,107,4,114,108,89,97,132,28,225,219,120,86,80,140,136,44,82,118,56,181,66,138,29,44,148,169,209,169,59,236,160,66,183,183,64,58,114,219,103,29,188,110,91,135,175,172,107,115,84,189,72,10,191,28,172,127,72,129,166,102,196,232,79,41,50,74,175,130,171,183,74,95,121,53,155,45,188,153,197,155,29,234,58,138,229,9,12,85,81,196,8,75,40,191,155,206,234,23,50,117,79,39,113,91,115,58,143,217,108,83,207,92,58,40,240,87,18,79,13,212,70,65,163,55,134,243,69,121,239,217,202,39,143,34,153,218,9,111,222,45,234,77,240,57,103,192,106,201,237,117,103,231,199,123,45,30,160,49,72,234,227,65,241,162,233,31,118,125,130,25,169,181,234,254,254,245,129,21,84,117,82,129,187,170,82,169,106,29,84,18,229,192,248,62,91,182,212,202,228,28,154,180,129,148,194,169,215,101,202,158,37,182,168,145,48,148,142,43,23,147,109,100,75,196,9,163,196,175,194,56,246,78,38,82,43,167,184,166,234,163,142,9,230,220,129,8,253,164,245,202,201,157,219,221,88,89,101,107,110,126,254,54,243,108,190,45,230,9,92,229,73,86,166,217,110,208,39,158,6,22,23,117,167,128,29,108,27,12,12,161,151,68,6,134,52,166,179,96,173,72,72,74,154,6,78,108,173,171,153,192,113,38,57,188,151,151,74,196,137,117,216,163,243,191,28,73,120,98,232,151,15,24,146,190,58,36,245,23,169,142,207,17,65,162,71,133,236,196,60,78,102,158,96,195,47,71,12,157,141,40,107,80,65,130,29,203,234,17,132,221,105,24,17,166,145,78,130,30,3,104,210,106,159,202,222,182,132,36,227,135,99,99,186,209,51,110,205,38,133,222,190,5,76,9,173,163,213,72,163,183,35,54,243,42,6,171,3,200,239,73,54,69,58,26,81,88,140,120,52,241,232,29,189,63,113,102,23,110,168,42,107,9,244,148,148,167,99,128,143,232,67,114,129,3,122,82,81,42,31,194,239,211,174,22,100,200,218,123,176,181,219,172,52,33,132,159,226,122,107,122,125,233,66,106,198,155,28,191,188,2,172,112,147,234,243,112,176,89,26,80,248,93,244,35,177,20,93,101,13,33,132,2,207,29,49,133,139,239,115,255,18,37,74,35,232,201,207,21,61,71,195,65,183,145,38,156,21,139,184,181,53,172,146,111,105,39,224,211,108,118,188,43,149,166,254,166,78,205,195,81,118,211,73,57,236,145,50,135,193,229,230,128,221,97,54,112,88,130,121,219,174,48,75,116,183,65,117,183,255,55,198,170,21,157,70,207,181,26,221,68,53,199,228,244,39,245,70,207,126,97,62,63,46,254,214,187,64,186,150,198,169,142,185,106,105,186,144,109,12,154,38,211,121,210,75,69,152,128,175,245,147,24,233,216,170,117,130,57,204,165,133,79,163,118,142,156,212,212,37,56,99,148,244,206,211,224,48,221,86,94,92,133,42,51,191,110,145,38,113,230,113,219,77,76,162,141,131,231,115,5,15,24,63,162,137,173,13,184,26,149,35,62,242,71,161,67,88,215,129,165,151,96,174,61,37,130,204,115,86,33,107,98,150,39,183,31,72,125,133,65,191,56,77,63,55,223,80,239,34,41,153,29,3,240,176,155,24,208,194,242,53,132,248,91,215,153,126,189,152,190,155,211,142,121,52,12,78,30,46,26,195,190,210,220,82,115,218,174,137,41,249,163,197,212,2,50,86,177,123,42,252,214,207,209,17,172,143,165,214,216,2,112,21,186,77,77,163,241,240,111,189,120,180,82,48,63,185,91,177,145,123,227,6,46,67,185,63,255,118,254,46,116,6,123,46,236,196,156,21,207,124,81,164,236,115,5,17,222,138,40,93,204,87,179,175,46,28,38,99,154,191,238,68,122,132,204,193,93,189,100,234,253,108,20,155,155,35,91,186,140,17,9,226,240,51,142,221,168,160,153,61,105,39,128,211,182,49,237,150,200,147,39,55,79,109,60,46,215,104,84,5,104,136,252,134,96,197,23,206,70,219,161,150,94,40,79,66,41,45,72,70,77,95,112,80,184,219,105,8,169,31,99,243,9,118,171,102,59,211,188,123,239,29,196,67,181,72,2,166,98,155,54,235,126,133,130,17,85,15,159,160,219,245,142,223,76,177,168,26,58,188,186,11,135,13,192,75,220,107,183,113,104,163,156,118,39,57,242,242,11,3,227,121,100,146,81,25,65,157,33,200,113,122,103,139,226,89,127,42,198,202,175,19,6,208,156,99,89,116,141,172,43,251,147,21,160,203,9,114,105,115,146,233,85,80,235,86,154,112,193,227,147,70,181,165,144,224,63,30,148,16,115,13,224,246,154,138,207,122,2,182,143,74,40,156,215,159,153,82,220,248,70,235,178,158,161,149,58,202,24,97,147,10,216,160,167,182,168,163,160,127,233,73,117,40,111,222,193,74,131,206,158,131,75,19,225,198,199,166,103,181,150,85,110,180,195,58,103,144,35,226,52,75,118,242,229,242,93,214,172,17,51,208,27,171,164,33,41,215,13,141,171,51,153,189,86,19,167,56,239,252,32,57,99,37,91,109,68,20,233,109,66,34,79,142,94,33,118,108,97,96,162,5,204,12,204,239,11,120,15,249,201,14,30,95,172,46,98,165,196,151,239,106,122,201,200,142,72,62,80,121,229,184,86,72,215,225,80,39,157,142,56,148,62,61,215,169,17,139,54,176,185,45,64,95,152,142,105,204,177,132,42,189,77,22,234,172,176,86,208,4,97,23,15,77,70,242,204,249,27,121,189,38,159,160,211,185,95,85,3,197,156,199,163,233,72,39,215,95,140,155,106,123,113,125,223,171,251,13,254,128,157,207,8,201,188,150,92,202,244,116,82,155,15,208,149,93,193,154,99,24,226,6,84,5,237,8,219,216,209,132,128,199,36,71,28,222,127,190,218,221,245,175,61,117,153,186,69,213,208,29,109,215,199,175,105,7,253,78,144,41,240,197,173,80,145,10,244,92,227,3,154,229,111,177,137,58,241,136,163,211,20,201,125,159,4,175,103,66,58,100,192,67,149,79,129,113,114,40,13,138,238,50,166,110,242,30,139,6,14,203,162,31,197,75,72,176,115,75,64,218,26,57,186,244,182,22,114,166,57,212,186,135,86,4,160,136,118,95,173,18,11,220,235,194,27,64,133,124,19,74,226,136,48,116,193,62,119,94,38,200,252,215,117,167,38,9,247,128,241,254,240,250,8,139,107,248,162,219,85,221,59,99,82,94,236,226,77,5,77,33,186,10,8,71,142,37,78,143,10,168,48,80,87,192,47,218,109,254,161,56,219,30,139,27,238,235,145,156,185,117,72,75,87,207,219,135,77,19,32,227,175,60,215,95,170,187,187,130,141,176,108,101,170,18,175,177,237,214,55,122,48,202,192,88,32,179,110,194,239,61,76,193,4,189,71,145,121,184,219,103,32,53,195,31,79,83,135,99,157,242,186,120,172,127,108,168,34,50,182,44,73,40,183,242,31,30,204,144,78,144,5,233,121,103,138,223,254,246,13,135,107,136,54,110,150,138,167,242,120,101,139,60,155,77,116,34,18,228,118,228,122,246,123,115,93,205,107,158,252,227,234,211,47,147,183,159,222,77,254,235,183,203,203,79,147,207,63,79,222,95,190,253,114,115,125,148,252,113,184,3,249,80,225,64,7,121,28,199,74,81,193,122,195,231,170,17,159,34,169,155,56,186,22,169,229,231,15,83,12,152,201,212,98,209,74,165,168,115,31,29,241,238,251,221,71,202,164,219,173,88,160,202,239,21,163,78,76,87,34,132,157,122,239,93,42,184,210,48,139,9,162,42,151,35,247,110,218,131,136,31,77,236,92,176,24,58,130,229,139,197,192,232,208,98,211,73,80,43,15,163,186,181,233,36,184,208,111,242,108,104,217,116,17,6,138,224,199,131,160,56,207,104,47,246,165,255,26,192,145,252,160,218,54,76,111,232,33,199,185,84,59,196,236,26,64,206,168,188,198,29,55,203,162,56,152,28,64,144,237,7,145,58,74,157,234,206,83,147,72,226,16,22,162,237,164,144,194,186,176,18,32,31,130,14,173,157,17,6,147,156,209,86,212,140,49,138,172,44,55,137,77,60,227,184,125,54,67,217,147,32,105,54,69,116,208,189,54,34,7,155,202,35,61,39,120,85,128,138,169,20,90,74,152,125,220,243,199,147,152,18,201,221,242,98,27,191,244,177,250,195,116,203,1,100,87,85,229,104,224,200,99,144,136,46,153,142,25,47,205,19,209,22,192,98,115,69,76,186,152,72,194,164,27,80,100,76,51,185,5,179,16,155,186,14,200,175,131,141,92,213,38,63,27,25,8,130,52,58,158,211,235,203,55,199,171,151,240,174,145,47,194,209,178,211,158,236,49,46,160,12,246,62,129,197,92,241,247,53,220,158,215,112,146,11,207,73,100,37,41,239,189,247,192,113,36,235,185,111,18,33,199,38,255,30,185,179,62,119,98,177,39,200,255,30,116,51,250,30,166,131,142,79,188,247,65,213,170,80,229,39,40,109,110,151,12,56,255,145,44,39,255,37,173,18,233,61,28,210,176,106,229,244,70,119,202,132,221,63,168,41,142,184,189,152,79,124,218,196,120,170,52,38,113,211,166,56,4,55,67,171,82,217,68,231,132,102,170,189,135,142,14,206,23,101,97,66,18,30,86,85,84,29,249,200,222,116,42,239,45,26,209,27,37,79,225,248,245,224,170,5,206,236,54,163,56,99,160,201,203,23,246,179,156,207,253,196,50,45,161,99,71,57,225,152,67,14,20,79,12,73,45,24,62,178,75,123,148,235,255,7,209,196,184,30,253,106,124,133,122,144,24,184,46,124,4,31,91,172,182,254,219,159,188,188,58,157,56,145,179,103,129,155,62,142,9,119,233,236,185,37,76,157,151,200,90,138,237,179,89,231,94,165,145,102,2,158,23,252,209,180,254,112,152,202,171,74,119,197,120,17,47,236,117,53,193,174,238,189,193,217,135,199,25,242,242,11,96,144,219,19,58,75,25,128,165,61,152,133,124,88,207,136,72,50,79,202,179,110,113,194,237,142,146,119,74,208,68,150,240,31,158,154,206,74,242,200,83,43,102,20,19,206,82,175,114,221,251,67,45,53,125,239,121,141,44,57,217,61,14,176,13,33,56,5,127,213,219,212,180,91,40,221,208,23,30,39,29,43,223,201,251,183,255,228,100,83,228,215,108,243,20,179,140,56,61,157,111,236,111,180,238,13,7,14,108,34,127,68,180,67,154,209,170,134,50,119,42,184,83,143,166,65,199,149,243,219,167,200,99,105,216,196,44,103,116,76,181,157,216,199,8,142,0,57,82,143,55,159,190,254,179,90,55,155,228,123,49,126,229,28,170,56,118,238,230,35,150,43,144,34,133,145,142,202,254,52,36,33,77,84,113,143,92,204,92,106,245,226,56,91,76,44,252,179,158,239,28,168,186,219,128,70,103,135,169,139,133,54,215,19,155,39,151,44,33,51,28,118,227,65,236,115,99,38,142,64,165,228,12,206,56,140,247,132,156,87,31,214,94,141,67,190,9,41,71,207,130,110,91,39,127,205,137,71,135,4,232,205,210,43,61,85,27,54,111,155,227,193,108,110,217,67,159,230,73,68,216,233,220,64,57,174,216,4,129,32,188,237,142,149,63,206,162,74,116,101,202,103,164,74,136,112,255,177,11,248,44,49,219,118,227,145,152,231,250,86,250,40,204,169,102,185,139,156,240,132,68,122,191,89,188,26,130,109,93,56,230,34,28,164,181,152,182,59,59,117,127,208,134,56,156,173,100,192,44,177,83,121,1,233,12,82,233,30,182,75,167,188,16,47,29,120,45,25,218,250,155,233,87,170,22,14,165,10,38,244,34,135,86,60,217,152,194,147,131,249,164,94,80,54,234,218,170,171,71,7,36,131,54,52,110,72,7,162,140,34,212,175,146,234,216,44,56,22,30,183,192,226,12,120,115,203,201,121,143,12,221,121,202,20,223,163,145,108,81,37,72,112,37,35,34,165,26,182,24,86,228,66,94,41,222,250,201,3,54,47,15,151,81,157,78,9,62,180,173,235,173,138,241,41,239,33,148,136,135,36,241,72,32,175,26,249,126,42,25,63,57,222,140,165,57,141,219,73,234,236,189,197,91,232,57,219,17,44,150,20,139,158,32,230,63,63,77,83,44,73,150,37,160,126,82,250,34,207,169,56,110,62,63,5,8,218,56,91,27,248,119,148,242,83,16,210,108,135,22,84,217,104,93,96,246,103,7,56,121,84,157,240,170,193,104,153,58,216,224,67,92,115,84,176,88,203,8,233,242,34,130,180,80,147,129,74,71,249,222,145,12,149,212,140,175,188,57,126,219,216,17,122,229,192,72,95,145,81,43,133,122,117,197,145,116,180,238,1,174,81,153,78,114,146,102,134,168,11,223,25,30,95,165,39,75,77,44,16,143,187,246,207,82,138,207,201,52,193,4,108,241,60,180,187,169,126,241,0,131,89,165,202,146,236,37,103,148,113,250,78,157,198,16,46,181,223,197,133,242,146,42,63,121,79,101,160,25,203,218,243,156,68,19,95,39,7,92,217,154,229,97,120,211,84,237,0,13,39,99,106,96,152,78,197,107,217,168,253,162,113,150,212,91,196,110,245,167,52,144,27,212,54,141,143,228,142,59,21,157,211,112,203,7,233,118,222,184,33,120,166,10,188,229,204,163,1,6,25,159,72,216,11,243,232,57,39,147,186,185,160,110,166,247,14,80,152,133,24,228,239,207,164,102,201,30,152,101,124,106,243,27,62,32,84,24,111,74,17,144,11,108,172,118,35,174,4,195,127,228,81,85,220,117,181,58,123,80,124,227,67,60,81,154,126,157,70,24,145,147,115,241,80,71,102,206,14,102,251,164,164,155,197,45,232,5,81,196,211,176,133,206,62,184,108,31,122,185,94,24,197,82,15,61,127,103,223,92,193,61,64,219,92,126,252,164,196,189,23,140,3,154,234,50,251,233,245,30,14,146,32,89,64,10,154,82,186,144,148,139,211,212,62,134,235,210,20,246,133,15,110,254,95,125,95,76,186,74,110,0,243,251,222,23,26,44,173,172,38,187,39,150,159,219,61,112,91,195,185,197,160,18,220,0,35,1,186,67,127,114,216,177,186,0,183,123,74,238,94,167,245,219,59,69,252,212,85,71,242,253,125,132,78,175,153,89,64,253,133,195,230,99,189,30,224,194,8,184,82,214,248,196,61,170,185,91,155,26,93,94,246,62,28,152,24,179,172,156,117,239,0,64,68,0,106,227,205,134,177,95,32,117,66,129,32,61,12,76,62,74,72,47,95,124,229,184,223,152,42,69,253,233,69,17,183,180,26,52,149,108,195,180,24,149,108,146,22,216,252,152,83,212,198,180,239,81,16,203,122,225,221,174,83,59,60,167,45,65,129,216,63,126,208,137,75,115,46,202,215,102,218,35,207,31,25,189,162,90,167,99,126,151,203,178,38,8,119,237,183,54,230,194,179,246,144,58,221,210,114,224,46,187,77,215,34,161,207,73,72,9,52,224,18,66,25,227,64,94,59,67,149,207,251,70,123,231,36,50,104,41,135,72,95,54,18,245,105,51,145,132,195,169,34,37,47,143,84,92,150,147,175,240,133,111,74,17,194,91,9,228,112,31,240,203,244,164,67,27,177,177,179,166,240,0,45,48,94,41,187,97,158,50,214,164,103,151,88,63,87,225,15,48,234,105,19,155,127,55,244,137,124,229,193,11,6,14,103,108,35,153,230,1,14,90,126,87,187,188,179,105,124,156,242,64,233,200,73,85,9,62,93,28,76,184,119,172,153,219,114,241,239,121,240,112,160,12,145,219,75,206,175,69,87,88,210,104,119,230,194,115,165,125,92,144,207,162,193,17,40,28,230,172,153,212,20,132,52,155,123,81,166,250,187,33,245,41,21,165,41,234,221,123,215,148,0,77,52,1,106,83,79,137,169,35,37,240,169,249,35,46,176,191,226,103,183,199,29,163,231,216,235,244,115,37,120,253,23,178,29,124,233,66,219,143,18,201,50,54,16,217,186,94,233,201,73,36,197,194,37,11,206,152,93,49,205,90,31,216,226,30,53,106,159,189,181,65,131,66,191,133,21,57,152,76,152,50,116,62,115,70,155,72,122,13,100,113,233,137,146,83,81,188,94,9,108,121,156,253,29,229,140,217,223,136,60,222,26,211,84,111,60,201,87,180,202,222,183,42,89,41,206,82,163,8,13,43,164,95,6,198,91,171,188,187,187,241,78,82,85,91,224,224,108,4,166,230,152,181,10,102,166,164,61,30,81,111,165,216,74,76,159,62,61,173,159,87,219,168,96,134,71,78,2,249,148,160,151,146,226,244,223,152,73,151,104,45,105,84,167,89,57,5,88,171,176,176,98,198,174,124,103,169,54,154,78,245,147,178,109,41,7,1,120,93,39,41,32,176,83,145,92,170,101,115,180,229,65,112,200,193,186,24,128,228,211,246,156,102,206,137,166,83,188,122,0,130,42,128,107,229,92,32,148,217,208,81,207,177,143,37,93,163,204,91,43,254,146,33,207,111,71,118,176,242,241,48,161,92,114,211,28,47,79,6,250,60,224,48,169,67,16,59,193,235,150,105,12,144,47,244,28,103,149,98,173,79,209,212,179,6,128,11,107,168,154,211,249,23,14,255,166,69,170,57,97,243,48,140,142,253,156,184,170,43,126,129,83,150,197,216,182,91,159,69,36,183,55,207,227,96,146,20,187,34,56,100,1,160,1,220,237,10,71,67,90,211,119,69,154,168,165,24,227,220,197,227,165,218,111,32,60,17,121,8,33,1,211,233,78,70,153,221,194,255,139,235,36,235,98,102,233,161,2,82,232,200,1,213,113,234,177,81,78,246,172,129,200,190,225,74,61,188,124,193,73,48,65,234,52,41,6,138,100,19,229,155,33,244,217,70,118,169,111,98,178,29,74,114,137,41,187,25,210,235,29,142,254,137,75,163,245,22,1,188,135,34,247,38,253,164,248,40,148,26,147,87,209,98,81,97,205,237,27,158,71,82,243,91,2,119,227,18,174,249,81,138,40,116,9,41,137,145,184,129,94,181,56,193,254,45,120,7,246,124,54,203,240,240,160,215,93,139,207,131,168,138,61,11,98,61,173,2,108,31,236,85,133,177,240,78,161,57,205,179,250,200,39,185,241,86,56,12,123,88,244,110,8,215,188,139,72,90,212,165,206,30,123,12,95,17,146,216,143,111,211,39,131,149,186,214,101,197,76,125,189,86,58,59,179,199,12,69,44,77,120,57,123,8,31,218,24,138,19,128,212,13,107,190,97,205,29,23,56,228,12,80,201,130,47,131,174,69,73,13,17,75,38,130,61,32,56,136,3,147,183,65,7,148,56,49,38,161,201,94,190,113,197,40,134,97,96,45,159,112,20,130,217,249,172,212,19,62,133,38,85,52,121,131,3,85,145,146,0,138,190,114,236,27,179,110,142,34,223,158,33,121,223,230,41,144,196,117,248,196,117,208,236,29,33,105,199,150,222,7,220,43,163,200,130,95,154,38,206,150,66,93,32,167,110,103,51,188,129,134,40,63,113,162,163,108,38,150,74,20,21,79,230,83,44,229,144,64,157,199,60,132,136,216,142,43,31,94,254,99,116,89,145,217,43,103,37,81,96,124,251,229,82,200,34,223,225,161,45,151,77,137,111,57,191,100,151,47,114,149,35,234,98,95,99,103,122,56,201,90,92,230,155,56,128,184,113,209,193,166,154,208,140,172,197,209,94,84,168,205,79,214,154,202,218,108,134,174,93,236,96,251,134,35,90,171,163,217,155,205,225,6,199,155,225,186,17,35,211,151,7,2,249,177,233,123,212,70,150,14,43,106,116,197,130,170,235,60,141,166,23,47,85,200,215,33,145,182,176,142,102,48,155,245,182,198,100,225,122,51,28,62,130,43,33,127,114,182,105,14,124,203,2,6,201,222,52,156,76,23,164,4,36,143,148,84,74,194,114,30,4,94,34,174,84,77,176,65,227,70,218,232,23,134,142,115,1,219,248,92,204,59,251,154,188,182,88,204,68,161,250,84,78,143,114,112,93,49,157,193,62,135,20,251,225,235,201,146,140,203,90,36,167,116,76,211,65,238,159,57,194,74,245,231,192,50,179,252,54,101,205,24,229,42,208,145,128,135,173,156,23,226,164,85,100,184,212,62,224,89,142,75,88,48,100,185,79,78,158,26,51,34,225,236,167,152,162,65,46,193,125,68,184,118,107,159,216,122,202,249,206,28,112,225,195,37,88,41,157,62,42,197,220,169,13,99,85,59,196,54,39,247,96,230,201,200,119,180,130,132,83,149,75,151,166,124,167,241,137,199,233,25,81,216,21,96,250,59,86,120,233,177,213,53,109,71,168,12,37,173,117,196,25,135,244,5,170,183,84,214,202,89,185,179,185,104,220,144,152,228,48,57,199,46,122,172,140,7,52,23,121,66,72,181,210,28,115,93,114,89,230,55,189,60,30,101,104,15,217,20,118,120,249,197,71,137,250,76,138,38,200,9,155,8,217,180,46,229,64,197,19,195,119,5,77,146,18,136,136,150,97,163,226,49,244,18,167,198,156,81,42,65,57,46,198,47,229,104,70,30,62,61,1,83,103,118,219,139,132,40,161,62,135,115,83,211,176,170,2,158,108,93,17,162,38,243,39,247,232,193,118,218,121,62,24,102,70,91,148,236,108,124,88,244,199,152,124,149,220,45,87,8,40,148,205,193,212,5,115,178,221,178,94,101,122,151,235,231,246,87,155,156,86,124,157,35,54,222,196,123,101,120,70,138,148,22,193,48,92,146,81,222,202,19,35,32,44,115,208,98,91,248,5,72,86,140,65,240,83,41,145,96,139,84,0,148,134,184,238,51,220,171,94,1,151,214,39,74,80,31,81,122,143,233,171,91,47,25,140,6,18,253,168,162,67,106,239,97,239,91,30,75,159,30,88,29,250,105,180,12,15,133,176,193,190,224,152,192,252,45,128,57,36,115,25,197,248,202,72,122,23,39,125,215,160,142,59,158,51,233,227,209,14,39,140,87,217,75,83,46,209,92,83,47,128,69,147,46,10,15,229,226,73,129,100,196,146,167,2,27,69,142,28,148,94,38,254,70,113,54,15,132,162,209,114,74,183,240,112,192,195,248,64,107,79,180,211,1,31,113,115,39,88,131,236,117,9,132,242,230,49,93,199,247,126,100,195,83,59,73,6,114,32,132,100,110,204,135,5,123,59,5,167,129,216,141,77,120,231,67,130,71,19,16,152,3,136,42,242,12,81,125,102,111,98,26,183,82,42,211,105,97,96,71,57,123,218,153,148,184,90,37,183,199,83,67,83,31,13,29,91,68,144,12,63,172,231,245,106,224,8,203,245,237,104,210,74,113,196,29,61,226,39,52,69,148,169,207,6,63,89,57,180,127,239,183,69,21,87,243,141,125,18,118,174,48,22,83,173,19,99,132,148,161,45,227,14,183,234,61,48,155,198,108,151,208,119,14,70,35,207,102,122,219,220,158,19,83,253,224,103,122,50,141,174,150,230,106,193,168,57,99,213,83,2,213,193,78,21,175,90,44,63,28,60,127,158,66,121,164,166,104,156,18,71,92,35,165,65,143,113,183,241,113,211,121,183,35,49,48,215,249,194,167,113,66,40,19,212,69,154,99,39,21,157,242,252,227,238,205,212,187,46,144,190,179,43,141,179,185,182,155,195,228,61,216,236,27,205,229,67,157,226,0,102,115,250,141,18,105,167,30,136,147,232,249,54,209,100,137,124,137,106,253,177,115,190,14,144,41,134,179,158,247,216,56,64,232,226,192,103,57,125,95,115,75,51,157,160,191,19,201,120,24,159,209,149,117,126,207,137,83,174,36,221,24,4,60,5,82,197,237,236,52,79,152,177,167,248,46,17,168,143,251,198,243,171,50,51,148,147,18,106,75,164,201,69,96,243,208,85,222,88,224,117,213,96,233,44,149,255,17,185,56,80,51,193,189,2,181,10,2,146,187,26,248,229,176,46,47,95,120,229,87,115,223,50,173,7,154,110,223,95,126,73,108,38,23,69,9,242,156,73,87,168,160,52,186,182,64,92,186,234,42,228,23,129,1,157,180,72,166,118,169,5,241,208,107,83,240,118,127,239,0,49,179,95,200,185,251,54,198,96,235,8,139,148,126,185,87,78,178,122,242,54,34,215,17,174,18,4,133,16,206,242,174,176,107,97,214,210,212,198,100,186,223,237,6,174,200,52,70,199,217,213,26,64,72,145,36,239,67,233,188,118,70,16,121,149,213,137,87,65,200,13,124,27,205,172,220,42,166,145,74,140,136,170,249,141,171,165,49,134,16,251,159,13,75,234,93,116,214,142,191,111,206,75,221,121,87,255,239,103,63,136,197,252,8,222,193,155,29,166,144,219,162,94,131,190,37,46,29,20,14,41,73,4,47,151,73,172,171,73,181,142,134,4,54,197,200,16,170,183,10,57,157,213,194,187,226,70,244,43,59,95,85,247,136,221,236,186,157,157,84,247,247,170,196,86,67,157,128,12,78,119,88,168,233,220,63,157,41,215,15,113,220,57,221,22,149,35,250,153,81,86,21,34,134,243,138,107,68,146,137,167,39,13,222,78,108,68,28,225,235,164,201,238,167,210,153,227,6,213,38,9,93,58,191,192,245,44,106,185,227,173,179,75,22,131,180,76,187,132,175,255,216,64,190,138,172,1,231,216,126,180,7,139,37,58,57,29,115,58,249,110,227,115,18,188,100,179,108,183,117,112,78,186,99,244,253,52,179,231,164,164,153,63,169,102,14,250,221,39,111,111,204,113,252,240,129,110,182,137,39,188,45,31,47,68,160,170,66,175,217,236,99,181,191,115,238,56,47,76,21,239,141,119,182,80,62,149,3,218,97,166,37,85,228,90,230,98,114,226,60,70,167,59,125,183,78,2,155,98,216,151,132,208,224,177,81,38,3,217,62,143,232,237,115,118,216,125,185,117,87,56,220,8,180,119,157,82,100,243,202,78,190,142,210,232,51,152,131,3,194,17,210,72,241,147,119,85,183,170,247,179,126,103,87,148,239,145,249,150,250,252,245,4,70,156,244,230,20,229,119,35,190,57,113,44,191,124,225,175,159,170,50,209,220,59,164,30,122,79,92,64,48,16,51,236,11,142,40,130,10,71,228,64,17,231,101,10,32,159,86,155,15,209,51,204,19,5,194,99,168,58,34,19,114,65,54,69,139,10,60,15,17,52,0,0,251,28,237,204,93,199,167,76,166,49,97,92,11,227,171,101,230,75,136,172,40,76,48,23,201,213,7,36,10,218,33,210,146,201,233,129,131,92,121,167,30,155,113,251,72,151,168,168,145,210,37,129,57,186,43,12,209,175,249,96,46,101,179,197,96,25,232,246,76,200,57,166,104,185,65,185,102,192,255,56,52,247,72,71,33,53,113,89,54,217,147,0,8,85,16,123,90,38,153,185,251,163,25,84,120,48,153,52,158,93,12,70,254,171,24,61,137,64,139,75,222,77,178,94,83,92,18,132,2,69,234,105,76,235,195,99,67,123,248,232,128,47,208,195,20,251,103,2,167,82,212,120,136,103,8,11,68,131,100,127,187,7,239,57,48,213,109,81,9,51,72,241,5,119,161,95,190,8,199,148,6,73,3,66,235,198,21,35,13,20,4,6,69,174,162,165,243,60,99,187,220,153,143,234,242,102,228,202,163,138,91,117,91,126,189,164,222,58,57,11,20,105,176,221,162,206,156,69,98,177,44,169,252,83,225,175,28,56,1,19,121,158,83,48,145,92,76,253,195,79,211,50,201,132,46,38,159,47,20,171,139,204,236,242,32,110,139,144,46,110,116,126,131,176,114,196,54,155,29,169,40,132,140,197,123,210,244,179,217,171,207,32,39,58,31,224,5,182,104,96,44,254,58,214,91,206,48,109,97,54,125,200,76,100,124,29,69,62,190,64,200,123,194,105,197,132,170,196,247,137,87,76,238,41,217,40,23,158,227,110,212,2,144,251,142,35,241,185,156,114,137,201,85,76,216,101,63,73,19,152,139,57,100,39,172,59,124,164,135,192,228,248,110,187,78,162,204,140,88,140,75,60,96,238,60,49,69,116,180,126,55,239,223,222,104,253,200,242,8,100,123,194,28,195,207,47,160,233,236,176,236,5,69,27,14,62,236,96,165,139,17,41,52,203,219,129,217,191,231,105,102,110,12,247,118,16,9,236,66,34,172,203,142,66,226,45,44,170,106,197,64,6,232,210,140,31,69,11,113,164,129,81,82,52,93,10,191,71,161,57,80,110,200,28,54,125,100,192,227,240,10,49,234,163,186,183,56,170,16,48,121,139,228,123,78,197,246,171,243,53,60,76,111,94,243,65,183,112,180,104,182,124,246,99,174,96,50,163,8,37,123,133,108,145,214,14,147,196,187,6,238,115,6,130,94,122,230,195,84,111,214,174,199,83,35,72,149,149,42,158,202,13,66,21,252,233,236,36,145,84,134,143,28,55,17,217,104,137,82,181,159,236,234,103,14,85,198,165,57,75,17,140,156,210,74,28,255,139,84,252,219,231,15,222,143,77,71,32,53,210,129,181,84,194,61,200,66,242,200,212,44,22,159,161,222,227,6,62,186,211,22,160,203,199,237,176,56,241,197,43,175,96,92,222,85,171,103,94,225,73,0,82,176,236,137,167,134,134,115,233,93,103,219,157,19,60,187,188,141,11,60,40,235,208,252,92,217,105,184,250,244,143,233,41,184,106,166,31,99,5,243,212,9,45,7,221,41,145,140,244,223,3,19,199,64,233,31,52,126,102,114,52,81,206,10,207,225,121,38,95,162,25,235,136,128,206,243,68,252,139,141,80,30,167,11,186,97,157,58,92,97,42,33,44,18,23,250,29,185,36,139,205,89,78,189,191,233,152,189,61,247,60,16,87,195,194,111,170,161,147,106,162,156,170,149,64,218,182,255,206,85,115,149,19,143,140,189,105,140,210,224,221,134,62,74,81,34,243,180,27,86,239,228,180,62,95,244,215,199,38,65,35,179,93,52,235,60,55,230,41,210,184,107,217,192,87,179,25,226,196,123,143,206,125,216,1,100,133,254,8,114,104,235,45,42,169,175,62,49,113,211,172,1,137,172,19,1,103,244,172,222,121,34,217,92,86,241,87,121,231,104,202,108,42,176,77,224,50,247,131,159,202,12,11,16,22,250,176,170,208,119,81,152,197,61,198,87,207,95,76,221,249,69,109,41,130,232,204,124,114,240,132,121,183,51,159,145,23,192,139,121,84,206,121,230,147,232,14,232,68,115,107,163,218,93,53,200,2,126,73,215,208,159,70,48,238,243,217,194,83,13,151,155,197,209,70,147,49,3,253,93,120,158,137,237,195,207,73,27,163,161,230,105,88,40,111,56,7,63,196,88,159,171,107,148,250,146,14,109,68,67,197,148,226,219,95,49,51,194,225,25,157,128,182,105,55,61,153,211,136,41,11,153,28,197,98,170,177,76,99,232,233,88,41,216,129,241,203,229,153,70,126,229,103,188,223,43,5,64,84,79,232,35,174,123,229,101,74,245,192,170,167,204,147,173,82,157,151,231,45,200,59,170,109,170,55,248,215,255,110,126,172,98,37,62,228,203,23,132,189,154,182,29,150,160,108,241,111,247,147,81,9,247,199,221,104,130,124,184,251,74,244,106,129,8,79,45,166,201,222,164,176,198,169,251,75,51,75,252,254,116,92,34,50,79,38,245,91,30,121,50,35,174,232,202,61,229,192,234,140,27,109,249,93,136,33,97,109,225,103,103,42,223,0,11,166,178,129,121,126,165,97,20,237,152,160,34,238,136,137,72,231,148,118,71,69,100,219,60,244,121,106,211,125,56,253,84,63,41,204,252,209,103,65,76,203,128,68,24,131,168,47,76,203,75,167,146,229,130,115,194,137,156,86,105,54,102,35,105,188,153,215,231,238,171,111,38,179,56,78,164,207,191,85,236,116,158,253,52,56,63,137,90,192,156,134,199,160,232,162,242,73,48,74,32,69,164,154,71,211,187,57,65,192,175,213,69,215,121,78,68,30,12,168,15,252,182,39,155,64,156,179,146,171,105,159,18,161,165,55,164,122,3,1,136,140,215,25,7,16,29,60,211,83,109,84,41,38,207,108,248,108,141,121,170,43,115,46,14,192,49,79,105,138,27,7,10,104,192,181,102,74,157,232,110,152,78,18,120,213,105,69,188,124,53,10,26,205,186,56,65,32,103,101,137,124,217,135,18,57,158,0,100,44,177,94,14,221,161,60,145,248,207,211,217,160,64,241,67,143,0,15,207,93,214,252,227,53,73,59,168,24,48,55,133,166,210,165,79,67,89,231,206,218,219,15,100,11,22,61,105,74,178,18,32,119,42,117,236,67,195,11,58,20,209,207,136,46,126,50,106,63,161,42,172,40,96,14,142,213,36,136,204,40,140,163,91,166,79,199,141,20,69,117,64,39,94,20,28,197,220,216,204,248,219,22,140,56,240,26,238,250,90,245,122,213,255,58,101,111,189,232,202,184,196,174,194,57,180,69,215,72,228,166,189,222,243,148,42,75,152,178,227,56,132,195,108,111,209,40,11,10,146,58,49,116,39,23,141,153,9,92,23,1,95,13,20,159,19,55,182,189,119,62,42,214,3,112,173,79,25,134,85,206,133,15,169,27,29,144,129,0,64,233,150,42,7,17,184,107,66,52,6,116,143,171,221,129,55,248,59,132,181,170,83,7,16,235,220,230,125,142,205,224,188,148,101,43,54,180,128,54,44,130,179,133,219,66,61,49,55,217,70,24,236,89,253,220,58,79,214,134,228,8,123,37,107,85,211,101,65,226,216,113,124,44,23,123,145,203,137,28,157,227,194,175,232,120,42,158,17,140,101,101,140,70,100,178,107,29,141,137,107,227,82,88,164,76,63,53,100,4,198,148,72,130,173,19,205,31,117,63,39,89,159,234,138,224,146,241,119,99,15,250,97,15,27,226,180,104,98,75,18,92,206,78,138,221,10,26,113,175,176,107,232,244,168,185,220,193,3,211,98,98,101,31,245,223,162,54,160,153,149,185,187,237,8,0,229,254,5,205,65,102,253,175,70,215,40,29,231,64,52,203,147,40,63,197,108,52,250,252,144,77,71,125,178,180,114,163,166,215,171,232,152,170,52,187,102,194,198,80,39,80,57,28,102,115,178,39,244,232,210,158,108,214,233,13,198,53,58,177,20,221,134,252,246,211,152,151,209,63,91,146,136,38,140,140,250,97,149,136,142,137,219,7,183,12,211,220,158,177,222,194,165,43,218,136,88,129,169,188,178,190,181,43,217,75,17,184,192,183,48,189,129,172,200,249,53,0,228,178,126,94,113,57,85,59,8,215,3,167,129,179,101,41,25,0,59,160,113,32,77,126,222,236,152,110,45,251,36,251,66,176,136,248,234,216,6,157,37,111,239,253,25,169,225,196,71,202,252,210,237,183,75,44,181,72,54,238,171,62,230,240,36,178,202,126,135,52,224,119,87,63,231,89,152,35,241,241,75,48,199,17,24,60,158,171,102,14,111,15,53,208,219,223,182,224,3,250,107,63,57,170,56,149,91,58,168,227,172,233,139,25,73,142,10,168,15,165,221,147,73,173,58,25,9,77,211,206,51,167,77,147,234,16,48,7,75,161,81,159,25,26,162,254,138,149,243,217,153,190,100,231,175,19,198,63,203,204,148,128,117,150,65,28,213,176,34,156,46,84,171,47,193,197,233,9,27,240,90,228,23,100,112,22,172,156,29,116,118,153,220,177,93,69,233,68,150,149,11,40,189,184,166,119,40,214,221,5,32,131,44,79,247,170,25,15,222,70,225,57,87,225,152,163,97,29,94,34,107,92,206,168,145,71,122,140,24,126,110,242,27,216,231,135,232,102,2,113,120,65,164,29,5,19,38,141,135,249,50,26,177,157,41,163,100,82,29,129,133,242,215,230,203,221,252,113,229,19,166,216,53,187,35,141,91,146,133,36,140,212,230,67,76,190,204,255,62,32,13,71,56,119,205,111,218,149,158,35,22,159,78,174,223,143,6,57,231,205,242,172,13,219,97,59,205,210,81,154,206,233,193,2,103,225,104,129,222,177,234,35,198,60,215,85,41,17,116,153,48,6,61,10,113,175,230,254,251,87,242,227,143,192,81,238,35,122,23,148,92,35,237,31,145,64,73,129,18,82,212,134,148,142,27,100,157,1,121,234,207,91,56,132,251,148,102,17,216,170,234,98,210,84,242,110,14,173,72,28,251,132,118,180,125,84,202,171,175,162,81,113,83,19,80,154,131,161,85,189,144,251,213,181,142,185,156,50,46,231,93,168,111,68,182,26,58,87,49,184,31,221,53,37,133,230,190,71,76,238,56,211,110,240,65,191,180,137,143,14,174,220,54,67,35,198,73,115,163,72,131,16,162,32,21,128,128,182,19,171,14,3,24,78,216,25,9,87,68,89,33,242,98,243,71,96,73,21,137,7,93,237,179,246,35,98,178,69,90,146,163,93,4,173,41,36,7,115,224,71,146,67,5,238,144,27,178,174,249,35,253,157,216,228,73,80,155,193,65,231,71,250,14,30,83,102,99,24,2,201,24,84,25,236,223,65,255,134,79,187,79,156,102,5,187,101,17,101,59,39,101,86,180,39,142,200,148,237,0,28,59,34,26,83,232,226,32,154,239,66,225,122,101,168,45,192,226,97,149,27,81,126,149,180,254,99,73,171,184,137,118,192,25,12,32,211,180,81,23,66,51,120,51,42,1,137,202,47,198,204,122,54,157,176,169,73,97,133,148,15,98,252,104,15,200,163,99,99,97,161,215,114,119,171,247,156,8,24,150,250,216,212,115,212,135,22,63,133,54,152,102,55,42,48,197,75,246,202,76,46,255,121,249,201,199,236,176,248,200,35,228,73,74,102,17,46,138,132,136,247,94,37,142,177,148,4,194,121,123,102,181,156,67,58,210,31,92,56,30,28,161,9,144,173,168,144,43,94,249,23,138,182,136,62,36,152,158,107,10,188,0,190,11,58,38,28,111,224,252,112,222,239,58,114,231,138,150,23,31,178,191,207,231,21,64,194,118,117,38,115,215,42,184,217,190,220,190,255,99,254,216,117,32,36,72,243,86,202,163,38,195,135,1,55,224,30,194,185,254,6,55,68,51,41,98,208,75,126,205,139,67,140,8,116,26,15,228,65,175,173,6,251,137,181,88,195,71,160,168,186,105,26,108,148,103,200,81,119,201,41,60,193,242,199,118,233,84,77,87,204,240,241,183,235,27,34,217,148,2,111,189,119,205,141,39,100,73,220,121,201,73,63,56,95,132,139,4,17,144,84,164,199,209,229,142,198,112,210,180,179,184,27,152,218,86,235,213,62,79,5,144,105,245,21,75,26,23,167,48,181,142,58,235,144,243,163,247,24,133,178,74,33,110,93,57,87,206,26,131,218,187,40,249,90,36,230,15,130,33,39,26,181,137,55,101,73,8,234,245,166,237,134,182,233,235,241,32,143,152,28,49,151,242,203,31,115,169,15,104,158,29,228,147,179,153,49,94,217,27,33,202,111,167,18,55,92,31,161,152,119,253,225,81,48,103,218,207,130,8,185,160,41,32,241,171,196,251,235,189,23,166,5,51,49,53,210,45,113,140,57,119,113,73,26,170,168,89,32,97,75,154,32,141,174,119,248,17,19,246,53,34,105,7,161,150,3,29,93,190,83,194,206,81,36,26,132,9,225,32,98,54,247,11,73,99,151,35,98,160,203,233,225,167,226,78,79,162,145,96,191,135,245,91,226,44,12,94,14,25,70,62,90,6,240,141,44,196,237,187,78,83,22,167,220,93,77,194,60,195,216,181,32,249,67,191,71,149,145,45,78,28,149,49,64,46,52,161,48,126,40,57,176,179,136,77,142,36,44,73,43,246,97,93,237,117,191,85,83,67,39,55,67,201,130,21,241,160,38,155,146,126,229,108,60,199,106,228,193,97,251,22,205,226,25,173,152,89,245,68,22,13,19,181,121,216,33,99,126,180,93,211,112,125,70,80,252,45,19,128,49,185,236,230,244,17,45,100,119,169,60,56,121,144,25,130,45,118,115,42,67,240,9,1,231,56,31,78,44,85,80,136,218,226,23,107,113,254,207,75,85,93,52,128,198,126,167,79,35,222,28,199,239,175,39,183,88,217,204,215,136,18,58,216,23,118,204,50,42,149,81,229,236,254,87,216,8,142,127,236,237,20,102,39,104,100,80,66,149,36,18,160,146,242,124,76,211,5,253,194,241,67,118,157,159,59,51,19,203,40,239,54,243,92,82,80,142,17,138,240,205,223,111,215,79,49,159,30,138,115,60,43,164,156,251,150,144,14,103,58,101,60,175,105,90,236,196,143,62,227,106,95,184,231,20,6,93,141,193,219,141,149,63,239,32,158,247,62,249,2,231,243,243,111,95,174,117,144,9,106,246,68,80,209,234,121,71,170,189,87,122,255,169,94,126,74,210,218,175,111,175,223,95,125,250,101,54,227,146,231,186,216,239,37,250,155,81,166,211,79,52,67,244,74,140,246,216,39,115,30,79,59,12,69,126,98,60,64,117,127,79,31,168,213,6,9,227,116,210,131,144,227,96,146,99,78,131,18,66,194,73,198,136,154,174,126,64,171,174,231,228,198,212,75,130,69,87,32,145,109,54,22,134,118,135,231,244,75,128,10,108,189,190,118,141,99,209,82,134,111,154,121,68,240,24,133,53,76,123,228,53,183,92,134,141,174,171,251,123,0,199,77,234,209,250,143,28,158,93,245,45,110,177,174,135,102,142,1,72,111,215,119,141,90,5,222,153,79,218,85,115,253,227,183,7,11,139,26,29,79,57,126,239,234,174,233,75,94,169,208,71,41,39,245,106,244,165,87,167,144,106,125,149,130,14,84,154,109,197,75,42,181,208,210,118,149,65,35,22,104,23,16,70,111,171,167,94,16,87,149,110,226,42,103,160,153,230,36,166,244,24,59,60,197,94,185,146,102,200,21,244,224,76,28,77,237,244,113,34,123,97,243,138,33,220,207,156,231,196,158,44,19,218,56,124,104,54,3,137,59,106,138,64,96,170,128,136,213,221,118,112,189,234,238,160,19,210,147,115,165,101,202,93,189,170,133,31,101,139,224,158,232,213,18,85,62,154,113,195,222,14,121,103,198,137,20,150,222,236,216,137,7,149,187,0,236,59,137,52,218,46,247,138,244,185,27,32,185,107,163,25,164,199,41,36,46,139,132,156,72,124,28,126,150,84,227,68,189,57,122,109,239,214,248,184,135,63,181,63,225,217,165,242,49,9,7,154,152,52,198,83,172,177,226,192,40,43,118,92,161,206,142,96,237,118,54,139,43,218,131,205,27,119,33,236,5,45,228,7,241,14,207,239,117,93,181,15,93,181,93,238,35,179,242,206,57,115,56,223,50,255,235,200,219,227,224,204,135,186,155,217,90,58,26,41,57,125,138,70,225,170,217,30,214,143,118,233,247,151,217,15,51,15,194,175,58,157,92,15,93,45,250,12,45,223,207,49,103,193,228,250,167,182,89,245,199,122,131,184,48,36,193,78,167,104,184,170,81,220,239,151,44,234,203,143,136,230,208,195,229,197,69,126,80,97,26,219,68,192,238,253,125,1,104,9,121,140,186,136,237,226,168,61,226,125,165,241,98,205,186,62,17,246,42,237,18,6,28,191,248,9,163,146,154,57,89,216,177,170,225,238,144,76,175,116,168,231,93,117,55,197,218,217,207,142,116,76,92,17,228,177,167,95,42,98,187,94,211,135,110,201,226,170,93,248,224,28,78,92,244,95,58,51,93,78,113,22,123,8,173,84,12,150,86,217,157,135,192,255,122,42,190,143,196,75,35,97,196,81,241,225,18,62,16,94,57,74,100,86,162,233,138,244,203,238,250,217,63,161,211,202,81,232,216,63,142,77,88,210,88,211,173,73,65,195,162,101,131,142,157,211,3,214,99,209,214,113,50,57,229,145,3,59,203,243,146,50,23,245,198,175,204,180,31,137,198,80,243,61,109,242,126,152,220,110,26,226,238,107,196,145,127,6,177,80,59,57,164,22,172,210,140,174,237,170,218,28,99,150,14,200,54,101,46,9,237,27,156,139,199,131,26,127,191,177,98,204,35,193,177,171,5,252,119,207,207,215,27,197,206,11,245,124,46,242,78,50,81,3,249,138,214,65,192,215,73,133,49,162,37,56,204,24,147,204,49,3,205,221,239,77,212,54,108,227,199,248,7,199,92,11,147,235,13,133,43,212,135,48,226,1,109,150,204,163,151,211,74,150,237,170,177,223,36,157,56,194,178,161,89,235,239,29,191,144,144,16,8,31,53,230,217,239,225,201,206,251,176,76,113,99,4,37,222,14,126,176,7,206,173,162,88,230,228,178,143,162,10,137,88,217,155,63,137,108,147,102,246,120,105,192,39,32,38,100,38,202,187,28,178,173,61,249,23,45,61,169,167,231,249,150,30,122,9,31,218,59,170,231,255,218,85,11,80,56,215,113,229,195,8,4,39,20,228,133,204,117,122,6,204,103,154,248,148,64,214,209,194,142,216,225,85,95,178,143,248,233,165,162,142,89,92,161,41,99,138,60,131,32,101,11,189,53,118,60,53,187,183,135,5,146,64,163,126,28,98,2,169,185,118,110,117,69,254,234,5,188,99,175,117,40,148,101,215,86,195,105,29,235,8,244,94,237,8,28,234,102,161,57,131,112,211,144,78,14,185,219,136,170,9,185,2,15,55,241,214,12,141,39,41,50,30,219,222,57,196,95,28,165,125,65,138,29,227,81,200,72,20,68,147,105,170,146,57,150,245,163,89,225,28,11,123,84,248,3,92,160,228,205,131,104,130,89,35,156,9,212,234,53,137,211,235,191,238,166,131,49,229,187,91,213,149,200,46,90,2,190,190,159,205,232,224,70,203,82,194,237,121,173,65,96,29,231,250,144,167,99,219,71,105,97,232,248,221,1,133,25,234,149,116,229,129,122,134,117,2,61,39,247,50,77,103,242,246,134,101,133,92,210,222,225,16,242,123,192,130,202,27,159,127,15,7,164,111,83,195,4,223,48,136,119,188,212,183,48,31,223,84,140,121,142,222,59,102,63,59,146,100,243,236,82,242,5,151,87,99,237,81,57,154,106,55,208,103,48,19,164,245,42,189,105,86,111,78,102,165,9,203,161,238,55,121,13,206,104,224,147,84,153,115,206,108,236,4,8,233,138,12,22,6,57,225,99,0,138,207,37,254,71,249,199,91,115,177,86,164,26,197,15,128,56,168,86,107,210,104,39,219,241,218,211,110,79,30,149,2,94,70,188,112,157,97,5,127,152,82,217,207,238,65,218,161,122,152,50,161,79,101,6,128,158,81,166,49,28,216,86,144,38,3,79,143,199,123,71,237,202,191,63,155,49,239,5,252,11,118,31,115,66,243,197,47,193,138,26,131,105,125,147,216,99,140,174,197,13,202,68,197,18,28,92,56,169,245,191,241,190,70,183,157,250,57,22,231,19,120,194,243,131,204,102,110,207,253,41,28,124,98,126,100,35,32,5,107,44,172,108,217,237,204,73,53,127,114,23,229,197,131,7,187,225,186,71,33,229,249,164,170,11,9,244,15,117,229,104,204,108,122,144,3,178,218,36,96,190,106,119,78,228,234,94,96,213,116,121,225,49,216,173,234,156,34,14,135,126,226,48,84,59,59,249,102,215,79,205,58,243,135,175,15,105,240,15,95,14,212,26,21,5,160,235,43,208,60,230,12,219,115,2,11,98,212,106,235,221,11,106,100,165,237,138,107,254,232,72,165,21,33,47,153,13,97,144,17,13,105,245,211,212,60,236,186,210,37,126,249,98,20,47,197,124,55,51,65,237,118,43,189,236,42,54,163,23,97,49,146,227,72,230,142,98,250,87,204,105,114,171,13,60,223,186,114,88,68,166,249,244,150,185,30,1,54,53,180,166,44,11,194,80,197,228,8,39,107,63,201,83,158,137,151,18,188,206,107,29,140,102,247,210,55,227,168,216,167,70,28,79,160,139,102,39,98,8,34,107,70,146,165,127,145,231,250,103,106,168,60,165,4,11,180,203,20,179,194,225,87,170,201,99,180,29,103,207,164,115,162,55,188,168,103,127,85,45,202,220,236,160,229,201,71,174,40,62,126,21,151,202,146,169,254,158,233,186,2,133,252,251,231,223,144,141,126,56,161,122,19,143,210,184,225,145,185,226,195,138,155,12,84,223,174,234,53,37,6,33,237,230,161,224,187,213,223,220,31,81,122,116,131,26,96,206,254,116,206,100,233,227,61,6,116,149,228,110,93,167,246,66,252,199,62,187,160,23,23,78,195,131,21,211,254,204,186,144,213,161,83,158,75,194,149,59,186,139,69,133,161,86,115,71,239,229,224,40,201,211,98,154,116,184,59,240,242,197,237,171,175,141,3,143,158,136,216,14,193,184,103,136,248,230,85,240,200,99,136,159,35,136,237,108,111,170,102,101,59,143,6,11,239,210,216,182,221,150,37,144,17,115,218,206,181,36,27,249,203,149,88,155,91,110,150,130,87,185,246,26,164,59,200,124,155,216,241,124,30,101,199,196,94,46,157,125,246,242,5,193,1,85,87,39,66,216,54,16,145,246,15,214,132,226,237,152,28,192,197,64,191,239,216,0,92,228,13,86,33,214,96,234,253,204,250,235,223,253,240,196,101,254,131,139,196,95,79,62,140,45,171,247,195,71,110,56,156,24,240,213,65,138,16,122,36,31,134,33,11,238,130,116,250,215,36,87,68,33,237,50,89,54,77,8,182,35,193,125,242,161,10,134,208,191,139,8,158,255,3,181,254,234,229,139,31,61,210,160,108,68,238,104,242,234,198,4,251,30,125,188,131,254,114,246,138,207,35,154,120,234,187,255,233,125,145,59,195,162,65,148,175,57,74,71,253,32,81,37,8,137,69,139,55,219,79,137,66,119,192,42,188,223,188,248,118,49,174,255,133,158,229,107,124,100,154,43,172,211,252,197,211,63,229,229,242,187,48,233,251,63,188,230,252,223,184,38,143,174,186,56,7,30,20,160,20,208,98,136,118,47,176,251,216,209,37,144,196,34,250,125,80,246,249,174,164,147,75,230,73,111,65,160,143,89,56,37,105,48,91,193,10,117,193,19,7,6,100,254,40,120,93,38,151,118,216,226,160,250,60,226,134,218,234,231,46,118,72,161,57,92,3,188,215,182,130,33,6,63,8,98,15,138,140,54,232,232,152,22,47,204,101,252,191,115,82,147,228,196,97,251,15,175,120,226,216,30,92,242,85,17,93,151,53,253,114,70,71,89,208,87,188,48,248,236,102,183,85,9,41,123,76,234,90,210,105,43,61,162,248,49,58,129,1,235,32,137,75,234,96,73,25,161,190,29,37,4,252,116,156,149,54,179,74,68,96,254,219,103,242,32,236,251,173,247,244,219,137,87,9,32,239,186,168,149,60,155,183,159,186,245,109,239,57,71,52,190,138,87,49,235,0,183,83,160,167,103,2,191,67,90,89,79,203,67,154,223,217,215,25,219,222,61,135,63,177,123,223,49,177,126,31,1,79,190,63,98,34,60,82,241,14,233,52,100,238,164,243,206,41,30,139,196,168,215,136,213,164,29,77,155,210,127,158,206,98,149,194,51,84,251,212,159,218,96,116,131,137,126,145,136,36,251,113,159,217,105,207,99,178,39,54,123,222,237,214,119,57,35,235,28,10,79,221,120,103,245,169,231,114,137,166,55,244,1,215,61,184,56,202,157,60,204,35,176,133,43,244,189,38,82,233,241,248,180,204,139,148,143,155,189,230,212,40,140,93,228,158,28,185,38,251,234,105,19,3,14,151,62,105,133,41,158,217,236,246,38,82,88,249,109,252,138,14,117,87,43,227,244,156,184,233,2,64,112,28,95,21,61,203,39,131,239,60,97,82,227,12,30,90,199,161,141,188,15,191,188,116,80,246,10,73,182,187,212,4,209,20,58,241,247,209,97,225,140,48,154,181,194,96,254,137,245,182,241,21,210,146,10,178,220,164,121,190,90,215,226,243,169,80,74,222,11,78,101,67,143,86,42,248,71,24,84,54,14,186,242,57,56,123,84,69,135,138,200,231,40,6,99,34,235,242,226,30,87,47,88,50,166,74,194,150,21,92,228,111,2,187,238,189,182,209,34,232,189,164,140,60,70,225,88,225,136,191,107,203,67,182,151,166,244,44,116,186,237,155,195,34,68,100,137,19,185,201,113,94,38,103,119,175,110,38,239,62,95,94,115,66,235,143,159,63,223,92,179,218,125,253,222,126,118,49,206,180,198,169,21,100,43,188,254,35,214,31,187,59,169,8,205,176,58,99,187,222,196,217,20,238,56,14,221,59,83,124,150,12,167,231,58,237,27,203,248,185,91,191,236,199,36,210,87,105,42,91,73,206,118,231,53,196,174,0,1,125,243,76,60,3,78,253,106,227,95,46,24,105,88,62,108,54,105,53,70,173,109,138,74,7,87,221,100,182,241,33,131,92,253,163,196,59,216,198,191,41,243,46,188,105,168,52,77,215,14,48,249,221,202,194,117,214,214,146,110,76,18,243,227,120,113,198,41,199,211,133,216,12,177,76,157,12,183,213,232,134,73,80,48,234,88,192,78,69,137,227,1,160,190,172,60,80,44,33,180,247,99,116,215,9,132,133,243,246,151,52,200,215,237,202,137,1,204,62,247,37,60,224,180,52,5,145,121,49,142,85,246,26,28,37,157,253,52,128,196,106,163,140,129,241,37,18,230,234,126,114,117,238,201,135,19,246,57,227,177,250,84,65,233,189,141,73,200,187,200,20,71,124,212,18,117,120,21,156,114,165,46,141,72,110,58,121,245,15,174,185,24,104,213,62,108,15,254,84,187,229,5,10,132,113,54,247,96,215,103,222,144,155,212,229,213,222,89,156,162,4,48,111,132,12,120,68,32,39,234,135,74,49,99,117,54,208,199,61,114,8,102,155,100,170,72,3,186,151,169,143,204,64,14,60,115,37,44,84,101,51,120,0,53,42,211,157,66,209,36,40,195,81,61,72,60,209,167,171,114,32,89,216,83,201,85,122,76,141,157,178,87,253,120,25,141,29,246,216,98,128,203,84,189,149,185,143,40,230,239,167,185,211,92,51,191,104,127,40,166,241,82,121,28,215,187,228,124,226,156,79,94,109,237,145,109,183,95,157,172,70,95,233,67,222,42,222,87,127,83,221,231,114,0,3,123,79,254,2,129,151,79,20,161,5,68,27,165,121,8,124,103,158,215,22,18,186,234,229,11,139,204,5,49,233,15,65,62,133,145,216,79,242,199,102,179,220,156,156,73,84,205,142,168,79,181,44,57,100,133,228,41,46,86,33,119,78,63,99,242,130,106,164,150,216,27,27,49,234,4,118,156,237,180,81,175,188,74,140,164,129,200,1,112,65,231,34,151,83,47,255,228,196,129,132,73,251,23,21,65,22,32,218,51,21,190,242,219,57,87,210,177,202,214,170,23,42,33,85,241,106,220,120,83,121,59,20,130,120,199,114,198,100,3,38,126,138,52,213,168,144,226,221,146,212,252,212,210,197,163,4,174,153,125,152,79,137,4,95,73,186,232,161,40,167,255,93,228,153,41,25,176,171,65,238,5,93,165,38,80,249,184,172,233,113,238,84,211,203,198,44,82,83,205,204,176,39,224,208,51,88,28,29,152,118,171,126,91,58,65,154,229,65,236,8,188,33,92,132,220,82,79,252,184,99,160,97,146,56,79,209,81,53,101,43,202,132,182,241,61,231,151,129,188,63,141,134,180,29,7,5,32,144,225,76,191,230,198,31,31,163,64,61,88,117,225,96,96,41,101,190,217,102,10,157,7,192,207,231,15,239,166,47,95,252,252,214,28,139,47,147,175,87,31,62,92,189,253,136,147,230,112,11,51,246,221,214,46,156,89,204,82,15,134,221,77,179,16,52,13,137,114,88,76,43,57,60,171,172,149,186,31,121,216,90,137,81,189,114,255,52,137,87,225,222,184,255,145,110,104,116,245,167,57,52,204,25,192,127,187,59,133,31,41,114,207,124,92,84,55,210,179,158,157,212,39,116,111,82,195,65,138,121,146,150,139,12,180,58,102,96,246,187,189,23,81,182,52,181,185,114,173,20,111,138,7,2,118,119,113,126,80,8,30,169,168,158,129,221,24,68,16,35,80,18,211,95,181,131,251,6,118,109,198,84,35,189,121,77,174,143,232,28,227,67,77,94,157,223,92,201,119,252,231,231,171,159,108,211,127,230,63,174,63,252,246,203,47,111,191,188,3,184,78,219,112,98,237,222,59,91,123,62,12,172,15,77,18,225,171,182,81,76,189,155,58,173,131,227,0,14,105,44,94,83,179,143,8,226,239,216,82,225,72,102,39,7,198,222,143,248,206,32,212,227,41,201,36,88,227,235,53,67,100,198,188,143,95,45,90,152,234,231,77,56,167,234,252,142,188,82,155,39,199,91,56,209,122,21,173,33,61,201,49,70,52,206,146,125,10,18,69,21,196,117,157,215,20,82,125,122,226,132,103,248,66,49,107,49,61,195,107,116,58,138,96,144,205,83,115,59,94,40,31,225,155,204,155,10,231,81,65,62,56,145,172,69,39,8,90,102,188,159,146,84,140,26,19,209,116,23,175,244,205,183,180,8,187,224,102,245,110,193,85,179,232,3,123,148,102,7,108,76,141,233,75,55,152,73,206,159,221,1,4,207,60,55,254,177,27,134,118,19,76,162,96,186,103,172,198,130,80,155,13,99,249,231,255,139,25,149,166,240,22,141,244,126,174,30,162,64,199,78,151,222,179,85,161,30,250,106,227,19,120,9,135,7,220,110,201,124,222,3,144,241,206,155,244,232,11,67,247,87,44,101,171,71,54,125,219,13,234,245,118,216,137,49,107,83,199,108,55,16,117,165,175,253,8,1,141,82,133,233,72,243,152,225,37,133,251,110,31,244,39,208,56,56,125,233,125,212,210,144,176,73,3,104,133,212,168,215,187,149,114,81,160,68,248,63,199,72,152,108,144,105,170,220,121,41,128,97,122,148,176,223,100,84,76,30,194,137,195,23,144,188,18,26,203,113,165,108,126,59,109,207,95,135,71,145,200,221,200,41,184,6,10,47,120,158,71,129,84,217,55,243,58,207,92,242,62,173,130,131,189,146,231,201,64,128,99,42,203,129,191,112,33,131,144,90,190,238,165,89,186,24,249,75,135,117,3,5,82,33,87,179,15,160,127,114,176,14,213,43,78,0,225,182,244,97,234,127,213,118,0,35,47,220,162,127,163,8,168,75,253,26,9,56,251,202,47,137,98,67,122,143,56,44,80,24,22,129,222,46,89,79,151,252,55,199,70,3,174,23,76,51,3,104,104,203,159,144,140,225,176,140,33,207,159,223,13,227,227,151,179,212,111,70,102,46,215,28,183,8,216,26,249,89,94,179,187,40,105,155,94,83,231,81,75,21,19,163,98,252,154,147,50,168,141,121,200,40,81,114,32,45,198,208,62,116,150,143,176,125,191,140,217,71,242,202,28,71,135,158,14,40,194,66,51,230,141,119,218,245,147,87,87,81,29,180,7,90,242,104,99,24,67,2,230,143,193,197,164,3,4,238,174,233,219,187,186,232,188,194,162,64,63,97,24,96,209,136,237,62,136,231,15,51,0,111,20,116,139,18,135,57,104,28,233,82,75,159,126,184,48,104,93,230,56,130,97,51,101,26,234,193,77,226,231,167,85,50,12,191,90,32,185,36,180,148,105,134,170,83,152,180,109,50,224,225,63,213,147,55,197,101,217,26,128,139,205,187,93,239,38,23,36,231,94,115,183,80,105,152,134,118,141,106,42,30,47,154,100,22,136,237,232,45,245,124,186,100,146,80,208,28,46,14,20,179,221,40,77,201,141,62,206,105,92,115,42,213,124,215,18,137,195,239,217,15,84,161,194,97,88,131,47,140,18,182,181,83,82,123,69,109,107,31,255,225,240,9,227,237,186,122,94,19,193,245,184,105,238,85,59,185,7,10,205,19,35,15,102,252,86,133,25,208,108,206,104,42,186,171,54,36,169,153,253,159,41,1,149,219,209,17,45,161,25,58,57,190,17,12,77,250,97,119,127,2,210,236,205,138,66,250,28,194,231,179,110,9,140,9,121,122,222,128,8,239,156,52,195,247,32,245,195,37,215,96,147,201,19,210,156,3,108,146,245,248,89,89,91,152,4,111,219,136,84,158,36,44,100,61,120,14,182,23,211,76,50,213,182,249,10,193,229,205,50,74,86,144,204,146,215,238,175,170,30,38,88,195,179,30,146,148,93,74,117,22,241,200,237,231,206,149,252,104,240,217,1,40,130,111,238,164,104,200,214,140,192,13,149,39,112,148,147,137,89,116,99,4,145,207,49,128,251,2,249,130,165,28,149,38,232,216,228,146,251,129,47,45,198,90,234,128,72,95,69,138,96,226,35,248,222,175,207,38,159,218,152,71,24,52,243,4,239,245,22,9,95,7,51,235,171,16,14,240,173,76,95,21,181,181,220,222,87,182,158,252,11,220,104,30,16,24,195,184,25,53,88,80,219,163,102,196,192,64,243,134,109,75,166,105,41,145,87,72,168,7,42,176,31,213,111,98,17,53,31,12,203,209,53,222,18,6,150,197,124,66,155,104,13,0,114,120,128,101,178,223,158,197,129,108,213,123,141,40,125,193,54,130,186,47,170,194,160,11,219,122,169,145,132,51,46,48,64,72,210,176,220,141,30,227,236,63,253,36,253,52,251,197,108,214,182,241,203,22,255,248,183,63,16,255,76,247,155,205,240,255,126,215,241,69,120,129,19,79,114,114,73,207,180,58,32,197,85,227,61,146,100,126,193,95,170,24,163,137,121,173,60,80,80,179,111,242,162,230,37,36,135,25,78,32,59,91,238,29,206,187,213,71,235,205,102,175,209,122,154,15,118,127,240,112,126,197,95,255,205,207,253,255,112,57,103,179,159,127,251,48,185,254,252,219,175,73,189,253,100,145,42,34,117,184,123,167,128,142,57,182,42,15,13,71,4,252,33,188,216,195,238,48,216,163,19,109,238,115,199,69,96,169,108,232,154,106,5,29,28,169,56,60,128,38,101,105,166,76,152,193,161,168,197,223,38,242,135,103,158,107,138,244,85,38,155,113,167,106,41,86,13,68,230,121,26,90,30,192,54,26,236,188,172,203,25,149,80,121,35,214,20,62,118,128,109,99,130,170,58,19,61,9,212,85,27,121,122,197,179,153,34,219,16,10,37,190,140,242,61,24,245,87,122,219,123,111,145,17,192,138,133,45,165,162,144,83,191,199,57,95,137,19,100,10,1,215,139,56,178,219,180,195,95,94,124,79,44,5,170,176,208,34,172,235,21,58,0,91,205,132,92,244,165,83,245,127,255,44,254,59,240,254,132,238,191,122,254,131,56,130,215,67,235,206,198,13,198,127,191,41,209,253,105,22,137,152,115,236,121,223,163,221,219,19,108,189,92,219,54,234,196,40,150,110,34,235,56,8,180,133,46,239,196,131,25,35,39,57,77,10,126,37,152,24,23,185,14,140,81,170,36,16,176,91,112,6,90,212,166,72,181,44,187,96,59,166,153,31,193,217,158,157,248,173,247,24,216,86,177,31,28,191,249,199,70,173,172,38,42,72,251,228,234,166,111,22,194,228,165,109,116,159,158,209,121,223,198,137,75,178,21,237,60,33,161,74,56,32,48,188,57,23,233,201,159,164,76,173,70,31,28,60,236,221,122,171,137,29,88,33,30,15,85,187,1,178,109,149,131,217,130,246,109,237,195,233,40,68,84,153,168,218,74,230,52,243,34,177,98,50,231,212,154,54,240,88,153,148,195,233,53,200,180,66,106,28,114,146,12,220,54,162,125,98,108,215,62,50,108,102,19,209,152,92,140,38,67,217,204,137,69,212,205,179,220,109,30,212,239,84,208,102,217,118,161,249,12,119,192,229,206,23,81,183,246,67,139,210,29,99,247,156,172,11,66,180,12,170,28,88,197,191,55,235,193,119,239,131,140,117,16,15,39,121,165,89,110,185,35,58,14,49,89,164,139,156,98,143,92,254,76,120,21,3,79,11,94,89,207,98,51,35,13,159,219,4,47,15,247,97,158,189,140,180,72,66,68,39,244,174,142,176,92,171,108,247,132,190,85,34,94,220,58,65,209,65,101,204,129,157,89,150,241,85,12,236,236,139,168,43,117,71,101,154,94,77,123,208,184,138,98,22,187,189,108,165,154,139,115,138,140,120,180,197,137,93,116,120,193,20,44,30,152,240,40,64,19,153,9,38,234,34,173,40,139,116,14,159,154,135,114,32,173,174,144,226,98,148,83,66,170,255,193,196,7,5,182,23,188,174,171,213,138,130,172,155,9,234,55,47,239,218,37,167,147,239,74,106,53,210,166,54,189,5,76,200,141,220,59,8,213,9,7,18,47,13,4,21,137,155,233,247,222,2,168,73,145,49,38,85,81,108,204,111,155,70,63,14,103,248,70,127,62,167,60,106,252,124,65,111,242,54,227,199,7,190,99,183,159,221,181,127,78,79,76,254,227,39,89,190,48,213,162,161,200,129,12,63,159,124,151,8,195,114,173,147,237,44,229,135,156,238,48,149,161,124,108,107,26,230,200,169,118,155,102,205,158,13,117,104,172,157,121,133,42,206,222,254,54,181,68,243,76,105,250,160,63,121,219,245,28,51,152,118,56,205,254,18,181,144,249,75,52,168,28,80,7,87,153,201,111,30,158,36,9,226,170,244,17,22,34,101,32,58,28,35,63,156,210,47,29,85,134,79,228,71,85,220,228,10,130,106,232,222,164,212,181,243,67,211,173,250,160,233,69,113,38,68,88,104,5,39,207,73,83,126,203,57,29,183,220,15,59,247,231,37,155,55,75,254,56,106,228,229,130,158,47,216,223,180,57,190,28,147,52,40,16,36,220,9,69,135,1,20,98,253,234,145,75,64,211,167,183,78,6,48,96,209,138,249,225,112,216,197,33,212,200,203,220,104,92,40,71,32,37,158,238,52,203,125,95,15,211,194,178,148,222,214,110,115,81,150,204,129,162,8,102,126,126,85,198,19,199,253,176,39,48,63,86,195,190,76,134,71,183,116,178,221,248,236,35,45,24,195,114,56,159,40,63,70,246,172,76,12,240,72,185,239,118,216,109,155,232,102,56,27,13,102,15,78,201,29,131,67,231,184,136,238,52,34,235,168,100,134,118,187,5,114,207,91,181,146,55,87,154,64,247,26,89,4,185,189,22,107,83,32,160,164,86,207,18,133,179,12,233,86,12,131,68,181,110,235,249,80,205,3,135,33,107,149,102,64,128,183,150,25,233,73,57,6,49,198,20,251,224,200,145,106,79,19,77,71,254,3,134,245,45,131,255,200,13,72,232,51,96,247,98,168,72,26,42,24,77,83,133,4,134,244,113,63,111,251,241,210,194,23,245,77,150,56,102,131,160,39,98,31,93,122,3,222,196,129,11,216,78,170,198,132,129,228,104,96,182,65,218,99,248,157,166,177,132,105,234,98,144,14,144,102,116,131,113,59,119,34,156,81,129,222,124,24,72,246,219,201,6,203,178,222,209,163,40,159,240,92,69,39,108,212,9,153,198,234,28,145,175,107,161,63,167,231,142,245,81,167,229,214,54,190,137,188,210,127,239,106,84,110,46,188,103,56,35,107,198,163,103,21,88,39,87,41,165,45,179,223,32,187,204,80,30,244,117,49,200,189,113,152,83,166,17,189,247,78,142,209,220,93,122,69,220,110,50,243,59,116,207,205,79,195,114,182,25,235,249,99,153,57,33,49,146,235,61,190,224,228,187,198,83,204,63,54,78,185,48,249,208,252,101,158,226,247,197,107,164,205,117,249,121,138,33,141,52,87,226,224,109,6,140,0,156,122,11,214,210,179,45,185,168,27,227,253,142,237,16,164,175,118,95,147,253,181,13,89,252,227,60,150,83,0,23,85,226,110,247,110,109,251,133,128,112,254,86,187,94,199,3,115,213,65,251,187,241,110,148,192,20,65,62,82,229,19,205,128,182,61,62,170,28,131,134,231,59,13,56,42,59,129,254,145,15,226,231,141,238,124,164,39,204,172,63,185,233,186,131,73,235,83,163,181,92,231,76,208,134,9,80,112,153,61,24,205,94,179,60,233,104,216,171,202,116,113,25,125,193,136,28,132,51,211,220,111,174,142,70,254,176,12,154,64,111,77,18,201,126,183,94,35,141,81,237,127,136,223,223,164,48,163,184,160,20,36,143,21,109,249,241,21,137,28,18,157,205,58,122,230,77,6,115,90,192,65,122,226,138,178,61,90,52,243,24,230,227,236,191,25,206,5,59,154,97,42,131,204,209,70,127,241,50,190,47,180,171,235,178,93,211,173,28,122,124,144,136,148,115,184,0,61,95,240,109,36,37,128,97,9,241,124,227,126,60,147,190,141,207,26,44,247,61,163,134,203,237,182,179,250,239,236,119,64,68,101,62,126,198,125,40,230,229,112,169,155,195,39,72,78,235,123,246,76,168,169,156,245,104,39,244,65,168,100,129,29,104,161,153,39,80,60,230,225,152,252,84,39,183,94,112,196,31,74,189,26,119,136,171,70,76,70,68,248,3,123,72,23,237,102,76,228,47,232,178,231,48,105,175,239,80,237,112,223,29,4,4,105,80,8,234,132,139,98,84,136,215,18,80,186,30,216,204,156,138,161,156,152,97,215,42,145,225,153,45,142,158,73,170,68,28,30,190,137,243,252,57,151,129,15,139,40,243,177,90,172,3,204,197,71,14,72,127,143,218,123,154,131,147,185,240,27,117,51,23,182,220,54,173,91,207,154,205,12,179,24,242,252,211,182,91,155,189,102,196,242,51,62,86,147,180,193,214,152,215,159,98,17,148,219,79,188,12,238,225,134,68,255,12,126,34,124,105,84,227,76,15,151,50,248,205,159,233,99,153,82,45,221,62,178,74,28,34,65,141,78,150,205,191,57,81,57,243,134,127,33,29,160,68,250,83,215,14,181,227,106,211,72,232,5,12,231,228,164,169,31,152,17,73,143,180,78,56,13,115,237,212,57,15,221,201,92,21,141,251,178,33,194,75,110,15,76,103,230,244,160,33,185,247,209,91,130,172,157,124,124,23,254,12,239,209,212,41,142,69,42,22,113,252,49,166,130,54,103,197,37,19,181,8,123,204,99,186,72,94,31,78,235,110,68,152,185,114,188,109,53,89,215,152,206,177,89,236,18,33,24,184,230,114,41,27,131,241,180,16,12,2,77,105,159,23,79,227,123,39,166,154,2,41,247,218,188,120,246,148,108,220,59,178,51,98,91,128,252,200,249,26,89,123,189,139,11,245,251,232,75,144,174,15,183,18,61,78,201,173,44,193,50,24,60,85,18,154,233,89,36,247,78,203,132,126,38,149,222,26,139,148,51,41,245,237,47,62,127,3,148,8,166,178,15,152,81,165,6,25,95,46,130,221,208,17,118,72,142,191,124,65,18,218,101,240,229,199,188,231,100,113,183,237,48,226,88,137,232,56,102,58,37,174,41,143,192,165,5,229,105,136,227,247,177,222,210,105,183,99,148,32,152,116,20,218,12,132,163,94,155,38,15,120,183,169,43,6,81,177,30,197,108,1,39,204,240,218,29,87,21,211,220,210,20,47,215,161,98,214,166,11,154,244,109,63,192,48,7,73,221,129,138,245,229,252,95,142,53,116,144,104,49,160,157,21,238,106,4,129,227,184,62,103,77,123,66,175,176,105,100,47,240,51,28,21,229,30,141,25,60,170,85,182,244,138,22,82,167,21,8,199,151,167,70,233,160,182,170,23,235,202,166,244,146,198,38,128,145,130,42,58,142,185,78,236,228,170,82,38,45,249,58,88,212,53,52,115,146,160,220,252,118,38,124,33,229,13,108,150,50,97,238,247,97,184,13,91,129,202,97,236,93,107,59,74,62,148,101,113,232,149,154,75,67,192,200,89,165,57,162,40,123,150,195,126,92,69,78,35,124,66,171,181,34,84,34,27,148,64,184,72,173,32,142,6,19,72,241,160,79,228,220,105,106,15,218,53,60,121,89,215,143,130,244,114,80,147,173,44,49,27,69,171,147,122,96,211,244,35,46,190,179,145,31,61,110,188,232,187,60,139,42,240,59,227,123,51,177,127,215,174,28,78,28,184,146,151,47,124,168,162,63,8,252,177,139,81,209,89,179,188,248,16,149,211,56,246,237,6,57,40,36,155,79,62,20,208,29,62,87,153,54,166,107,204,111,19,32,234,30,132,147,237,38,230,186,46,3,179,231,129,202,206,34,86,164,177,232,248,128,24,7,58,224,155,76,66,58,161,202,70,151,217,223,209,0,22,231,35,40,20,95,206,103,198,20,143,103,85,29,67,45,33,125,251,209,59,165,199,41,44,125,145,103,148,19,229,207,100,55,176,37,239,250,209,51,154,23,244,35,111,233,143,6,164,110,202,75,244,12,87,162,61,78,9,45,0,24,106,38,7,148,6,241,89,161,79,36,116,179,7,209,35,35,167,225,53,132,62,178,83,120,172,37,252,106,178,130,49,141,192,22,20,123,174,191,85,215,201,228,37,200,142,51,247,218,179,155,3,151,116,52,133,38,41,105,86,218,6,31,149,4,81,10,232,180,125,101,211,22,173,29,180,80,140,30,215,213,177,183,88,24,191,162,242,29,175,151,144,57,36,222,83,7,168,123,141,170,253,201,89,156,205,56,163,240,174,253,22,220,120,62,93,70,223,161,174,75,78,217,145,123,27,156,213,28,70,99,46,220,44,226,45,144,166,108,30,87,158,198,227,15,72,27,84,116,225,29,125,226,73,244,155,167,34,64,248,34,178,184,233,89,134,212,19,228,107,144,59,152,15,26,53,242,141,28,61,229,254,252,205,97,184,25,51,210,144,249,243,230,51,194,236,215,42,45,3,6,138,78,222,201,132,64,174,179,103,182,105,244,80,153,173,69,37,66,242,57,193,75,179,85,226,99,213,139,98,154,197,108,150,6,187,103,71,149,207,88,18,12,39,78,225,131,207,29,146,129,121,76,70,210,185,3,182,225,179,103,189,57,187,124,189,217,139,58,249,111,188,102,139,142,236,115,192,51,140,1,129,88,70,104,75,199,216,68,102,10,128,249,3,118,205,74,195,3,59,59,53,211,177,222,240,247,61,181,140,162,155,86,125,113,148,207,139,194,128,83,116,211,152,250,139,64,65,123,224,68,205,145,238,195,23,72,16,205,200,114,23,19,98,82,57,32,109,208,244,128,190,103,18,90,16,102,204,167,148,187,225,224,81,161,94,246,195,146,183,240,199,112,34,22,7,102,0,197,129,55,231,69,30,143,14,243,152,94,252,198,135,60,210,104,198,104,242,231,189,115,108,56,217,222,139,143,6,87,95,218,177,3,109,165,104,47,180,85,89,237,89,55,125,221,209,146,249,198,144,39,199,89,211,220,95,163,119,124,160,40,210,132,178,141,103,190,91,213,52,31,55,117,154,192,248,55,154,142,92,193,56,254,197,91,177,253,217,25,111,240,61,114,188,141,87,162,80,32,116,236,139,117,125,216,89,76,83,205,56,163,16,204,104,28,143,193,71,68,22,107,109,177,75,99,130,9,195,138,194,74,87,7,156,241,89,99,133,9,66,111,125,92,169,173,133,215,74,192,249,136,250,175,134,195,93,9,224,68,99,25,152,183,65,122,198,89,65,113,247,133,186,172,110,188,89,24,201,21,121,200,182,229,223,48,162,163,122,152,134,117,107,68,192,155,230,216,239,6,103,196,234,7,88,78,212,179,157,221,73,233,51,208,189,52,220,176,241,34,76,5,240,247,70,157,212,108,66,126,34,47,255,98,204,81,82,119,196,194,93,21,77,242,140,139,55,71,227,95,18,159,78,116,208,123,193,211,173,246,166,126,234,183,149,216,97,253,29,162,246,128,172,177,253,212,201,40,212,121,128,22,58,136,221,122,59,40,84,217,218,26,186,7,138,229,56,216,187,201,209,214,17,169,118,194,209,16,241,72,224,193,99,246,98,187,72,174,62,74,82,182,20,236,5,42,155,71,175,52,82,216,251,104,82,183,114,234,61,14,186,120,165,164,61,117,64,158,218,66,135,140,236,156,31,236,7,80,186,96,66,215,169,179,29,174,176,199,122,247,166,19,225,136,245,196,206,20,3,206,110,156,189,141,79,112,125,117,115,148,186,24,155,204,20,252,198,24,194,144,142,227,19,146,87,118,76,242,36,100,75,164,163,14,14,218,169,209,171,104,201,125,130,59,71,28,37,194,159,118,227,56,205,194,13,138,70,89,191,180,187,46,199,11,147,70,167,134,121,144,189,8,217,242,104,52,170,61,193,57,84,250,150,238,86,150,218,19,139,247,208,30,234,149,156,229,113,77,232,152,37,19,59,186,204,148,54,119,99,3,193,196,146,77,192,152,188,14,88,248,154,5,235,29,105,78,160,38,232,127,248,188,32,77,119,179,11,177,41,174,28,91,233,73,34,120,37,148,241,145,154,202,182,47,89,211,131,17,86,69,237,47,157,16,175,67,176,60,232,76,7,38,101,105,183,35,141,203,72,47,37,87,79,170,222,155,131,143,165,84,107,30,233,58,183,77,242,50,74,32,166,248,44,219,26,148,159,40,189,123,131,68,1,130,81,144,134,89,153,56,223,216,83,79,4,106,153,245,74,42,58,62,48,178,74,35,238,184,39,25,176,192,255,110,235,118,203,30,70,135,231,224,101,229,113,218,37,204,72,253,149,202,42,222,72,245,111,39,113,10,164,48,169,50,243,111,249,214,7,176,169,72,165,38,239,198,69,119,132,16,210,240,116,92,70,14,63,230,68,135,171,255,123,97,57,213,213,196,48,108,86,255,89,113,62,250,205,251,171,235,216,137,3,143,140,211,162,215,196,193,251,127,15,210,132,9,38,148,113,106,166,144,155,8,2,229,199,98,168,45,241,189,32,16,194,148,91,230,190,98,192,173,191,206,156,53,140,70,147,88,68,242,17,28,161,196,173,148,210,57,77,140,30,169,217,63,189,173,40,234,89,160,39,84,41,181,238,251,139,253,74,1,154,210,241,94,237,159,89,252,219,27,211,4,243,85,218,185,106,66,239,111,239,24,226,40,16,102,159,234,167,22,157,155,82,118,41,11,50,26,35,187,52,25,126,84,13,226,130,224,215,165,138,93,120,218,248,6,90,130,213,200,82,92,38,222,92,85,110,59,18,174,104,145,56,183,127,254,218,108,144,172,210,63,202,145,166,172,250,63,146,241,81,15,249,243,193,208,39,143,176,80,92,202,240,47,181,123,41,31,55,77,193,220,216,75,246,52,102,116,36,166,147,147,103,182,178,173,169,70,29,80,22,206,155,144,166,121,167,241,137,69,211,199,192,245,84,115,162,185,181,7,92,28,170,142,66,145,55,221,209,72,11,11,207,78,42,160,34,71,34,141,168,6,118,218,115,118,245,7,163,96,204,100,252,66,14,128,41,236,201,162,70,47,46,218,119,79,28,154,163,27,189,124,113,21,197,23,17,106,216,21,160,111,184,205,149,169,181,216,134,232,35,72,243,4,199,5,76,1,163,238,119,74,71,36,64,20,172,17,198,66,151,36,79,145,186,244,64,39,88,135,14,84,107,64,251,201,171,98,235,52,155,121,65,119,31,100,189,212,134,36,112,9,141,53,249,253,242,230,52,6,12,239,185,174,30,176,4,204,34,165,137,220,169,243,111,244,54,116,237,36,40,142,232,107,183,52,71,50,114,104,126,136,50,120,140,29,93,58,100,237,150,11,245,31,66,84,255,6,163,58,73,195,196,47,253,45,227,186,168,63,215,9,153,236,56,46,175,163,17,14,83,142,79,190,95,145,177,61,146,78,158,87,94,70,110,55,117,245,33,217,183,25,229,162,0,117,242,163,151,82,191,192,219,173,183,114,217,57,37,131,221,251,78,10,31,253,177,131,252,243,36,11,1,62,43,90,234,98,22,33,247,228,177,129,57,219,109,123,127,242,2,105,178,95,115,202,89,24,112,8,103,159,220,3,225,105,193,179,246,148,124,153,0,58,97,122,115,191,245,145,8,209,142,108,81,99,67,44,44,243,197,158,154,197,43,144,222,248,97,213,222,137,54,195,244,63,41,47,98,109,170,57,114,211,155,129,124,133,124,78,39,10,174,235,199,32,13,42,26,88,174,38,63,94,254,34,147,170,42,169,15,147,205,124,245,167,152,88,76,187,172,171,178,13,4,211,89,99,224,217,154,49,18,25,86,133,165,36,60,195,129,224,244,115,112,216,28,248,16,143,155,34,197,120,31,212,67,18,89,74,184,35,182,164,14,50,72,175,59,249,86,153,87,146,152,159,69,102,159,40,165,130,172,117,14,48,194,124,80,217,180,165,124,178,110,103,234,159,20,21,201,95,73,224,195,73,28,100,207,110,52,5,103,127,128,103,45,120,32,135,94,215,206,235,227,138,174,119,198,144,50,174,99,86,50,236,168,170,28,135,162,3,187,234,15,131,159,55,196,254,109,53,99,123,14,130,142,151,47,222,126,248,160,202,107,74,128,82,113,75,93,91,160,182,172,250,24,155,75,167,0,193,112,80,216,50,98,9,165,179,136,150,170,17,11,145,235,145,188,6,162,54,120,82,50,38,59,133,61,146,72,60,97,216,130,173,187,187,130,212,232,83,149,108,211,19,80,222,217,119,47,145,57,204,2,169,185,193,41,86,209,213,7,14,174,98,24,233,164,132,232,139,59,4,159,148,254,216,49,201,79,232,228,218,206,175,123,180,196,18,209,5,29,50,51,151,30,97,203,40,81,133,139,215,19,86,0,228,35,0,72,212,60,108,154,123,100,216,98,144,210,177,126,126,93,180,248,70,49,60,205,20,53,103,228,183,171,155,75,200,185,24,220,251,152,125,234,194,66,216,125,181,231,225,232,115,224,151,186,152,123,61,122,149,65,176,46,224,190,96,137,136,62,19,136,216,179,16,77,143,116,13,11,130,56,238,105,185,83,129,59,149,168,193,111,150,168,147,3,111,181,80,27,116,61,154,66,175,22,137,253,136,77,95,179,14,26,64,154,54,66,155,6,170,73,252,63,62,191,51,78,114,156,236,169,58,134,210,48,116,151,19,119,171,19,118,220,105,206,240,138,132,179,168,245,47,225,56,137,226,110,134,204,10,160,236,11,104,74,76,155,60,84,127,233,253,243,65,238,90,76,50,56,174,193,8,100,186,104,15,211,7,204,217,0,148,10,203,254,230,184,98,239,184,183,2,192,179,60,228,125,58,248,221,228,235,251,183,55,104,31,183,171,165,246,234,163,64,37,62,12,15,131,128,219,83,87,44,121,69,154,53,224,113,213,230,68,188,112,162,252,127,225,212,188,116,247,163,21,41,23,78,159,28,104,129,146,181,39,10,135,17,52,34,53,138,140,125,143,34,249,141,244,200,111,159,242,83,141,178,137,154,4,53,165,25,76,212,92,163,0,131,239,100,62,55,10,254,36,213,97,79,35,103,71,164,40,6,50,186,22,12,80,227,98,144,103,7,19,58,253,57,142,93,141,149,26,61,73,49,46,76,68,76,163,53,11,148,149,214,142,55,137,150,107,77,213,33,217,229,129,83,139,102,218,184,193,108,182,219,20,255,192,96,245,226,159,197,95,207,243,80,11,238,195,208,237,181,229,76,163,181,221,194,73,14,112,6,109,213,252,93,174,51,46,93,234,64,144,22,31,101,91,60,135,99,75,149,177,187,45,30,226,226,252,8,86,59,81,75,70,112,243,216,127,25,132,251,240,19,136,185,134,138,39,112,173,75,66,226,99,152,196,20,218,181,3,65,0,43,144,190,60,53,225,54,204,204,24,42,80,4,30,37,155,123,26,157,203,104,71,8,113,219,148,46,181,125,138,119,96,168,103,104,218,64,191,23,7,128,83,207,7,114,57,186,199,220,57,54,79,3,218,146,135,155,223,185,253,178,51,101,106,241,218,176,159,13,79,45,8,182,62,124,152,252,122,249,229,250,243,167,235,201,199,207,95,46,49,96,234,211,228,237,228,227,213,135,203,151,47,222,95,253,242,126,114,243,121,242,225,18,228,155,32,156,249,233,243,111,95,110,66,109,231,249,220,207,49,198,159,127,36,18,4,67,80,208,18,136,9,187,167,142,248,239,154,56,250,92,62,227,147,34,117,244,15,224,58,125,92,40,99,168,24,101,29,82,110,244,75,207,111,142,43,64,229,3,104,132,16,146,92,56,167,158,95,213,19,199,4,191,110,71,150,53,104,204,102,3,30,171,154,224,91,170,147,81,126,54,90,56,204,137,3,160,21,223,75,99,86,176,250,207,188,220,141,79,116,47,231,170,126,218,161,124,2,176,242,169,229,74,25,156,2,246,19,142,191,167,249,146,156,20,124,181,207,2,54,11,99,31,199,109,26,16,123,115,216,83,141,215,125,184,226,193,201,186,206,26,84,10,240,2,145,73,128,167,186,136,14,75,44,153,168,104,156,106,138,121,6,10,89,70,53,69,59,129,60,66,204,224,227,157,82,107,105,45,247,155,145,206,104,12,213,57,115,14,227,177,2,35,49,73,51,101,130,239,171,17,44,181,248,252,248,249,66,9,192,110,247,209,242,101,139,84,123,62,216,142,42,184,132,61,105,129,240,213,116,38,208,17,24,6,200,179,141,179,82,8,204,228,96,36,212,33,197,155,215,203,118,27,48,49,77,2,199,29,247,25,90,159,189,29,53,9,33,232,118,253,174,90,21,35,10,242,154,180,234,82,53,55,166,83,56,48,180,177,56,7,101,192,117,177,74,129,204,75,223,18,112,235,185,101,178,157,138,209,173,220,99,138,200,38,236,188,63,186,87,19,62,255,118,115,125,245,238,210,233,180,118,27,228,243,18,106,90,3,152,178,145,243,126,68,17,0,166,167,202,203,175,148,160,32,101,78,116,205,248,79,248,241,190,224,2,124,27,177,167,159,206,216,41,144,9,218,61,92,229,166,89,175,65,181,224,83,103,246,135,43,244,169,149,191,72,116,69,251,119,242,19,77,16,209,18,71,234,169,58,234,244,169,148,131,245,248,238,38,12,31,28,72,87,175,65,243,26,229,177,247,117,33,65,205,186,25,24,21,133,160,177,81,221,223,233,132,242,25,223,225,142,129,1,143,65,4,176,233,54,191,62,123,138,117,61,64,203,167,25,45,224,126,85,83,64,226,247,94,106,178,152,206,158,148,31,84,139,167,75,135,18,51,8,67,114,32,86,111,22,101,237,107,47,52,1,49,98,246,185,19,88,128,160,83,38,174,33,113,207,194,121,82,37,162,237,8,241,77,85,106,174,26,29,163,200,94,246,243,37,103,1,154,37,102,147,63,169,60,16,33,124,75,15,199,69,224,211,146,50,3,88,51,240,86,193,35,216,20,213,107,175,35,86,49,144,104,50,199,72,49,7,160,44,69,154,37,175,128,210,26,117,10,51,216,132,233,249,196,133,249,202,105,134,163,116,228,174,219,34,94,28,206,124,53,154,229,54,249,245,203,231,127,94,94,171,137,114,215,172,70,171,52,86,127,190,29,249,116,166,14,247,110,60,71,216,153,140,167,153,70,133,35,152,55,199,156,228,18,225,132,86,249,226,109,23,235,103,108,223,205,161,103,125,178,183,202,193,225,34,229,49,81,189,146,23,111,234,229,132,121,121,67,115,54,66,49,252,200,73,185,46,85,41,0,56,194,37,51,77,65,52,149,250,117,216,95,61,140,6,119,196,64,241,141,75,239,134,61,102,197,182,247,225,227,46,107,87,58,167,51,151,69,187,71,180,124,236,19,77,43,107,244,225,21,58,83,229,97,99,6,28,201,166,221,4,187,28,28,246,31,242,103,144,10,120,144,116,7,192,116,190,172,48,202,247,224,82,64,135,240,229,175,138,94,160,254,169,89,95,148,143,247,190,22,182,159,233,45,118,114,94,9,181,7,86,12,150,1,243,21,191,251,90,75,44,154,240,101,134,110,87,127,95,60,220,149,218,217,60,149,176,221,169,57,59,60,234,196,72,20,253,255,213,144,50,205,222,137,132,5,122,83,62,223,213,36,241,65,51,72,161,194,121,8,158,95,243,26,71,151,196,249,231,47,145,224,38,48,30,72,16,243,97,94,231,79,113,63,32,107,93,237,62,150,59,210,107,7,81,140,174,120,35,138,171,33,133,154,76,228,143,210,141,233,213,175,38,222,196,234,239,239,237,226,92,170,242,154,87,155,111,237,234,91,237,240,5,212,183,238,239,81,254,26,237,138,45,45,26,83,28,215,193,108,189,239,210,189,189,215,232,25,47,255,180,221,87,38,242,73,66,58,122,178,143,251,24,235,18,195,169,71,98,56,218,225,31,243,4,76,113,83,97,242,110,51,124,159,63,244,214,44,252,93,207,211,171,107,177,187,229,174,30,158,14,174,245,62,58,225,24,168,218,251,246,209,58,61,122,58,225,103,205,208,115,7,40,94,253,82,26,216,251,21,16,57,142,222,247,103,102,48,17,116,17,1,163,118,249,226,9,129,109,238,224,162,50,213,202,221,141,148,100,119,120,173,31,245,224,26,153,142,176,88,124,93,37,201,125,248,254,68,221,165,16,52,55,235,36,247,248,169,62,167,168,34,89,72,103,179,96,14,148,17,235,118,166,38,188,168,73,75,97,30,85,15,87,239,137,43,144,114,148,179,194,56,146,190,38,119,100,18,3,125,204,162,231,5,136,239,18,33,128,74,9,118,113,85,24,158,169,41,228,122,65,154,22,207,14,169,234,190,163,235,120,159,19,34,122,238,53,219,196,129,240,34,103,14,246,172,111,254,84,155,200,100,242,191,175,254,119,24,145,152,88,17,142,0,106,112,62,164,61,26,179,249,2,99,18,0,247,88,138,30,151,163,196,205,237,181,133,170,17,171,251,93,178,55,250,220,109,166,26,245,184,41,87,210,49,64,181,178,96,9,73,21,30,234,69,222,131,194,155,57,188,234,73,55,165,175,96,123,43,228,80,187,149,3,145,218,29,217,3,242,244,27,29,215,77,93,107,198,178,24,46,72,200,96,91,46,126,108,208,75,3,165,151,231,144,40,164,75,112,208,126,155,38,94,121,178,218,77,147,44,237,203,23,64,198,229,193,111,185,116,190,30,49,231,41,1,92,71,79,76,237,41,151,226,93,149,58,77,126,184,61,222,171,217,236,250,237,213,59,123,58,50,42,78,62,125,190,153,92,127,189,250,56,155,189,18,240,207,7,85,63,65,15,64,104,161,218,207,83,81,245,40,169,71,87,179,140,130,217,213,40,56,117,66,174,112,180,152,15,117,184,18,69,3,125,53,134,130,203,212,184,245,157,38,183,33,67,26,12,13,4,73,218,51,70,170,157,37,126,88,218,174,22,89,19,136,91,238,90,251,159,228,27,3,213,222,9,58,208,107,196,212,73,240,78,222,15,83,72,48,116,12,167,83,225,45,124,133,148,121,67,94,226,213,215,203,201,63,62,125,254,58,185,186,65,14,230,199,203,201,205,151,223,46,177,116,138,33,20,66,43,90,79,201,190,217,12,132,141,191,32,93,3,58,232,207,159,46,167,200,219,252,238,63,186,250,56,185,249,250,25,215,0,105,188,50,30,169,78,244,228,240,244,69,12,207,102,254,94,237,162,33,146,35,100,41,38,10,153,7,32,81,122,197,219,32,159,244,229,242,230,183,47,159,46,223,77,126,254,242,249,163,238,249,25,229,238,76,82,60,30,90,14,215,178,168,8,86,227,49,125,202,116,116,205,14,21,30,228,222,167,147,109,235,115,210,163,185,79,136,140,104,208,68,101,228,162,200,46,139,92,218,135,138,18,75,177,225,28,117,165,135,125,32,162,173,201,143,151,63,35,3,6,221,241,254,237,59,193,87,126,190,186,193,106,241,253,157,194,149,224,69,172,9,166,199,169,150,239,220,127,111,142,114,41,35,143,155,24,132,179,67,127,28,115,172,4,192,193,42,120,163,7,57,14,30,133,228,139,46,8,47,49,121,246,82,137,95,15,20,17,58,163,107,220,180,95,84,76,208,237,205,103,141,174,138,156,75,12,15,27,202,114,114,208,148,61,13,156,128,198,117,58,213,206,166,69,24,213,61,190,142,241,101,236,244,247,20,178,106,160,94,106,10,174,68,88,147,71,7,233,49,107,97,59,56,23,50,62,141,9,70,58,123,90,246,11,53,26,35,85,68,184,55,81,252,23,107,179,116,156,237,73,57,82,38,159,180,80,95,132,105,23,109,159,137,57,9,217,195,139,113,128,182,160,202,80,250,52,135,70,26,38,184,27,181,26,150,56,143,3,22,66,198,185,117,206,134,98,190,60,185,39,63,20,22,59,77,53,113,99,53,234,152,126,249,162,40,101,176,3,32,205,30,26,160,57,154,26,231,81,56,152,113,212,231,164,255,71,97,30,112,96,200,86,194,235,96,84,57,155,249,29,165,162,89,158,44,217,54,238,229,216,68,135,210,40,4,36,217,70,154,29,165,66,51,35,217,111,84,100,12,27,71,55,75,49,224,123,159,36,130,60,216,230,97,87,31,61,104,86,242,24,38,145,249,128,175,52,233,236,236,84,190,56,195,145,188,48,126,54,134,68,105,12,109,70,134,4,130,33,242,151,159,152,55,99,229,116,145,213,80,73,18,40,67,116,202,109,114,0,134,2,51,59,188,154,251,249,151,83,203,121,127,211,197,247,25,57,30,225,245,157,6,133,148,28,96,9,186,227,21,2,74,122,166,10,235,208,153,95,214,245,2,0,39,135,250,126,181,231,234,243,64,17,58,189,36,96,183,143,240,47,149,79,53,40,119,106,143,191,98,93,240,94,253,107,98,186,90,221,51,73,86,249,241,39,69,182,15,51,191,171,195,19,32,61,158,88,93,119,155,60,13,141,79,160,72,25,193,117,133,51,63,218,152,236,84,166,77,96,45,176,203,216,88,85,84,205,27,180,104,70,121,48,84,138,153,146,225,225,100,127,135,123,161,84,190,43,90,208,24,28,20,5,97,54,35,213,125,90,8,170,151,180,185,156,67,185,157,6,91,177,105,237,16,172,252,72,175,71,147,143,168,149,108,107,129,207,139,49,109,203,106,49,26,85,119,229,63,12,124,77,0,167,192,230,188,62,27,203,79,234,201,180,3,33,88,75,44,68,193,245,146,57,87,162,135,34,188,42,5,39,232,219,24,58,108,149,25,209,60,85,67,43,59,10,220,190,165,138,103,189,73,240,99,42,149,215,94,238,99,254,194,101,58,83,4,231,7,155,60,54,196,187,46,67,44,164,156,144,56,250,250,246,26,158,235,232,117,167,142,107,75,222,148,131,129,97,42,186,157,16,75,173,107,130,186,122,205,28,173,133,32,14,37,34,107,199,121,49,74,196,59,15,131,12,145,242,71,35,235,197,195,149,143,130,234,208,195,17,43,200,222,89,121,99,190,137,98,55,71,109,149,15,25,179,24,238,178,89,254,209,199,14,248,75,247,36,22,78,189,19,190,39,52,162,234,63,118,127,87,20,234,44,180,149,112,97,194,239,194,4,6,78,170,223,37,142,76,127,1,228,146,253,108,58,62,101,163,33,120,36,160,78,207,156,183,120,154,135,131,112,152,128,224,194,124,39,110,172,156,238,232,224,76,119,19,2,154,188,166,248,104,202,59,253,172,238,11,92,110,225,51,180,51,155,161,243,204,5,35,23,227,115,40,118,193,154,116,212,154,205,222,243,152,204,120,204,205,110,11,109,230,171,145,99,10,42,6,233,27,210,19,16,129,139,106,115,65,103,20,58,14,247,156,205,242,33,88,6,70,154,133,242,52,33,128,107,239,120,34,10,102,237,102,81,179,28,2,100,211,246,137,245,75,152,216,86,141,253,128,122,196,0,249,224,190,199,24,6,93,67,131,248,170,149,41,161,158,152,244,120,50,62,184,183,29,74,66,66,56,52,214,101,193,196,177,64,29,36,34,228,143,167,165,82,7,150,9,24,226,208,161,228,97,67,146,110,213,120,3,182,159,238,114,86,135,222,64,47,5,83,3,49,61,247,67,87,196,66,116,162,30,58,144,7,34,45,180,146,1,164,34,172,235,212,49,59,74,69,122,31,129,169,222,253,108,134,223,222,231,42,192,71,53,137,217,35,179,191,66,162,180,167,135,234,201,174,130,184,137,214,187,109,87,39,247,174,171,98,198,55,173,49,59,183,122,2,178,240,239,162,169,176,242,209,21,26,19,235,44,231,129,230,161,243,61,171,197,144,105,65,231,106,154,166,91,7,222,115,52,168,195,25,116,58,223,95,180,51,44,217,112,147,60,101,83,62,187,218,243,103,106,64,179,147,131,182,200,104,200,102,148,223,60,204,238,170,187,189,90,81,2,157,223,250,49,200,109,5,146,119,233,165,109,6,30,129,221,210,254,58,239,180,138,190,243,205,160,219,0,229,233,247,17,140,59,30,62,17,216,242,87,164,163,42,18,244,10,4,160,61,233,194,207,132,110,202,167,13,244,211,101,62,63,183,38,21,29,50,128,33,54,137,164,136,142,197,186,249,83,229,159,20,252,137,108,23,245,145,187,212,198,148,250,242,70,243,236,19,108,195,177,99,74,61,240,66,28,185,180,224,233,153,38,151,35,178,50,217,149,0,215,205,87,106,190,21,53,105,49,56,128,124,125,97,170,216,96,210,178,102,235,41,154,4,114,211,56,129,167,148,88,125,16,146,106,199,68,174,157,177,193,197,92,167,36,97,215,80,48,50,67,130,67,83,224,113,45,14,91,140,208,123,8,244,183,219,85,145,142,112,236,94,64,118,205,253,88,244,186,3,101,158,159,116,113,63,124,168,33,250,132,237,181,234,237,140,185,176,85,129,22,164,248,158,39,40,51,16,196,105,14,232,72,206,237,251,91,91,66,28,226,118,159,38,182,74,84,211,135,32,193,211,191,147,179,180,120,195,50,136,176,165,75,55,152,255,214,79,199,207,255,93,108,202,247,9,230,46,108,63,6,96,173,170,53,108,124,220,121,215,147,82,127,61,219,155,204,206,102,121,82,252,74,145,110,44,222,92,90,226,128,229,217,239,203,214,36,110,3,52,104,92,187,16,191,115,194,59,171,111,123,138,170,11,227,135,138,157,24,148,156,173,197,61,59,231,79,76,163,124,57,4,2,145,176,234,121,114,149,229,6,192,64,211,165,226,3,76,227,185,104,103,103,26,122,127,151,108,164,15,56,216,216,135,215,224,122,166,144,131,190,129,73,83,190,1,12,207,52,105,207,176,244,38,80,128,99,152,166,236,125,123,154,245,86,28,46,192,34,125,147,163,81,9,221,139,47,112,220,204,178,109,23,26,30,192,87,200,55,121,240,78,208,196,39,235,91,233,175,198,47,119,121,58,198,35,90,116,46,175,190,168,39,230,46,199,4,180,211,206,215,182,70,110,185,74,118,105,32,214,196,158,122,89,153,84,171,203,44,105,11,122,88,88,185,124,142,233,86,48,188,127,104,79,62,51,26,15,60,62,151,139,75,74,67,45,67,223,118,182,172,126,42,148,245,20,164,132,51,68,54,249,27,177,110,127,180,123,40,182,240,157,221,79,3,9,143,94,126,182,106,238,11,183,4,147,109,246,5,99,90,63,170,58,156,252,3,12,212,229,167,119,47,95,252,63,254,47,80,75,3,4,20,0,0,0,8,0,51,116,58,33,102,89,94,1,220,190,0,0,251,232,1,0,12,0,0,0,97,115,121,111,117,108,105,107,46,116,120,116,205,253,221,114,227,86,182,37,10,95,75,79,193,188,105,246,137,160,244,0,210,133,66,182,211,78,85,103,58,221,206,116,229,113,236,240,5,72,130,36,44,16,96,1,96,210,172,56,15,127,230,24,99,206,133,5,74,217,85,181,79,196,23,95,199,238,114,138,4,241,179,176,214,92,243,103,140,49,175,30,63,205,126,255,248,219,236,253,211,255,122,59,123,250,124,125,125,125,245,195,175,143,31,30,63,63,125,154,253,242,246,215,79,31,127,126,124,107,31,254,240,155,125,253,233,237,207,79,31,127,189,170,171,175,85,179,157,85,205,108,89,52,85,191,219,151,205,112,235,135,252,248,235,219,31,222,254,250,244,253,255,186,218,85,253,108,217,181,195,174,236,22,179,162,153,29,251,99,119,40,187,89,187,153,225,171,117,187,175,154,170,109,122,251,229,245,227,135,167,183,63,127,186,250,127,174,175,254,159,217,172,110,187,117,63,43,134,161,108,214,184,78,219,204,236,36,126,173,114,61,91,31,159,203,219,235,191,61,254,239,223,222,226,39,215,215,239,223,206,190,123,251,248,219,85,49,91,181,199,110,168,236,34,227,175,143,7,251,253,143,93,185,46,187,106,245,108,23,251,254,221,227,175,239,237,151,167,174,236,135,218,142,29,218,201,247,215,31,223,63,253,253,237,175,87,184,27,251,255,186,206,236,127,250,127,127,176,107,125,252,253,211,221,255,53,155,225,94,123,123,0,60,209,167,170,155,253,218,158,234,162,177,251,43,103,223,181,103,123,46,252,252,227,175,239,31,127,254,225,227,21,111,244,241,135,199,15,254,144,125,217,125,45,154,161,199,213,63,218,128,150,221,237,245,15,111,127,254,249,73,143,244,249,227,111,223,191,251,244,249,227,207,111,241,84,117,123,106,236,206,62,61,253,58,211,205,205,62,60,254,250,249,237,255,253,217,190,252,90,173,138,14,183,253,253,199,95,159,126,142,179,239,202,131,141,251,218,110,226,211,211,251,191,63,253,166,179,126,121,122,255,254,201,110,129,3,213,12,221,121,182,41,107,59,57,94,101,221,126,45,103,167,106,216,205,30,143,235,174,60,219,41,175,30,103,246,194,236,17,103,93,121,176,209,178,215,140,17,125,247,251,135,183,63,223,206,254,39,255,123,247,127,93,95,255,250,241,211,227,251,167,159,127,184,90,23,199,237,110,208,144,190,242,202,174,191,127,107,151,159,28,149,15,252,47,239,222,126,135,199,141,155,47,123,204,141,199,223,126,248,245,237,239,217,45,159,202,102,181,195,221,189,199,60,89,204,14,197,182,236,49,195,214,254,214,49,172,139,217,255,88,217,11,248,159,63,182,120,203,101,103,183,121,245,63,31,103,248,9,255,249,99,213,245,195,248,231,167,114,213,218,239,47,190,254,197,206,156,127,237,127,219,139,248,254,173,189,24,189,182,121,63,219,181,199,190,188,159,253,96,15,57,62,144,125,206,217,120,207,59,179,209,184,190,210,205,96,186,60,218,211,225,141,98,181,189,88,127,143,223,127,158,61,93,199,101,102,79,87,31,187,213,174,232,214,248,225,244,154,56,195,213,127,189,109,48,152,62,209,120,53,204,179,63,174,211,220,123,236,103,79,246,10,247,229,126,137,181,248,184,46,246,139,89,53,204,78,69,175,229,49,96,65,110,138,126,103,235,241,250,106,89,254,227,88,22,3,222,219,222,222,161,141,120,85,215,179,229,113,152,29,218,214,150,150,29,110,23,199,117,86,157,77,204,126,113,125,101,127,216,27,232,249,205,172,47,206,246,152,139,25,110,122,139,147,156,71,59,96,23,179,107,217,53,106,123,187,54,153,22,152,4,203,174,212,181,78,54,27,239,98,188,58,187,118,185,173,108,125,237,207,215,87,125,177,110,48,33,102,31,210,217,102,127,43,236,70,109,40,202,217,115,89,30,96,50,102,253,106,215,182,53,103,195,245,149,205,218,182,179,207,14,101,241,220,207,182,109,109,131,94,159,195,0,29,186,118,83,13,119,179,141,61,147,221,226,161,232,6,123,146,116,50,187,157,238,216,15,182,186,106,251,141,157,122,215,238,75,123,128,142,183,204,115,206,246,246,66,175,175,236,68,182,76,234,243,98,214,15,197,153,191,228,221,251,111,102,199,230,185,60,216,60,192,133,112,182,217,185,61,94,95,13,59,251,30,151,194,146,218,112,92,183,182,192,234,114,111,182,210,110,17,163,86,117,195,206,46,103,71,94,95,173,171,205,198,22,227,172,105,135,217,166,107,247,92,96,118,193,186,166,141,220,192,196,182,127,61,204,222,85,152,28,93,95,218,40,23,24,67,155,144,54,144,182,50,58,222,194,194,254,232,43,91,92,60,47,206,98,79,103,199,109,138,170,187,190,162,1,176,207,204,156,109,236,165,232,13,197,33,3,23,174,127,109,183,105,203,65,239,94,235,221,206,102,171,111,214,217,201,237,62,215,101,97,99,98,35,109,215,191,227,236,121,90,248,187,143,201,176,45,204,238,216,243,236,104,167,27,251,153,29,176,231,177,91,155,89,195,78,99,198,181,115,218,85,171,29,223,155,217,148,125,81,247,62,149,204,180,52,219,157,77,208,158,183,104,115,112,127,92,237,236,34,102,45,120,95,56,163,125,250,116,59,251,46,61,119,213,167,203,242,182,49,146,173,189,200,26,22,110,115,196,11,223,218,58,195,171,92,104,156,237,61,102,199,55,197,112,180,139,109,139,175,118,103,120,221,85,47,243,84,54,69,179,178,195,203,114,79,203,62,20,102,18,248,182,246,229,29,46,83,151,67,207,159,96,116,101,110,241,99,59,53,76,217,178,232,56,125,112,201,67,93,216,153,240,94,179,17,139,117,134,103,196,127,171,134,207,87,87,176,128,182,159,150,90,44,152,72,85,93,13,103,93,193,166,82,185,62,174,138,193,150,247,237,236,51,46,136,255,27,194,20,104,130,109,187,170,212,51,39,147,101,211,188,234,170,193,167,227,166,208,77,232,85,60,97,10,87,205,51,78,133,171,216,173,96,180,124,201,218,179,239,143,182,91,216,196,193,91,238,7,142,186,45,99,219,246,170,225,184,182,209,120,146,93,105,90,219,122,154,173,189,123,155,60,24,85,220,23,236,200,118,55,59,151,3,174,243,220,216,22,101,199,157,170,190,164,29,91,219,188,178,143,236,34,197,215,182,90,219,79,110,125,115,253,189,229,52,90,217,251,194,80,216,44,133,245,95,96,201,117,97,55,110,71,203,248,147,157,129,11,223,71,66,207,13,27,182,43,106,204,139,162,227,149,118,37,111,214,238,127,135,55,138,69,125,184,205,108,47,55,229,63,146,235,240,115,123,50,99,80,117,111,108,172,108,186,236,241,27,187,3,154,133,135,241,234,63,107,14,98,40,138,61,23,118,172,176,86,191,41,108,252,120,200,109,58,245,23,157,176,227,249,236,105,26,94,40,59,233,135,162,235,206,252,112,161,243,238,202,154,54,134,63,104,249,91,78,98,189,198,159,90,51,148,251,98,109,175,174,144,125,63,54,39,179,154,187,209,204,218,219,199,240,217,12,227,108,170,214,182,76,180,55,251,61,229,151,92,150,110,108,102,229,254,80,183,231,114,173,81,181,207,27,61,92,97,23,174,203,236,37,124,218,193,40,62,209,24,234,69,237,218,109,207,95,149,88,156,199,254,89,83,12,207,187,127,184,214,24,152,213,93,87,219,162,158,193,198,87,48,6,182,26,237,44,102,153,155,65,115,26,127,217,203,172,237,9,49,33,104,183,177,112,236,136,99,119,126,72,247,255,191,48,191,48,60,39,218,109,222,130,25,147,203,145,253,232,143,104,27,240,153,91,213,189,236,188,205,124,254,164,213,54,125,251,242,188,203,210,236,152,77,33,219,14,46,79,250,120,94,196,128,217,45,107,57,243,181,249,111,48,247,177,38,111,49,64,246,239,235,43,156,16,166,14,171,218,118,52,91,90,254,162,238,101,30,42,185,203,218,76,240,228,230,7,115,128,236,61,46,235,182,93,115,53,248,200,152,101,227,105,121,133,207,59,30,111,78,75,217,115,155,108,104,50,236,85,192,73,236,249,51,108,75,188,93,191,16,44,71,220,17,46,187,129,231,116,179,108,187,230,158,134,156,86,164,192,224,119,133,238,195,236,134,205,109,109,100,197,169,56,243,148,186,175,83,169,179,224,127,205,205,27,210,28,196,174,81,14,167,234,175,193,194,8,172,23,190,236,48,132,185,121,154,209,14,217,87,188,45,27,146,122,89,194,162,60,153,77,104,54,54,109,221,22,172,16,126,108,99,148,237,23,176,78,141,173,119,249,165,176,145,157,153,195,206,156,205,114,186,250,236,125,181,231,55,227,27,252,158,126,193,138,255,139,23,210,141,222,78,26,152,182,197,191,21,51,193,16,102,103,172,234,65,38,167,182,161,176,25,176,230,206,134,147,125,53,139,99,182,51,155,44,110,39,226,155,123,205,20,12,49,207,142,185,208,235,69,127,194,102,126,17,144,220,211,140,21,125,110,203,241,245,14,15,111,103,49,175,213,222,127,17,103,215,18,234,225,209,112,213,20,49,194,102,226,237,213,249,81,8,115,190,148,157,63,3,222,105,238,238,153,141,231,44,147,109,123,46,181,247,238,232,157,185,19,3,11,215,181,240,68,176,27,240,123,153,157,93,177,158,29,108,47,182,125,178,229,68,178,141,109,176,157,226,88,210,43,176,27,195,11,236,219,59,93,122,103,150,126,214,21,21,143,199,205,159,251,178,222,196,190,240,233,84,150,131,239,6,61,173,212,193,230,182,77,49,249,127,156,18,122,188,121,15,199,17,190,114,135,189,156,199,218,221,21,171,85,155,175,237,247,56,157,173,178,22,15,105,247,114,155,191,37,223,216,96,134,42,154,54,243,44,138,222,246,188,179,111,45,181,182,22,44,186,15,246,88,62,176,225,48,227,168,74,222,13,207,100,243,17,238,136,174,7,123,157,118,115,157,145,139,193,214,151,237,255,116,163,235,10,123,135,153,185,194,188,116,56,181,237,178,95,29,59,12,23,223,119,197,192,216,221,18,44,238,209,243,188,193,111,175,175,254,113,44,204,125,48,175,130,70,225,53,55,128,30,154,205,140,161,107,57,173,225,212,104,58,125,123,95,191,211,218,230,138,163,73,161,39,196,201,85,254,85,118,43,219,222,123,46,234,2,70,134,38,59,115,138,225,123,155,151,226,3,65,23,137,225,136,157,8,246,232,156,221,91,93,110,6,197,46,54,101,108,85,20,200,80,220,199,30,194,141,129,247,184,181,216,227,168,31,218,38,114,180,93,109,124,193,143,246,40,220,189,79,105,133,174,219,7,76,126,120,64,165,47,15,123,69,220,112,176,43,217,142,224,59,196,214,38,135,94,98,230,230,12,28,15,76,39,27,179,163,5,64,107,119,183,105,167,178,153,129,183,9,135,147,33,73,236,190,60,203,29,188,161,67,103,195,99,31,45,236,49,11,14,198,107,115,111,182,49,51,174,221,123,3,175,92,238,130,109,48,26,88,186,153,30,249,96,78,141,207,253,147,223,187,251,166,123,89,49,139,157,236,241,183,177,156,158,250,217,220,63,154,227,20,93,121,178,157,239,97,246,161,133,167,215,29,203,69,216,232,26,159,236,249,30,74,56,15,190,87,210,15,52,203,10,255,3,67,18,126,42,78,170,85,250,134,177,216,104,62,52,44,135,246,185,12,115,116,210,130,52,39,236,175,210,124,239,87,35,96,61,211,19,188,221,153,153,243,198,6,246,65,62,106,248,67,152,199,138,130,247,229,131,191,45,27,100,51,31,213,74,247,106,118,224,185,225,206,129,51,195,39,229,36,108,218,20,8,219,174,201,72,120,214,216,94,3,15,115,246,174,53,235,184,152,253,80,54,77,213,191,25,61,69,165,120,236,206,60,215,243,125,129,200,69,47,216,130,182,93,117,24,221,146,47,133,54,201,239,205,44,212,112,240,49,231,145,73,177,240,63,146,87,11,185,32,41,34,213,56,194,201,244,11,124,106,221,248,104,202,200,214,71,120,202,19,114,17,217,131,85,251,131,47,2,219,4,86,43,123,96,156,214,126,53,206,141,239,57,63,205,67,169,26,31,120,27,214,244,72,87,243,207,202,20,112,217,218,164,178,205,230,236,177,68,123,99,177,50,70,26,151,212,205,51,133,216,103,94,180,39,230,254,24,83,116,63,225,36,241,195,118,50,76,217,132,197,65,31,204,77,169,74,251,58,13,22,214,238,188,231,245,154,242,132,255,223,251,35,99,159,63,41,57,243,48,94,235,51,6,101,142,17,207,143,213,97,225,219,186,63,131,73,138,99,238,60,138,175,252,221,112,69,32,9,132,204,103,164,190,150,103,26,114,109,208,93,138,229,210,141,225,7,17,112,117,165,157,196,54,34,60,103,221,50,201,202,100,168,45,5,204,254,131,174,191,183,141,13,129,90,213,216,152,124,109,107,155,251,133,153,191,242,47,219,251,198,101,139,144,185,181,215,94,211,165,192,249,225,207,52,72,152,148,77,7,215,127,114,7,120,148,176,205,240,30,25,254,226,98,122,147,50,53,118,189,83,129,0,43,159,18,190,146,204,250,205,170,205,236,215,182,183,173,3,126,104,54,91,35,227,135,205,212,70,32,134,70,247,90,198,206,155,189,12,115,181,155,54,69,255,47,79,195,221,210,214,94,133,240,167,101,238,18,131,164,43,96,216,224,186,165,52,73,101,7,155,247,105,211,66,217,144,161,53,3,141,131,253,253,245,201,208,112,152,55,45,246,166,114,205,171,112,84,177,245,232,187,117,5,179,141,229,54,112,147,66,224,62,227,138,255,164,165,53,157,54,24,246,166,189,190,66,182,203,142,198,125,50,141,135,51,31,155,85,93,134,211,111,78,207,169,73,15,120,175,252,85,195,167,24,78,246,128,230,59,219,221,235,247,204,179,149,103,91,185,185,99,138,37,45,111,33,159,137,72,23,78,39,249,25,222,138,219,129,162,238,202,194,130,105,15,25,54,211,252,164,103,209,10,164,122,108,147,44,59,236,177,102,66,99,138,221,103,153,58,222,16,46,54,147,3,17,55,241,107,187,180,147,191,195,20,178,211,190,109,182,152,142,119,58,28,247,193,83,115,109,40,107,97,59,189,93,97,83,183,171,231,72,222,148,140,183,214,197,89,195,185,169,225,201,225,252,67,181,71,188,98,14,54,134,23,249,183,52,50,200,9,120,24,196,172,31,172,70,189,190,244,227,185,205,201,144,102,22,202,67,130,124,117,100,35,232,177,238,186,69,58,203,172,194,189,251,60,171,66,1,102,177,50,223,201,86,230,184,135,22,136,175,225,161,220,202,93,199,210,106,220,162,244,229,170,43,135,250,140,95,50,1,102,211,10,99,206,105,73,115,231,118,35,5,227,31,59,140,160,141,76,129,83,219,147,218,150,216,71,92,213,50,12,193,163,219,231,219,163,249,83,235,148,127,209,237,33,129,14,71,190,174,205,111,255,28,207,156,210,5,49,26,238,25,216,205,89,204,118,31,81,130,162,189,178,95,21,7,57,16,120,62,248,230,244,86,236,14,159,109,164,235,106,191,116,79,6,99,97,27,132,189,68,51,70,102,31,110,103,191,103,105,24,90,201,227,224,129,17,167,82,137,33,80,24,107,78,113,248,229,152,245,99,40,177,132,79,129,135,183,167,217,180,85,45,31,5,25,62,27,231,35,242,206,126,243,88,80,187,182,177,51,44,96,152,184,40,57,56,153,27,10,223,248,24,142,45,43,32,218,102,22,241,70,119,149,140,245,244,197,202,113,43,106,79,51,104,211,87,120,92,33,197,65,227,128,185,75,11,196,196,87,133,228,224,26,126,40,108,137,13,65,251,44,63,6,111,170,67,170,15,35,132,231,128,191,141,225,179,48,228,216,208,200,167,80,27,94,12,150,173,146,66,145,200,198,131,246,22,78,32,237,201,42,72,29,6,110,124,249,74,226,103,102,59,182,201,39,90,160,103,12,73,233,246,118,28,9,184,244,76,19,97,70,166,172,216,166,26,189,252,61,220,187,103,251,160,134,19,136,215,205,76,133,197,110,246,54,24,129,193,133,169,148,201,28,35,67,51,230,135,99,119,192,254,132,87,97,143,199,105,79,19,107,27,38,151,2,162,68,187,131,194,220,170,186,88,218,107,164,229,198,120,245,199,98,93,166,241,181,177,29,180,55,203,168,217,20,182,61,145,247,49,135,57,44,101,19,237,81,252,161,239,240,11,133,188,200,160,31,151,200,86,192,240,105,38,122,73,204,238,247,71,143,0,145,17,182,137,178,177,213,187,228,82,99,61,179,108,190,86,182,5,205,202,253,177,46,134,150,121,50,217,42,51,106,136,34,185,113,194,135,135,231,232,75,157,243,156,161,115,131,223,174,218,102,232,80,209,137,55,149,210,201,76,49,23,117,12,88,30,58,29,251,82,209,176,13,5,206,105,55,116,175,49,199,244,169,171,114,227,225,74,181,102,114,8,126,33,79,89,174,158,109,134,244,252,195,94,226,22,38,233,49,50,158,39,4,241,75,12,67,141,185,57,180,115,47,89,84,27,127,251,107,188,107,166,211,205,102,247,53,103,122,154,189,60,112,70,127,18,111,220,158,3,223,87,200,164,243,123,251,29,103,131,138,185,229,34,82,170,51,11,103,86,131,89,42,187,179,148,41,46,57,11,14,109,213,99,172,109,205,116,197,33,125,12,99,99,119,100,143,181,178,33,193,40,174,75,196,18,218,108,185,101,186,183,130,31,48,0,135,207,71,131,57,20,115,70,110,216,171,54,233,108,182,188,214,85,87,174,6,159,110,120,151,76,168,209,8,49,141,106,115,78,123,130,7,185,69,205,153,175,136,178,68,218,254,73,30,184,102,163,54,69,149,25,236,145,17,207,101,118,174,111,179,41,160,188,184,109,111,51,149,213,111,227,76,156,210,254,250,163,106,181,103,82,13,105,104,218,66,187,49,155,39,237,190,250,167,150,131,202,174,165,91,145,138,203,27,54,17,245,182,99,191,227,197,79,200,178,166,60,55,190,213,11,63,20,181,134,240,212,186,135,23,91,158,103,145,109,34,243,117,154,47,242,210,58,34,76,152,61,37,43,139,189,40,237,45,92,134,12,153,112,143,44,189,21,231,61,115,47,149,150,12,61,78,115,147,138,26,99,197,121,224,63,211,251,204,183,165,67,135,167,69,229,237,78,70,195,70,19,65,228,152,61,246,8,225,77,50,118,63,154,139,112,98,116,206,37,233,102,96,140,96,198,192,3,153,123,77,75,123,9,67,213,41,31,181,181,103,101,17,25,171,172,61,48,203,204,13,174,47,49,109,27,150,189,226,253,248,238,211,219,11,90,168,128,49,243,250,5,82,238,231,5,103,98,57,22,160,246,114,54,224,5,154,201,250,189,132,25,51,243,40,103,104,161,1,176,135,100,93,19,219,185,135,160,54,197,205,104,173,101,156,152,171,109,151,54,66,90,10,230,175,110,48,154,118,135,22,210,193,225,95,217,5,80,188,175,207,225,134,106,30,219,204,71,33,170,111,189,108,230,94,19,223,54,206,202,112,13,190,147,14,47,109,102,174,42,86,68,101,207,109,239,177,96,185,108,15,53,183,138,86,22,132,15,204,125,217,179,45,54,129,198,93,9,182,161,183,215,216,71,97,176,26,124,60,49,70,203,82,30,125,179,189,247,181,145,128,26,58,104,133,71,71,218,231,46,141,97,87,238,97,58,60,64,131,147,242,164,77,73,110,220,178,101,25,69,57,114,149,61,112,131,154,151,182,179,219,230,50,164,217,240,199,191,89,149,127,186,122,95,156,154,220,91,252,65,81,138,45,164,98,53,41,205,19,246,192,241,11,164,196,31,129,133,120,154,49,157,35,195,50,198,78,189,210,149,230,129,181,255,100,6,146,222,247,109,6,181,248,1,131,240,125,89,87,197,66,101,142,147,102,210,30,53,99,205,39,14,187,13,181,153,202,30,32,149,123,185,7,114,163,224,172,104,118,50,233,142,243,87,22,130,205,126,107,24,171,224,235,149,74,39,3,12,173,187,143,246,172,200,109,21,99,120,27,137,228,115,24,19,26,127,206,78,22,194,21,185,7,248,128,91,71,249,151,217,115,11,107,171,6,97,43,179,19,102,92,19,60,228,157,28,130,39,172,46,207,140,35,188,163,7,203,69,228,149,32,205,252,83,137,125,198,61,230,39,247,92,108,52,105,141,246,103,69,89,11,154,252,203,123,198,74,92,143,159,226,144,116,180,98,206,60,83,222,43,221,195,31,97,91,45,145,76,226,238,226,57,23,213,24,82,20,233,165,60,164,190,194,157,242,12,120,74,83,210,84,84,141,25,50,59,57,95,75,175,76,163,221,90,165,181,55,116,199,97,167,133,152,187,101,122,105,246,171,14,79,95,218,62,82,51,197,182,63,148,157,34,68,156,151,62,142,182,132,124,234,40,81,233,14,156,191,81,197,172,89,165,8,213,37,115,99,7,140,70,139,140,248,159,45,246,88,207,223,245,233,109,153,71,239,5,164,244,88,220,105,27,139,69,118,21,252,117,85,254,27,123,214,166,109,84,103,97,130,26,225,157,13,212,157,170,86,246,160,136,224,152,89,221,49,206,238,23,89,41,22,245,31,85,202,75,68,42,24,185,147,87,238,125,99,71,236,193,114,82,212,21,82,90,221,198,196,142,95,149,233,153,59,198,25,190,85,18,132,128,252,117,177,217,152,11,64,103,202,252,2,142,95,132,15,250,157,226,32,222,225,147,220,42,159,118,8,71,144,141,85,144,117,196,204,111,27,109,24,99,164,33,20,11,215,181,173,115,254,77,140,132,255,245,218,26,255,145,209,3,42,80,72,79,239,252,54,22,50,10,42,236,124,69,73,188,71,226,174,191,157,189,47,229,63,218,194,185,215,240,168,66,207,4,238,134,81,159,227,246,48,147,30,226,21,122,72,11,83,84,201,16,173,219,69,170,65,243,228,51,197,59,119,242,62,56,15,27,124,143,145,211,166,202,237,168,55,151,81,47,58,165,159,237,123,158,1,217,12,247,22,96,155,184,102,250,98,83,14,220,73,10,132,3,102,168,233,165,200,49,41,206,240,91,170,136,225,20,188,181,155,141,222,216,100,62,43,135,83,40,245,200,236,50,174,200,101,220,164,167,68,193,198,220,45,139,149,57,116,123,102,24,118,170,168,8,77,117,130,75,248,163,114,160,30,89,224,126,237,133,151,17,233,177,240,81,109,6,213,40,178,87,195,178,119,63,48,109,84,162,122,82,79,222,100,4,175,167,210,77,132,121,201,125,171,121,172,146,90,83,110,170,129,24,150,204,117,198,62,137,205,100,29,200,4,236,101,71,97,84,108,176,42,90,115,123,11,230,63,182,176,65,204,181,155,193,199,123,195,200,165,187,69,226,206,198,175,73,203,118,254,25,182,161,59,150,145,100,107,251,114,150,146,97,123,22,104,129,8,226,159,22,240,119,40,13,234,99,123,31,132,119,185,15,249,242,119,58,0,31,196,79,24,21,217,212,189,217,20,95,25,200,77,71,231,103,228,118,26,38,135,237,205,111,91,252,154,171,216,95,198,28,187,215,6,230,7,166,232,103,130,111,230,253,93,122,87,182,95,108,27,130,97,244,180,19,191,197,38,158,109,26,238,215,216,144,149,44,6,241,32,157,41,203,64,143,168,203,180,65,255,220,62,104,201,235,96,89,27,224,37,152,70,97,102,177,228,55,11,78,9,62,52,221,152,243,56,149,48,51,153,172,245,2,121,249,48,251,44,128,139,78,234,193,9,19,67,152,163,182,56,184,217,214,200,77,216,208,250,137,22,97,89,7,66,9,121,110,96,50,163,168,108,111,178,101,177,112,197,148,134,6,161,232,182,199,61,11,84,217,108,164,211,151,69,41,113,54,212,169,137,52,196,156,248,217,31,11,79,63,94,80,47,52,222,65,10,83,185,127,28,145,229,186,193,149,225,126,166,99,78,132,231,104,56,127,41,187,98,109,143,57,40,156,18,18,9,227,53,190,106,123,109,207,81,72,89,200,224,196,169,238,233,98,154,61,95,149,54,86,216,24,109,177,199,45,156,42,78,244,214,118,110,132,235,244,58,10,47,135,51,211,178,109,215,192,148,150,202,134,115,44,57,124,242,50,227,52,120,116,70,17,187,114,176,5,221,248,10,41,234,19,42,225,242,12,234,70,30,149,242,156,28,118,79,39,164,95,165,73,88,193,50,191,99,0,112,90,48,113,4,84,144,76,161,146,233,176,207,15,19,200,239,7,119,218,50,183,74,213,80,236,111,81,8,209,238,150,70,246,139,67,87,52,57,113,233,61,30,22,81,254,244,228,63,155,221,185,220,224,184,73,19,27,176,172,152,101,225,229,60,3,55,181,181,184,140,7,31,81,84,140,29,16,3,49,189,214,71,152,246,85,217,13,216,100,159,155,74,240,65,88,139,19,156,85,175,141,184,133,71,234,22,137,194,206,141,242,161,104,86,156,109,140,153,95,255,129,114,126,152,178,184,121,33,140,238,70,239,158,233,84,60,143,7,229,22,171,196,73,121,157,128,36,185,113,205,207,181,37,34,133,17,38,252,228,147,23,227,112,152,63,136,13,15,238,106,52,170,120,203,135,14,155,99,12,204,136,198,233,8,101,42,139,67,20,116,5,107,179,144,110,91,230,107,19,120,160,189,54,100,60,197,177,217,31,255,249,207,186,140,26,112,191,110,247,183,147,33,254,196,71,36,202,8,123,128,182,35,251,233,29,107,243,207,254,75,243,197,154,222,31,199,156,16,115,59,150,103,7,197,217,31,235,62,15,212,236,249,204,47,75,79,245,221,121,54,30,199,84,234,169,100,178,9,213,33,247,209,44,90,156,222,213,119,172,170,243,68,120,20,251,145,18,84,254,30,26,143,59,132,17,170,54,74,170,166,27,115,100,170,234,235,196,81,4,146,134,232,87,31,247,59,150,86,24,245,156,10,135,117,250,171,225,153,136,239,201,39,76,236,183,81,89,97,198,172,57,223,143,201,43,251,100,225,255,229,140,107,16,155,98,213,193,255,100,160,23,233,138,190,56,249,238,151,102,84,235,192,58,159,69,163,205,11,183,10,198,171,234,231,67,60,31,22,107,89,96,179,188,88,53,141,239,169,168,160,36,64,249,34,95,246,11,5,69,233,26,31,206,9,190,162,48,161,66,212,207,61,6,126,182,214,139,69,228,119,254,233,27,27,109,38,153,224,198,225,185,34,125,97,215,152,203,145,50,35,117,56,148,218,11,134,226,175,66,53,134,209,180,217,163,175,11,208,28,242,91,7,90,132,231,59,84,195,217,157,38,152,5,57,76,120,123,81,167,238,75,115,112,78,12,214,137,235,68,221,103,221,242,96,139,199,232,32,164,249,103,83,105,64,34,44,34,2,2,204,51,247,165,175,128,186,213,6,63,16,245,198,45,116,188,56,35,50,76,146,190,170,225,180,121,121,82,71,243,24,155,166,238,205,167,187,225,143,180,223,21,190,128,17,103,155,53,135,233,32,138,226,250,42,21,158,223,151,179,239,202,98,106,44,3,222,187,111,17,197,165,76,77,121,26,95,220,23,225,154,35,25,138,157,27,62,0,43,26,135,106,91,2,126,71,172,176,234,152,76,34,230,215,248,140,197,36,231,247,84,18,101,105,103,191,89,117,197,126,95,142,83,240,209,235,130,129,3,63,149,163,195,60,196,43,51,179,243,92,14,197,178,206,93,34,231,214,32,55,246,157,221,217,159,92,70,151,15,125,119,81,109,239,31,70,82,206,143,112,146,44,178,104,86,105,67,203,128,33,218,151,205,216,211,101,79,247,251,9,127,189,193,96,49,140,89,181,230,10,117,217,73,191,140,159,194,92,174,139,253,27,166,26,122,135,146,22,141,89,128,216,88,71,219,42,215,138,85,68,119,103,188,42,146,47,190,206,203,136,179,31,108,146,85,13,234,174,107,228,238,203,108,171,197,214,82,84,44,100,22,218,27,106,251,19,175,78,37,63,76,215,83,121,113,102,186,185,180,132,204,85,58,86,14,232,146,197,205,205,228,149,50,231,209,115,142,239,132,137,233,247,37,111,52,6,0,97,119,177,47,144,9,53,195,162,242,240,93,170,145,41,1,209,122,154,199,70,81,176,177,132,187,8,12,247,244,101,176,28,66,243,217,110,242,41,246,123,148,247,143,26,23,11,56,26,193,130,39,96,142,236,238,60,206,230,143,28,167,44,208,77,83,33,173,39,152,234,6,182,85,216,20,98,53,59,60,198,25,153,219,240,123,224,79,151,154,160,22,177,143,112,0,230,24,225,179,97,99,70,73,168,141,18,165,251,171,238,9,17,195,59,4,123,65,136,79,58,134,202,8,236,103,153,99,170,164,200,228,70,23,105,11,178,56,93,153,215,229,177,171,184,172,226,73,137,26,113,184,57,8,24,132,47,53,14,179,35,168,178,44,73,18,227,43,142,156,159,98,192,125,49,16,133,129,58,104,92,211,231,143,206,52,20,92,138,227,181,112,50,177,77,188,154,176,71,37,25,117,167,191,86,118,255,112,102,69,156,224,13,136,178,181,42,95,152,164,37,233,18,170,196,216,226,68,93,200,134,124,254,29,48,122,76,230,152,5,66,184,130,181,180,135,243,207,45,25,6,223,89,96,253,237,124,50,4,1,68,246,41,161,167,246,180,173,195,60,114,16,147,133,171,83,20,83,100,101,253,32,56,77,133,217,164,189,188,243,174,60,169,134,204,55,64,159,198,161,50,170,127,118,213,178,95,196,158,234,17,77,236,3,76,215,219,113,44,247,136,45,193,108,27,166,122,217,125,45,157,230,64,126,215,34,213,19,244,16,149,237,225,51,39,20,56,190,161,188,231,119,4,30,250,187,38,136,132,124,25,223,152,109,199,32,48,149,72,243,74,177,250,218,54,152,89,251,85,39,218,251,70,83,36,163,188,3,72,161,235,149,32,84,129,196,115,46,44,215,84,83,147,255,88,23,128,148,229,222,214,113,144,161,140,162,166,242,31,123,55,211,227,224,184,165,240,74,43,86,253,196,168,114,199,174,146,51,168,173,154,198,96,178,197,31,123,238,143,88,159,68,207,97,199,236,70,156,198,221,108,44,175,18,14,110,207,91,237,221,165,161,255,244,196,2,195,90,73,52,175,100,227,45,106,139,86,186,8,139,93,119,155,214,168,153,230,39,229,169,108,41,247,229,139,196,38,134,65,215,237,196,157,40,107,0,160,218,102,203,12,136,108,137,88,169,200,22,154,159,86,173,148,98,2,140,19,220,160,135,241,247,103,22,107,133,84,88,183,168,216,0,36,120,125,101,247,121,19,247,253,48,251,20,59,111,58,121,102,100,133,80,122,152,90,109,97,20,228,242,58,80,128,142,176,167,130,202,24,57,38,126,108,206,31,14,45,176,3,235,100,253,178,11,120,220,34,251,38,40,15,50,36,175,152,55,77,227,197,172,63,190,98,19,239,152,187,60,246,140,56,120,75,140,184,202,82,103,184,250,175,31,177,209,154,87,118,59,115,20,227,132,233,187,152,57,19,211,1,152,182,34,188,162,166,59,124,76,172,204,63,94,144,132,191,103,86,207,92,249,209,133,59,211,89,74,160,217,101,201,2,176,121,95,240,218,24,170,195,64,217,51,86,117,112,192,236,105,129,63,117,86,202,152,231,64,29,35,150,47,214,106,246,42,222,126,101,162,217,189,135,204,81,42,250,64,73,38,212,254,27,78,6,172,158,182,125,38,26,30,190,12,121,98,47,105,207,17,234,39,48,23,199,64,83,225,13,7,157,181,149,174,60,12,94,63,21,158,204,55,186,244,118,95,4,133,180,63,219,146,149,136,17,210,169,194,170,189,59,214,188,95,222,206,239,132,33,193,210,20,207,201,225,93,151,170,222,35,243,45,110,132,237,56,177,91,7,20,144,216,102,210,43,214,235,62,226,88,27,196,219,217,83,67,247,222,205,253,245,213,10,139,128,153,134,121,239,175,47,60,145,77,33,48,82,130,108,4,82,3,46,250,43,111,248,118,246,137,70,71,216,175,240,108,238,53,25,55,162,154,224,102,247,173,202,201,233,197,37,104,234,206,19,71,219,9,44,116,244,206,47,198,231,135,150,20,2,21,155,117,51,203,115,182,233,166,51,48,195,149,30,84,174,66,184,181,102,28,72,236,28,19,38,25,99,131,179,159,118,223,55,119,86,32,80,72,149,43,186,62,14,231,11,119,11,59,59,0,239,180,210,124,228,184,112,170,94,103,147,165,236,38,156,178,133,242,146,113,111,247,137,223,65,78,80,137,28,215,248,28,68,148,51,217,195,64,188,97,220,33,202,77,84,1,200,185,118,200,159,222,55,146,83,205,118,8,226,13,223,120,94,16,178,219,207,80,251,194,123,147,65,208,39,54,204,18,187,103,32,188,224,200,21,93,79,120,152,227,188,81,93,91,89,124,7,124,72,219,110,52,213,16,73,9,90,19,119,112,151,12,105,113,82,97,10,24,147,64,213,219,158,116,102,92,142,92,75,249,234,1,127,30,215,219,189,19,198,64,202,44,186,49,63,51,38,42,53,151,193,240,180,159,7,112,188,80,212,196,108,255,245,85,9,195,200,162,246,237,236,75,57,27,65,250,9,198,70,152,150,45,66,21,212,200,47,89,149,249,87,44,134,96,70,112,73,187,183,64,72,41,10,123,195,164,250,219,46,220,3,36,4,81,48,245,210,162,71,70,233,89,53,61,213,159,88,64,203,234,238,39,143,56,89,227,1,183,3,47,233,168,196,115,148,63,221,79,153,152,37,71,184,225,220,219,54,12,239,100,194,155,119,94,150,10,46,22,22,208,162,186,58,41,221,138,225,103,191,18,172,200,206,198,188,110,84,125,157,166,133,159,40,58,60,86,53,83,9,230,231,151,205,153,254,25,39,56,241,8,201,239,117,132,236,200,152,156,193,27,168,203,193,99,11,254,132,211,129,35,204,233,9,199,197,220,90,60,136,215,112,89,245,66,34,160,171,80,237,138,187,98,208,182,44,137,55,156,36,206,151,140,215,75,242,66,247,116,38,61,28,84,130,9,208,39,96,196,238,113,134,231,170,230,143,211,111,24,85,164,95,224,109,144,96,220,10,2,113,151,80,38,107,221,211,198,66,15,64,185,65,132,5,233,70,83,203,105,22,44,173,14,0,10,211,105,118,222,178,25,89,212,64,240,147,170,249,243,136,76,28,17,93,76,107,165,95,114,188,238,237,158,234,51,11,161,169,118,98,135,108,48,71,142,7,20,232,224,143,68,224,40,134,142,167,19,236,233,143,135,131,109,78,169,56,234,153,147,53,103,22,230,238,249,34,101,17,27,81,178,36,238,113,226,135,35,212,19,18,5,130,53,107,218,140,187,52,10,120,85,195,165,52,43,159,75,18,196,96,179,38,213,211,216,107,165,42,192,21,185,195,38,217,232,101,90,80,143,42,194,218,107,218,111,50,3,214,9,0,3,200,121,105,11,12,184,241,241,46,222,140,200,40,81,255,78,163,219,22,64,255,217,182,0,190,107,76,98,130,94,206,115,17,242,213,98,43,31,217,223,123,121,153,184,228,46,51,229,191,194,161,115,144,49,55,205,224,131,177,116,161,151,232,70,104,223,50,254,66,233,68,193,194,43,94,128,38,19,172,185,207,64,135,1,167,167,249,153,92,54,91,207,93,209,56,250,152,216,189,224,139,134,77,241,205,90,49,25,13,97,196,79,170,145,138,191,52,75,85,76,104,136,96,251,95,235,23,172,236,21,138,12,50,195,241,40,30,1,18,162,92,133,168,207,162,228,177,9,254,118,48,86,131,12,132,212,239,234,217,69,42,104,227,132,38,226,110,166,116,185,210,147,99,157,209,92,179,119,101,183,58,214,122,163,72,174,216,62,92,174,195,152,218,238,242,102,140,210,79,142,177,59,137,228,251,181,234,171,101,173,57,183,242,208,189,116,2,156,61,149,80,163,138,148,205,238,108,233,56,127,134,163,237,187,244,31,217,157,124,204,44,215,43,151,142,108,57,128,190,196,194,218,118,73,111,141,69,27,179,98,19,159,237,180,107,19,34,112,45,165,152,171,255,250,4,96,246,109,64,219,156,224,105,95,190,116,193,127,86,6,120,17,169,224,236,157,252,46,132,112,102,209,125,74,100,148,117,22,71,112,27,8,138,236,217,215,175,187,196,235,54,176,45,225,193,100,206,248,187,18,79,147,178,195,114,118,197,238,186,56,213,119,100,228,3,131,106,47,215,118,218,20,244,158,103,77,177,47,179,23,153,19,183,133,153,31,125,232,251,8,52,46,57,179,47,53,124,46,111,32,166,133,115,78,71,40,80,203,105,75,56,41,50,64,8,61,239,174,105,235,100,75,129,32,44,247,115,225,140,2,41,195,188,60,50,174,22,51,125,199,26,28,168,11,4,88,227,33,133,47,210,75,111,202,253,153,39,76,43,161,247,181,230,244,113,197,4,235,192,229,203,26,177,208,123,125,245,174,8,104,17,44,218,10,248,151,181,74,236,17,226,186,158,12,239,98,227,100,238,210,89,238,81,226,65,26,220,237,26,125,190,187,235,215,134,131,121,71,98,53,210,201,83,169,50,113,245,46,35,72,178,87,21,46,142,25,231,172,176,249,148,67,177,136,127,137,213,185,110,249,164,151,44,105,21,33,204,220,174,125,71,205,222,238,28,246,24,137,155,119,137,152,165,89,224,8,159,100,102,128,154,220,122,226,98,37,244,204,2,180,9,82,220,214,237,97,32,73,168,122,161,100,148,214,249,135,145,146,74,234,78,62,197,28,136,77,160,232,53,183,180,72,8,105,194,192,41,200,25,183,115,130,186,214,119,124,155,92,149,73,32,160,201,183,158,189,19,138,244,136,33,129,160,169,34,136,1,29,121,130,150,153,230,115,123,14,196,213,245,213,91,241,191,252,71,3,114,61,252,165,187,194,99,73,225,39,185,80,206,194,186,14,124,205,150,74,48,205,179,3,197,215,192,158,98,142,111,25,174,217,205,231,149,170,142,5,42,29,37,48,253,132,207,242,105,176,225,164,39,168,218,105,103,6,237,83,213,101,69,4,26,30,155,209,76,229,97,58,42,26,176,57,49,194,129,61,91,212,7,238,73,115,252,207,163,217,100,81,134,210,217,96,147,75,172,140,130,184,116,254,204,158,140,14,65,194,81,166,186,201,174,56,28,38,126,205,79,41,230,193,68,255,73,34,105,28,6,76,36,187,186,216,32,165,50,174,168,168,124,129,53,115,232,70,71,167,141,229,53,49,82,224,141,187,238,133,87,43,48,247,84,248,192,187,17,19,154,150,59,112,175,51,193,239,108,60,205,89,227,200,21,36,232,167,44,21,232,234,182,122,18,40,106,246,226,255,61,154,85,157,120,78,30,78,166,128,46,219,30,190,39,200,148,102,187,56,143,84,18,84,93,40,211,228,118,9,12,8,155,224,34,125,251,54,196,141,42,18,88,73,140,132,142,20,107,246,200,182,93,35,129,131,71,43,102,255,56,86,205,32,11,1,152,92,201,124,174,72,117,160,138,229,111,129,123,9,242,219,71,144,48,87,207,119,20,119,130,40,17,153,29,137,105,28,140,239,123,187,204,156,204,27,205,217,128,21,210,10,220,206,126,168,84,68,193,57,93,187,227,234,98,14,166,60,55,9,60,128,130,155,239,175,199,68,125,48,224,221,10,72,205,140,231,41,205,47,149,151,72,198,55,51,62,73,241,53,243,125,167,111,37,183,165,241,3,94,155,167,205,180,191,164,149,82,244,189,36,82,152,10,101,42,95,192,89,23,0,67,129,149,210,10,15,176,24,249,94,204,76,12,61,176,82,24,175,35,37,10,24,165,185,56,134,121,51,76,136,167,109,54,237,23,227,64,188,185,70,246,54,114,23,40,217,38,69,165,147,93,197,166,137,107,51,68,82,247,234,191,126,45,111,202,139,18,100,248,11,164,252,58,101,109,141,216,102,230,193,209,174,58,228,97,58,109,117,144,65,144,86,39,50,123,246,72,77,144,241,13,134,1,193,134,96,246,200,28,200,61,18,150,98,250,160,202,60,179,165,94,23,224,221,112,109,129,143,102,102,1,3,130,8,181,234,29,188,150,136,170,9,73,235,11,118,199,208,123,5,80,104,7,2,174,214,65,145,223,130,45,252,91,185,11,193,32,222,29,109,113,51,120,140,41,9,180,84,227,59,58,231,149,76,132,231,35,236,244,12,104,102,14,254,78,156,112,38,240,199,205,49,45,82,78,103,135,223,142,249,10,186,148,123,13,152,89,84,213,167,163,176,115,106,185,45,165,212,166,127,174,100,129,63,170,195,49,46,19,7,153,187,247,179,35,65,233,160,36,78,175,128,37,72,200,16,231,163,42,35,150,39,204,53,102,159,115,21,228,95,247,189,24,132,249,57,52,126,137,92,248,186,26,225,92,204,88,223,114,121,187,235,18,182,101,46,174,54,152,185,80,170,148,38,217,138,174,217,103,223,79,242,139,97,154,28,136,30,113,158,181,56,200,143,60,159,100,100,240,30,88,17,15,46,87,43,158,72,95,113,170,223,134,207,151,103,95,29,248,177,49,11,62,248,172,213,232,190,27,249,75,216,36,29,53,63,155,59,105,138,60,21,109,201,77,101,145,173,221,245,79,54,123,232,232,113,137,155,119,175,145,9,68,160,174,158,50,60,34,113,96,34,84,98,229,37,112,234,215,202,44,37,159,13,69,69,36,126,243,111,153,103,77,59,58,18,92,247,60,146,90,127,123,17,173,22,10,115,139,26,24,206,249,72,243,98,197,247,90,70,176,63,174,37,207,39,194,26,113,76,190,221,111,38,145,252,53,25,2,30,23,178,82,232,27,141,220,38,31,245,170,119,231,167,144,135,80,117,142,114,32,58,6,203,56,193,175,60,227,55,89,36,36,66,51,255,68,33,185,178,113,216,221,221,244,102,70,14,81,134,147,80,129,12,160,189,167,76,169,111,223,18,148,235,115,177,223,7,195,140,32,239,225,204,152,155,75,95,165,215,248,40,248,127,122,91,202,95,216,32,5,85,228,205,127,76,91,121,186,122,52,191,203,174,233,25,253,255,136,174,194,18,97,212,50,192,102,26,111,100,246,253,241,80,185,155,105,91,244,234,252,70,10,79,148,233,120,152,68,225,202,62,112,36,80,62,68,41,212,197,69,2,115,43,194,198,73,66,176,158,50,62,116,37,147,105,238,207,175,160,247,67,64,164,234,114,171,163,25,11,63,99,47,172,184,146,238,64,100,89,196,39,129,38,228,199,82,132,36,124,104,127,123,9,167,81,122,79,98,84,167,214,159,215,33,30,199,195,125,200,191,148,145,250,75,188,100,230,0,243,83,39,100,161,150,222,190,112,205,23,2,123,155,12,227,164,202,101,17,10,72,23,154,68,211,225,91,164,231,83,157,53,200,218,160,91,204,251,8,182,102,31,23,128,196,92,95,5,236,104,9,130,79,159,242,84,158,43,186,1,243,144,43,39,165,31,62,71,117,144,4,68,10,191,133,214,130,59,111,46,26,138,154,76,131,26,123,93,225,44,14,163,186,115,75,126,42,234,231,89,134,189,30,58,224,111,65,23,179,27,236,153,112,102,197,248,96,171,183,90,181,197,224,217,173,148,91,217,79,17,244,242,122,37,192,199,23,11,160,49,41,82,133,148,133,250,146,119,203,91,175,104,123,20,51,140,196,162,189,207,8,228,14,94,65,231,15,9,170,168,107,173,236,238,230,246,131,185,3,134,47,75,78,153,240,87,48,20,61,242,182,241,11,54,201,100,122,125,244,218,171,51,129,70,137,159,209,136,37,85,98,216,49,81,168,211,155,249,184,72,202,42,200,170,243,53,32,35,233,98,3,158,222,195,120,87,184,41,188,28,51,125,102,178,21,141,43,225,135,196,248,130,52,21,233,89,98,220,254,180,139,246,30,120,184,72,35,242,126,94,22,30,240,38,47,136,30,119,146,144,180,183,217,246,158,23,67,225,65,202,60,178,229,147,172,221,8,130,71,42,212,101,163,10,168,69,36,212,11,242,6,211,40,61,143,205,31,46,50,200,83,126,150,199,215,210,177,85,205,158,250,163,233,101,253,0,112,108,149,21,68,204,21,239,143,229,232,134,249,125,214,42,44,50,124,102,138,222,78,242,48,251,238,172,69,3,82,33,134,210,226,185,190,92,204,178,224,122,80,117,83,184,133,9,23,234,181,219,186,119,238,29,190,22,95,192,157,231,219,139,149,110,177,23,96,143,113,126,129,97,131,98,90,100,162,202,95,144,203,12,86,176,29,245,48,35,37,100,167,194,139,123,184,220,179,242,129,116,21,51,127,232,189,99,12,10,103,119,172,185,229,165,111,81,66,90,209,11,134,215,125,59,123,223,182,207,174,63,36,0,84,184,130,89,116,227,25,110,22,94,194,16,21,100,158,103,154,72,23,185,32,78,6,66,10,94,38,43,71,100,60,156,32,90,138,115,8,109,168,208,88,108,74,38,198,122,140,236,35,107,61,122,193,220,138,197,36,58,118,147,106,218,7,123,149,116,245,30,94,75,156,135,245,187,230,227,200,152,1,124,2,71,12,148,0,50,245,2,207,187,52,247,31,160,211,35,144,68,159,32,37,84,136,78,112,56,46,205,251,209,181,9,48,148,190,225,190,170,153,118,249,44,194,62,153,47,168,208,76,238,239,101,148,206,176,231,101,90,214,211,48,46,143,54,113,112,56,37,143,245,64,28,119,148,187,148,49,241,136,152,149,81,16,156,81,121,105,224,143,86,91,4,120,140,220,164,183,232,18,24,212,184,213,175,144,154,100,56,175,58,201,130,39,244,98,142,148,0,102,107,219,11,247,20,189,112,248,54,252,154,106,5,64,156,148,169,145,193,235,228,46,41,167,124,115,51,80,216,148,244,184,240,193,127,102,69,205,137,202,174,125,43,41,106,212,35,143,13,68,28,174,175,16,174,63,101,154,103,8,50,182,59,7,134,92,188,91,250,105,107,193,220,144,127,28,218,174,191,243,7,64,82,239,96,161,174,234,169,72,202,34,122,171,122,238,102,244,75,248,210,124,163,228,221,52,237,10,233,124,80,7,88,217,181,208,204,70,244,78,175,4,20,231,163,115,152,40,75,160,33,210,115,243,19,123,238,9,10,160,244,18,12,19,79,100,128,40,42,223,187,0,109,17,247,140,164,176,199,108,172,68,181,65,117,122,46,235,106,7,147,189,46,15,8,142,95,27,1,15,212,199,156,116,38,179,116,47,99,57,15,36,121,126,123,159,20,8,62,201,23,154,12,52,156,53,9,78,192,22,172,219,253,253,245,255,241,240,20,150,41,63,248,217,89,59,206,11,170,26,187,135,138,216,31,47,10,220,99,66,70,184,136,55,131,180,235,87,150,26,211,18,247,116,192,66,90,177,243,208,186,6,117,246,33,179,206,34,117,228,3,201,121,199,125,110,196,219,4,163,206,139,216,137,43,255,153,153,103,139,165,145,96,98,170,227,76,239,106,84,166,24,119,31,204,228,30,199,128,170,182,8,245,71,5,232,47,223,11,240,62,228,118,11,169,61,20,231,249,58,5,93,110,230,24,194,190,5,192,141,100,133,93,212,19,83,186,29,200,226,45,147,153,109,51,250,214,170,48,56,52,160,73,181,60,39,227,242,231,184,30,178,98,170,75,43,135,26,225,102,17,203,10,139,190,43,45,162,98,153,67,220,161,81,230,84,195,93,169,160,254,181,168,143,60,179,199,242,100,231,184,70,0,16,40,246,38,123,194,32,199,57,205,23,7,17,5,88,132,39,31,133,42,137,35,214,0,79,101,42,94,160,208,50,140,0,31,21,249,195,97,33,142,210,28,169,141,26,195,183,152,233,49,211,111,164,239,104,47,164,111,165,49,129,221,145,63,4,57,249,111,199,166,69,56,123,42,168,111,255,73,68,111,29,2,35,126,8,45,6,187,94,105,78,156,163,230,47,222,227,167,17,72,214,31,151,161,96,129,229,158,0,203,136,4,109,163,166,190,32,35,91,57,197,206,83,72,71,73,173,20,198,56,225,163,198,160,61,3,2,70,120,126,123,61,46,238,130,158,249,29,7,185,107,151,74,177,5,167,28,85,51,5,236,218,192,168,118,57,202,9,44,73,48,15,60,160,151,85,152,16,176,233,141,151,68,246,1,159,114,139,20,214,140,1,84,107,246,198,231,24,86,209,1,102,245,199,170,83,65,160,234,186,242,107,187,194,136,225,103,160,65,183,224,218,42,211,228,224,1,100,44,231,158,185,160,108,131,95,36,140,69,70,174,65,13,77,216,65,16,52,144,50,116,36,97,19,66,186,177,148,239,178,228,38,181,202,60,211,190,27,179,57,175,151,206,105,227,57,138,196,40,45,60,197,66,178,23,18,203,1,44,26,43,16,118,102,2,41,25,248,208,25,87,158,53,35,221,105,208,115,126,152,179,10,169,214,100,134,78,254,179,57,5,223,46,156,169,96,230,174,146,199,8,50,71,109,151,201,73,36,190,97,146,50,221,182,15,215,153,246,176,23,186,100,56,250,144,193,84,137,129,179,5,55,126,203,225,163,70,45,63,92,196,142,46,38,19,102,134,52,228,215,145,130,44,46,66,56,37,7,112,32,253,200,219,111,151,33,62,39,73,95,122,188,242,192,108,158,58,151,138,9,0,251,111,103,62,229,29,77,201,60,234,155,146,221,77,73,73,166,205,210,22,179,247,84,84,108,113,211,160,34,211,19,208,110,60,166,35,226,195,135,52,170,94,98,25,34,23,160,210,146,38,49,37,51,74,201,84,148,153,119,40,169,56,120,67,13,38,227,167,140,182,211,179,206,63,95,63,140,100,30,9,211,75,50,96,91,117,230,184,219,173,8,171,59,110,97,182,42,159,199,34,174,185,45,202,34,123,140,227,2,1,129,110,194,178,62,149,68,239,108,234,51,141,108,82,240,129,16,74,72,222,50,195,18,110,226,177,119,251,224,254,28,175,24,106,22,78,46,228,236,137,112,52,74,164,69,23,174,105,85,110,250,17,125,199,28,186,75,215,98,161,220,147,93,188,16,118,130,18,15,72,114,137,255,88,56,50,141,82,66,212,86,193,182,247,169,56,135,190,129,240,160,128,84,39,57,23,202,236,134,74,200,148,253,128,140,85,44,134,126,44,138,165,122,216,231,86,143,23,194,33,223,80,70,188,68,227,75,109,212,102,21,165,250,184,116,42,66,73,33,235,7,187,254,161,168,144,201,2,235,212,89,41,244,58,190,150,181,19,54,9,106,131,230,45,80,170,195,153,150,165,125,214,20,82,91,134,190,109,155,72,11,64,212,112,220,209,231,78,28,115,23,222,110,249,16,154,174,68,211,20,195,80,117,30,12,57,61,41,226,216,35,69,89,250,125,213,173,84,20,51,199,245,254,218,17,90,207,165,71,128,100,76,100,211,178,239,53,200,58,165,160,110,84,75,178,111,138,10,248,128,73,210,131,5,252,106,112,120,45,181,227,241,156,10,37,71,222,233,40,132,132,2,12,188,88,148,220,188,172,32,183,133,0,69,151,172,38,44,190,15,173,107,2,62,174,30,19,62,97,101,97,86,93,222,20,127,149,99,129,11,30,39,172,238,108,217,22,221,13,92,175,46,242,68,5,232,69,246,63,55,55,89,226,200,60,247,42,228,232,85,130,169,214,210,146,36,10,85,104,81,255,26,226,6,55,40,232,206,195,73,41,224,60,244,187,16,221,198,45,118,67,85,212,220,26,108,211,88,48,250,161,254,101,36,7,27,98,37,87,237,137,140,92,97,156,248,244,246,26,236,87,27,69,21,105,106,67,157,161,220,47,107,132,99,57,161,48,169,97,60,9,149,44,36,135,236,84,114,9,132,144,25,109,115,186,111,192,11,225,213,217,49,240,13,244,70,254,102,198,109,46,165,65,180,91,74,14,67,216,25,42,136,69,153,20,111,232,39,123,174,125,185,14,68,73,8,105,171,196,177,84,137,118,190,78,235,238,211,180,191,138,139,91,218,201,85,99,20,44,19,142,41,130,250,159,147,178,184,235,31,33,79,249,104,59,124,83,92,176,65,198,196,165,216,49,12,25,48,73,225,79,83,196,181,4,118,23,211,157,61,182,48,252,100,243,187,99,144,165,96,163,157,19,182,77,165,124,202,192,139,163,53,213,30,203,24,167,36,47,157,43,251,97,204,59,78,44,83,59,119,66,194,9,174,131,99,61,100,160,239,17,44,186,97,148,22,26,133,59,136,133,167,188,139,221,5,146,151,139,49,179,65,16,51,212,205,148,107,38,236,205,30,138,250,152,201,215,253,65,219,0,45,89,101,11,176,119,231,156,110,157,18,38,228,56,127,198,149,214,164,19,48,148,178,8,88,152,224,244,250,150,194,117,218,245,81,127,161,201,32,149,224,118,6,112,29,128,180,180,153,208,53,100,137,9,245,215,106,201,208,72,90,184,218,92,242,182,113,225,218,252,31,43,24,147,126,88,120,95,175,244,210,154,228,147,212,170,110,49,83,103,57,247,144,79,173,72,218,32,143,189,247,32,158,6,68,246,221,92,159,63,166,157,238,216,200,133,57,230,155,61,85,219,156,130,38,128,188,61,168,228,129,221,205,160,216,31,242,198,22,174,67,91,95,66,12,100,163,109,220,239,225,110,206,85,221,164,74,223,161,16,193,231,96,46,232,195,236,177,11,167,138,85,122,11,69,123,175,246,110,112,219,122,47,36,191,164,250,98,128,103,98,130,146,159,188,41,75,249,22,199,168,239,53,54,45,72,218,96,175,27,77,251,94,117,138,249,76,237,165,176,216,66,70,119,86,173,176,33,132,153,95,237,142,93,77,251,228,253,3,146,192,5,6,157,50,31,148,109,165,7,228,66,78,216,4,171,52,108,236,33,18,214,120,217,174,49,141,73,195,241,38,9,253,174,67,52,205,181,176,178,113,100,126,21,9,50,159,167,54,65,231,209,188,8,10,67,53,85,117,207,145,251,23,159,137,181,255,218,12,152,155,78,12,131,116,239,2,134,170,68,137,239,58,183,243,107,239,13,17,13,76,142,128,10,33,75,185,182,109,173,7,139,61,61,147,100,171,224,209,183,208,9,56,226,172,212,243,44,155,118,223,114,163,255,66,88,21,185,99,99,193,138,235,51,58,58,216,214,178,78,246,179,82,29,132,243,163,252,11,72,233,88,120,204,22,238,138,35,22,209,143,232,14,229,0,13,49,113,108,38,160,139,5,233,72,238,162,116,71,17,72,41,45,203,152,181,236,64,0,164,2,19,20,73,28,249,142,220,6,38,46,195,76,111,46,116,245,244,18,244,166,158,74,234,203,248,14,80,167,89,213,79,83,141,194,34,97,14,118,230,129,121,189,122,84,84,141,104,198,129,54,118,17,101,255,1,230,113,33,84,184,21,26,124,251,213,121,140,160,125,245,169,192,146,249,105,170,219,86,162,34,219,168,87,172,11,112,44,207,74,178,85,221,243,216,65,11,94,208,26,208,13,178,231,218,186,167,223,129,65,66,99,155,175,44,23,109,185,146,131,94,194,60,185,61,148,94,251,39,229,211,171,32,202,98,251,3,240,133,125,182,2,152,245,76,12,96,129,85,250,206,85,71,237,80,150,222,249,254,86,98,24,8,58,55,182,29,76,34,60,158,213,242,245,184,47,177,157,239,90,155,89,222,221,46,218,114,185,34,198,194,139,235,161,8,252,28,122,129,156,119,194,190,209,210,16,196,224,150,134,165,128,115,174,189,60,110,179,41,54,98,9,28,154,208,107,245,228,193,93,210,90,236,109,103,213,228,145,135,169,44,43,247,206,164,128,174,38,107,172,232,159,195,57,252,141,212,59,112,153,33,248,64,144,4,50,191,246,84,40,64,15,182,32,209,103,207,182,90,59,212,11,138,46,140,204,187,91,118,197,169,118,79,51,74,150,45,64,126,159,149,251,16,100,76,109,210,188,117,85,143,206,133,176,227,115,220,95,177,141,73,154,170,240,187,163,27,171,2,76,49,208,47,8,168,40,236,11,118,255,251,129,137,222,189,83,41,108,189,217,208,228,66,153,151,175,235,212,149,131,189,224,181,55,165,83,232,178,14,159,158,244,149,174,181,197,225,247,161,185,1,217,94,69,209,244,105,7,158,131,182,161,38,130,186,107,88,211,180,23,45,145,89,108,152,182,17,15,57,229,211,236,234,214,39,25,145,156,215,182,88,16,94,173,89,90,31,121,171,39,25,157,148,157,110,218,158,43,17,137,162,146,123,6,42,89,161,228,238,4,255,93,81,117,42,231,218,206,115,36,221,131,211,220,45,254,139,57,202,4,25,37,222,125,63,250,203,158,9,146,169,200,101,109,147,20,82,127,170,54,131,222,48,102,241,145,196,43,10,210,229,66,186,23,54,32,121,143,208,91,240,235,61,232,69,185,7,102,179,221,2,242,127,250,86,75,94,93,161,90,78,182,218,62,2,192,6,245,26,7,87,68,7,203,190,98,5,230,150,249,169,16,15,231,92,243,206,140,9,177,209,216,235,39,226,16,47,172,64,82,123,254,11,13,76,105,46,214,220,140,154,202,109,139,217,220,245,235,158,49,0,118,169,232,63,67,127,159,238,30,54,36,209,235,182,2,137,146,136,112,220,51,247,67,174,214,103,239,167,232,176,72,76,212,86,105,231,187,249,76,197,17,245,57,80,248,65,95,145,197,159,141,12,107,177,68,49,17,144,38,231,200,155,63,250,181,28,178,188,248,156,10,112,204,238,221,141,119,127,143,187,7,122,5,140,238,179,236,198,129,161,16,102,251,166,62,254,197,234,167,114,101,119,168,139,183,88,61,161,193,143,76,26,150,198,143,94,233,83,133,187,151,142,216,159,199,253,33,150,51,101,121,246,211,248,145,242,90,232,199,130,13,129,90,52,243,199,115,220,90,154,104,115,236,214,135,89,235,213,229,77,161,7,70,254,172,63,195,112,219,76,104,144,177,224,243,253,233,229,149,104,110,234,148,46,229,70,162,186,217,62,39,3,84,12,99,236,236,44,113,27,201,231,238,120,240,202,241,195,60,240,61,45,107,65,95,81,228,183,193,101,71,133,67,5,101,50,6,103,68,54,107,212,224,233,196,96,120,15,219,133,118,24,239,18,1,40,97,161,149,29,251,80,56,5,139,81,201,72,243,161,20,194,140,24,88,111,168,12,237,3,98,133,250,148,192,145,138,90,239,208,181,141,114,184,184,126,244,206,116,85,172,103,239,23,177,23,218,54,246,57,160,69,183,152,60,116,217,181,85,174,81,58,6,94,228,224,112,161,124,145,50,59,228,64,89,101,118,212,36,70,15,195,96,96,111,191,67,45,205,150,101,214,108,215,252,37,252,112,52,171,105,221,137,52,189,119,19,145,237,16,125,187,92,226,0,172,187,139,219,248,196,180,117,214,62,147,9,223,80,77,93,65,10,34,221,23,60,198,30,221,197,26,132,68,152,89,63,42,53,223,72,127,57,138,213,222,186,97,186,117,83,33,169,203,154,42,138,172,209,21,12,133,254,27,33,205,191,6,101,253,39,69,114,224,178,149,127,10,112,134,102,143,75,118,74,186,138,157,20,159,82,89,113,73,21,218,125,153,250,186,121,34,154,83,84,147,142,43,191,161,100,30,77,231,17,17,3,107,193,99,87,187,124,148,226,212,59,103,213,138,155,137,116,70,37,117,129,168,83,132,44,133,250,186,140,77,156,83,110,126,87,176,115,49,18,127,39,29,179,28,5,172,181,39,181,130,179,16,93,225,149,217,141,182,71,150,150,214,128,213,117,42,98,197,70,86,141,168,254,219,233,172,252,16,179,145,142,117,123,86,94,166,22,100,29,86,217,222,148,249,174,237,102,112,118,128,119,112,64,130,175,109,6,121,15,102,0,22,2,117,145,12,199,118,199,183,228,156,32,124,43,166,12,242,185,131,55,153,91,130,128,130,88,176,209,165,183,151,72,137,122,133,32,129,64,253,12,191,248,68,104,96,151,58,227,168,80,238,96,102,13,51,161,248,110,47,237,134,71,165,76,7,29,69,186,169,146,108,47,92,250,250,172,46,27,92,122,230,248,158,206,129,226,246,32,70,165,187,154,78,170,115,33,191,134,96,10,98,170,109,59,18,23,164,13,64,93,129,174,172,207,163,103,253,205,234,203,167,82,150,42,107,38,127,111,49,157,16,98,118,198,200,247,185,186,55,235,47,94,75,92,246,44,231,105,157,102,191,87,25,56,96,255,44,167,19,250,226,126,236,93,48,138,18,34,213,179,45,200,187,43,255,141,86,27,62,249,44,150,17,91,101,6,104,68,173,204,183,58,237,81,88,88,134,198,69,205,16,163,21,78,74,252,207,77,196,147,197,46,220,184,164,106,63,255,244,175,123,128,155,93,181,205,212,238,102,66,8,104,231,174,113,242,224,221,220,212,13,71,76,126,18,136,224,66,63,0,64,136,238,112,2,21,167,166,108,172,47,245,89,59,197,55,179,143,206,220,180,69,104,107,239,227,230,18,201,229,80,209,215,122,225,178,204,27,136,218,168,43,66,113,21,206,71,96,146,107,151,84,124,200,170,182,106,34,232,63,12,177,252,128,149,33,38,55,159,176,80,95,62,34,73,67,243,92,242,242,155,86,211,10,21,121,245,43,208,78,221,52,228,138,244,35,180,61,80,248,222,7,72,43,206,65,210,220,219,246,66,167,210,185,133,27,208,38,58,170,71,84,169,11,44,43,83,209,144,56,184,130,145,137,167,206,210,103,46,6,95,155,66,108,113,119,38,9,166,15,242,8,235,64,10,242,228,195,116,253,157,162,59,71,106,47,166,47,109,33,243,109,254,174,249,42,155,202,11,215,244,223,3,246,146,58,189,193,81,230,123,42,60,51,233,112,81,79,232,132,200,16,30,27,118,246,109,195,220,71,239,218,16,133,224,69,0,6,190,201,103,220,121,210,142,77,91,106,76,190,143,102,153,73,165,146,117,120,115,45,77,152,144,11,72,107,8,125,234,250,251,241,51,120,175,45,208,138,159,119,206,142,228,30,163,20,115,26,68,148,121,81,125,254,61,11,126,111,110,154,150,108,215,100,80,206,174,128,222,183,13,178,248,191,251,74,247,143,146,110,56,179,35,161,51,66,124,224,199,141,55,236,37,227,1,125,4,196,14,230,49,129,249,195,41,153,31,148,232,209,121,156,65,125,196,115,200,104,209,73,99,120,165,128,145,81,95,212,22,215,91,194,36,147,180,25,75,39,164,145,123,250,195,65,112,100,133,223,185,154,229,198,44,146,230,49,243,6,239,202,160,143,127,77,128,100,246,59,113,201,96,214,173,55,27,166,131,176,48,116,187,193,227,35,127,198,123,181,244,220,182,83,38,142,190,214,189,23,239,96,147,66,26,161,192,255,2,11,3,230,234,227,114,71,100,219,66,133,19,252,195,43,138,162,249,84,57,27,60,175,212,69,115,238,92,33,63,112,230,42,222,113,34,97,77,20,194,208,198,239,212,117,69,139,84,158,200,132,222,44,187,247,141,211,42,6,40,183,226,138,181,235,7,226,224,188,126,182,44,156,11,180,108,201,229,128,129,128,94,40,136,140,212,154,71,153,137,149,59,152,125,53,118,137,232,216,171,91,93,91,224,156,28,70,117,105,97,68,104,67,148,181,11,81,45,118,221,222,105,82,14,58,56,77,70,252,0,189,192,8,168,49,111,11,155,218,172,43,162,214,15,82,197,242,79,245,181,9,196,136,72,24,156,185,232,30,6,212,82,201,220,108,187,142,44,45,226,149,177,85,58,199,22,81,120,148,127,219,219,0,105,108,216,211,197,156,44,248,84,234,128,233,121,17,52,19,222,0,137,82,145,187,219,51,43,114,12,177,227,164,149,54,130,62,148,9,97,5,144,232,126,14,58,70,246,166,65,90,35,144,38,2,38,7,208,85,181,58,108,54,104,58,198,214,71,196,224,107,73,28,155,174,220,218,12,102,15,52,175,74,116,141,40,102,184,87,100,146,4,195,14,188,235,59,247,147,25,246,210,245,67,33,90,250,155,17,165,57,228,163,129,173,95,21,100,172,133,48,87,111,238,85,71,145,231,239,202,188,36,100,247,104,55,240,70,178,161,161,196,99,119,125,159,179,126,249,98,137,183,32,217,207,97,156,75,175,176,227,193,109,55,115,254,247,22,35,198,146,27,179,228,130,18,23,251,124,251,171,109,62,157,85,88,247,97,146,239,245,228,225,54,198,27,153,81,179,225,239,90,249,243,93,185,68,136,135,169,92,87,22,117,171,192,145,154,115,99,211,233,18,120,76,200,128,198,214,193,14,250,118,216,238,144,4,69,138,46,18,153,133,98,8,208,251,152,10,22,173,126,89,213,21,239,108,4,41,104,124,232,42,67,105,149,183,238,101,133,5,249,49,61,98,101,216,19,53,26,115,8,68,153,116,91,206,20,173,162,59,183,118,122,141,79,20,162,222,133,34,103,129,149,65,110,218,35,150,112,147,227,214,154,18,126,184,154,30,103,210,1,74,152,135,214,159,35,40,8,101,87,93,213,6,81,249,55,22,17,91,161,207,242,235,43,236,86,218,51,20,233,167,147,249,4,100,26,38,17,148,160,22,33,113,12,215,109,253,38,131,113,197,231,89,58,99,84,226,69,57,79,112,71,202,90,183,46,109,234,39,199,216,169,119,82,187,111,73,107,116,246,91,241,53,82,11,52,36,171,157,196,21,85,90,214,237,33,51,192,42,77,234,187,162,95,133,202,159,67,34,51,188,133,42,175,19,141,68,25,215,67,7,194,45,182,5,179,46,192,79,163,142,145,21,18,50,116,165,166,130,205,188,222,188,164,217,185,42,209,137,198,222,157,45,241,99,236,243,200,154,29,24,170,114,127,58,246,72,122,193,3,253,46,84,64,72,34,50,127,251,94,239,44,149,96,47,96,128,98,251,184,106,234,206,151,10,166,245,201,230,165,55,120,94,68,113,95,202,105,44,99,209,129,235,203,129,236,95,168,127,120,217,51,172,230,7,247,245,236,186,109,51,105,142,173,22,163,28,175,69,74,104,215,128,59,109,139,254,224,209,189,122,191,136,113,122,70,237,238,214,217,98,61,26,185,14,80,157,160,110,150,234,103,68,203,40,97,140,254,177,253,138,137,196,119,34,75,195,252,62,105,13,225,56,130,223,124,166,184,230,199,213,227,240,226,188,123,69,236,20,183,116,182,52,225,49,142,227,44,178,43,133,228,99,219,138,184,88,32,145,243,236,219,86,136,237,250,43,238,208,129,218,198,148,50,203,73,67,72,37,81,244,247,139,86,136,94,47,222,159,221,143,165,28,207,210,54,137,255,78,248,244,247,127,85,53,78,44,106,44,148,128,47,44,156,12,135,207,132,48,88,72,134,116,210,41,34,147,117,249,219,17,137,245,46,12,5,26,28,21,50,113,174,128,54,21,238,124,98,234,116,92,242,233,48,226,155,145,20,43,183,33,85,15,171,139,19,190,198,138,98,240,154,65,87,188,81,162,210,18,251,212,145,208,140,21,50,181,145,254,3,191,201,241,51,204,59,72,102,232,41,53,28,192,123,115,57,40,113,180,191,34,37,81,179,64,188,102,11,243,193,67,137,30,64,46,38,25,91,130,71,209,5,143,96,36,215,126,112,218,94,162,122,229,237,12,253,144,133,55,76,212,48,103,50,60,35,53,57,167,46,220,207,82,126,105,219,102,13,103,166,90,165,63,106,80,133,164,147,166,142,187,71,227,185,206,99,103,244,162,163,90,88,176,115,18,179,175,96,75,27,243,112,250,94,252,48,102,72,28,224,230,156,159,167,217,216,108,39,128,52,230,231,149,231,212,243,28,104,138,87,26,49,69,23,140,215,113,102,217,195,60,122,79,0,64,162,113,82,30,114,31,233,47,239,67,241,228,244,68,134,36,246,198,7,70,164,11,15,81,114,186,172,50,164,194,7,16,176,82,151,216,199,248,242,151,101,102,203,38,50,148,140,159,29,34,255,185,53,75,205,218,114,198,230,249,254,227,175,79,63,115,90,124,122,122,255,247,167,223,216,86,239,189,227,131,164,129,47,182,144,100,79,139,76,181,132,149,11,73,31,131,110,211,183,117,185,39,12,12,16,121,158,87,91,69,244,218,80,51,12,101,112,80,66,128,127,39,46,215,32,89,111,191,3,91,151,223,183,157,248,139,1,26,132,32,32,48,163,242,157,215,173,179,156,144,226,240,75,61,113,218,160,227,225,145,50,138,153,218,154,200,102,90,149,167,236,58,64,138,250,149,84,158,161,127,54,130,20,37,155,119,20,214,219,61,57,58,18,225,158,9,130,77,102,107,239,202,3,188,88,199,226,145,10,37,182,255,4,50,186,152,237,171,181,2,199,67,133,29,197,105,194,85,214,47,140,198,67,93,49,189,235,22,176,188,78,190,33,166,63,102,46,125,59,30,137,151,193,31,247,45,131,87,164,213,177,23,20,98,52,170,248,209,85,235,106,117,172,137,3,127,87,68,0,69,49,164,117,135,214,120,240,228,207,51,81,75,154,161,232,207,15,105,104,47,170,112,153,250,27,27,146,209,59,200,223,159,15,162,58,154,50,73,223,148,115,103,253,73,206,89,221,41,223,56,125,199,142,141,150,115,243,62,11,230,185,121,139,100,85,43,79,28,146,196,60,19,70,96,239,212,76,34,42,212,126,215,157,176,128,35,235,245,223,49,30,172,54,17,55,250,119,125,193,119,231,236,167,147,67,66,206,81,229,219,73,26,192,95,122,164,159,231,158,15,248,143,174,36,37,108,150,182,61,125,138,24,27,165,42,215,181,161,225,147,240,7,27,180,177,147,193,254,27,23,161,140,199,47,59,139,1,22,147,255,228,4,243,11,204,171,74,238,187,242,128,170,223,27,207,139,38,100,16,147,110,68,4,249,139,69,205,15,9,133,81,86,83,9,250,224,144,93,24,59,58,75,132,157,207,158,210,203,92,100,198,45,244,124,216,140,173,5,214,155,137,73,4,225,190,56,212,136,135,81,109,165,68,198,16,1,31,166,25,133,79,153,170,189,241,206,52,237,236,111,133,253,226,19,106,194,209,216,59,181,46,180,57,113,125,245,172,60,126,84,38,150,197,16,155,160,66,251,19,156,148,227,214,211,246,59,44,220,67,103,246,22,244,236,22,138,191,212,182,193,62,100,215,120,46,215,175,95,197,162,40,191,72,97,123,102,97,134,141,68,147,1,17,150,174,188,208,139,103,37,226,137,140,43,219,168,201,85,95,211,29,78,165,101,129,61,64,122,86,87,85,150,209,177,239,161,211,142,74,109,146,130,154,187,24,145,242,213,35,193,116,14,57,83,233,149,195,161,164,81,162,73,234,211,2,97,233,11,152,33,52,6,71,146,206,243,149,164,252,98,75,49,63,162,96,200,212,120,79,41,91,178,78,119,215,39,233,93,142,135,114,133,78,169,249,176,236,96,191,16,175,200,36,173,67,224,60,66,58,21,172,82,189,210,117,33,132,32,100,53,32,230,168,67,71,2,35,27,134,16,135,118,125,37,5,10,12,192,142,209,133,11,86,76,73,153,128,196,46,8,140,125,227,229,2,95,9,108,1,202,101,71,1,35,70,51,129,122,243,184,237,229,84,199,125,120,51,28,105,248,247,153,66,142,197,148,117,2,241,223,190,230,25,121,87,22,236,125,68,192,84,68,226,55,107,143,121,149,13,180,151,138,180,67,70,237,56,74,48,117,35,92,205,19,213,154,135,136,34,40,184,90,80,217,55,187,217,119,246,90,10,213,222,89,16,123,147,13,201,47,37,213,34,197,54,98,21,53,56,64,22,184,247,210,142,210,6,240,101,167,44,105,63,109,124,163,44,45,221,147,158,234,52,233,7,47,25,34,164,190,57,104,239,44,210,84,160,113,110,95,222,19,114,80,231,219,25,133,131,202,175,73,206,99,225,136,136,116,157,71,121,198,252,202,147,232,212,25,42,210,231,51,137,102,102,46,120,106,155,24,51,96,145,56,193,156,211,62,238,215,170,203,122,238,218,145,102,130,47,45,143,103,37,65,161,67,179,87,180,249,29,171,72,232,6,231,106,20,164,109,200,61,36,145,226,171,35,250,144,157,114,81,20,0,155,146,63,229,235,60,120,6,156,135,237,225,192,253,102,173,192,151,239,91,9,44,136,154,183,227,120,179,107,139,43,44,5,167,44,24,4,128,68,133,250,75,79,98,100,66,238,71,71,83,44,169,133,180,222,34,112,84,155,89,86,109,88,144,70,123,54,86,13,51,102,160,178,88,62,138,212,88,110,18,54,126,202,65,217,185,177,154,109,234,18,137,155,112,33,44,226,249,103,41,149,57,5,141,176,51,36,236,59,122,117,34,48,199,178,158,148,104,45,40,125,102,140,194,80,42,115,47,197,70,177,251,67,69,202,129,7,107,149,166,91,72,43,20,200,103,193,239,42,217,65,64,252,162,85,59,56,211,104,3,125,50,7,192,98,187,19,36,210,78,161,162,12,54,102,100,18,138,96,241,5,225,197,38,212,1,103,113,39,226,187,115,214,205,142,162,208,40,111,174,202,105,171,241,29,161,18,81,106,245,84,67,73,80,152,140,139,215,111,164,90,129,88,254,54,177,208,204,58,125,101,139,87,53,54,47,107,29,178,43,18,104,127,202,164,145,31,190,75,221,31,169,138,119,60,143,15,173,30,36,66,255,60,76,252,119,205,208,254,84,4,136,241,236,10,222,124,20,220,167,253,247,180,19,178,154,191,240,151,132,96,89,211,213,174,36,148,72,194,176,78,87,100,234,169,172,54,51,234,3,39,130,44,187,83,162,168,251,221,241,172,189,67,91,247,48,32,10,141,59,78,123,58,159,101,145,49,36,217,143,54,90,236,160,149,185,51,246,201,167,25,121,24,92,43,33,178,45,5,248,179,18,74,112,104,28,74,156,52,201,98,109,213,14,86,86,88,143,72,128,241,59,209,250,172,237,140,150,138,45,233,215,181,115,12,185,81,84,33,142,99,161,19,108,194,79,73,216,58,9,165,243,194,220,142,186,82,141,54,8,3,111,171,58,0,9,237,166,10,143,38,83,188,32,26,233,58,58,251,156,147,122,11,5,42,152,2,134,116,34,172,183,30,5,83,161,202,21,191,185,245,8,137,20,133,245,255,70,30,39,79,227,228,217,155,128,249,255,237,241,127,255,22,125,39,132,210,255,227,250,234,250,234,211,199,159,127,186,13,52,243,111,169,37,4,176,102,13,80,165,204,68,94,115,91,162,142,215,68,162,121,31,98,97,108,237,75,37,43,116,234,197,130,43,129,114,13,73,39,214,196,151,21,61,0,148,24,88,116,99,49,51,234,81,171,111,252,225,230,219,87,17,243,215,229,236,231,86,101,77,103,208,48,31,174,68,61,227,198,83,25,162,170,122,102,114,4,22,46,8,153,109,74,46,233,235,207,254,52,100,178,239,170,218,7,152,51,107,235,37,180,221,120,234,16,141,179,233,55,251,240,234,5,92,197,204,118,17,115,68,51,128,168,19,105,10,148,75,183,11,101,117,237,206,161,207,135,99,45,166,221,110,81,77,124,253,172,233,182,63,132,113,66,213,183,216,110,161,96,239,20,242,148,6,26,123,98,228,55,30,34,20,82,0,115,184,150,31,170,44,210,186,157,126,123,125,69,164,206,76,232,115,220,199,125,218,135,96,71,254,217,222,169,194,139,195,231,229,222,63,132,43,227,119,251,37,55,192,255,135,97,117,215,116,146,2,84,186,21,204,43,170,89,153,107,211,98,235,151,74,140,132,237,147,102,100,47,89,189,24,35,238,173,174,26,209,9,9,237,14,242,248,196,4,112,143,119,192,78,102,194,147,154,125,240,222,60,122,215,48,173,76,221,179,174,146,68,3,109,167,78,106,163,188,61,14,5,2,208,186,162,244,124,213,143,60,9,106,191,54,76,239,34,38,60,161,148,185,189,177,32,193,11,223,12,230,200,69,211,5,8,221,143,88,126,129,137,196,204,68,31,185,129,81,190,22,113,17,192,26,130,60,121,71,239,158,227,36,192,215,118,11,36,152,159,54,94,102,31,237,199,70,165,61,188,34,142,237,66,202,39,28,61,167,90,140,243,207,91,166,99,36,188,153,7,39,52,245,233,184,155,126,13,78,215,142,161,227,16,77,174,180,218,214,36,182,28,221,238,72,35,194,214,204,59,39,27,51,103,82,176,105,173,200,201,116,60,130,83,55,190,45,197,196,174,249,172,159,204,242,95,20,182,70,214,226,138,189,83,163,117,182,195,53,143,231,200,182,126,73,41,204,241,187,41,243,131,21,170,116,63,58,54,211,253,22,156,63,58,195,110,85,48,160,120,190,191,41,242,1,96,69,208,132,115,217,22,169,253,215,62,70,219,98,44,234,66,193,208,221,142,86,152,86,150,37,214,98,191,20,118,170,223,29,27,216,114,182,41,244,218,12,157,1,228,14,233,164,141,70,25,74,31,115,189,129,99,67,154,75,249,236,72,104,6,50,152,14,102,26,67,174,208,69,177,213,75,203,25,222,118,129,254,255,167,166,89,212,100,47,238,218,220,69,244,236,21,121,57,110,137,7,43,114,221,153,36,6,188,213,138,210,58,161,224,181,63,19,114,220,12,138,33,125,114,114,90,176,219,173,192,244,227,117,137,84,70,64,217,150,253,29,26,208,33,20,172,88,202,15,150,3,66,85,119,178,124,197,107,155,43,152,163,4,27,49,224,115,78,43,196,99,98,76,201,164,13,174,143,139,143,133,157,1,147,226,184,90,83,144,125,125,241,143,215,6,148,90,149,125,239,205,58,53,243,240,254,28,199,34,89,56,191,225,125,182,45,228,226,46,115,63,255,252,33,61,62,33,224,197,236,167,14,148,110,27,184,118,21,154,174,142,209,209,245,196,9,184,190,90,85,221,170,198,86,230,116,205,222,66,139,67,8,194,161,58,18,255,162,181,192,81,215,87,29,32,54,145,32,8,253,110,182,54,184,225,184,216,75,123,187,61,31,134,87,222,214,214,185,230,131,107,21,220,9,164,88,52,102,185,105,70,45,84,67,185,102,157,203,63,160,68,215,161,187,252,191,237,48,137,46,185,121,225,49,93,98,5,255,240,162,37,165,106,2,165,166,93,125,90,96,1,46,240,137,101,58,152,19,44,185,55,169,206,40,105,176,80,118,222,187,104,76,75,114,58,98,179,175,165,116,140,41,44,141,108,26,141,72,47,132,245,4,251,179,139,54,90,192,254,64,74,82,18,25,165,183,230,136,250,251,195,236,125,5,154,116,225,33,194,125,2,94,100,159,64,40,2,238,183,212,7,252,243,91,79,21,219,64,31,177,77,137,205,133,61,147,213,230,49,180,0,122,133,145,193,147,247,172,114,245,218,165,219,155,240,254,59,7,126,86,67,26,24,122,19,44,138,207,62,239,206,174,208,171,170,185,242,192,76,176,68,22,11,178,29,39,233,194,254,56,38,224,84,139,225,51,193,134,223,107,155,210,15,11,110,55,179,194,171,116,69,183,167,88,19,157,35,65,189,24,80,149,99,117,62,58,56,214,128,96,16,194,202,214,54,206,48,40,67,225,40,177,177,91,216,210,0,192,93,95,141,130,32,174,170,204,122,237,93,116,113,30,70,21,51,135,64,122,119,169,76,19,186,96,107,15,1,44,81,224,4,106,206,38,85,234,169,250,70,109,129,184,253,225,68,124,123,204,104,199,194,153,60,207,63,142,213,234,25,161,132,3,164,24,226,148,125,82,157,180,33,43,204,153,129,208,241,42,10,97,34,50,163,216,199,83,4,20,211,98,238,154,178,87,197,52,212,163,255,168,233,126,125,5,213,15,121,180,235,10,2,197,158,235,137,50,123,54,109,60,211,67,9,198,18,210,245,223,199,147,168,206,137,121,253,223,8,128,158,94,46,232,199,153,182,247,158,124,240,97,210,165,239,21,30,52,202,113,16,24,160,155,102,199,215,197,233,146,247,28,142,129,160,212,228,119,162,163,224,124,29,4,42,27,190,222,133,59,220,72,64,55,128,195,144,186,87,140,210,12,83,98,64,66,215,239,18,80,144,41,185,134,12,114,8,228,32,179,17,251,196,73,188,66,134,92,18,206,74,169,113,186,96,23,55,190,161,215,66,15,103,69,143,228,207,2,30,26,251,84,178,225,99,81,179,38,19,251,15,245,164,118,45,11,125,32,230,161,124,224,83,167,71,26,138,88,199,159,160,185,10,91,77,124,56,165,154,29,246,41,77,82,111,105,173,30,105,89,45,84,251,208,31,147,167,127,87,18,14,215,143,147,63,154,148,35,13,93,28,44,0,47,86,187,139,199,154,154,196,232,235,249,38,160,186,234,110,234,72,221,49,1,212,169,68,19,141,163,88,217,61,73,163,43,65,238,9,144,46,188,195,58,93,78,140,52,75,105,201,237,228,62,185,112,5,164,55,240,82,202,80,149,10,95,76,211,145,62,193,190,53,235,42,250,224,61,43,148,54,251,57,61,93,101,54,137,254,113,189,44,149,126,94,76,206,234,145,120,225,85,27,210,24,153,65,43,250,103,9,197,165,119,116,12,44,19,118,226,57,41,136,239,209,7,243,71,199,156,132,108,169,189,142,61,229,9,253,111,172,21,126,166,112,160,148,97,74,119,110,47,125,206,100,241,158,202,51,74,106,39,154,223,211,237,108,78,29,222,106,66,253,179,223,124,239,250,23,10,231,108,124,164,90,38,207,153,206,62,249,51,251,50,18,163,119,243,164,165,1,230,17,212,18,79,52,46,69,237,253,34,224,9,180,33,88,190,224,59,114,52,105,228,87,96,147,110,0,155,235,212,28,136,2,57,189,231,196,217,104,125,49,155,63,169,110,14,85,172,249,10,57,173,59,103,178,121,102,217,230,247,148,198,184,115,77,251,232,70,178,5,142,154,46,21,203,59,13,160,190,230,245,194,141,97,239,206,202,59,159,85,77,228,75,168,209,205,218,4,15,101,242,119,62,132,142,68,89,99,213,7,139,164,245,138,214,78,241,23,255,11,54,216,172,171,14,74,198,225,31,139,113,176,190,121,124,192,25,219,33,151,41,97,245,17,180,203,66,109,149,231,179,47,170,36,174,201,36,45,92,60,62,155,2,51,49,33,193,46,13,232,46,149,188,152,92,174,143,56,151,133,153,10,175,1,126,149,189,3,123,126,168,204,143,36,186,76,236,99,122,153,163,76,116,143,132,67,121,184,201,120,113,95,227,201,116,63,36,15,1,176,79,231,212,102,105,229,245,164,71,31,117,183,24,152,37,230,143,217,108,83,116,103,171,19,43,240,4,250,241,217,87,235,7,62,145,67,239,217,227,13,40,162,23,246,197,239,51,172,200,232,68,127,156,158,238,99,227,177,74,22,185,138,36,86,37,60,93,111,179,143,251,162,55,229,91,42,169,171,180,111,161,186,67,23,250,153,142,186,67,112,191,97,209,137,89,29,128,216,157,222,37,234,14,138,151,1,23,22,82,116,13,108,149,30,171,43,247,69,197,232,122,105,38,252,8,89,98,233,147,88,168,213,158,233,188,237,60,214,142,82,37,211,174,189,189,184,98,191,71,57,132,82,181,237,146,64,91,15,18,18,199,124,167,246,55,61,173,135,109,103,91,9,10,152,241,192,224,123,228,198,250,70,17,47,129,149,12,143,111,143,74,89,39,251,2,0,212,197,248,127,190,72,44,11,82,19,209,227,224,58,121,124,123,16,100,161,16,26,113,200,235,49,129,126,66,162,255,60,86,208,82,111,203,94,104,111,240,25,15,85,83,5,209,85,85,198,142,121,61,78,239,125,210,90,178,123,135,221,184,13,44,152,64,47,210,113,209,80,21,66,129,213,164,177,179,191,77,199,241,118,100,142,164,64,64,97,168,85,224,240,66,181,194,67,97,105,72,195,193,202,192,217,199,165,122,78,197,102,85,34,192,240,138,0,158,168,240,154,169,33,206,29,30,192,59,228,138,185,157,137,30,164,166,121,11,125,195,83,246,237,131,214,247,220,190,157,207,148,118,7,24,170,143,50,143,69,90,18,55,57,118,171,29,125,15,191,15,45,11,230,43,50,131,138,236,192,181,68,165,149,6,23,195,139,126,106,45,81,90,198,182,16,125,34,116,90,208,56,72,40,246,64,62,214,46,142,65,23,181,93,50,61,143,176,210,101,5,192,46,114,145,41,60,47,103,124,83,12,237,190,250,39,42,71,196,227,122,171,185,254,31,199,2,83,31,123,194,86,90,80,113,98,223,200,158,154,175,236,102,16,170,232,154,134,247,222,64,200,93,121,190,45,57,50,56,164,242,118,232,225,46,59,163,217,93,99,103,55,127,95,3,228,237,186,66,102,221,38,84,231,170,129,0,58,222,156,131,158,165,171,123,214,249,164,103,9,167,171,83,27,70,94,181,92,87,43,10,13,78,22,199,143,85,233,6,184,124,51,237,123,23,96,174,160,112,80,63,59,82,155,244,106,180,240,60,11,57,105,26,6,139,180,37,175,99,114,177,15,156,82,80,104,168,202,175,90,186,71,102,86,40,185,17,218,55,246,247,93,48,134,153,73,84,108,73,72,141,219,68,45,23,223,12,123,190,245,163,237,36,190,66,150,221,113,192,124,235,93,0,1,63,159,240,1,108,127,220,47,219,30,185,171,30,190,149,103,58,217,70,177,252,90,213,201,207,115,213,78,184,1,213,138,98,89,40,48,82,42,8,34,27,188,165,21,25,162,11,151,174,74,157,224,170,126,219,118,219,172,43,69,244,7,230,43,203,135,242,236,192,189,14,230,156,57,253,70,61,149,38,50,48,59,117,75,29,138,191,24,6,217,1,95,129,5,6,140,14,126,102,72,176,211,55,130,93,128,103,127,220,98,53,249,168,244,37,240,181,159,171,104,143,227,208,211,206,235,251,226,20,216,187,43,151,75,247,91,5,92,13,111,16,172,122,124,255,164,102,128,14,180,143,110,246,46,199,137,131,110,244,179,101,14,221,87,2,211,9,185,120,192,99,227,59,159,182,110,8,99,94,59,114,161,81,58,170,106,66,154,40,229,239,32,184,23,212,150,50,9,226,19,135,212,139,198,235,45,131,144,66,104,208,131,9,33,128,147,139,198,162,42,250,53,152,165,4,82,237,216,172,178,86,66,216,91,99,75,228,160,56,4,63,216,218,189,108,136,5,111,73,52,32,238,42,154,111,199,123,98,247,32,53,193,147,149,9,138,16,17,237,126,70,244,199,92,237,30,156,175,65,207,235,126,230,174,97,243,16,107,16,255,116,202,74,47,177,57,92,129,158,146,114,233,218,124,217,183,214,149,158,189,50,187,22,121,158,133,65,89,191,38,237,213,217,225,92,31,158,14,92,74,10,203,53,130,233,56,163,68,90,252,133,39,14,60,115,85,175,111,108,121,3,204,84,171,179,221,111,205,202,108,254,94,154,24,158,235,84,151,224,41,38,245,225,69,142,108,49,182,106,21,190,140,248,198,140,83,107,134,0,83,105,225,201,209,33,107,165,153,47,33,207,221,235,0,155,17,22,117,100,105,175,159,137,166,243,132,195,194,65,253,78,74,97,183,93,53,169,26,207,105,155,250,41,36,128,198,134,125,68,31,172,158,53,65,219,205,133,121,123,236,134,48,89,232,143,214,218,180,166,72,50,43,61,142,214,92,135,198,62,39,101,73,156,205,172,59,174,75,165,162,157,28,43,145,108,53,105,10,43,0,11,89,125,37,195,199,19,40,104,121,201,254,13,106,3,156,117,105,252,157,197,54,91,12,115,106,109,127,197,140,132,19,138,72,249,206,107,218,109,7,51,2,161,71,186,48,75,56,5,113,119,154,34,210,239,97,36,224,194,15,130,159,219,209,18,86,78,55,116,167,32,79,216,233,90,2,31,165,227,96,232,114,50,7,212,152,35,123,68,61,243,59,81,102,244,90,105,60,228,20,208,161,117,53,241,35,181,157,168,224,232,153,196,77,71,231,147,22,236,201,37,147,208,10,196,252,93,245,37,49,3,6,71,113,157,23,117,70,172,70,8,10,250,65,121,43,153,69,34,9,86,151,251,163,219,193,96,56,99,142,61,204,36,75,64,4,83,51,182,45,116,110,226,69,83,58,126,106,19,86,136,48,104,176,164,223,77,154,34,57,48,44,79,253,42,89,230,124,44,206,238,234,210,183,253,196,85,238,17,60,169,116,170,253,57,194,36,52,19,93,65,59,174,38,153,107,86,57,253,126,206,15,179,95,138,110,237,154,206,35,250,141,200,181,232,3,32,159,77,117,49,68,104,64,90,170,63,43,147,184,2,157,95,170,87,30,88,227,74,244,76,248,10,77,209,56,75,18,201,105,73,146,218,93,83,178,208,109,134,109,109,115,241,25,133,140,140,21,144,195,187,170,166,88,113,5,171,197,235,136,60,176,215,177,150,137,29,107,229,75,60,2,171,46,173,179,75,155,210,66,141,149,246,193,85,231,112,77,4,128,114,241,42,148,59,159,188,110,155,120,7,72,16,40,17,226,113,0,186,84,44,198,3,57,28,39,207,12,215,238,127,99,9,64,145,147,193,44,125,224,236,23,196,52,171,62,20,171,94,242,167,220,108,226,40,46,66,206,167,242,92,214,208,187,61,89,196,206,38,198,12,175,211,66,163,209,154,15,2,171,16,92,38,170,45,254,93,145,105,137,173,36,155,187,148,254,36,181,209,217,181,44,52,47,41,239,210,228,113,26,20,94,158,44,230,56,134,106,23,213,44,3,22,124,25,115,1,201,202,38,54,94,9,246,9,220,99,124,166,67,231,92,185,144,216,231,203,98,203,99,28,250,98,228,34,8,230,160,105,192,202,52,96,46,210,195,145,241,177,82,124,182,238,218,67,168,125,20,43,172,126,225,238,96,229,74,139,88,37,15,125,119,57,119,123,111,100,200,21,134,100,87,26,54,63,178,8,188,143,79,225,168,130,214,135,120,226,112,36,61,49,120,42,164,202,229,61,222,45,20,32,197,153,154,235,177,58,185,77,47,71,19,25,118,4,36,226,0,107,5,128,235,11,254,219,47,98,103,94,183,92,189,232,19,235,96,59,226,98,79,14,199,219,70,43,7,59,23,213,228,5,110,115,90,8,243,153,82,72,129,35,166,4,211,222,221,5,81,20,220,97,180,91,62,64,192,119,127,96,210,26,228,27,225,150,239,34,37,71,63,130,121,89,239,204,129,153,247,49,0,146,94,98,64,195,67,24,34,185,220,228,169,138,108,8,70,233,136,135,146,174,169,124,189,229,11,11,248,83,59,38,197,205,121,246,9,21,224,48,199,117,56,216,107,8,112,71,87,162,14,123,251,74,231,70,135,166,47,89,220,240,134,49,14,177,106,215,81,43,202,113,251,47,51,13,37,33,212,194,207,178,75,27,248,118,20,156,117,49,134,59,103,166,83,163,182,32,155,26,92,241,190,96,108,82,12,48,120,191,168,148,212,43,177,119,106,75,192,192,32,15,76,237,158,164,78,138,118,211,165,51,83,209,60,133,185,23,20,178,179,61,176,206,26,31,19,196,218,15,162,132,229,1,209,190,212,30,98,190,59,92,190,146,18,50,56,87,201,190,45,147,108,82,101,43,203,30,62,53,96,195,223,13,82,63,171,36,92,131,167,245,216,129,144,12,64,236,112,54,231,61,82,43,103,33,247,184,88,13,189,51,122,200,145,156,9,198,247,232,238,74,196,187,5,129,187,31,202,83,29,10,86,135,227,115,42,5,209,185,232,137,209,69,230,40,75,251,186,5,163,128,145,5,158,22,181,223,44,219,115,238,117,162,209,81,89,135,224,142,142,12,201,163,13,1,206,105,123,224,50,235,27,138,209,252,214,140,136,66,164,31,120,110,101,73,134,92,183,158,210,74,230,129,167,223,111,108,234,241,180,174,119,224,47,119,9,181,29,243,153,62,80,217,86,170,60,35,135,197,76,217,178,107,79,222,3,162,32,8,81,73,193,208,131,139,228,91,203,14,112,154,196,98,232,39,200,144,13,59,214,225,223,202,2,204,34,190,28,181,75,112,212,32,127,197,162,31,190,251,199,177,232,108,26,92,192,64,150,199,229,146,144,94,224,94,20,59,49,99,18,81,34,42,248,48,200,123,84,125,47,134,3,138,113,21,229,77,109,107,97,231,99,169,44,194,222,159,53,28,90,102,5,108,170,141,45,205,6,179,135,108,114,197,2,125,57,62,155,43,160,66,28,114,197,165,31,99,193,28,79,95,156,28,73,211,174,225,102,168,123,201,56,71,73,109,242,89,201,66,0,123,96,19,177,89,253,133,55,179,133,43,81,109,148,155,244,248,13,89,25,197,165,117,117,56,80,12,243,0,2,150,57,6,77,220,107,146,73,100,164,219,132,195,113,160,13,3,34,71,177,189,55,72,23,194,19,52,207,133,184,185,20,116,88,36,145,24,192,140,96,41,148,18,17,25,162,59,154,173,234,97,177,238,147,126,8,68,43,109,113,213,142,230,67,216,224,109,232,92,45,137,210,231,234,100,136,236,136,77,44,34,136,14,182,93,250,126,102,235,4,82,85,125,44,219,30,111,231,118,246,30,105,14,90,26,103,135,71,72,194,202,151,248,25,62,249,72,114,230,243,216,153,218,14,201,196,39,188,55,202,127,197,165,147,44,0,149,246,218,37,36,60,56,122,159,40,152,82,150,232,202,198,4,61,222,186,255,115,128,5,143,143,17,156,7,52,57,107,102,60,13,41,29,120,49,241,230,229,23,223,206,62,149,238,55,59,216,182,241,50,218,146,56,140,40,123,213,18,75,164,99,253,218,102,193,206,28,190,73,168,56,73,148,199,167,150,174,49,101,137,196,31,176,24,103,85,32,14,32,142,115,108,50,19,103,17,118,204,225,131,175,220,240,189,90,252,13,109,2,31,112,83,236,200,19,198,25,152,6,179,24,140,240,155,140,165,114,116,225,156,8,69,72,23,64,209,213,25,42,140,203,88,186,189,119,102,147,182,57,9,187,187,170,218,5,196,247,187,26,53,187,37,255,215,19,100,28,125,36,166,243,214,56,174,56,112,68,182,100,29,130,252,115,76,174,109,103,150,99,176,160,151,82,21,48,159,204,94,37,189,131,231,146,175,96,108,99,144,159,81,223,61,70,34,24,65,53,56,69,44,152,48,146,134,14,28,114,63,55,187,246,13,31,1,5,138,248,251,152,210,113,128,39,195,221,172,177,31,51,51,153,245,185,70,184,137,110,82,252,53,223,177,153,114,110,12,172,194,251,175,62,179,84,22,39,87,85,131,103,124,227,59,124,212,142,121,134,63,69,186,186,250,209,174,252,79,80,121,252,191,162,118,86,244,137,251,231,115,44,174,117,27,92,68,0,212,108,84,192,163,227,48,46,109,186,66,87,209,233,156,163,112,73,2,220,159,36,158,98,11,254,176,208,16,123,46,52,13,177,25,15,40,24,63,246,254,212,35,165,147,194,0,175,140,225,255,88,189,132,3,100,245,17,87,248,230,252,153,54,154,236,37,137,209,143,81,20,236,140,108,103,32,220,235,115,58,77,56,38,189,200,46,102,2,188,219,34,90,29,154,47,185,173,36,16,45,55,156,47,110,232,142,53,216,246,251,208,213,116,81,160,32,135,115,23,167,114,140,142,140,240,216,81,136,42,202,4,84,44,88,17,164,33,103,130,58,119,94,13,51,235,125,12,66,88,90,83,11,242,1,164,71,179,42,188,9,178,119,251,118,102,84,200,117,100,43,68,136,253,184,27,230,105,51,106,141,189,131,79,199,3,120,4,52,66,94,146,48,255,198,78,232,213,5,222,2,104,143,153,193,242,22,30,147,21,47,120,44,137,26,255,54,47,96,210,21,224,63,85,208,84,3,0,142,130,20,245,94,10,105,254,172,197,44,189,47,228,133,31,212,144,154,213,165,33,83,45,97,44,202,180,64,73,66,117,16,142,131,106,143,145,220,75,123,190,91,113,199,137,132,93,234,168,131,61,123,41,113,205,212,160,251,35,83,176,16,84,108,182,177,10,29,192,165,44,4,1,27,246,74,43,172,176,31,73,213,56,14,110,111,90,97,89,163,199,217,156,208,57,123,103,247,114,150,248,80,210,218,183,33,0,176,44,148,18,247,64,151,173,1,104,211,28,205,26,95,194,79,62,129,122,182,111,27,236,128,40,128,72,164,140,250,118,163,122,177,30,41,155,228,204,241,0,89,130,45,247,86,11,190,38,25,182,72,46,62,51,54,35,69,159,214,101,21,95,33,132,144,172,118,89,253,243,40,237,59,180,133,179,191,188,130,17,19,173,31,107,8,137,120,255,15,181,177,40,203,72,114,166,38,14,116,2,175,83,50,245,36,46,205,115,2,117,18,190,103,27,43,167,200,213,199,100,79,178,14,134,208,18,24,165,55,124,160,88,4,110,18,183,156,97,110,40,80,86,169,51,250,75,197,75,230,230,92,132,149,79,32,108,156,57,65,199,126,23,33,36,214,182,4,241,178,69,133,52,36,226,88,101,135,188,242,32,126,45,92,118,68,223,104,88,1,85,7,111,172,150,244,218,104,144,48,116,119,40,211,232,69,151,127,29,202,181,23,233,138,145,253,178,55,251,25,94,205,127,186,70,255,5,22,53,133,27,7,240,136,179,252,250,187,34,164,174,23,202,21,67,219,152,157,56,171,188,105,26,195,251,145,169,197,118,213,54,30,55,148,38,43,17,54,96,63,181,99,73,247,70,68,209,125,45,189,160,205,73,1,49,244,65,24,154,208,140,71,32,88,7,22,12,158,202,215,210,183,171,29,21,101,17,248,68,159,28,245,229,130,127,207,77,149,91,66,207,94,211,54,111,198,70,233,131,20,155,208,195,33,120,115,76,82,177,157,67,222,21,174,2,193,156,13,13,206,145,224,236,5,129,68,189,221,130,82,18,39,147,134,193,153,27,145,82,97,177,90,29,210,90,235,212,106,56,6,139,134,7,147,90,100,140,225,124,237,39,161,193,176,91,254,245,104,142,67,135,255,241,222,196,247,96,170,16,156,16,221,35,72,154,226,43,45,100,17,203,24,66,165,12,108,10,97,132,42,98,236,162,141,29,83,18,47,213,66,38,138,58,35,25,119,23,192,26,49,54,166,60,107,73,100,75,102,41,83,35,153,146,138,63,99,63,157,144,115,193,125,99,0,164,30,234,240,105,23,46,96,164,246,218,232,10,179,113,242,67,118,52,95,113,28,119,121,27,144,188,161,243,194,90,235,237,236,233,213,223,89,76,92,13,5,144,140,79,222,122,166,26,28,87,96,139,252,254,219,87,132,142,0,203,169,227,157,242,103,95,1,0,166,37,153,177,89,77,246,99,84,34,170,212,31,100,3,84,115,207,95,11,133,161,150,112,249,101,175,175,198,159,142,253,87,35,43,14,9,29,87,121,50,187,128,238,166,179,199,94,87,96,3,15,96,213,253,141,4,117,133,63,160,27,8,235,120,220,171,59,145,93,80,36,34,85,125,131,189,170,52,146,221,27,250,34,147,235,184,8,238,130,55,92,13,147,204,124,112,187,7,76,114,70,229,17,230,107,44,114,107,251,246,176,11,89,225,140,144,157,232,167,161,155,154,40,76,78,34,27,66,67,7,73,33,139,52,158,33,251,55,72,138,129,189,176,6,114,30,124,3,245,164,146,200,36,202,29,23,202,131,53,165,104,75,133,139,146,185,136,206,140,153,52,44,97,92,22,181,121,250,160,238,204,223,3,135,236,213,238,67,215,30,216,45,201,102,38,48,79,78,233,60,185,200,196,6,52,53,128,202,33,13,122,175,107,243,84,193,90,149,200,199,70,146,209,96,47,164,91,45,174,175,136,160,87,235,197,64,105,72,248,2,97,128,227,154,29,84,169,115,95,95,237,114,180,23,91,170,150,107,66,125,161,47,126,14,245,134,6,40,11,186,56,103,226,189,5,174,137,34,161,133,62,165,58,6,117,94,102,37,122,151,211,119,13,107,137,224,75,53,177,108,217,126,26,43,231,156,237,188,84,81,143,239,25,84,132,47,120,251,220,99,49,123,125,146,190,242,214,23,242,170,167,87,248,60,105,137,182,46,246,77,57,10,1,56,55,15,37,133,219,215,204,201,197,239,60,187,109,239,171,174,111,58,176,161,128,211,216,130,242,8,220,60,120,219,156,89,8,253,130,98,111,195,33,223,145,9,144,193,219,55,169,114,167,162,223,244,202,172,33,7,202,94,158,133,164,130,134,88,158,217,55,125,113,50,195,239,154,90,94,166,189,191,248,181,142,185,172,228,122,42,236,28,31,205,66,17,234,132,117,225,21,63,253,155,123,47,108,19,67,113,166,156,52,101,49,40,204,188,221,206,82,36,65,237,41,51,18,82,12,98,47,183,241,93,141,227,142,108,52,21,92,23,153,69,71,96,211,70,183,64,169,138,143,247,76,149,171,100,164,162,33,247,40,79,148,217,48,52,95,112,179,131,110,246,80,50,108,147,212,115,124,31,193,48,120,10,204,184,232,244,62,191,216,1,214,214,32,66,165,210,153,235,245,113,240,60,250,144,91,75,179,50,212,19,179,9,222,247,99,32,212,223,121,236,128,163,202,62,212,169,193,156,102,211,73,36,200,248,162,3,86,233,226,9,49,86,253,116,90,60,121,206,144,82,231,229,166,62,223,59,211,33,146,137,153,234,198,121,17,89,255,104,167,220,176,27,137,74,81,167,81,144,216,124,143,235,171,13,202,131,66,134,63,19,120,206,145,103,167,141,87,102,166,51,109,29,92,174,59,159,247,174,120,67,29,202,7,65,58,185,177,136,177,194,147,185,76,231,254,56,216,171,38,36,111,215,214,101,159,226,205,144,200,132,216,179,26,23,206,232,200,224,142,122,253,195,182,162,136,181,170,52,28,172,218,223,59,253,208,135,32,169,52,164,151,193,135,130,48,209,237,75,41,18,180,46,78,42,10,222,41,131,247,195,94,156,183,113,27,138,21,110,5,126,199,216,182,162,122,142,183,50,185,135,4,116,148,6,13,133,48,145,198,94,83,117,121,212,217,52,247,116,11,27,137,231,78,154,16,119,94,2,201,171,253,200,146,113,138,217,105,30,144,29,246,169,154,191,0,92,203,118,150,141,69,150,94,219,90,153,91,54,76,31,154,153,10,31,82,12,244,27,79,158,1,234,122,179,39,19,104,234,60,21,110,96,14,232,135,204,84,183,189,184,157,55,75,122,51,123,143,13,99,108,20,215,151,206,63,177,27,57,144,166,196,123,112,137,14,169,42,3,194,219,37,78,84,33,175,242,250,138,155,69,90,29,169,19,13,90,207,128,147,30,164,220,113,196,95,24,150,223,99,176,144,172,230,240,212,172,22,58,93,11,18,9,116,173,61,54,201,103,119,106,147,76,95,90,6,255,97,246,19,185,166,245,33,249,26,227,176,33,211,226,236,216,170,89,85,148,224,170,2,193,152,118,142,174,56,165,187,99,90,65,160,97,233,190,137,26,162,204,15,71,209,221,21,190,132,109,57,184,207,240,196,114,231,130,36,113,111,239,177,163,97,45,155,175,103,255,4,202,143,40,234,81,235,118,1,144,40,171,18,161,0,142,124,231,150,20,140,240,86,28,107,139,95,117,251,177,229,148,8,120,125,96,205,136,255,115,255,4,33,133,125,4,11,2,55,163,248,103,25,224,151,186,128,50,51,184,254,151,155,175,176,110,137,89,95,153,215,80,106,255,80,23,97,74,89,4,49,205,79,29,183,210,21,251,126,100,10,243,83,180,227,216,120,43,227,82,102,8,30,54,243,15,158,151,90,181,135,163,186,208,80,18,166,16,61,80,138,25,203,226,36,197,25,236,11,182,135,159,36,16,27,231,54,227,2,184,9,221,254,27,60,147,207,254,44,27,194,95,131,9,208,218,206,120,115,176,161,178,33,165,0,224,202,158,222,254,1,176,43,27,47,134,40,2,103,27,246,121,238,50,123,20,249,44,110,240,45,122,201,26,45,45,165,187,24,146,7,128,122,11,243,128,40,73,7,52,46,19,118,7,29,59,237,20,153,74,38,94,17,177,92,2,239,17,111,46,52,232,245,213,188,135,114,87,154,140,228,93,201,83,19,102,223,35,172,81,21,213,94,44,115,30,81,251,235,51,193,240,75,65,213,105,84,191,192,35,175,213,146,34,41,182,80,208,233,199,104,210,6,152,132,156,94,97,111,158,152,59,52,215,221,251,40,58,115,45,2,106,230,129,59,177,20,66,119,113,79,16,79,106,72,22,120,244,0,49,231,229,102,239,88,144,157,45,170,209,135,106,5,239,182,103,116,203,40,26,213,62,233,246,32,128,88,210,103,182,27,205,126,11,228,10,184,178,40,28,218,172,122,46,15,116,124,246,44,47,124,119,140,102,84,21,157,142,241,119,147,253,156,86,104,119,14,239,162,157,149,116,210,93,235,55,164,139,157,127,216,203,162,246,71,84,250,122,47,251,169,20,124,35,164,80,249,215,202,238,2,138,25,30,189,193,158,42,173,107,79,1,137,117,22,212,231,206,5,160,162,102,247,92,78,196,206,62,30,135,133,83,27,46,229,85,11,149,189,238,8,4,42,176,147,18,212,201,177,177,63,53,242,239,189,74,197,180,32,166,127,54,100,79,238,125,185,24,131,131,58,158,245,195,79,146,179,57,122,143,229,252,119,95,84,210,217,154,141,18,10,193,221,212,168,201,218,79,249,145,13,7,119,227,236,167,159,19,205,192,38,227,193,15,219,149,197,198,197,2,155,245,189,67,81,201,20,239,220,36,102,103,96,207,80,46,208,163,7,71,61,204,53,101,49,117,227,158,126,59,114,204,39,115,85,87,238,227,12,29,28,91,57,25,156,37,31,112,55,196,139,212,234,186,108,134,214,213,148,38,143,48,170,198,186,16,15,22,55,216,18,237,1,147,139,73,50,115,53,189,149,10,11,112,194,228,143,157,216,195,213,216,63,188,84,76,35,168,232,232,36,121,224,238,83,59,37,180,175,231,54,85,126,43,52,82,118,75,68,106,80,218,215,2,70,222,94,54,156,182,157,98,179,201,101,130,210,102,211,36,201,190,56,6,228,107,154,17,179,64,117,161,82,135,83,224,148,65,147,233,232,196,254,117,32,166,179,19,221,179,191,15,168,140,179,136,93,133,60,122,106,44,225,7,162,189,37,153,102,41,114,118,234,148,86,140,231,204,82,39,68,220,202,11,199,209,113,100,69,181,14,213,45,237,83,78,29,97,220,183,96,206,150,107,209,115,116,160,235,76,132,116,33,35,53,34,48,186,106,184,176,154,124,81,222,86,64,214,26,137,145,74,204,125,183,178,119,46,125,85,68,232,73,109,170,255,250,21,13,75,145,134,251,146,224,237,74,174,21,129,92,92,162,217,205,143,162,182,147,34,175,94,60,230,247,252,140,110,20,159,189,25,173,247,13,23,31,113,204,10,70,129,80,175,144,16,92,56,227,76,240,3,160,123,135,229,137,24,5,155,17,195,22,142,39,211,166,108,186,214,48,255,40,208,3,170,6,118,129,67,85,111,187,106,47,92,80,180,211,140,246,153,35,39,248,128,223,126,103,59,110,14,18,80,111,69,117,46,215,133,177,66,170,22,90,229,235,217,215,246,212,131,218,120,170,254,138,166,47,199,90,66,109,42,60,50,245,194,127,122,153,231,24,221,232,98,107,72,216,205,143,221,44,165,99,81,167,33,35,163,84,103,100,161,130,99,17,235,157,242,97,236,69,170,81,124,16,31,240,246,130,11,167,12,235,63,142,48,119,125,31,12,15,191,2,244,146,40,243,78,130,233,41,218,98,56,4,15,67,125,155,183,90,240,227,126,86,218,70,93,72,215,62,154,72,80,144,192,51,50,21,55,21,144,141,158,32,247,197,184,42,133,10,187,41,27,178,191,48,36,126,190,164,45,64,144,182,255,246,93,89,115,115,1,143,255,57,36,232,41,141,170,122,201,130,60,162,214,252,165,174,0,38,167,248,211,229,217,30,135,2,173,189,240,97,86,70,35,4,99,61,123,127,68,51,180,138,191,104,215,248,197,173,211,89,99,120,125,30,57,144,139,10,122,162,225,130,67,119,110,90,170,171,209,139,234,133,252,243,195,81,136,53,23,139,96,30,231,220,8,8,134,230,232,193,85,12,236,247,26,50,14,246,250,237,53,252,179,148,117,207,94,68,106,221,166,140,63,8,142,137,7,138,83,37,206,103,8,219,224,122,64,87,211,33,174,161,150,49,17,151,23,31,78,170,148,230,201,82,105,222,57,224,158,146,133,216,119,85,51,123,136,205,3,30,188,139,206,176,141,100,84,139,69,118,171,90,250,15,167,160,243,53,46,255,108,209,35,15,157,179,159,177,152,90,216,17,20,233,209,12,188,153,167,230,246,34,165,191,49,43,191,122,14,57,205,254,141,133,198,145,110,223,210,51,207,117,55,66,150,142,140,148,190,234,186,226,66,100,52,26,63,199,41,96,42,193,197,245,26,150,16,97,133,48,94,232,234,55,48,133,74,223,46,53,39,89,22,91,231,140,111,183,100,128,2,254,207,111,122,123,188,131,60,37,252,11,136,197,92,98,229,91,37,9,62,238,15,213,216,42,104,212,203,213,94,155,111,162,209,111,246,201,155,62,113,219,4,44,201,209,94,76,227,182,65,132,36,83,131,25,17,117,37,118,62,166,203,186,151,101,232,120,237,226,82,41,101,196,221,71,183,246,89,123,85,19,109,144,4,6,224,175,247,242,246,66,51,83,231,120,161,236,30,222,41,126,193,132,19,122,233,120,26,59,74,213,73,54,99,239,10,164,99,90,219,207,27,59,120,224,147,7,213,83,236,84,169,225,159,14,76,55,206,230,66,23,227,26,167,61,181,193,109,84,216,114,102,177,13,17,78,216,40,118,43,151,137,102,121,106,157,140,115,20,217,242,247,34,229,104,129,56,83,10,220,12,31,128,222,81,88,85,104,128,235,34,22,140,78,110,118,246,189,51,87,89,222,144,42,171,98,112,185,70,240,138,174,175,14,69,189,191,145,190,151,46,230,185,86,56,178,55,116,235,215,194,18,92,95,253,114,182,215,186,109,187,162,159,139,90,30,65,62,187,137,153,11,68,74,106,199,38,85,234,147,100,75,147,17,126,199,96,210,225,48,227,12,232,188,211,28,8,77,116,74,215,45,233,218,213,116,12,188,98,131,76,90,174,86,73,26,111,82,201,103,55,48,108,54,39,74,243,9,163,69,185,170,18,177,252,213,247,106,19,175,254,90,53,57,108,175,138,226,218,189,164,171,124,36,232,66,208,139,55,169,142,69,85,112,111,221,181,201,244,42,80,231,64,255,66,57,81,12,233,216,237,197,129,233,246,248,172,171,115,77,195,72,239,254,113,68,245,67,89,2,132,77,161,62,151,207,116,230,245,151,78,250,98,237,42,221,157,198,37,90,166,62,92,254,40,61,19,133,74,148,35,129,65,62,216,62,132,156,130,104,138,59,144,19,8,229,113,104,141,46,52,16,44,147,134,65,211,107,115,172,23,249,63,101,26,250,97,252,12,245,39,255,231,155,81,168,130,88,201,139,223,41,106,242,78,111,89,130,97,215,130,244,189,205,101,154,165,107,33,25,184,186,252,203,110,253,141,176,22,142,205,170,154,231,133,215,155,153,146,194,164,227,142,209,142,133,14,151,6,212,142,88,188,236,6,130,114,204,254,156,171,237,62,80,58,192,38,254,142,224,133,18,24,112,218,55,204,1,120,101,199,97,119,211,151,5,191,133,16,11,28,156,251,92,18,114,50,160,61,67,2,87,255,241,218,3,65,139,118,171,43,173,61,223,131,57,65,61,209,129,86,220,251,50,192,59,106,212,13,219,136,215,72,132,138,247,43,94,149,5,72,231,244,67,147,85,56,11,43,66,226,251,9,70,195,139,89,33,113,217,176,253,215,13,244,206,237,48,116,85,107,177,225,45,66,48,42,90,120,83,227,151,59,42,35,129,70,2,78,144,149,158,60,173,247,33,64,215,178,231,217,229,77,120,121,14,75,65,226,130,248,102,32,57,121,156,103,159,36,88,141,131,64,113,42,2,238,238,34,1,23,250,234,79,65,60,253,169,93,211,17,3,158,250,97,70,118,153,42,45,238,82,61,204,158,232,152,163,58,200,150,95,29,35,20,242,173,29,254,11,119,54,125,65,28,116,90,101,92,75,193,240,84,147,64,247,86,121,220,84,100,216,14,69,38,85,173,172,74,223,57,67,114,137,143,227,209,31,211,161,205,179,45,135,212,29,12,29,197,61,111,217,158,134,93,8,39,243,42,56,133,235,76,249,76,44,19,102,11,62,183,189,124,245,173,143,135,25,85,215,105,180,148,22,115,92,68,204,38,248,18,220,126,180,131,120,79,93,102,95,203,210,155,110,171,8,68,156,208,146,128,210,134,69,67,181,13,123,213,78,141,185,62,206,8,20,165,20,215,97,182,3,108,204,78,229,39,165,129,152,58,134,244,247,120,191,115,1,24,145,221,253,231,66,180,171,221,212,175,212,83,140,70,90,127,223,94,244,123,208,141,20,103,119,56,21,217,145,73,31,210,12,153,17,176,71,54,43,224,147,71,10,43,18,251,84,226,81,117,71,115,255,252,8,132,202,24,165,135,25,220,73,42,127,225,39,248,54,72,35,232,241,91,166,217,72,51,143,132,18,9,187,179,31,116,133,162,127,246,92,190,255,210,133,65,240,196,15,106,99,130,96,160,212,237,132,132,216,195,40,69,42,250,109,48,87,117,5,90,219,135,217,35,57,153,46,162,192,246,106,98,148,105,204,16,244,43,255,68,185,32,28,246,147,5,71,246,78,143,69,16,13,130,218,202,87,80,16,89,32,228,188,202,242,84,42,104,98,121,7,161,212,124,83,192,83,45,186,184,157,125,70,102,23,73,104,225,177,154,214,9,219,189,40,246,168,118,178,247,106,159,9,178,99,15,21,157,84,245,87,180,44,180,249,220,239,243,215,171,238,142,212,253,9,56,68,200,128,92,224,136,88,191,131,105,39,74,218,219,73,61,216,126,222,62,247,122,3,128,12,67,7,67,42,142,124,247,76,114,64,204,114,92,21,163,57,208,122,66,115,219,162,39,73,133,123,246,140,90,23,37,191,160,82,124,223,214,10,189,128,131,105,99,79,241,186,17,41,44,242,18,184,70,60,37,169,58,197,245,21,114,105,142,108,212,70,1,225,121,84,169,134,140,207,225,210,47,44,151,94,133,71,135,247,175,82,158,210,93,35,137,205,238,129,220,70,180,28,154,24,81,130,32,68,146,128,112,159,196,75,254,166,68,158,78,113,242,188,21,9,127,204,254,32,38,193,190,16,73,50,141,76,0,104,139,227,58,15,192,246,197,186,152,188,189,95,186,118,37,240,127,196,1,242,221,49,222,139,200,143,224,94,107,74,48,167,134,95,120,48,48,50,189,103,253,164,207,198,118,23,13,228,73,229,86,129,199,17,133,189,192,115,21,81,193,53,92,100,237,131,110,106,143,205,120,43,223,155,75,52,7,218,188,152,107,174,134,28,64,230,77,221,227,76,43,32,241,16,165,31,155,62,42,34,103,170,216,194,21,6,27,201,94,216,232,124,236,94,184,117,22,111,161,151,139,133,192,111,102,187,216,153,145,64,161,216,181,67,51,179,214,25,46,220,198,90,1,228,97,192,191,243,144,3,77,107,209,89,235,206,235,48,136,62,8,165,216,151,105,27,62,54,19,19,250,67,27,13,158,67,147,154,133,60,138,76,60,68,203,26,119,172,68,227,182,149,12,251,125,59,99,34,25,102,28,242,62,19,123,162,218,151,46,106,199,181,155,225,77,82,41,72,221,108,95,138,21,112,134,39,225,185,116,139,20,238,218,149,119,32,5,153,187,176,116,159,137,218,179,226,133,92,104,125,7,231,35,23,139,227,26,243,121,232,187,10,155,170,153,141,97,247,213,77,38,78,44,174,136,88,133,25,49,37,88,77,182,109,61,105,201,146,18,66,191,223,155,90,66,245,114,49,203,238,67,58,198,233,102,250,118,85,149,72,248,196,45,195,69,32,62,101,78,62,56,28,0,24,93,196,177,188,47,122,23,112,218,72,110,153,176,100,70,241,111,151,65,91,38,208,182,243,133,186,137,14,250,216,114,101,175,166,112,50,181,196,114,74,99,88,121,90,139,120,109,205,223,96,98,5,254,36,208,156,147,235,191,126,62,21,88,35,212,119,17,128,53,79,203,188,0,64,70,155,226,107,171,6,0,227,253,165,220,87,229,112,19,175,32,32,102,206,165,23,144,153,0,209,237,21,161,116,174,48,106,147,20,251,252,189,201,170,48,158,109,103,193,182,135,94,10,176,132,152,168,138,59,185,137,242,56,139,26,118,29,146,209,77,57,145,146,193,118,63,120,211,31,41,162,80,164,34,174,243,183,163,154,159,1,92,237,77,172,98,237,250,41,126,23,225,94,64,91,42,182,176,191,146,118,185,30,136,64,79,121,41,95,129,222,29,197,202,66,195,138,21,65,183,248,22,14,236,237,95,22,120,159,208,33,124,17,104,61,68,56,24,226,228,246,99,17,246,217,253,145,18,208,70,167,68,223,90,201,215,85,27,54,191,204,170,110,177,58,0,34,182,157,158,130,150,35,92,163,31,96,210,221,25,12,38,84,63,125,66,15,172,154,106,79,233,68,232,161,133,40,231,124,192,107,32,157,0,89,163,44,79,74,63,115,34,16,239,20,50,239,99,240,32,223,12,24,119,16,155,113,216,68,192,152,42,125,161,175,49,86,72,249,35,234,135,233,251,146,77,40,199,73,44,125,102,114,237,217,85,93,242,215,145,236,241,42,43,53,128,9,181,29,129,156,174,10,70,155,41,150,90,113,172,135,108,36,62,235,247,241,205,56,132,169,211,133,55,142,202,238,199,85,159,245,131,188,115,187,18,22,201,140,44,225,208,168,158,115,235,130,109,162,142,139,55,51,222,196,119,103,2,176,187,86,246,78,9,36,177,77,37,47,69,133,48,183,242,116,28,136,250,202,110,233,29,111,120,237,48,244,80,166,5,82,224,78,201,36,225,111,23,17,34,32,191,21,72,237,137,113,214,42,140,210,24,81,23,209,192,106,83,109,143,23,221,205,213,90,91,129,36,7,203,3,81,191,99,73,99,85,135,151,82,229,128,35,17,61,2,151,161,28,251,100,222,217,168,186,120,179,227,164,63,129,128,102,39,122,63,125,7,28,205,0,154,112,180,215,208,178,198,170,191,155,65,20,240,232,187,72,244,70,0,109,58,132,48,18,78,252,149,109,236,191,30,81,200,194,227,112,163,252,99,22,111,56,49,22,233,229,185,159,208,23,199,213,89,154,189,229,217,49,233,107,79,147,216,60,90,18,11,237,81,226,115,51,10,60,96,200,99,83,223,17,95,35,255,183,236,50,75,240,247,64,109,223,57,115,36,48,89,151,137,176,176,240,46,239,52,31,66,129,243,66,13,199,115,154,136,98,246,158,90,36,41,189,157,35,238,242,150,169,202,240,242,231,168,231,42,99,27,132,138,204,135,19,157,57,97,171,199,182,109,179,201,143,238,137,9,1,128,83,236,111,149,149,108,82,29,29,196,111,30,93,209,140,223,80,125,146,79,10,93,227,33,196,73,234,226,159,103,233,141,217,251,254,92,237,125,187,69,53,31,107,145,183,123,225,4,160,46,157,250,50,158,160,253,152,255,254,129,30,130,190,71,162,67,162,106,189,227,163,243,17,254,78,48,39,64,174,89,76,184,211,245,213,245,138,123,47,187,220,131,59,189,242,221,212,110,221,63,178,255,129,229,245,30,23,165,155,77,36,152,244,16,48,190,189,42,207,40,145,164,47,96,12,198,202,73,250,88,213,247,244,3,15,44,201,225,102,25,182,119,216,165,190,190,112,4,198,124,105,10,198,112,25,63,56,127,228,15,133,107,33,251,125,48,129,234,117,226,172,251,151,249,49,167,82,243,0,128,64,200,31,8,181,167,142,90,93,87,133,156,133,135,246,193,52,80,227,85,84,180,238,34,213,66,172,5,24,126,165,231,108,250,114,222,52,33,218,101,207,62,215,0,139,227,160,59,10,242,2,68,160,180,157,212,101,179,101,112,107,215,96,10,254,172,2,198,104,178,90,31,115,141,231,203,71,255,226,80,162,174,242,238,38,3,145,38,253,236,125,49,184,26,91,97,91,241,106,23,77,69,128,97,71,166,41,166,218,182,61,186,187,137,191,8,202,6,92,134,241,39,42,103,75,17,122,137,124,15,228,148,109,215,231,17,6,39,188,26,234,117,125,104,37,79,126,181,97,178,199,230,228,193,147,233,186,12,110,115,20,40,64,128,193,42,93,137,20,35,231,9,66,86,208,210,137,178,39,157,117,188,26,118,72,252,24,219,43,127,203,134,42,168,103,158,83,233,239,80,54,71,100,76,149,17,200,230,239,203,233,246,37,155,99,142,24,249,230,80,155,207,129,234,188,51,146,137,113,236,99,0,67,230,18,141,213,57,111,54,131,34,127,46,101,148,42,54,172,121,237,156,84,215,39,188,26,28,122,160,104,101,164,46,110,13,153,59,230,226,243,213,242,226,214,234,226,4,229,143,84,83,42,162,187,131,191,220,179,222,108,44,3,36,228,187,189,147,94,227,31,110,38,207,176,4,146,161,100,96,101,238,8,199,15,5,134,126,114,115,176,168,235,147,27,138,69,248,158,148,72,120,113,131,19,182,18,161,151,9,159,113,175,242,81,229,139,179,127,54,55,36,147,237,164,150,182,43,113,48,252,140,142,166,169,129,118,110,76,189,62,5,192,253,215,50,101,142,40,112,155,223,211,99,239,233,228,230,60,86,120,224,66,232,121,164,8,213,147,225,66,244,85,61,17,20,32,30,26,98,86,141,243,152,162,69,192,166,106,162,17,231,57,82,237,215,87,7,8,33,21,44,4,192,30,68,173,166,208,197,94,52,108,27,195,70,2,235,251,54,170,247,222,90,128,120,98,23,1,2,75,169,174,182,156,243,68,4,167,62,158,3,169,87,51,137,138,121,126,20,230,148,209,136,67,65,248,170,148,115,165,8,28,219,158,183,33,106,76,38,39,193,193,160,216,43,238,148,187,227,147,170,35,7,8,192,248,228,121,70,21,132,133,94,229,12,9,223,32,154,0,242,93,196,16,142,77,68,67,87,85,225,237,79,240,162,232,46,53,98,62,180,172,172,200,95,19,204,192,109,123,223,122,135,158,109,181,166,204,234,6,81,133,183,75,81,58,221,245,59,161,246,82,252,85,38,28,63,241,244,246,170,255,122,105,9,190,247,215,150,250,207,38,53,187,82,82,152,213,193,246,49,170,31,185,215,84,194,159,170,214,97,17,132,33,161,160,9,80,132,15,83,39,164,43,163,121,125,147,157,207,27,91,73,49,153,108,201,103,218,72,24,66,217,59,60,83,81,111,110,14,12,156,10,228,252,229,127,224,60,242,236,177,171,48,34,134,26,62,100,38,122,23,118,162,46,2,161,216,58,112,85,120,227,24,224,107,37,79,247,202,182,219,149,74,60,122,49,158,65,224,36,31,223,46,38,193,4,137,55,208,14,6,18,122,119,238,171,21,103,42,45,90,48,85,236,121,58,209,201,114,37,43,7,105,31,37,146,52,46,119,255,197,242,216,179,168,212,249,86,126,168,201,45,115,166,118,71,60,243,60,2,253,185,93,144,57,129,72,46,220,187,202,57,48,49,78,242,45,78,20,82,84,253,161,172,75,136,19,144,145,180,236,180,63,44,4,76,176,251,48,139,140,24,103,93,86,155,115,236,85,36,183,98,199,142,107,222,121,31,28,58,171,123,7,39,32,64,107,86,231,155,189,2,134,167,240,17,213,56,10,200,79,140,107,40,119,64,0,57,122,136,134,123,48,162,107,80,214,107,81,203,42,154,0,178,4,95,121,127,25,99,4,63,77,110,135,114,46,59,11,120,216,2,37,92,239,168,28,50,44,235,56,215,215,23,173,133,147,167,220,68,246,133,166,133,117,48,48,112,121,125,70,64,184,191,209,208,16,149,224,154,229,169,190,134,219,184,39,61,153,33,216,202,220,44,238,215,221,177,7,104,72,93,78,143,110,182,67,130,235,160,2,235,212,29,42,28,137,65,161,37,220,200,196,160,75,233,199,129,85,186,86,10,144,169,33,90,64,11,79,250,20,142,18,110,158,33,7,242,234,177,16,188,141,100,4,176,53,72,81,86,93,53,124,243,212,4,182,184,68,33,33,84,47,143,139,60,201,65,194,141,145,83,28,66,155,25,129,199,254,32,101,13,240,113,66,45,64,231,174,82,59,91,208,66,4,48,71,57,141,130,8,199,210,33,160,250,41,214,220,8,10,177,159,80,144,28,16,124,49,1,150,200,237,12,246,197,178,64,222,123,225,169,68,243,16,48,187,154,37,201,71,227,231,187,150,108,44,232,17,106,221,8,218,40,148,94,200,213,216,66,145,241,129,239,185,101,11,41,212,67,144,60,89,163,98,65,127,196,147,156,233,77,43,141,206,109,135,145,62,62,237,148,48,161,210,233,13,138,125,171,50,213,105,109,207,181,203,97,206,194,12,96,39,115,153,151,132,226,229,222,235,230,80,110,54,227,60,87,185,13,88,126,210,170,5,248,252,172,66,118,228,193,211,106,246,154,51,149,33,217,155,247,41,178,43,99,240,49,126,89,13,111,82,129,25,73,17,248,115,60,197,46,98,108,62,33,23,240,248,155,123,205,39,165,82,186,14,162,105,225,118,20,7,130,24,90,11,208,218,168,95,193,97,217,72,193,20,148,250,50,216,115,32,13,53,97,170,205,225,192,216,37,103,80,51,81,66,113,114,34,163,115,17,155,84,121,91,166,10,137,237,166,95,177,188,210,83,81,99,145,26,134,184,45,44,124,153,238,74,103,220,200,190,102,80,172,232,13,129,28,176,203,109,216,57,194,90,146,32,109,166,169,88,239,171,142,117,175,209,126,129,214,214,249,70,42,196,53,25,12,231,120,132,129,232,166,245,196,250,58,75,200,247,98,47,61,31,27,169,168,64,109,123,90,220,69,105,47,30,161,119,248,65,244,90,47,60,73,76,80,82,47,135,41,207,116,122,182,72,84,4,80,124,189,3,49,252,122,103,246,211,254,225,164,249,53,145,11,98,21,82,10,125,48,139,107,81,143,10,221,255,144,252,103,130,141,191,18,179,19,249,2,11,68,187,231,76,150,130,100,208,131,250,19,66,127,213,230,192,157,23,187,129,202,214,45,157,36,4,125,78,214,212,158,245,112,244,162,17,83,187,72,149,227,93,36,232,135,205,4,27,176,213,217,183,142,182,91,87,132,240,140,194,227,59,170,167,245,90,162,49,104,230,17,222,206,208,106,10,219,75,203,137,105,231,246,190,95,203,115,236,110,217,130,67,113,26,195,79,24,216,74,173,133,213,145,96,28,50,102,228,109,58,47,162,233,197,32,139,223,144,102,232,101,48,232,188,236,139,45,60,221,61,139,211,61,111,105,49,145,225,187,119,239,178,119,198,133,12,151,26,68,162,230,220,146,233,134,125,133,75,132,9,38,55,2,65,158,81,128,191,183,213,108,227,199,61,19,211,114,219,97,253,46,152,70,52,215,211,140,13,121,102,202,170,98,191,88,48,91,72,151,76,250,70,207,12,98,109,148,142,246,214,33,142,104,62,19,251,47,217,58,103,19,113,167,204,65,58,161,193,66,28,104,11,34,175,15,213,216,126,252,179,223,75,70,20,251,7,31,10,80,59,182,69,201,130,17,2,181,137,170,153,197,151,146,83,162,227,204,99,8,223,89,182,231,62,211,146,100,57,193,83,2,194,116,217,238,1,107,30,66,232,142,11,2,204,237,222,135,171,9,97,10,38,28,249,23,100,13,133,26,184,215,214,148,122,186,235,32,126,6,55,139,235,158,135,17,74,102,81,42,235,192,217,81,104,249,136,183,228,231,98,57,126,141,148,22,99,200,35,84,116,236,39,209,31,200,86,70,200,43,132,195,68,50,154,211,223,210,87,40,220,115,41,222,135,133,44,122,198,26,233,166,232,144,98,196,49,155,138,125,192,82,189,137,67,176,225,212,133,19,1,105,227,29,163,176,208,109,47,228,27,78,210,150,71,248,58,92,121,122,14,133,220,149,122,110,156,132,134,79,250,180,172,175,14,12,214,188,99,52,174,194,80,128,172,79,101,18,73,173,21,19,86,192,154,162,27,198,37,157,218,74,186,144,54,211,59,7,101,21,57,42,85,51,159,250,255,167,12,217,170,91,117,59,60,141,79,117,216,202,125,182,69,52,211,118,20,238,209,101,138,246,101,102,246,85,80,218,151,147,21,40,216,157,167,86,181,24,39,10,240,167,100,254,89,94,205,116,109,34,250,184,27,157,89,69,236,1,45,204,224,125,81,238,145,50,148,12,2,251,131,194,90,187,94,48,161,209,190,211,64,181,225,236,13,104,234,12,102,55,166,40,82,107,68,182,215,131,67,112,149,138,76,219,54,219,52,18,83,32,234,118,158,231,127,49,166,63,187,107,78,212,204,229,232,141,253,122,69,102,57,77,174,245,223,208,29,250,150,240,208,136,240,230,128,60,254,246,195,175,111,127,191,247,186,131,77,9,208,215,254,120,1,77,23,198,48,250,248,29,215,93,121,78,162,135,27,160,45,128,1,147,219,185,53,155,96,75,76,7,73,106,116,199,174,150,252,224,65,122,244,129,101,59,151,195,3,92,31,193,169,156,17,187,41,157,172,225,228,92,21,24,116,167,202,202,248,17,253,27,226,106,195,169,154,1,10,193,34,66,250,126,74,51,84,248,212,229,205,20,181,64,161,242,205,187,118,208,23,44,34,49,160,93,181,82,166,177,69,201,126,103,171,203,222,221,199,175,149,173,25,34,150,17,252,241,23,63,217,35,100,85,60,21,109,254,152,205,62,102,224,58,212,176,171,134,69,24,44,58,233,172,208,231,251,27,153,11,52,47,88,216,204,128,208,31,152,62,192,151,212,60,122,222,135,47,150,228,216,66,77,142,188,102,202,147,4,104,137,47,237,196,180,52,20,63,35,187,226,147,124,212,31,117,181,118,230,237,185,109,48,31,217,153,197,143,24,158,165,122,74,165,241,182,147,192,74,87,174,158,219,198,35,153,132,110,132,56,221,237,204,41,114,41,62,86,74,122,45,161,122,150,116,249,34,48,194,216,42,111,211,155,78,5,250,76,66,61,142,66,67,163,59,151,50,247,183,2,144,150,231,204,136,208,92,63,248,247,78,47,231,86,56,213,73,74,42,41,247,105,47,196,161,132,198,150,174,139,49,78,135,144,158,244,6,0,45,235,41,212,135,96,143,110,40,187,243,87,209,232,219,123,148,158,221,233,133,34,183,206,234,160,11,64,0,137,214,208,153,120,168,61,49,47,51,142,130,215,228,78,20,135,77,189,93,94,14,226,126,28,194,135,139,89,191,190,124,76,24,190,147,243,120,216,95,120,22,12,125,160,24,49,154,119,106,187,24,226,41,39,240,227,10,95,5,79,78,174,80,97,191,165,99,6,25,122,239,176,3,86,195,197,51,124,73,218,13,204,53,23,66,121,233,74,223,120,35,11,155,206,181,106,242,113,125,84,88,18,6,228,94,177,180,206,65,31,20,84,61,37,17,139,227,112,246,114,185,210,148,16,41,242,218,168,18,165,199,109,209,189,178,88,31,145,49,43,59,54,34,20,243,215,31,192,245,232,82,210,18,28,184,216,220,131,246,225,201,151,120,51,88,124,207,217,115,190,202,27,117,231,98,76,173,197,243,120,242,91,157,152,106,136,170,72,203,179,37,172,217,21,246,217,124,1,94,79,19,58,17,128,145,239,242,21,148,146,172,56,73,6,113,87,38,54,205,34,30,136,139,93,200,64,72,133,175,43,64,24,11,194,41,127,160,121,116,230,111,224,93,189,185,190,194,21,134,208,17,198,20,151,152,167,221,54,129,250,82,111,92,114,247,46,184,46,41,157,180,28,251,211,238,89,130,87,96,232,3,51,184,158,113,222,3,222,89,177,80,51,253,40,127,233,3,18,31,127,13,170,30,125,181,21,144,244,109,26,251,248,250,138,210,130,91,47,52,50,107,108,30,250,158,207,196,217,95,70,167,176,177,138,192,228,85,230,5,196,139,226,52,179,125,230,149,201,19,46,211,6,206,175,4,231,42,65,178,148,251,143,181,192,49,77,3,185,117,201,223,63,219,243,212,214,63,154,151,126,203,25,137,12,131,212,113,118,158,91,38,4,212,246,56,112,33,18,165,16,250,241,219,40,118,35,179,48,160,213,226,112,239,73,71,225,189,60,75,53,99,23,198,82,154,100,114,118,181,107,160,9,122,185,95,162,190,7,238,75,219,53,55,236,123,219,143,45,64,130,119,246,96,30,203,177,179,113,125,51,123,236,103,158,111,197,205,177,54,183,72,193,233,245,149,90,250,88,164,121,59,19,246,21,150,111,49,155,123,247,2,60,33,76,60,43,136,165,7,255,120,2,76,243,254,110,46,156,209,253,44,59,124,87,248,174,198,203,186,196,202,197,57,148,207,158,197,120,23,161,4,0,120,144,75,204,72,238,127,83,222,11,161,28,169,208,232,76,187,69,233,201,222,221,236,29,174,242,224,146,234,189,69,195,191,176,41,3,54,99,96,253,64,16,198,224,221,107,206,181,234,81,96,123,81,231,149,88,34,216,188,245,87,106,224,88,244,216,237,64,44,32,30,0,146,245,165,232,23,163,77,193,153,122,103,32,43,26,56,9,94,59,176,247,133,96,207,196,85,163,102,233,53,169,98,150,38,124,223,198,67,227,116,228,46,72,196,131,181,112,209,61,180,169,103,4,195,68,188,99,243,33,34,237,245,163,101,1,73,254,214,45,31,26,114,122,42,196,158,149,149,25,246,54,22,148,144,39,161,48,7,240,168,244,241,83,50,134,12,40,180,138,151,252,157,57,15,244,177,18,122,27,210,114,183,57,201,123,92,235,25,89,252,211,211,175,174,98,59,251,240,248,235,231,183,255,247,103,176,187,95,51,11,145,137,60,201,205,183,205,45,188,107,192,34,250,3,171,36,71,181,194,74,112,153,42,192,203,222,163,170,198,242,217,182,110,125,152,98,143,182,194,187,226,80,98,211,125,121,71,87,79,161,247,199,185,181,115,27,158,50,115,130,203,94,108,215,163,146,120,36,22,109,47,96,171,208,172,139,215,171,87,27,117,31,147,52,4,125,19,169,214,210,229,118,8,132,75,29,214,197,105,67,163,159,140,217,26,128,112,177,238,3,102,205,132,6,254,225,10,6,172,111,148,23,26,0,100,88,149,188,150,80,78,210,79,65,62,255,230,92,222,32,220,153,219,192,99,198,72,154,1,22,171,234,168,253,198,151,147,20,33,245,134,0,112,157,87,238,53,4,128,13,117,56,196,78,130,230,186,66,52,127,72,224,149,131,182,89,179,80,207,10,148,51,73,193,220,137,215,220,149,14,152,105,96,81,185,95,179,215,252,215,105,131,170,20,232,45,125,200,48,8,234,33,57,125,89,94,96,110,255,210,182,66,178,13,53,186,66,27,116,71,31,159,169,148,99,183,28,147,120,155,162,94,161,188,83,138,149,212,47,188,214,57,158,71,24,93,37,183,152,43,60,84,219,18,248,255,37,215,83,143,42,237,26,32,163,68,140,157,53,213,114,233,133,230,212,105,107,157,230,122,228,186,100,65,3,164,22,74,133,11,50,138,194,44,4,3,96,9,1,94,71,150,45,203,173,121,77,15,179,159,36,53,196,149,234,125,147,68,130,19,124,83,148,233,12,172,146,154,87,114,189,157,196,102,73,211,240,78,75,205,203,151,162,54,217,70,243,103,171,98,0,94,96,72,30,185,139,204,175,78,40,45,175,80,109,161,79,236,134,91,142,50,16,250,54,99,121,55,222,148,193,166,75,89,43,23,203,167,145,204,252,80,161,254,187,144,32,59,255,119,58,167,179,173,221,253,40,79,13,64,219,198,203,60,220,143,195,230,181,147,65,228,78,178,151,89,227,202,101,93,226,46,138,128,177,4,237,126,240,148,238,254,36,125,82,135,170,251,75,211,194,136,169,40,105,16,241,45,124,196,203,191,86,72,31,139,11,52,122,93,76,93,149,158,68,59,73,125,57,65,200,103,99,35,205,189,251,92,78,36,243,148,46,157,177,233,152,204,61,77,1,12,127,36,2,216,92,62,12,78,186,73,187,147,147,127,28,201,51,40,78,81,10,251,199,9,166,50,140,133,236,246,29,171,109,55,55,80,16,214,101,244,57,4,11,212,2,114,252,224,125,233,177,132,70,10,185,11,222,51,49,20,60,199,23,124,4,215,154,74,243,91,38,156,169,146,119,217,201,8,203,137,156,153,148,27,200,25,242,26,179,197,235,217,147,63,94,53,198,4,229,102,212,244,134,122,228,69,158,22,118,4,166,251,42,2,28,123,215,186,26,5,183,145,126,65,1,251,64,145,36,73,225,127,51,23,244,247,111,164,130,34,51,197,71,17,184,52,79,87,49,123,63,20,181,4,146,202,251,240,211,145,188,77,180,141,31,218,9,177,197,217,13,89,139,107,200,103,120,77,11,171,169,11,229,87,74,59,121,128,47,62,141,44,211,101,41,135,103,122,114,4,2,251,78,180,188,131,145,199,237,174,160,190,45,122,167,170,193,38,202,134,222,103,65,154,223,123,186,2,186,189,8,229,137,26,97,149,0,73,230,22,208,15,198,132,80,18,60,163,152,70,234,125,73,116,179,251,58,127,59,174,139,94,197,115,34,21,9,41,234,145,161,161,15,28,95,195,111,99,178,165,43,167,44,170,68,90,164,68,249,120,55,69,64,8,38,55,241,136,122,212,202,86,16,242,99,250,238,46,188,17,123,203,208,96,66,126,74,175,112,231,93,208,211,57,198,122,58,25,95,186,83,239,68,65,242,145,215,31,204,21,24,216,172,78,219,28,177,57,130,225,177,31,28,48,63,233,142,222,5,191,85,60,9,104,159,73,242,139,193,45,101,37,237,143,31,170,162,41,238,168,18,37,64,159,186,148,144,240,7,27,176,195,179,250,184,225,149,211,67,76,224,167,250,124,175,237,83,109,96,37,11,67,249,237,74,17,191,171,72,92,206,33,10,66,137,48,233,133,136,152,33,234,199,184,147,39,45,8,34,247,91,249,157,118,7,83,18,239,74,181,13,151,124,202,161,198,34,182,10,174,113,73,146,18,135,161,31,249,166,191,99,95,15,110,195,184,21,216,152,85,171,231,155,3,138,220,145,193,163,3,113,99,67,83,212,216,170,188,1,29,95,154,13,2,31,187,73,217,242,117,171,138,143,58,29,20,226,117,23,170,123,22,225,230,216,124,34,103,85,231,135,208,229,13,68,14,205,91,63,78,233,184,236,101,115,76,117,192,252,238,157,210,167,91,175,154,192,60,92,62,80,53,153,226,137,227,33,125,16,66,100,248,54,192,215,16,151,68,60,154,52,167,230,95,160,19,225,39,155,87,136,5,151,161,102,202,89,93,168,96,80,4,206,187,183,96,179,245,206,137,177,48,189,150,163,200,199,236,217,65,104,196,49,60,37,43,217,113,130,155,170,219,11,72,32,113,177,148,216,236,89,147,132,41,111,214,172,194,188,40,20,120,81,28,205,74,242,6,37,211,170,202,190,28,178,163,136,175,95,59,185,149,153,60,196,71,169,81,144,128,219,236,28,44,170,47,2,54,1,207,96,66,193,68,181,173,100,91,138,161,193,25,69,176,32,107,106,120,90,183,140,132,203,221,123,103,45,182,141,247,44,169,239,246,219,246,214,91,121,208,50,195,226,159,36,109,202,39,136,183,157,102,188,88,145,204,46,227,220,47,216,212,10,183,217,212,78,251,53,117,85,73,133,173,134,210,251,56,123,254,122,225,180,192,248,244,164,22,37,156,24,241,89,214,59,173,195,161,78,9,227,151,88,138,232,116,225,240,119,118,73,176,195,79,160,155,211,1,39,241,60,130,125,167,205,114,57,28,142,85,15,92,104,85,15,73,30,161,199,218,243,38,17,93,239,249,145,76,201,122,225,119,32,137,173,1,50,109,238,29,51,234,167,52,108,47,239,3,37,161,121,60,65,32,67,40,160,65,24,156,202,182,117,13,112,227,17,51,250,118,246,229,91,61,153,41,207,147,90,4,124,8,182,146,176,156,42,23,37,4,82,187,193,178,179,17,81,167,95,151,200,24,149,148,221,39,119,193,114,117,134,166,249,80,123,201,179,184,234,160,81,13,46,35,186,47,19,222,227,216,129,202,244,11,242,129,1,188,97,173,27,219,229,218,78,135,116,84,134,254,117,149,173,83,209,79,234,245,105,121,43,53,19,201,114,247,151,147,132,249,211,232,207,51,172,43,162,209,162,215,183,65,99,153,175,233,214,37,208,191,58,87,140,42,31,220,206,131,7,146,218,15,206,104,5,107,229,53,122,240,153,121,19,147,71,81,235,32,177,216,82,65,195,113,6,82,120,107,155,245,81,202,130,234,8,155,110,22,168,181,217,84,250,239,227,194,5,170,93,214,73,224,96,245,170,18,187,56,222,67,135,88,168,92,151,52,73,146,21,113,60,210,213,119,196,92,168,93,177,128,214,162,37,59,131,42,24,82,200,170,50,80,143,24,200,130,56,179,48,171,161,13,34,140,237,203,24,188,219,255,70,93,241,239,54,134,194,171,30,180,174,50,11,152,187,150,159,158,222,255,253,233,183,79,188,183,95,222,189,253,238,45,125,100,126,38,33,201,217,47,187,18,185,95,247,0,245,22,224,100,234,131,133,190,135,118,93,145,97,183,89,209,222,59,30,15,139,12,36,98,129,95,216,189,80,253,186,216,197,153,45,3,209,0,22,42,125,127,149,171,35,76,170,119,169,199,184,202,48,224,238,139,149,133,78,67,139,54,233,233,85,172,217,186,76,173,5,118,234,207,248,163,141,110,159,72,21,197,95,229,40,137,183,59,2,85,10,100,32,40,74,236,163,205,38,153,22,50,247,14,4,28,115,78,106,175,204,192,159,11,164,73,136,78,54,218,22,144,4,76,11,91,123,203,218,236,247,89,188,249,135,215,116,102,93,49,145,14,60,86,205,98,172,224,114,216,47,235,253,200,217,103,163,193,38,120,155,58,178,238,240,44,242,31,84,205,159,71,117,16,43,163,133,28,34,121,180,55,87,235,113,237,7,123,240,51,58,23,125,37,246,210,206,203,240,71,100,1,182,157,241,0,147,158,155,205,204,37,241,51,209,202,229,92,6,74,169,240,142,101,27,176,52,231,158,121,7,203,66,249,4,236,196,110,170,250,157,114,215,132,180,177,136,185,133,86,51,53,169,36,165,0,225,188,132,143,100,6,202,150,255,25,149,226,158,179,103,165,205,77,183,111,255,124,3,201,221,147,20,62,54,240,237,221,240,121,189,56,175,241,123,19,162,106,147,30,153,149,88,105,12,56,54,70,91,253,94,132,124,70,165,58,191,75,52,109,202,138,113,103,127,106,1,153,20,57,236,164,150,130,240,136,238,169,172,24,21,56,245,116,226,188,255,168,23,101,203,125,95,230,255,68,239,95,95,26,56,109,113,206,238,13,195,122,249,156,196,70,200,59,2,194,36,245,117,243,206,194,235,112,112,112,223,159,86,29,179,164,66,74,30,135,36,112,28,20,206,33,23,31,145,226,36,187,43,170,223,204,189,112,187,203,208,145,44,8,12,94,200,254,173,44,20,30,208,181,200,21,205,14,204,66,87,123,194,237,216,201,233,179,122,18,57,164,122,15,0,211,128,118,132,135,94,158,39,201,180,241,172,234,191,76,30,40,119,196,181,244,79,84,52,5,116,236,168,117,175,161,194,80,132,14,185,102,105,238,216,171,77,188,13,131,122,86,127,142,124,150,77,16,156,230,118,52,106,179,23,255,239,35,165,18,221,206,165,158,225,139,155,155,194,121,5,12,206,188,22,220,128,114,137,124,5,101,85,96,31,43,129,188,36,46,34,196,179,118,184,246,20,14,106,179,82,91,66,151,113,169,83,219,130,241,173,194,59,255,90,81,221,43,235,160,103,126,201,51,217,133,80,110,145,200,224,109,24,12,42,54,87,161,202,169,134,235,68,128,200,242,177,147,70,33,241,248,36,34,147,14,149,255,2,145,199,205,166,174,86,52,19,158,79,1,88,106,245,108,203,141,250,26,58,31,86,81,127,113,181,180,193,18,33,78,45,14,229,98,38,65,171,173,150,69,6,119,127,160,243,20,154,127,114,191,247,234,6,231,143,141,161,177,153,121,172,109,117,148,127,241,63,132,90,2,127,233,218,84,182,222,34,92,62,185,130,136,171,239,120,217,52,131,121,123,149,153,175,236,177,103,121,131,61,189,93,32,162,231,236,114,177,47,79,100,210,212,135,226,134,26,208,241,237,111,91,225,63,153,61,92,227,132,148,67,246,244,243,152,186,144,123,66,71,165,26,0,12,68,69,74,253,45,152,83,101,7,30,10,223,217,77,135,0,178,184,214,0,41,67,14,232,181,27,83,144,228,161,76,64,66,169,13,170,78,55,8,205,205,169,186,49,199,252,249,118,54,255,72,161,172,115,120,68,222,7,42,66,63,86,30,116,35,230,163,20,42,105,157,101,130,134,182,165,225,89,196,48,233,129,194,43,92,168,151,61,227,96,122,173,108,240,231,73,52,239,177,97,151,96,71,185,83,239,160,117,233,145,247,149,69,44,72,153,44,174,5,15,90,30,113,97,52,103,46,152,91,111,146,168,7,151,17,146,6,128,250,45,178,21,141,72,106,47,168,33,41,0,253,216,28,222,34,129,93,117,184,213,218,4,46,0,80,140,81,169,243,148,222,144,15,57,220,122,91,131,154,124,239,201,104,107,183,91,212,191,224,255,31,208,121,61,210,140,167,202,165,118,209,248,232,225,58,9,61,20,156,114,61,13,107,181,39,252,70,52,96,90,140,198,39,19,70,219,233,83,174,177,36,77,29,187,197,222,161,206,254,132,114,100,18,170,49,101,120,70,85,141,249,58,165,165,242,97,135,167,183,173,139,94,27,166,202,8,226,190,212,76,107,50,86,137,238,226,74,85,202,21,37,201,133,223,18,176,239,149,62,60,130,223,188,179,174,68,44,53,147,34,176,63,59,241,238,52,122,10,74,23,217,12,161,109,11,18,192,157,116,30,90,39,13,60,55,165,44,143,52,172,153,135,40,88,143,218,32,63,132,204,142,164,11,162,143,206,188,143,238,121,63,210,237,97,166,58,17,162,165,200,40,253,78,158,31,6,26,109,36,197,27,116,230,31,6,62,103,180,240,10,30,2,148,3,90,11,126,47,72,131,10,173,232,132,121,47,39,86,40,87,22,248,152,231,219,208,25,251,17,120,143,104,198,3,108,69,20,109,8,4,17,67,174,128,179,140,227,111,41,248,158,138,132,9,84,31,83,83,210,5,138,75,236,182,147,133,151,255,157,248,16,35,91,95,122,22,5,41,202,73,117,159,46,34,114,19,206,216,160,86,41,31,158,71,123,138,69,208,109,192,8,38,217,85,88,15,56,52,101,34,9,37,97,133,46,97,71,228,226,237,202,57,10,55,116,127,38,199,238,145,30,217,2,64,242,180,113,137,166,190,37,82,111,67,216,12,88,184,88,8,18,67,201,252,53,186,112,236,239,14,173,174,133,3,66,137,1,218,97,26,74,51,87,29,126,153,118,184,165,225,140,78,110,236,146,124,112,211,233,67,167,6,86,51,81,116,9,230,93,250,112,76,211,60,227,152,122,124,243,202,99,193,110,106,230,1,123,131,108,147,39,172,190,106,79,150,255,5,213,69,40,112,71,218,235,105,108,13,136,134,192,179,60,240,148,168,200,89,200,193,133,175,98,7,139,13,71,213,143,91,197,22,162,117,194,105,94,158,167,200,214,128,160,62,100,122,198,160,43,241,221,83,173,240,42,71,170,222,166,195,184,66,99,187,97,107,92,86,197,124,73,46,131,242,101,54,255,46,54,212,105,87,10,17,114,122,74,169,255,140,140,203,42,124,119,144,73,64,18,36,79,64,49,26,115,90,233,94,188,21,234,198,69,23,82,217,230,34,80,26,227,164,20,31,253,0,76,196,248,164,146,178,218,84,142,10,69,42,132,84,91,177,254,231,240,50,178,254,166,195,216,146,216,91,97,41,238,227,45,62,204,95,15,121,109,135,247,107,191,244,25,223,21,190,155,155,247,62,119,121,210,197,236,83,85,127,173,142,253,195,55,66,104,119,168,210,250,254,34,223,8,14,109,139,146,162,67,27,129,222,149,144,182,159,47,243,94,201,242,150,102,47,197,252,64,26,65,214,189,220,164,234,242,93,74,114,172,219,56,76,237,63,65,147,216,164,52,52,101,199,183,66,225,115,182,139,93,230,63,64,156,225,191,64,213,16,181,83,100,95,209,162,181,131,7,191,78,79,193,104,19,169,253,212,230,52,18,193,28,245,6,29,66,208,47,168,62,103,227,18,193,107,104,128,223,126,123,168,57,74,67,162,27,34,57,62,216,186,97,238,0,48,18,14,145,119,118,32,99,36,220,118,88,195,65,76,227,144,51,71,197,107,236,31,233,71,133,246,180,146,79,247,202,11,80,6,121,54,74,177,42,172,99,202,53,0,251,189,243,175,21,246,56,214,33,24,137,64,231,242,86,170,238,153,225,1,75,115,99,45,211,246,172,20,106,211,222,1,231,213,202,135,134,7,230,98,254,161,124,133,213,74,29,50,11,102,72,124,66,33,238,80,54,125,164,38,216,134,88,96,168,90,60,138,236,230,145,64,209,249,231,235,108,50,217,166,196,250,144,107,18,163,5,23,27,108,246,9,216,31,34,240,88,205,82,216,59,32,245,165,30,144,172,24,134,107,22,193,128,220,75,105,56,147,173,130,194,87,9,212,208,202,156,10,42,213,111,25,98,18,183,212,181,207,160,162,32,131,92,164,12,104,248,77,131,255,69,84,8,152,88,106,137,210,83,151,136,133,151,83,82,74,64,127,179,126,69,79,7,217,33,240,113,178,254,146,28,96,214,182,177,79,164,185,246,191,236,12,243,94,81,41,46,117,78,234,181,96,102,60,251,59,67,15,14,123,167,84,93,142,145,67,201,37,225,96,22,94,84,113,184,172,184,77,237,38,82,15,187,105,189,77,245,139,97,200,245,77,150,140,0,179,135,134,208,128,197,228,117,171,136,135,19,201,27,155,183,155,108,229,97,172,49,63,158,146,175,146,171,35,187,228,40,234,18,190,199,136,62,117,40,209,89,0,119,100,78,14,139,192,37,103,118,31,13,80,83,137,1,156,81,10,71,249,198,251,32,165,122,252,83,61,174,225,9,124,241,10,147,15,28,211,238,204,167,168,151,107,63,203,250,35,194,41,129,162,149,203,107,231,26,21,132,19,68,218,9,31,223,185,91,169,104,127,167,118,51,36,108,133,218,52,81,160,108,245,21,66,143,122,214,119,112,81,92,146,223,157,217,25,125,111,14,118,74,80,121,33,240,250,74,154,193,89,58,90,168,142,141,70,156,123,61,97,102,212,135,188,38,107,142,39,119,157,3,117,2,57,151,94,186,44,106,204,255,227,65,13,117,220,214,136,163,91,0,48,130,59,143,210,160,26,39,241,217,240,37,238,29,213,143,146,21,94,230,77,97,195,239,211,19,51,120,160,176,211,117,38,123,151,6,178,139,190,151,186,225,186,58,96,9,39,152,127,117,240,142,100,244,242,235,99,175,159,36,19,130,109,162,250,107,190,142,223,51,10,187,119,81,183,63,233,118,179,228,14,167,22,15,62,77,233,7,77,142,89,251,66,137,170,45,178,173,235,194,230,238,115,52,251,144,159,64,106,223,30,94,127,178,224,187,194,123,15,194,41,159,175,253,213,52,200,203,174,74,5,74,79,24,226,69,190,119,0,40,194,68,7,77,203,75,239,141,238,251,50,116,117,246,231,104,212,49,174,24,190,30,4,158,59,82,84,245,65,26,241,235,80,0,225,144,37,96,67,58,54,152,192,113,54,143,82,78,162,227,114,245,219,183,160,12,183,225,182,15,138,241,223,57,177,96,204,253,9,162,164,238,84,218,127,9,47,224,39,234,29,30,126,143,185,12,161,138,49,183,15,153,148,159,175,117,106,198,1,123,24,204,154,185,202,80,2,156,187,239,3,177,15,223,93,162,250,135,24,179,41,239,33,83,58,176,71,161,103,213,80,175,27,66,119,22,75,138,117,65,87,50,139,54,185,3,228,34,232,68,228,110,164,119,113,131,102,49,247,215,74,96,206,111,123,74,238,35,189,72,224,38,107,151,221,128,232,46,5,209,198,74,77,10,187,51,239,189,125,61,1,180,78,87,141,19,221,165,189,23,66,81,30,77,248,20,81,182,166,16,182,194,194,90,92,54,35,171,45,50,79,236,223,170,196,252,61,3,245,252,11,76,207,164,52,144,68,229,50,81,79,23,1,201,77,229,34,10,194,163,34,232,40,35,233,241,210,101,50,238,51,9,46,206,108,83,234,98,159,100,237,28,214,151,107,110,210,43,189,87,142,93,252,196,97,2,25,102,121,250,66,44,231,243,180,17,46,210,177,127,65,30,160,146,195,16,18,127,106,86,15,150,46,179,157,186,182,215,141,213,203,112,24,155,120,12,109,8,191,181,235,178,67,39,101,243,122,216,115,109,100,101,173,129,29,44,212,125,54,137,121,158,93,81,156,105,4,69,228,189,207,10,47,70,93,222,254,23,49,181,155,151,63,132,223,51,149,36,85,122,49,212,243,145,69,193,64,22,152,130,227,176,134,51,8,184,67,185,247,254,142,202,114,13,130,254,86,171,10,9,142,241,192,9,25,25,32,137,206,109,107,244,76,205,14,245,221,208,143,161,54,218,250,242,152,98,111,83,93,56,255,56,151,196,169,230,125,82,197,192,169,208,251,189,90,229,7,173,207,147,19,53,21,104,133,77,171,22,43,42,129,78,175,164,24,49,170,234,222,65,3,212,217,52,203,66,12,201,220,84,214,89,15,46,244,28,237,144,68,43,196,141,97,222,20,144,238,160,76,169,190,109,151,127,154,123,218,7,15,157,20,50,142,188,157,164,59,131,114,75,30,34,10,230,209,71,147,218,152,20,219,91,140,154,39,123,220,200,0,159,177,59,146,42,78,8,71,103,158,37,150,212,62,60,87,48,147,41,221,211,203,159,158,100,182,253,180,53,154,28,125,151,167,148,83,234,57,248,118,212,0,96,91,116,206,63,96,161,55,145,153,113,98,150,192,211,29,189,119,32,52,162,109,233,245,85,214,7,245,222,167,102,112,165,122,10,25,211,41,23,229,5,159,98,194,56,147,60,163,85,81,115,46,53,141,58,180,173,183,23,206,84,93,189,31,16,111,188,64,120,199,108,240,95,230,47,80,128,226,50,171,175,68,91,250,218,211,150,194,36,240,17,243,60,20,239,203,117,61,9,159,21,219,10,250,116,103,173,223,236,76,227,1,16,148,247,142,222,200,152,113,188,185,137,179,26,215,190,121,161,46,253,199,72,245,37,200,125,196,235,164,254,178,44,244,4,147,247,77,122,124,66,198,52,188,83,189,102,74,207,48,247,142,192,15,192,216,26,9,203,232,17,148,240,157,105,112,70,188,108,168,135,206,62,199,76,185,27,51,86,117,213,31,66,239,182,72,114,206,36,207,227,46,171,94,189,189,61,235,178,44,155,114,83,73,132,77,232,122,130,19,213,56,144,170,7,158,209,189,200,219,81,117,141,176,64,137,228,114,90,203,9,193,99,210,33,98,39,141,40,47,12,94,242,108,10,215,4,166,190,4,17,194,33,101,186,130,51,230,81,222,56,133,79,146,227,103,203,229,102,109,118,240,86,97,251,78,29,184,22,1,61,122,227,204,237,212,250,203,53,144,21,56,162,187,54,226,44,81,13,100,98,222,204,30,245,6,40,198,193,222,25,196,54,134,26,23,234,145,207,11,111,100,68,144,160,182,124,37,159,224,180,101,36,246,15,92,166,227,12,192,156,231,111,48,102,106,119,177,115,161,2,54,17,38,247,108,130,81,4,168,40,14,83,60,130,67,194,229,68,195,67,79,85,16,220,190,182,225,103,162,214,69,75,69,2,28,75,6,108,255,54,226,165,212,148,189,152,32,54,226,88,20,36,252,227,236,116,178,251,197,6,79,213,39,132,144,115,246,18,117,117,196,183,15,179,239,143,7,246,179,64,68,186,170,11,118,10,96,188,170,110,148,146,41,10,0,163,92,46,113,182,163,167,133,221,196,13,69,219,178,113,253,69,18,74,112,148,38,43,236,130,84,159,86,147,50,133,131,253,234,44,188,77,94,234,138,151,103,102,4,247,41,230,45,18,87,75,178,223,74,199,7,246,77,81,229,82,38,31,211,135,19,29,170,243,34,59,124,164,213,74,27,82,49,99,111,222,7,246,106,74,145,18,20,31,200,50,56,251,173,66,33,120,148,247,36,87,208,5,2,183,1,69,183,177,164,182,152,37,157,65,15,60,189,222,227,64,200,25,243,29,128,69,8,225,134,198,128,85,115,206,84,125,39,218,90,115,229,111,30,166,238,201,34,120,116,218,201,148,147,233,147,75,71,70,163,147,27,150,229,14,238,0,208,95,81,31,99,66,217,70,64,27,116,122,126,52,169,85,235,12,239,166,129,22,2,14,180,2,59,199,181,224,122,172,96,85,180,131,142,151,221,243,223,213,124,84,113,3,233,136,24,5,103,160,217,43,205,229,223,41,108,221,30,251,203,93,133,78,39,111,53,155,64,169,21,71,100,19,56,149,91,233,50,40,251,127,31,207,195,89,93,140,130,68,122,245,254,202,234,50,211,130,204,47,173,204,180,20,47,198,255,74,170,229,148,90,141,128,9,87,87,107,128,182,92,179,196,149,100,208,66,147,19,202,177,243,37,56,113,95,38,170,203,234,141,162,108,18,205,33,26,168,41,220,227,227,210,191,229,255,196,157,63,188,20,2,1,216,122,182,12,10,51,19,84,47,214,151,74,72,35,209,69,202,211,204,117,7,126,207,43,98,56,138,237,208,185,55,105,51,96,228,73,95,108,72,88,69,149,234,81,187,178,93,103,181,42,164,91,211,242,110,110,103,212,153,86,143,18,219,237,219,28,129,234,152,221,86,108,230,210,69,85,160,29,115,159,164,112,28,71,231,242,179,55,55,20,156,52,123,211,64,32,226,230,38,238,131,14,48,146,134,234,159,219,239,64,177,147,127,195,219,200,196,204,145,18,151,225,244,225,178,117,214,84,212,182,154,10,80,163,18,117,56,14,125,16,4,237,173,193,97,59,231,32,153,101,185,69,131,30,118,19,231,173,92,104,193,166,178,7,31,210,5,138,244,130,212,205,73,21,135,40,139,190,34,147,236,93,56,99,158,144,59,156,79,140,177,162,10,191,251,41,107,135,107,219,239,126,100,161,163,59,118,204,110,242,135,134,11,115,178,240,61,13,30,198,195,5,118,124,44,7,119,209,54,103,76,177,229,95,226,199,16,208,217,123,206,113,178,84,39,51,150,181,78,38,121,254,108,207,1,114,114,43,181,8,69,226,132,96,99,139,44,115,176,188,81,238,5,22,251,139,11,154,18,203,72,81,108,241,130,114,201,203,172,140,144,53,133,104,18,210,13,254,82,250,173,197,72,151,234,153,238,188,163,191,233,242,12,240,184,25,48,104,162,124,38,142,71,217,79,116,175,237,147,27,213,87,127,141,251,184,178,120,109,168,16,193,90,132,71,35,92,206,144,117,168,24,130,26,138,203,165,84,219,120,135,11,240,224,215,101,109,161,161,36,223,228,9,221,112,204,160,210,209,86,245,81,122,18,156,101,157,128,92,235,130,130,98,237,8,249,250,9,124,93,136,48,214,199,101,202,243,34,69,121,10,177,84,77,96,228,167,240,224,156,185,78,17,44,167,26,118,232,180,10,48,100,79,42,136,164,101,223,151,220,15,22,35,71,131,111,1,105,246,117,80,192,225,151,92,95,97,120,82,94,250,93,217,169,197,138,109,159,136,51,154,99,195,105,95,13,73,86,93,78,161,64,0,59,112,75,170,117,127,68,111,188,89,35,130,249,6,72,176,81,187,71,183,80,194,71,113,218,197,176,75,114,77,216,46,28,52,243,14,166,206,12,103,51,120,174,65,93,75,10,212,32,146,208,202,170,43,246,7,245,223,245,158,8,145,165,119,68,9,134,173,83,123,90,14,14,146,29,236,221,0,108,94,165,162,207,156,79,105,95,127,178,229,217,246,183,243,200,183,65,254,186,72,210,178,16,12,4,57,93,240,183,42,162,93,150,177,168,3,88,237,67,142,169,219,247,58,76,20,16,36,72,198,134,197,97,75,191,33,31,181,115,90,161,168,27,249,230,40,60,128,186,194,111,4,175,51,151,22,16,206,5,215,155,192,149,218,3,212,174,104,234,14,159,117,134,29,9,155,209,239,156,74,48,248,71,1,196,170,244,8,4,170,102,199,232,49,9,55,177,31,154,233,202,178,34,55,180,189,129,238,86,214,164,209,113,96,89,7,130,168,167,223,134,41,216,202,81,157,88,63,218,1,135,35,47,94,245,76,25,252,186,5,16,88,96,49,251,177,195,86,47,223,252,19,224,85,233,175,162,206,189,78,231,237,70,123,88,85,128,46,29,80,78,32,204,207,51,61,182,75,21,85,179,101,165,151,144,39,191,236,198,86,49,152,235,19,3,75,8,86,223,190,158,189,2,54,7,107,215,187,7,165,222,142,35,73,205,37,118,38,0,129,69,134,77,119,5,17,103,7,139,191,128,104,29,62,91,106,254,197,215,167,87,31,125,249,188,169,94,208,19,206,9,163,144,197,10,158,223,43,23,217,57,83,239,171,144,181,119,125,22,161,61,46,168,73,78,96,221,2,209,58,15,64,68,186,135,155,155,212,255,25,196,217,118,108,57,147,14,89,56,235,177,165,19,171,41,252,186,227,85,241,101,191,104,69,12,31,39,23,22,19,34,248,62,131,186,208,191,192,123,200,158,113,234,128,36,129,49,60,235,60,90,161,112,92,198,240,148,133,55,56,218,243,23,187,235,55,15,157,210,152,28,131,241,178,103,214,30,76,194,54,49,194,214,173,59,121,58,111,26,41,175,154,236,142,61,196,105,199,70,31,54,145,170,206,86,92,11,184,173,59,61,227,148,145,139,151,72,120,17,12,49,168,97,25,20,185,183,38,185,179,204,10,175,162,211,80,60,232,39,214,77,180,147,242,71,253,72,6,3,220,102,91,78,3,76,84,113,93,31,14,121,7,40,62,102,74,120,78,104,235,188,208,76,175,156,159,161,169,46,197,59,102,23,98,180,46,230,232,74,159,235,98,34,203,12,182,195,156,159,46,230,147,70,211,115,252,230,118,238,74,35,105,36,239,145,8,149,154,227,163,141,81,157,249,201,22,113,44,102,63,148,43,137,156,103,159,179,127,61,218,101,8,22,254,1,202,132,185,119,205,86,26,253,216,138,179,127,62,131,233,143,84,82,127,113,36,99,191,100,39,151,94,206,250,179,44,106,115,97,66,67,199,179,233,197,236,187,162,91,66,111,116,213,130,229,72,57,131,25,121,123,138,132,225,162,200,80,215,133,231,72,253,135,7,0,149,135,36,40,15,215,100,225,210,39,230,69,223,108,10,21,4,117,180,253,223,161,212,215,51,233,198,43,250,119,65,5,181,77,229,158,96,206,237,168,98,7,102,176,71,103,158,234,100,16,70,194,106,214,118,70,29,153,67,208,158,191,92,187,78,81,10,130,24,161,104,139,9,73,42,165,37,19,133,154,85,142,212,218,239,92,54,78,59,29,207,147,0,22,85,179,170,153,57,133,187,91,139,190,28,115,137,5,117,111,247,151,54,60,194,115,46,218,197,16,176,187,17,54,48,221,180,10,159,109,158,236,112,82,141,252,180,211,69,150,234,99,199,206,57,178,65,83,47,128,70,85,116,134,181,200,73,119,202,33,225,28,30,106,157,138,51,88,26,72,88,134,232,178,29,108,193,93,80,2,124,45,179,208,36,135,215,159,142,45,10,29,226,96,177,58,144,162,247,65,255,40,188,249,234,124,184,60,212,94,238,13,18,74,118,232,208,30,120,40,42,48,146,44,4,239,46,249,102,253,30,168,140,252,42,230,221,193,81,207,54,228,212,92,133,238,100,33,19,175,38,5,66,176,156,42,58,55,110,26,201,194,178,93,68,82,226,76,41,98,63,7,38,236,101,104,237,142,16,38,160,178,165,187,242,31,199,50,37,165,3,155,183,71,217,216,83,46,27,24,75,140,211,182,205,115,49,9,21,5,230,225,164,153,197,99,176,236,240,35,189,189,83,53,164,29,203,229,35,46,115,67,17,79,42,210,210,230,227,189,38,0,164,86,126,23,221,76,152,91,229,38,143,37,41,225,0,199,165,134,21,163,145,100,201,56,105,187,41,5,142,237,225,242,64,97,34,110,103,31,3,163,213,166,241,215,94,238,242,106,244,38,217,243,128,53,1,109,39,160,217,123,78,65,37,77,194,61,117,91,13,201,213,56,152,112,231,0,40,7,143,198,87,7,85,81,224,241,197,26,117,57,184,220,136,203,235,70,87,57,100,109,251,197,36,253,171,85,94,250,218,152,22,58,234,162,127,163,132,102,240,182,221,61,97,162,68,6,51,206,58,113,189,185,175,139,130,172,213,3,18,49,121,99,16,77,190,163,184,169,253,208,91,109,33,207,25,102,57,211,187,132,13,189,116,62,182,145,202,51,111,116,250,23,44,22,59,132,132,103,12,198,56,38,15,201,133,119,172,80,165,222,245,108,142,64,217,234,99,136,194,60,133,90,24,34,138,25,94,186,107,153,59,126,92,147,23,239,58,210,1,88,255,76,250,58,164,93,12,220,114,212,200,243,206,231,173,83,42,33,250,88,12,187,55,179,207,217,163,87,174,243,141,49,204,60,42,60,171,36,69,94,115,216,39,77,239,60,224,150,182,74,1,74,225,16,23,102,149,195,140,208,26,123,239,34,180,176,10,50,46,89,76,23,95,57,213,171,241,106,215,132,48,163,94,106,179,74,48,74,229,230,241,104,127,182,99,50,36,82,255,173,151,29,216,35,196,19,243,46,112,146,158,44,77,180,177,110,194,250,47,213,42,15,40,147,73,101,132,87,186,137,51,71,220,169,106,164,184,10,204,152,73,192,55,125,117,108,40,43,150,80,250,2,188,219,213,210,78,163,246,29,94,18,88,161,72,223,140,93,219,217,25,23,185,178,34,169,177,161,189,0,3,34,246,44,31,153,45,203,242,68,183,195,60,3,47,194,227,55,176,135,110,239,198,146,201,68,116,215,103,84,232,67,52,114,0,38,154,149,94,207,69,79,228,177,153,7,181,233,171,242,120,153,14,90,168,5,146,43,166,97,58,3,156,84,5,96,179,252,171,64,214,71,37,105,149,139,136,212,90,147,69,24,124,122,111,150,118,190,75,215,240,206,126,99,57,113,108,120,171,50,151,250,65,216,19,18,226,204,148,88,249,87,34,30,48,75,115,232,44,62,191,99,31,75,90,129,200,76,117,121,11,114,181,132,56,212,199,21,148,2,232,89,169,174,135,42,131,207,222,145,243,135,204,211,41,144,129,203,10,138,12,200,115,175,217,25,168,149,73,70,152,222,92,52,218,251,168,182,234,227,255,236,3,89,23,128,48,126,154,96,162,112,133,160,9,74,116,58,21,227,144,196,129,180,64,187,135,72,222,33,229,194,85,235,250,238,200,88,59,19,182,237,85,207,167,181,41,54,0,147,226,101,43,43,15,233,75,156,185,161,142,195,208,70,39,68,62,84,193,201,251,11,74,15,91,42,203,70,187,119,47,34,47,102,250,77,205,92,168,22,236,24,107,97,194,31,56,126,227,69,225,250,217,189,49,202,104,47,245,50,34,241,90,176,244,199,151,176,180,115,21,210,158,248,123,217,28,221,42,32,151,99,145,38,118,177,118,19,97,8,70,179,97,71,46,30,222,31,106,82,244,96,93,192,141,102,2,93,77,5,220,79,92,114,17,74,71,16,114,44,173,19,165,189,159,78,234,30,52,239,157,190,24,9,210,72,12,82,173,17,57,230,218,209,165,54,214,127,30,161,84,76,153,54,190,26,123,248,244,110,242,166,129,138,231,30,107,179,253,69,182,133,41,107,157,212,51,19,159,218,195,149,59,157,193,118,24,66,236,161,207,85,172,133,183,85,67,70,111,104,164,26,82,166,118,19,114,222,238,0,255,199,104,169,111,193,165,66,215,233,189,100,39,48,218,63,122,223,203,254,143,12,245,227,96,148,128,163,34,15,229,48,17,200,60,66,157,154,167,128,252,224,34,178,117,79,35,16,226,61,219,51,131,208,10,230,170,151,154,98,11,79,189,59,127,109,137,81,182,105,96,238,95,23,58,139,85,84,124,28,25,43,239,107,72,23,167,40,60,213,55,189,99,144,170,138,65,119,90,118,128,201,224,29,124,173,160,1,112,86,187,96,201,159,67,44,165,117,106,84,169,108,141,74,153,192,238,28,59,4,48,246,108,49,34,74,105,89,20,53,62,216,39,181,129,240,189,58,169,93,205,92,118,93,221,106,81,248,147,22,101,184,109,77,139,157,72,5,174,219,235,171,235,171,79,31,127,254,233,118,188,144,18,88,204,25,237,202,8,49,124,220,231,249,184,59,174,85,144,144,254,217,251,33,106,56,40,20,69,92,176,74,51,236,11,128,98,179,77,173,123,76,1,76,137,78,165,31,101,167,10,127,116,53,28,132,4,226,103,69,42,62,84,20,41,240,211,242,38,112,161,123,226,142,133,151,93,241,116,84,121,228,22,4,75,130,213,123,39,48,191,244,84,200,137,82,72,192,218,244,144,176,141,113,4,126,83,138,0,249,217,175,146,228,4,253,95,66,217,226,111,226,140,37,31,36,248,49,96,163,133,87,14,121,203,255,173,5,243,175,0,134,175,139,134,161,82,22,69,25,179,202,15,144,55,173,148,77,62,96,48,50,255,212,59,51,179,132,193,60,98,128,57,178,150,245,174,235,206,44,27,125,216,3,188,3,181,114,193,136,117,220,252,214,170,86,168,212,46,193,213,98,94,54,33,199,168,76,139,168,206,133,74,197,132,247,70,66,31,210,197,48,43,182,130,91,111,159,55,202,176,220,190,208,180,200,148,44,62,156,237,93,119,126,78,197,96,11,65,65,88,64,176,153,97,71,56,233,134,64,84,219,103,233,35,83,67,83,254,90,213,19,65,202,221,49,196,37,92,248,190,119,136,49,3,117,115,145,161,168,242,157,50,152,212,144,144,54,43,19,249,69,143,254,34,158,237,10,2,124,239,133,25,215,69,243,46,229,209,175,93,204,252,5,103,239,82,92,9,172,158,45,208,83,182,50,45,158,56,4,254,226,206,251,245,17,231,207,36,221,209,130,89,250,94,123,228,184,72,207,203,102,193,47,197,32,216,85,208,63,101,192,176,21,82,70,101,208,50,19,178,87,147,63,53,37,238,79,148,49,70,141,63,45,200,133,254,41,36,251,39,28,132,180,249,68,141,219,247,222,39,5,81,106,35,211,223,235,104,236,143,4,225,101,56,127,47,145,230,153,140,200,230,59,49,201,213,141,58,214,85,204,28,238,218,178,169,254,202,40,208,112,189,223,0,112,221,57,146,117,84,7,217,73,198,162,240,20,232,206,86,222,29,201,218,33,129,68,130,108,171,218,253,131,107,20,103,148,226,224,255,64,93,11,227,173,145,74,65,2,54,111,245,204,186,205,201,35,147,58,203,55,166,148,221,134,102,34,43,118,14,123,126,9,91,80,97,101,196,244,34,254,117,43,117,36,38,156,152,35,156,120,2,197,117,165,154,39,18,231,132,210,163,195,205,33,209,131,208,192,73,144,21,69,95,232,27,160,152,213,148,55,146,167,3,66,223,190,67,224,9,129,179,90,202,109,140,112,156,201,66,199,180,166,130,207,215,128,183,35,210,199,236,20,167,32,174,220,251,116,209,181,119,199,222,19,39,186,192,114,132,170,143,50,141,186,121,229,58,148,49,192,229,171,6,128,149,124,214,222,231,175,71,57,104,29,4,47,177,112,89,61,61,228,72,140,34,227,68,8,86,172,140,139,50,139,227,131,109,203,110,89,221,64,2,84,73,226,85,119,44,209,159,230,12,120,20,40,73,248,23,236,215,205,106,71,118,237,22,147,93,162,8,92,244,229,6,104,35,215,4,177,29,236,243,81,2,3,223,239,58,59,117,5,252,16,105,18,104,14,33,243,68,11,138,202,77,172,6,104,206,184,137,100,134,107,107,191,26,110,186,35,105,169,254,160,54,186,248,234,173,141,11,10,71,174,221,69,98,65,153,137,13,149,116,159,157,14,146,62,205,48,129,99,49,69,244,98,110,112,28,230,135,9,173,76,88,29,55,179,68,15,234,21,73,80,174,162,244,164,189,152,223,203,193,63,202,107,84,156,246,243,94,131,57,76,179,238,59,183,207,61,243,14,20,112,138,64,73,130,49,190,110,185,27,252,106,222,21,156,195,171,199,206,11,116,91,33,186,71,141,45,174,145,224,176,21,76,168,115,176,37,58,36,222,22,143,65,177,172,72,201,79,100,182,225,90,79,24,12,223,7,34,137,179,15,71,168,143,197,216,32,62,221,144,115,26,129,157,89,147,171,192,182,165,133,115,83,190,216,30,24,164,210,40,230,71,253,132,55,246,112,61,237,220,197,119,193,151,159,174,138,157,165,118,41,1,80,147,4,177,150,49,105,157,138,248,217,17,159,114,89,109,105,125,197,4,45,2,134,139,41,252,161,84,135,245,189,132,133,11,184,24,160,151,10,241,238,225,142,20,30,84,93,46,207,200,131,188,83,97,229,36,182,59,219,18,232,254,188,211,17,81,25,240,166,48,3,9,114,136,154,110,64,97,99,42,126,113,192,11,235,36,221,179,126,203,78,244,7,251,254,77,122,206,32,186,179,202,75,154,80,176,57,223,105,126,68,25,219,243,20,5,251,51,67,220,139,59,131,246,0,225,243,220,122,120,167,42,196,79,88,156,12,152,165,92,63,126,95,249,166,251,168,212,18,149,18,193,255,58,30,248,118,81,89,191,39,65,110,72,109,7,241,185,136,134,204,157,176,31,211,23,23,30,154,69,210,69,58,3,158,114,253,184,153,57,12,160,8,253,149,39,175,45,62,151,18,31,98,186,223,111,192,185,155,0,62,157,147,195,106,143,175,184,12,253,194,163,51,168,128,48,175,79,95,140,165,166,175,71,118,53,218,113,17,11,19,171,231,205,75,1,77,50,156,161,13,199,210,23,13,156,154,232,97,118,225,75,26,16,239,76,224,44,90,207,202,83,96,125,38,172,82,128,192,149,8,109,80,213,177,121,113,164,154,80,17,62,136,116,31,201,3,138,144,10,199,191,113,153,96,2,238,197,178,93,191,241,141,59,75,152,18,28,31,97,212,147,208,246,226,112,37,81,37,93,125,70,185,145,190,41,158,61,133,168,218,52,253,72,58,197,209,243,113,67,139,158,144,6,79,209,126,216,37,31,36,108,135,115,222,199,177,129,150,24,187,247,106,53,71,165,82,201,119,31,44,7,168,69,147,136,36,40,64,118,74,146,206,3,253,138,90,120,139,164,75,93,208,220,103,221,37,228,51,7,210,2,164,229,49,247,53,186,206,9,92,79,177,100,96,235,249,15,65,235,247,100,137,187,11,13,12,218,93,166,164,224,105,83,172,21,74,60,101,10,156,22,21,212,85,121,236,19,246,196,37,57,217,201,168,231,142,137,246,105,55,236,67,70,110,229,218,91,154,210,12,82,19,65,221,44,211,196,252,66,73,207,188,177,248,66,122,35,126,201,84,105,241,20,146,135,106,64,204,81,102,161,175,96,8,188,221,216,254,216,237,213,49,81,61,230,32,92,13,57,6,207,240,185,246,169,0,219,52,21,142,30,228,179,225,218,174,207,25,142,51,209,228,138,7,225,219,179,125,22,203,71,213,0,119,251,222,41,145,115,111,105,33,24,250,109,26,235,167,192,23,81,215,138,152,110,52,118,84,55,199,194,243,241,163,178,148,247,75,13,241,21,28,100,235,111,213,85,7,54,123,117,39,96,11,188,111,40,91,114,245,17,190,118,55,155,127,38,21,249,44,22,18,69,122,204,244,108,202,61,164,26,37,62,227,73,116,248,129,39,34,113,241,20,238,186,20,228,151,58,224,227,206,115,151,216,115,106,160,126,104,33,115,25,230,221,216,55,247,118,62,123,244,244,187,43,225,16,177,87,166,238,48,26,189,39,247,240,168,153,137,153,243,144,161,131,149,212,88,182,69,159,160,152,69,255,12,114,164,215,196,78,4,94,141,99,235,65,172,222,9,240,16,101,179,142,132,15,7,15,213,5,55,159,94,55,150,217,78,113,74,14,27,17,157,83,229,21,70,179,210,3,108,138,131,89,248,219,89,96,121,118,19,108,16,226,162,59,23,133,66,174,248,148,90,131,121,169,130,34,81,233,142,63,121,251,111,192,56,161,35,119,159,90,253,37,77,17,124,91,94,43,43,179,39,200,184,216,59,162,79,176,99,23,228,114,40,176,36,219,220,255,53,79,112,197,92,7,34,80,212,206,231,25,252,58,91,222,204,42,10,98,165,251,34,255,155,253,30,6,145,232,109,236,99,116,15,210,116,35,172,141,239,246,29,28,198,205,32,94,54,203,28,112,16,74,56,98,42,121,93,179,100,48,146,49,22,206,205,92,73,200,180,19,212,58,101,60,236,21,125,191,43,79,161,114,186,33,22,121,227,197,35,14,163,152,158,33,194,246,190,117,225,142,101,9,222,225,27,101,10,187,242,148,72,220,5,245,99,245,230,233,96,74,243,148,228,51,206,192,200,14,106,13,223,121,51,54,220,111,91,40,45,209,151,98,251,123,204,179,111,251,126,238,189,220,216,111,251,145,83,141,137,159,195,108,89,212,254,221,186,3,85,103,168,64,187,229,214,157,228,205,204,92,89,172,77,88,229,98,214,206,203,110,75,96,158,184,3,90,170,239,17,11,33,61,194,140,129,231,84,64,28,118,3,138,191,37,123,249,232,93,21,48,58,91,243,165,236,188,220,222,88,48,63,117,12,252,214,254,116,46,225,168,11,201,211,180,93,165,218,83,248,175,225,200,21,48,37,7,123,155,197,106,55,95,251,234,61,148,77,160,121,169,146,132,36,139,32,11,199,181,57,38,53,30,239,83,201,101,154,160,70,32,205,55,182,152,192,253,78,87,23,192,142,162,221,246,59,204,165,109,77,58,5,222,68,95,163,251,46,123,68,62,137,90,131,62,24,119,222,21,67,28,9,124,2,105,52,123,184,82,92,248,86,92,48,158,21,119,211,169,80,180,238,10,68,235,221,217,7,211,28,227,149,240,37,106,199,211,160,78,70,209,72,239,119,63,48,27,124,130,220,162,246,185,172,229,91,122,19,251,34,89,102,139,231,58,109,195,8,31,125,27,106,207,230,46,102,40,199,132,41,165,179,77,82,187,205,55,148,7,2,239,162,175,105,182,208,88,27,41,15,52,250,187,243,165,12,94,96,66,29,113,148,226,229,104,135,131,59,245,72,252,125,134,87,21,144,88,58,124,90,8,32,1,37,251,156,9,70,63,189,80,6,39,197,32,238,154,37,21,255,217,168,127,129,187,232,88,127,115,34,82,170,92,82,186,174,168,67,242,144,53,21,246,106,164,114,105,182,21,114,30,148,74,51,59,114,3,182,219,165,153,248,141,239,124,158,60,75,231,190,208,152,231,134,144,170,28,46,54,47,0,128,223,27,89,61,63,58,249,151,47,243,184,194,156,164,25,61,50,239,230,147,104,180,205,159,79,168,62,250,217,104,204,98,253,201,124,41,69,143,162,180,203,107,192,241,215,60,164,32,181,67,205,184,51,146,116,179,13,19,36,113,191,197,133,86,58,206,78,65,134,132,159,176,88,13,78,43,158,129,73,203,165,26,4,251,35,196,172,215,114,54,3,179,122,118,214,247,200,88,176,189,40,113,100,33,154,89,19,30,253,35,249,183,64,7,145,147,216,215,71,194,212,158,176,238,158,203,113,139,72,91,220,56,149,38,228,165,194,165,18,149,202,95,29,201,201,112,23,174,232,231,195,200,65,228,202,6,122,122,96,50,172,171,20,136,17,82,44,221,105,31,244,249,103,86,111,238,61,161,228,105,189,167,177,31,37,183,73,174,161,36,23,119,82,248,196,230,194,210,248,97,219,219,6,68,20,37,74,90,109,30,208,218,133,254,71,31,238,4,115,12,92,128,216,85,95,204,170,232,75,57,217,249,199,123,253,238,236,248,131,91,55,21,66,122,99,203,162,18,21,107,1,196,181,14,167,234,47,106,79,15,39,11,48,62,139,90,112,148,228,207,177,25,228,187,81,131,30,75,8,243,8,53,69,26,109,76,25,245,61,127,18,254,199,147,127,24,84,4,98,131,156,212,59,104,87,66,132,25,234,78,11,205,255,181,247,228,37,30,64,153,38,150,188,52,97,182,222,189,69,26,167,72,246,235,113,82,19,105,220,213,130,120,226,189,11,146,239,225,204,168,171,176,79,7,215,241,187,215,41,253,146,149,52,67,236,17,120,52,67,207,226,171,59,181,29,227,187,234,112,144,26,136,240,63,226,39,116,229,88,69,51,135,86,214,212,103,185,232,5,72,78,72,152,181,230,77,171,181,140,18,238,83,194,41,143,71,121,34,154,249,208,136,108,66,78,1,171,112,229,253,124,26,125,204,109,129,215,31,241,41,144,253,198,112,62,241,77,125,165,224,6,5,121,168,238,131,148,0,47,136,63,100,25,23,14,69,229,77,246,123,130,21,212,188,87,19,78,43,126,230,170,57,24,94,249,152,84,126,16,86,109,17,249,146,78,181,7,73,101,182,81,249,165,246,125,155,136,70,35,132,77,40,50,21,229,92,132,201,221,177,212,209,209,91,159,97,81,113,42,95,95,253,112,30,233,42,156,229,122,101,180,144,145,80,163,139,156,210,191,212,141,58,180,157,111,87,4,165,228,94,179,178,116,81,167,162,190,114,159,96,23,83,2,241,79,22,166,238,203,181,133,247,114,237,210,223,105,133,125,40,154,32,153,225,68,25,0,150,10,22,146,187,227,125,39,155,245,57,9,99,59,247,212,220,90,52,75,52,195,240,202,5,84,117,162,253,226,251,157,164,133,131,111,225,236,45,60,126,94,24,255,66,69,162,26,142,132,167,88,180,177,78,60,235,36,60,238,114,147,251,8,75,109,130,103,150,132,65,128,122,205,88,176,44,220,62,228,147,88,4,80,11,7,114,204,185,249,68,107,225,208,82,201,110,152,248,83,81,160,155,13,85,131,236,233,31,119,44,28,119,5,160,85,54,117,215,231,177,29,48,176,75,222,35,93,34,68,185,66,54,178,44,151,97,130,163,130,124,253,243,101,250,78,61,249,33,58,118,216,180,188,217,181,227,96,127,142,235,176,159,208,120,180,195,145,84,199,107,165,178,96,247,6,50,173,185,13,163,10,104,214,90,64,233,153,168,252,82,229,165,85,79,27,199,139,77,171,42,233,82,212,230,163,176,117,80,203,60,222,113,88,5,10,188,98,250,170,195,37,83,198,196,189,79,117,195,151,175,52,76,178,93,6,47,64,237,175,102,85,234,41,148,40,126,169,139,106,74,57,47,157,192,147,230,212,247,169,244,195,217,141,142,10,157,7,75,84,27,200,180,45,205,181,5,246,96,15,252,22,228,51,153,196,97,239,187,173,59,247,100,40,164,177,119,6,59,152,48,155,81,115,85,181,61,34,67,233,218,40,183,202,44,180,80,169,163,173,127,157,105,19,34,113,40,137,245,34,8,114,71,245,97,152,72,156,42,34,183,233,123,206,199,211,203,230,224,75,143,165,136,127,187,243,250,191,33,203,243,173,190,97,147,102,187,209,251,75,208,24,176,180,162,107,250,61,152,114,149,18,112,190,141,122,127,245,212,87,246,71,189,233,145,44,193,137,41,252,34,113,22,139,164,78,235,232,182,235,43,157,74,43,185,47,206,210,173,201,219,27,202,25,112,44,211,216,90,51,110,107,17,162,38,95,109,187,131,167,200,134,155,164,102,141,135,164,133,85,164,76,71,202,220,145,30,134,123,173,81,208,93,213,69,74,148,140,15,6,208,166,251,224,40,205,195,33,187,79,172,108,136,177,98,128,213,0,92,59,191,148,100,8,112,187,203,83,147,30,167,56,150,154,11,39,239,187,41,133,194,82,128,114,155,219,52,75,237,44,193,157,81,135,171,45,60,38,206,22,128,66,71,138,158,66,131,78,186,97,106,181,238,172,58,214,158,216,161,25,179,155,79,123,143,31,36,58,20,251,188,177,167,248,169,12,12,21,8,246,25,236,224,203,211,123,91,150,31,108,178,248,191,242,94,155,151,179,0,208,212,179,223,134,142,192,116,174,232,88,198,207,225,120,164,3,18,108,65,176,158,111,116,244,212,148,19,210,23,91,153,130,138,179,3,141,86,241,183,144,134,247,209,93,211,37,166,178,14,155,51,172,108,212,110,93,152,120,225,231,124,24,239,238,199,42,192,29,164,182,189,114,99,143,202,8,22,219,210,187,231,194,45,182,215,228,79,154,157,203,63,121,245,28,204,49,227,119,182,226,3,166,3,139,57,230,128,162,13,79,26,55,221,204,34,181,207,254,137,123,126,222,28,241,115,124,126,63,15,251,173,87,143,92,221,64,197,156,252,81,181,100,121,78,10,242,93,156,13,49,67,59,23,94,5,237,153,191,6,45,222,255,57,118,128,195,135,222,41,116,162,69,122,239,255,76,146,127,186,15,175,0,246,223,120,58,239,228,233,160,78,177,190,115,67,165,42,163,168,120,52,52,165,200,146,12,143,78,73,66,142,29,215,97,84,40,69,236,76,87,185,108,121,163,176,19,221,195,212,136,26,22,156,217,4,21,197,220,63,79,27,30,206,113,59,39,131,122,199,148,146,29,121,48,111,187,237,219,3,55,136,104,76,38,154,70,226,42,206,184,176,65,229,60,32,10,144,87,133,124,82,40,26,246,233,151,7,151,153,138,192,97,239,88,158,189,23,45,105,208,150,14,182,228,9,35,33,199,242,142,95,10,239,130,167,133,54,177,93,71,20,137,80,61,115,197,236,42,159,249,24,192,215,214,225,37,47,50,123,135,53,93,141,252,36,63,191,118,10,38,242,121,172,46,204,124,238,93,8,57,229,162,78,247,206,58,185,190,162,193,222,84,219,163,140,117,183,43,205,229,175,86,30,246,193,58,70,64,1,140,172,40,226,244,126,204,76,90,80,226,154,52,161,29,127,182,83,177,125,165,54,159,198,139,22,104,80,126,150,189,86,110,39,237,81,42,168,161,232,174,54,145,46,129,225,94,215,1,81,6,81,20,119,242,227,3,169,194,174,53,135,62,245,178,41,160,45,147,217,62,197,105,59,181,1,158,246,242,125,87,166,190,189,145,57,143,142,244,12,176,224,106,205,62,7,104,125,161,188,51,119,4,219,6,129,114,111,155,197,205,77,210,45,243,58,209,215,99,189,5,211,3,153,32,251,154,123,94,223,174,170,146,205,35,252,104,151,173,109,109,128,123,254,56,84,127,111,110,188,4,5,57,59,20,76,46,127,227,13,142,226,6,239,149,103,201,186,230,2,60,229,119,167,144,74,215,30,43,101,58,237,172,69,178,215,159,134,83,11,210,89,22,127,129,116,9,6,55,35,178,179,11,128,0,200,31,5,5,198,172,235,42,63,16,196,162,167,177,237,205,130,85,87,21,41,157,193,129,232,178,175,33,118,137,147,130,154,166,9,67,42,199,66,91,73,93,45,41,9,204,47,150,109,179,54,131,159,216,122,107,202,161,90,120,217,86,125,234,148,167,139,169,205,21,128,215,85,83,96,69,233,131,126,40,203,58,17,240,48,34,25,5,172,84,8,78,244,92,58,6,9,241,238,152,117,0,50,75,211,214,213,106,164,241,165,71,36,186,168,89,135,66,233,166,218,192,112,154,79,115,151,119,115,7,80,106,233,109,196,214,229,65,145,147,111,220,232,163,202,253,226,229,126,141,61,157,251,145,28,23,50,178,180,196,147,80,216,235,157,226,62,66,234,67,98,179,228,90,71,227,56,112,183,88,99,188,119,156,151,211,106,236,127,223,76,237,134,109,180,225,99,188,129,38,86,246,215,147,51,145,22,233,95,255,38,204,244,223,129,101,59,87,130,183,61,86,138,131,8,133,180,30,232,181,149,119,171,103,37,213,182,183,232,210,230,154,149,163,218,152,7,63,76,172,35,129,232,169,112,108,138,42,22,136,162,174,131,88,80,231,81,164,116,180,84,50,183,208,159,127,83,200,135,83,158,8,190,157,98,88,10,4,232,248,20,108,67,117,67,201,87,168,192,64,175,68,169,75,15,134,126,118,141,199,85,56,228,160,170,82,78,78,184,76,76,200,104,4,185,144,171,156,105,100,239,130,84,169,252,78,254,196,228,99,168,28,130,109,78,55,219,168,72,239,159,135,49,165,223,25,93,212,198,166,4,174,97,43,108,255,253,248,101,194,154,4,32,1,238,242,61,241,234,52,205,234,167,208,134,214,245,73,149,101,61,123,137,66,129,247,191,198,238,50,234,1,56,118,66,30,140,211,194,19,78,90,21,90,199,168,104,159,96,26,251,24,122,104,5,245,81,24,154,252,218,158,106,145,255,20,99,94,95,217,232,193,196,48,161,70,103,51,229,248,234,112,50,161,80,82,164,60,83,70,48,74,236,28,229,113,37,191,244,190,116,160,79,244,138,230,3,220,8,182,192,165,158,168,158,200,70,160,245,210,224,68,87,82,245,244,28,192,160,9,141,137,52,160,186,197,32,237,99,126,163,246,49,73,100,29,72,234,246,151,32,41,142,246,153,169,143,197,4,112,113,158,230,189,166,40,237,28,155,13,59,210,59,111,104,145,21,97,178,82,200,8,96,246,238,14,175,137,17,126,92,136,78,109,219,218,168,124,32,188,63,132,253,53,47,34,104,18,206,201,1,243,46,153,43,77,14,104,254,109,50,78,165,7,96,32,150,239,167,209,125,48,8,199,19,48,179,138,44,198,201,165,62,71,157,149,186,56,245,238,135,32,111,155,115,198,252,88,186,196,139,177,139,153,99,217,188,219,50,20,74,243,203,59,34,110,76,55,165,156,191,39,196,243,148,147,208,228,99,158,80,54,226,164,156,116,114,224,88,18,175,202,205,5,51,145,133,83,36,158,200,12,224,6,171,170,12,166,250,237,244,5,164,128,216,53,157,224,252,220,41,238,98,197,2,200,157,200,105,217,34,9,246,43,114,153,42,54,32,26,144,49,8,207,123,19,92,29,96,244,187,98,223,139,15,248,125,81,246,212,159,29,118,29,68,71,157,81,88,176,10,59,87,65,96,1,188,175,83,216,97,164,240,217,221,124,212,133,136,161,227,46,116,246,185,37,242,9,20,111,224,90,15,113,31,106,192,130,172,120,250,222,63,73,71,8,82,117,113,196,215,236,0,242,142,38,7,136,93,148,31,162,118,186,240,68,147,230,35,173,11,158,17,63,132,155,198,83,147,254,58,126,151,93,100,84,222,71,200,179,70,115,106,167,141,14,228,6,175,75,84,196,251,68,145,63,43,66,24,91,99,3,15,1,194,43,129,105,93,87,65,240,71,238,221,144,164,205,86,117,181,95,66,5,160,133,193,70,61,132,162,93,130,230,149,249,23,81,114,139,83,221,249,131,118,99,82,68,205,5,58,111,155,60,242,40,210,213,194,111,188,167,188,19,180,111,149,147,56,120,179,204,92,79,240,51,7,33,12,57,175,202,21,112,19,48,174,76,35,97,73,12,55,100,17,142,207,169,32,212,28,15,67,85,212,158,47,250,40,43,226,192,138,32,179,120,40,50,120,174,93,65,89,40,175,38,224,70,188,66,23,16,192,106,166,128,110,239,240,95,149,134,187,72,188,60,141,119,201,168,114,208,232,236,202,88,2,210,163,68,3,41,87,120,93,10,221,200,147,61,5,209,61,233,165,165,76,180,221,24,115,197,187,66,94,131,215,43,78,244,164,177,30,94,87,214,25,239,102,148,170,161,46,41,87,15,235,190,88,75,175,138,201,0,177,201,237,12,108,88,149,114,5,241,105,158,47,116,168,147,208,5,52,56,156,44,220,100,63,19,30,2,109,233,92,53,237,246,154,189,44,20,46,250,173,142,250,133,170,208,195,204,163,208,228,165,232,224,38,102,112,49,17,8,82,170,113,172,50,144,237,40,61,78,157,75,92,133,170,31,203,74,238,147,41,67,236,138,128,246,234,35,209,110,67,143,203,212,229,122,139,40,182,177,59,241,23,68,29,183,252,22,238,97,2,181,59,175,91,210,68,8,222,243,150,96,110,117,65,62,43,93,124,31,190,11,150,13,159,206,61,203,189,89,0,196,195,72,124,19,184,76,1,209,64,33,49,246,65,11,246,179,119,40,139,4,208,218,177,163,106,109,2,4,244,236,59,252,244,107,12,106,181,17,29,79,248,246,68,101,241,78,147,129,93,86,247,211,59,79,208,160,113,54,11,205,79,222,154,198,76,141,58,119,81,48,206,107,207,177,53,178,96,179,165,44,248,194,59,168,116,173,99,53,162,218,57,36,117,62,234,43,172,139,61,149,212,19,36,52,114,23,137,255,109,171,171,73,76,56,172,24,179,127,78,188,223,218,80,98,164,80,224,36,3,140,60,211,80,72,73,59,2,238,74,202,168,193,36,29,27,89,42,248,166,199,232,175,18,139,31,226,226,142,231,118,233,226,80,22,117,213,146,53,10,251,77,162,78,170,37,188,253,119,63,70,12,82,226,148,56,28,164,106,139,206,187,221,114,208,154,138,146,111,145,23,117,182,37,113,133,178,175,124,0,111,105,232,203,118,119,100,202,202,73,86,85,239,161,128,244,44,176,233,138,255,159,171,16,97,198,135,62,151,154,125,34,101,230,57,166,254,91,250,45,200,17,121,144,15,43,38,240,11,92,177,250,60,182,104,145,46,40,147,31,168,16,233,181,79,114,23,135,99,116,196,116,134,56,187,151,176,0,127,71,91,205,103,116,101,7,207,9,101,160,64,40,43,190,98,239,207,161,1,146,170,189,163,36,70,246,243,151,148,58,30,30,109,162,83,65,52,185,184,174,217,156,116,222,69,138,73,159,57,149,70,237,28,126,151,114,223,57,220,119,210,217,247,158,137,63,54,50,67,142,89,249,220,142,124,248,58,245,32,32,142,163,83,141,237,124,217,216,109,149,146,76,27,95,135,119,158,98,133,95,3,20,188,78,11,51,178,46,33,75,90,2,119,143,59,142,139,251,121,239,198,110,143,114,211,60,16,144,152,196,8,217,143,216,228,94,3,19,240,4,240,220,83,31,65,149,59,208,165,178,247,91,214,96,168,30,151,104,101,99,249,94,133,24,174,36,185,139,109,8,253,165,78,90,33,133,186,148,170,32,61,23,184,44,21,240,135,124,189,128,144,56,24,11,138,10,123,239,232,67,34,77,186,5,82,183,249,121,84,190,47,68,105,158,38,91,219,75,237,94,109,56,158,127,251,215,247,199,113,19,6,217,118,208,106,85,254,255,225,29,162,19,3,129,152,217,167,94,63,78,124,140,248,92,174,131,31,92,172,161,135,203,140,192,250,24,162,178,237,18,79,202,208,95,71,169,27,185,252,22,170,146,4,27,147,38,113,159,42,137,58,218,54,238,138,167,194,220,48,191,177,214,63,199,179,254,91,3,152,127,251,141,97,204,15,249,214,96,230,199,100,67,234,157,90,60,101,233,13,32,209,132,102,89,23,10,172,60,226,140,134,115,121,75,184,255,232,87,201,175,250,143,126,149,185,116,109,146,41,116,247,8,98,130,255,167,95,103,18,124,159,219,49,199,82,165,254,171,106,143,161,124,185,62,42,166,100,219,84,220,14,181,115,207,237,222,107,109,39,57,12,51,117,194,222,217,247,79,204,52,159,90,246,66,9,93,53,121,201,173,248,226,118,51,25,107,195,125,199,93,89,31,18,27,131,14,202,157,31,155,172,119,32,86,226,1,227,80,124,104,123,80,242,116,217,228,122,239,221,8,60,234,184,125,229,100,148,55,163,43,16,39,99,36,251,228,31,114,138,100,253,238,94,221,154,226,38,71,9,150,56,115,111,139,161,223,188,56,183,62,174,2,26,93,52,161,183,253,205,104,231,238,155,99,230,185,158,116,9,90,221,80,29,39,191,204,169,185,158,219,241,139,253,31,34,171,219,151,143,243,216,59,98,35,243,207,22,28,227,87,110,172,200,14,246,254,72,60,210,149,80,163,237,91,44,192,133,119,105,194,49,183,179,79,237,180,173,108,248,163,194,223,235,121,246,251,66,125,64,210,34,156,139,146,4,243,92,251,140,64,208,146,214,246,207,168,214,100,6,35,254,254,143,19,202,255,31,0,24,227,220,116,5,160,63,219,51,118,96,136,49,38,28,198,24,170,169,23,195,169,204,94,209,152,206,103,49,212,139,143,85,72,39,215,99,251,169,123,15,142,41,184,154,220,84,32,182,165,189,157,21,46,199,127,45,147,252,127,18,84,34,202,1,64,167,17,229,0,133,5,241,91,150,230,75,82,189,25,65,55,244,71,138,173,83,88,53,38,56,244,23,124,102,227,240,35,225,162,248,75,64,164,125,9,57,59,221,75,138,221,166,85,197,137,94,214,201,127,4,116,128,196,95,7,255,31,121,107,144,25,193,132,40,109,182,175,227,58,234,46,160,44,209,29,142,142,2,252,190,90,175,217,10,34,187,173,79,92,15,39,166,248,84,95,156,15,51,66,231,217,17,41,196,227,138,147,4,191,145,242,57,56,104,20,236,66,86,162,157,174,99,15,102,190,75,25,253,14,220,7,155,181,13,100,1,45,48,170,91,168,45,204,4,253,47,214,179,175,173,57,18,15,211,187,127,154,59,182,170,210,63,244,70,153,254,102,122,83,162,39,50,190,64,220,110,205,57,67,160,67,169,195,93,203,78,47,73,248,100,84,16,145,87,27,4,114,86,79,69,93,193,175,202,115,12,231,174,77,255,42,161,18,107,65,67,27,212,91,212,173,84,82,32,31,3,116,218,27,179,101,160,227,86,106,71,70,152,46,203,7,7,41,176,17,106,20,67,144,186,254,165,175,28,91,12,145,40,22,99,123,231,47,128,155,15,40,233,44,170,128,205,22,140,123,34,41,67,132,95,213,238,184,20,102,95,222,220,175,128,98,74,204,215,238,92,254,219,15,75,100,46,212,174,116,175,222,181,6,78,244,115,31,59,80,197,106,70,51,125,202,255,177,194,61,124,22,34,216,94,181,146,95,203,114,155,244,29,193,14,250,15,198,92,68,96,162,11,88,200,164,184,19,27,98,110,152,216,255,214,45,56,131,54,106,131,33,137,25,52,160,24,248,127,235,54,238,197,87,8,25,138,149,75,140,167,244,182,93,29,136,245,87,111,100,82,239,59,214,210,164,180,67,124,213,151,77,10,44,83,58,25,91,131,67,36,93,239,199,203,209,107,91,112,56,129,203,19,53,224,91,226,120,228,29,81,52,198,162,96,78,97,178,178,35,14,90,151,146,191,98,121,243,14,107,245,185,60,248,72,224,175,26,121,11,236,34,204,138,85,196,193,126,203,30,89,120,126,31,217,121,42,17,29,117,34,157,132,44,93,52,119,116,154,176,107,176,203,74,93,52,107,210,194,30,53,255,24,26,211,34,244,111,220,216,37,20,214,127,186,93,253,253,27,187,213,15,191,217,47,62,189,253,249,233,227,175,118,246,15,79,111,127,254,180,72,90,85,190,71,46,188,50,186,240,60,189,75,241,100,63,189,250,161,141,4,195,82,249,166,76,129,57,113,138,150,237,89,34,4,73,21,57,50,112,1,178,115,12,247,52,239,72,148,101,133,29,103,221,142,167,103,224,149,127,3,16,18,221,147,172,91,235,198,147,70,103,110,127,250,209,179,119,203,61,243,219,87,42,89,139,240,96,22,147,108,193,75,205,25,118,182,221,51,205,113,18,137,63,128,187,133,186,16,31,187,45,37,144,127,15,49,113,186,35,100,222,38,156,111,242,161,116,152,103,61,192,79,149,252,72,147,168,80,14,18,203,135,253,243,216,165,229,73,253,71,129,134,104,182,235,118,223,39,12,124,148,84,47,67,160,115,220,85,202,182,4,113,219,243,103,113,171,187,137,254,249,244,154,132,35,61,177,160,69,152,130,95,251,50,35,252,123,118,173,121,242,179,61,57,246,164,53,80,187,220,68,244,6,206,48,188,137,26,140,42,170,34,140,163,11,97,95,240,88,34,253,179,6,41,115,227,205,78,211,213,56,198,212,133,115,89,164,46,32,95,130,73,97,22,191,200,135,164,91,50,135,212,253,181,101,209,93,170,155,166,39,140,148,242,60,6,212,29,223,140,51,159,5,141,159,221,224,181,153,190,55,65,27,88,14,167,212,182,156,82,137,151,237,30,221,29,142,69,147,84,7,210,218,114,147,137,58,54,50,236,224,109,99,108,84,88,110,145,168,249,232,186,112,49,87,248,213,26,154,94,82,158,249,221,15,239,243,245,140,161,165,253,164,231,16,71,223,141,87,136,179,251,147,231,35,146,189,138,144,125,224,123,18,227,70,160,30,234,221,85,125,122,1,175,156,57,235,154,126,121,110,167,37,104,180,125,14,0,131,70,184,12,18,232,148,23,128,206,85,171,204,92,40,53,144,223,126,92,14,98,83,106,208,146,157,125,93,141,44,95,139,79,154,115,142,72,172,154,233,51,200,248,125,82,138,255,107,9,114,22,232,153,114,73,80,228,246,81,164,100,27,152,234,89,136,242,1,149,74,166,213,70,182,21,181,63,149,66,100,36,73,25,36,244,27,254,80,70,17,219,121,132,197,88,79,110,167,239,55,250,83,239,189,5,82,92,132,98,102,98,209,115,191,184,1,98,213,217,124,82,148,161,83,117,28,218,110,30,69,200,89,119,92,87,123,5,151,31,189,27,38,210,146,37,228,68,153,175,132,75,74,133,15,80,27,87,181,51,179,246,226,163,128,99,147,82,88,222,122,50,149,17,236,140,203,126,69,232,95,128,209,170,206,206,112,33,194,112,251,175,99,48,215,18,12,218,76,180,230,142,162,222,166,22,105,18,36,131,212,71,169,87,159,25,244,245,164,239,160,230,30,81,89,44,186,231,73,80,148,74,174,215,87,44,129,70,73,133,108,216,177,219,168,55,216,161,254,129,159,182,240,54,86,109,221,79,189,141,79,69,125,28,138,36,247,4,95,59,104,4,44,57,65,27,44,158,76,226,22,49,95,144,95,7,11,199,66,38,220,221,157,70,75,54,12,10,248,230,117,157,111,160,241,2,86,114,42,155,249,180,242,222,158,106,53,202,182,240,81,219,213,112,223,165,93,219,89,30,209,226,149,20,163,30,197,191,139,7,177,53,153,58,7,97,161,241,74,163,38,40,74,5,74,89,1,243,126,176,205,147,15,125,27,247,98,254,22,124,81,47,141,221,199,199,174,239,12,132,139,48,21,233,27,222,151,55,134,117,212,81,136,72,219,155,223,183,45,128,118,250,156,45,172,155,114,63,254,248,216,72,159,150,213,174,161,168,108,68,251,248,82,109,253,54,88,75,255,56,154,209,97,123,86,98,184,42,213,156,117,99,90,134,118,150,81,197,146,75,8,33,125,225,158,143,244,3,143,135,41,66,212,241,218,0,54,149,30,216,170,132,134,225,247,75,138,36,236,170,49,230,95,178,211,221,78,29,190,199,11,82,38,49,255,234,97,54,157,35,158,180,35,64,211,91,40,79,173,154,176,108,246,126,84,210,47,89,86,153,160,247,215,179,121,21,253,191,122,80,196,159,34,149,128,249,233,33,23,78,115,139,138,209,161,139,6,239,204,56,18,8,27,140,105,33,28,66,15,165,140,96,11,11,240,192,238,195,95,65,103,29,90,77,175,168,253,216,124,228,223,102,227,87,22,131,42,82,236,61,59,7,164,195,210,166,184,183,169,228,10,167,76,117,127,199,174,200,22,204,124,173,58,244,98,65,153,147,106,13,51,219,162,111,100,133,181,21,17,133,87,121,79,201,232,199,117,239,63,79,237,244,188,104,20,216,222,54,34,173,194,177,196,148,126,107,184,231,73,47,253,78,141,109,163,7,218,26,99,235,89,212,66,140,101,63,151,58,147,170,239,45,112,106,247,179,168,126,162,164,88,39,95,210,230,72,61,107,207,142,167,202,95,227,164,197,175,10,135,50,79,39,180,162,83,17,131,185,193,74,109,13,115,2,67,26,83,55,121,48,81,80,253,111,235,33,94,95,8,177,172,143,245,170,4,1,186,103,210,113,156,134,19,134,241,100,62,222,75,2,216,213,192,200,72,226,124,142,89,30,104,226,201,28,158,220,224,111,106,234,96,113,129,142,154,41,36,176,173,24,80,157,187,155,155,165,183,43,238,68,7,84,59,15,20,206,248,98,21,82,217,97,92,146,71,215,157,117,177,22,123,146,200,106,219,36,148,226,120,17,125,97,178,166,214,4,14,144,4,148,8,174,116,84,168,193,254,164,46,166,202,242,67,118,32,209,2,143,162,52,44,98,175,14,174,18,108,178,51,254,70,163,237,59,4,70,227,87,64,228,7,48,61,187,161,228,27,131,113,125,154,37,209,95,92,92,217,118,91,155,67,186,160,56,143,246,46,230,51,229,244,40,235,0,225,152,184,97,170,195,136,150,48,36,25,60,167,70,8,119,120,121,47,255,251,88,29,102,31,90,180,3,101,1,127,114,85,149,196,39,151,141,238,192,180,65,16,129,134,215,144,158,18,56,160,236,49,33,87,254,253,14,162,75,253,238,229,217,5,31,152,158,93,207,20,237,31,0,30,145,12,240,144,144,106,184,200,229,112,154,15,13,225,108,139,196,138,230,149,199,248,246,133,84,255,182,185,183,126,237,69,93,7,29,243,198,59,109,252,111,223,46,218,240,72,37,205,137,155,120,95,225,112,115,108,142,123,50,202,171,162,14,23,4,223,205,126,48,131,186,26,94,110,37,144,25,136,229,131,187,121,57,205,226,190,167,203,198,38,248,17,174,228,150,202,121,27,155,73,94,18,106,210,37,167,119,227,221,220,137,49,237,60,63,178,117,202,200,244,38,239,227,209,78,37,201,44,61,13,105,79,213,70,39,120,66,85,103,124,150,239,157,44,215,192,183,42,212,25,216,14,46,133,0,98,190,199,17,110,105,55,185,48,2,31,101,137,78,227,246,8,204,190,133,175,195,34,72,200,203,182,125,14,203,233,219,56,62,162,251,40,7,216,197,92,19,246,191,137,74,90,118,7,18,121,142,150,164,175,45,198,123,55,88,200,224,58,160,58,91,35,250,214,166,74,56,244,211,73,126,175,31,192,183,8,146,229,197,236,188,247,48,96,227,223,167,57,246,114,138,249,157,84,127,197,169,240,138,196,47,24,95,237,42,14,147,133,93,92,78,184,217,163,3,162,123,175,42,66,58,225,107,91,37,132,227,139,23,239,71,153,63,198,195,180,3,162,71,148,138,19,141,45,175,219,177,219,7,148,191,112,233,235,43,239,129,208,103,74,185,220,66,143,7,179,185,254,90,199,254,101,122,118,204,164,42,209,162,148,13,132,177,162,163,48,246,127,220,207,34,42,90,6,121,8,183,1,197,227,197,108,238,176,35,90,233,158,25,43,102,63,252,111,48,236,212,50,137,40,68,64,35,40,249,170,73,78,101,109,143,176,122,82,175,58,152,143,112,178,149,230,46,139,85,233,237,132,9,15,249,234,205,134,57,20,105,21,60,133,172,47,25,81,148,3,150,79,182,8,119,237,193,86,31,122,151,57,221,22,105,209,17,104,27,152,42,167,174,77,29,128,119,54,140,189,247,133,6,254,227,28,126,70,239,16,188,27,86,10,28,63,178,70,50,57,203,17,23,19,101,31,97,141,219,65,103,19,107,47,34,175,119,191,127,120,251,243,34,203,165,229,225,242,213,127,125,162,234,254,7,139,247,87,246,55,15,190,154,249,255,251,204,134,167,189,39,127,247,54,68,59,185,137,5,168,161,94,25,64,73,107,87,251,35,247,2,47,104,246,60,14,234,39,17,5,94,197,66,74,111,68,190,2,184,238,136,126,175,175,222,157,247,161,99,162,139,224,61,122,232,140,196,252,239,101,177,200,63,10,205,10,175,126,48,221,73,57,10,51,134,232,167,157,212,128,163,39,118,207,16,183,119,204,90,52,105,87,124,109,235,211,30,54,79,231,160,118,154,189,178,63,108,68,20,225,61,185,153,61,143,253,131,82,167,233,254,149,18,237,191,249,179,137,155,191,241,97,7,207,160,59,106,228,217,83,97,100,188,101,89,138,219,11,252,194,191,254,101,134,195,72,24,11,245,108,224,42,218,21,135,56,131,18,3,1,88,13,49,80,182,56,201,5,59,159,82,126,13,187,151,55,217,168,146,164,164,240,11,119,215,211,227,188,109,211,171,7,162,16,220,148,168,104,33,1,229,213,254,233,113,61,25,126,211,89,251,11,214,54,10,152,32,42,45,11,228,127,27,228,179,90,72,241,207,63,87,125,136,15,48,205,4,40,106,205,111,153,38,145,85,85,63,222,208,141,253,234,226,217,239,164,171,40,164,240,200,20,148,180,6,236,15,95,52,231,157,253,31,231,242,92,77,112,80,200,195,107,225,219,0,199,91,40,253,84,254,191,117,64,152,155,106,27,151,21,27,232,8,7,0,139,122,55,61,130,133,204,224,83,56,254,242,119,9,71,38,37,89,181,140,98,172,160,220,158,115,123,189,159,150,167,158,96,196,94,57,57,177,174,177,116,23,158,197,103,143,196,65,121,43,70,54,39,73,122,223,38,205,220,2,175,10,10,255,55,187,243,190,33,221,93,36,224,31,209,138,199,211,187,84,238,198,122,12,146,19,200,72,190,132,29,104,47,14,4,119,182,117,101,30,136,237,195,169,220,118,236,39,97,184,222,152,91,159,13,15,205,171,171,95,156,174,3,38,53,147,88,127,59,54,237,220,235,100,246,224,31,33,211,195,94,141,224,25,194,162,46,91,184,106,140,77,203,245,27,159,50,178,76,135,178,101,214,73,253,85,6,196,156,80,188,217,238,226,177,181,81,45,145,14,111,24,172,98,218,240,159,11,201,243,233,115,158,189,43,209,187,70,25,79,158,30,44,64,222,193,120,250,55,83,163,240,49,177,111,154,170,92,177,50,198,60,210,44,181,12,36,192,213,110,250,45,140,103,24,135,116,28,3,215,104,157,36,247,105,92,254,99,171,93,230,250,206,30,126,200,223,243,211,35,156,190,143,134,22,145,191,129,14,98,232,26,39,241,75,139,240,243,6,10,218,80,103,63,188,157,125,247,241,247,79,41,241,23,31,160,75,10,53,136,56,69,145,154,68,70,88,8,109,70,78,45,33,11,209,140,96,116,231,80,182,163,232,234,148,9,22,59,130,202,37,62,69,40,63,220,167,218,2,185,78,133,189,250,253,178,134,134,214,15,160,39,252,104,239,172,236,170,21,81,168,133,138,45,81,228,213,107,89,195,143,250,80,10,204,206,25,197,94,89,200,146,180,157,120,64,121,14,20,107,103,189,70,134,101,206,92,25,140,199,89,66,214,1,230,117,21,123,56,9,131,170,214,209,165,7,79,120,92,13,139,128,216,215,231,200,98,36,161,37,145,15,74,111,156,133,140,93,214,98,134,14,254,93,38,57,138,142,158,85,55,140,106,185,39,228,137,78,18,155,33,159,231,62,244,117,247,158,212,12,23,17,35,236,221,182,142,253,76,216,160,199,81,109,42,214,114,236,180,251,5,163,29,97,209,201,118,251,14,51,67,123,59,228,0,49,45,44,28,112,15,39,105,151,17,213,178,208,227,113,141,218,106,178,115,23,169,191,137,84,240,176,204,231,235,164,13,163,71,116,62,165,189,214,154,238,32,198,191,237,226,149,64,216,80,114,160,170,100,177,160,237,55,59,43,255,50,251,5,144,218,46,1,55,125,231,99,21,161,108,182,72,91,57,22,251,98,171,254,18,139,75,197,115,112,177,175,89,70,146,230,246,92,37,172,206,95,222,46,113,70,250,121,144,9,239,104,4,224,45,9,249,129,155,199,173,237,202,104,0,239,111,207,145,243,143,60,198,37,45,161,12,85,67,23,122,193,252,23,1,103,112,178,214,237,222,102,245,143,10,139,162,250,225,147,146,41,222,35,171,180,42,206,150,218,190,188,199,66,233,163,35,49,191,237,81,121,238,248,179,29,124,74,177,220,183,136,110,83,62,163,68,132,105,168,233,23,103,100,151,113,9,103,219,158,214,149,167,245,44,117,191,102,3,118,223,16,208,56,86,88,159,126,23,200,28,49,63,54,46,88,231,45,222,29,248,143,247,126,153,12,11,162,134,194,12,208,25,193,4,237,93,121,94,128,2,251,249,182,116,191,94,93,100,235,122,14,41,251,109,83,65,148,0,15,135,207,196,57,226,149,25,9,145,129,90,119,176,22,191,212,40,45,238,225,55,191,153,37,254,164,217,27,40,137,114,243,192,63,183,22,39,238,89,190,10,60,71,220,158,89,151,131,106,53,127,182,231,197,197,205,247,188,250,24,135,176,181,212,242,236,25,70,175,118,51,41,242,228,186,153,216,183,169,229,68,29,212,207,65,59,85,13,159,109,20,17,192,164,229,139,89,28,48,20,46,50,62,104,83,110,107,72,210,50,206,104,247,7,28,201,140,218,195,11,123,253,78,231,30,111,17,0,86,164,185,68,127,189,203,154,1,246,101,88,1,180,81,184,206,36,210,16,120,121,69,84,75,78,207,194,188,61,20,43,230,235,240,165,115,47,252,58,185,58,158,98,237,246,84,2,227,198,250,148,204,133,106,165,221,20,2,45,0,135,98,61,78,231,164,38,95,13,175,32,69,253,58,69,64,153,10,231,0,211,121,211,6,200,253,206,110,32,251,125,144,214,39,183,201,5,235,172,242,114,228,123,98,106,88,180,252,10,82,51,187,182,135,146,184,225,27,191,97,58,39,241,171,49,235,242,135,131,139,206,250,241,9,30,108,77,174,183,82,189,231,32,181,127,109,207,212,13,126,18,96,105,163,253,21,141,145,209,191,18,237,194,142,88,19,107,128,62,23,233,33,152,125,196,252,140,141,24,191,11,6,101,33,166,218,218,220,1,213,142,117,232,133,177,252,52,96,221,252,173,192,126,1,173,65,246,192,30,231,16,120,195,16,246,135,132,131,237,42,79,87,209,124,52,235,185,237,33,4,126,75,21,79,120,40,241,102,92,239,194,86,22,52,31,115,14,115,126,19,191,116,237,170,4,216,232,160,127,16,112,228,64,143,109,226,112,178,237,135,124,223,83,73,83,217,29,85,18,57,227,250,44,90,225,96,76,134,53,150,214,110,80,240,247,200,65,40,191,129,4,186,122,251,203,211,251,143,63,253,246,246,58,15,158,18,236,155,185,164,162,223,81,103,46,17,169,89,71,227,63,202,67,69,140,162,205,239,229,113,212,251,17,252,251,216,48,16,145,75,88,76,79,96,102,50,82,8,66,57,210,128,168,83,27,159,65,162,54,82,177,178,173,168,177,129,17,52,21,130,199,25,185,120,230,144,55,30,202,198,9,60,148,196,217,116,119,2,130,181,217,249,6,23,78,68,249,159,159,226,180,28,96,174,134,56,89,175,254,178,74,16,138,153,227,233,66,34,208,157,66,56,94,169,191,101,139,7,20,1,144,25,39,135,64,175,176,137,190,142,251,145,0,232,119,29,63,38,188,222,105,151,85,99,177,202,17,185,78,37,228,156,36,165,251,176,77,105,163,82,67,186,209,55,169,11,213,245,213,198,182,37,225,109,61,137,99,243,104,91,72,168,33,80,126,176,112,219,228,100,179,37,35,222,19,187,206,80,49,196,57,35,102,44,255,116,133,192,251,28,220,190,133,235,146,96,125,236,225,115,59,246,132,224,246,243,81,31,143,133,29,41,90,40,96,46,58,69,7,36,157,250,125,246,169,69,78,52,59,56,179,80,55,118,219,185,115,180,242,244,50,255,226,34,188,11,214,111,158,32,134,161,84,79,236,95,232,121,202,238,191,76,95,55,209,253,23,251,137,148,218,246,208,202,41,36,92,91,70,95,245,168,66,241,212,218,161,112,179,108,96,192,155,245,237,80,90,153,30,228,62,69,69,229,185,234,153,164,35,10,194,175,87,244,174,37,0,1,67,205,20,157,201,155,251,142,122,143,254,45,134,108,29,141,83,80,177,76,173,126,237,58,236,187,196,20,41,71,108,161,201,225,104,6,191,112,209,143,74,113,120,255,188,112,164,186,55,5,18,173,128,43,19,67,27,231,199,124,209,80,163,6,15,109,94,121,149,9,17,166,44,134,109,210,253,121,17,61,230,128,210,247,186,240,8,75,252,127,1,80,75,3,4,20,0,0,0,8,0,152,137,108,33,187,12,170,55,103,50,0,0,96,149,0,0,3,0,0,0,115,117,109,236,90,125,112,83,215,149,191,239,73,182,133,48,32,11,3,54,129,228,249,3,108,62,100,190,41,113,160,22,216,230,43,14,166,216,164,73,219,173,44,75,178,173,169,44,57,146,76,76,119,119,80,178,36,27,178,109,42,28,151,48,45,105,100,175,215,161,153,108,74,58,36,195,108,221,197,147,178,105,232,100,91,173,135,101,152,9,179,99,18,182,117,51,100,235,206,166,13,155,146,106,127,231,190,251,172,251,4,164,233,238,204,110,255,136,60,215,239,156,123,207,57,247,124,221,143,39,157,67,141,77,219,21,85,97,211,31,21,127,140,41,76,153,121,28,207,245,140,29,221,203,251,215,51,141,229,177,106,182,144,45,0,150,207,123,20,26,231,159,148,104,121,2,183,160,93,200,10,101,69,226,105,21,79,69,250,143,79,165,69,111,224,159,30,169,180,50,181,82,208,43,111,66,228,102,0,5,98,28,58,86,218,48,110,19,2,158,16,207,2,250,183,170,55,22,93,21,10,182,175,10,249,107,98,145,154,53,98,172,30,109,31,218,54,102,254,108,32,22,1,223,39,158,247,162,185,209,214,162,109,66,91,132,246,89,180,45,236,246,159,187,197,115,9,218,118,180,38,105,172,58,135,182,82,60,239,20,207,58,180,26,105,252,158,28,250,61,226,185,49,167,159,124,82,47,224,187,208,26,208,40,94,159,19,125,85,104,159,65,107,70,219,137,166,161,185,208,150,161,237,254,24,91,254,20,62,139,209,202,37,188,12,109,57,218,29,31,195,179,238,19,200,93,136,70,57,177,90,224,75,115,198,87,160,213,10,184,2,173,81,26,91,201,216,116,206,239,66,219,138,182,227,150,179,40,122,254,91,178,185,62,41,112,85,199,45,13,2,183,232,184,205,47,112,61,231,21,123,82,224,121,2,63,41,240,124,29,231,235,147,240,2,29,191,203,224,215,215,132,162,49,129,207,16,120,161,192,237,2,47,22,248,76,129,107,2,231,116,198,218,3,62,75,224,54,129,207,22,184,161,223,28,29,95,114,90,224,14,129,167,5,110,172,125,67,31,103,14,62,55,7,47,206,193,231,229,224,243,115,240,5,57,120,73,14,94,202,248,126,118,103,43,158,43,157,186,191,108,134,253,69,186,253,243,133,63,227,98,124,49,244,31,166,113,161,108,57,240,41,60,173,69,186,61,171,152,240,103,145,238,207,45,24,239,146,232,183,3,127,95,162,111,102,106,149,91,167,207,252,26,143,86,140,95,135,90,238,50,125,252,65,224,43,37,254,118,195,255,130,190,15,248,152,52,126,8,248,155,18,126,24,252,113,9,255,58,240,115,98,126,138,199,128,200,143,19,78,61,63,190,133,241,189,18,125,10,254,185,132,103,147,176,255,5,200,191,33,141,191,12,250,132,132,159,97,202,188,1,136,26,19,244,231,141,252,16,250,142,139,124,48,230,255,5,240,175,73,252,191,2,253,148,132,255,214,240,135,240,215,13,140,95,202,142,43,170,225,79,221,95,138,29,254,220,148,245,175,226,96,138,19,249,168,20,235,250,40,243,65,63,154,157,95,161,120,54,72,242,42,128,111,146,240,106,224,103,36,250,85,192,109,210,248,70,224,99,210,248,22,35,255,117,123,149,207,27,249,46,240,47,3,47,150,248,253,240,63,237,249,155,133,126,7,144,63,142,108,254,40,127,197,20,126,254,25,252,79,50,125,61,210,124,200,51,229,25,200,251,146,36,239,59,76,41,44,20,56,201,59,133,248,81,124,68,126,43,163,224,47,17,242,145,223,202,121,208,147,127,95,20,227,63,133,255,54,75,254,123,27,242,223,144,236,251,53,112,77,154,239,67,224,199,179,56,46,12,10,31,46,116,242,253,69,45,128,63,174,74,227,115,160,207,139,211,250,116,6,226,145,158,56,243,120,26,90,155,247,121,154,118,181,180,122,60,204,19,139,123,163,113,22,13,120,253,172,39,26,233,140,122,187,61,97,111,119,0,100,245,18,217,129,142,158,104,48,28,239,96,158,64,248,64,48,26,9,19,224,103,158,96,164,29,148,29,161,88,123,47,198,118,52,53,111,219,218,228,105,222,190,189,165,177,213,211,186,117,91,83,163,135,121,227,129,190,96,156,241,127,177,120,52,16,141,70,162,12,138,112,93,130,97,244,214,244,70,3,221,44,230,237,8,120,184,30,29,190,80,36,22,32,125,49,25,243,232,122,131,52,30,136,134,189,33,230,105,120,112,207,214,251,118,213,51,46,202,195,21,243,144,238,92,111,76,17,246,117,247,48,67,95,93,69,93,5,161,58,248,194,17,54,173,72,16,134,232,51,70,122,2,97,234,241,70,59,73,14,137,1,6,66,230,217,187,175,185,190,177,97,255,190,70,120,100,207,189,91,119,52,26,230,121,2,126,111,220,203,58,56,175,199,227,143,120,58,67,145,118,111,200,227,143,71,162,49,195,141,141,123,26,200,217,176,168,15,86,227,86,228,57,16,136,198,130,80,166,163,35,212,27,235,50,113,250,56,167,48,59,20,9,119,26,49,211,165,116,123,131,97,97,123,119,32,22,243,118,6,60,190,72,111,56,206,132,72,132,20,182,19,83,71,48,68,113,1,30,34,229,58,224,109,102,4,82,18,239,137,132,67,7,25,148,242,77,95,212,248,58,47,211,207,4,190,39,172,39,88,211,247,191,165,250,89,192,247,190,42,3,198,62,177,193,128,145,131,123,13,24,251,203,58,3,198,94,230,18,48,173,235,45,6,140,53,186,213,128,145,208,247,25,48,246,226,74,3,198,62,113,143,1,99,15,169,53,96,236,159,43,12,24,107,115,187,1,227,28,208,12,24,123,114,181,1,99,125,214,24,48,246,194,181,6,140,117,181,199,128,113,230,44,230,240,168,67,99,19,150,148,123,200,146,106,56,81,145,210,18,73,108,130,9,102,77,98,167,115,179,237,245,138,190,182,119,38,157,26,46,170,219,235,8,119,51,235,207,233,9,26,71,191,131,21,125,115,165,166,14,168,41,235,128,213,109,199,33,121,228,152,243,202,251,23,202,199,232,98,187,85,167,223,190,94,60,55,208,243,145,31,77,216,12,185,227,170,86,152,24,58,148,113,38,216,236,1,167,86,152,134,156,196,16,194,144,96,246,126,232,70,52,232,119,244,171,109,202,209,229,109,106,90,101,118,26,95,123,54,243,17,245,165,250,221,68,91,8,186,29,68,59,4,25,71,161,15,232,138,158,123,77,191,20,165,14,215,101,156,103,51,55,168,159,232,160,199,172,164,179,162,242,145,31,79,216,30,193,109,233,217,119,206,38,19,35,124,206,25,112,202,17,208,28,73,58,203,75,144,16,59,251,157,109,9,208,219,47,168,131,83,171,49,62,87,31,39,127,156,68,127,193,184,234,157,34,28,176,21,125,105,55,107,252,47,248,165,68,150,61,162,219,81,63,236,44,31,38,254,116,190,155,165,203,57,223,145,177,242,178,52,46,130,59,113,81,222,137,75,96,61,206,157,6,226,135,95,75,7,230,181,107,199,230,105,213,240,247,231,142,67,70,98,168,46,3,29,29,176,63,90,126,54,243,193,112,113,251,112,113,130,229,3,143,113,159,157,205,252,39,241,66,79,11,198,127,53,92,172,13,31,202,100,206,39,29,154,226,56,155,185,70,99,52,103,90,45,187,68,244,229,176,135,240,172,77,229,152,171,113,28,54,189,129,231,143,193,199,64,123,65,196,35,143,104,33,239,149,164,110,15,201,25,29,26,97,54,196,110,102,81,86,198,166,231,206,37,88,63,215,87,99,75,19,172,100,132,230,79,176,5,68,3,187,108,196,151,24,98,37,243,19,204,73,125,101,92,150,119,244,232,114,196,45,223,109,211,249,89,145,224,87,137,63,109,45,27,77,170,120,86,234,188,249,103,51,239,131,198,33,244,72,11,29,41,15,142,64,247,225,164,179,236,58,249,11,186,21,144,125,228,131,113,213,183,105,30,143,149,162,12,56,135,54,129,238,41,248,100,174,28,171,20,244,30,70,35,95,205,229,180,141,3,253,206,246,77,70,78,74,253,71,209,239,30,234,199,89,132,126,196,79,131,141,141,194,151,71,134,48,191,49,47,98,157,166,113,244,215,141,56,43,50,105,171,155,37,213,186,12,201,132,15,242,211,149,110,172,141,198,4,100,23,65,70,62,249,104,220,218,102,77,34,191,211,149,109,214,113,187,155,209,26,193,252,51,19,95,211,104,125,230,13,91,83,202,209,245,220,175,150,148,202,138,7,1,167,172,108,6,226,252,203,84,33,155,155,46,108,43,76,60,169,105,160,157,75,241,34,93,12,251,97,59,244,103,99,199,96,139,100,207,23,36,59,55,159,114,212,101,208,183,79,232,180,137,112,137,182,89,162,117,12,28,254,91,162,221,145,228,49,227,62,159,73,125,194,126,150,51,239,16,205,11,153,21,36,115,37,226,59,96,125,254,247,34,119,246,82,76,33,107,205,55,107,83,246,196,72,155,98,213,243,142,198,218,208,191,162,95,215,225,200,128,179,29,121,212,110,147,252,88,144,46,7,238,208,224,173,198,213,160,179,99,14,251,41,145,171,224,183,93,80,53,107,191,154,82,198,203,53,43,209,165,151,39,24,141,27,241,183,212,101,62,120,212,225,75,62,251,78,66,25,66,255,73,115,30,56,115,243,0,125,165,148,231,35,136,87,98,56,67,118,207,88,82,151,185,142,121,107,73,199,17,225,119,35,7,104,44,85,112,118,138,114,174,223,202,156,110,102,121,8,126,177,13,32,135,96,231,44,125,205,184,237,27,207,102,174,159,204,195,28,136,103,218,206,156,180,207,81,63,114,254,198,144,213,109,67,140,167,104,28,54,23,11,253,110,229,231,157,230,248,54,188,45,233,95,167,199,183,129,246,132,185,208,247,30,194,5,221,37,57,182,232,171,35,94,162,51,98,75,125,183,153,115,133,136,109,149,200,151,34,240,94,236,119,250,50,3,143,149,101,22,33,87,41,183,7,242,42,140,120,119,97,252,85,196,122,6,98,109,236,49,34,214,13,167,62,89,172,27,94,249,159,196,154,214,250,111,171,82,123,175,87,165,90,63,172,74,61,32,246,145,211,98,95,204,39,156,206,143,207,224,9,217,179,146,243,223,70,188,27,70,72,246,205,103,68,123,15,198,30,161,51,130,232,137,22,58,45,68,223,179,3,5,169,189,124,207,87,125,155,105,255,18,118,206,72,151,251,54,99,252,120,146,246,121,248,132,120,132,255,35,144,215,39,236,46,129,221,37,57,118,151,8,187,31,54,236,46,146,244,185,149,221,250,158,216,240,48,141,139,115,206,170,159,199,13,123,228,179,234,28,222,16,18,169,20,223,71,31,119,48,245,177,234,137,146,199,54,165,74,18,169,196,12,244,241,51,155,108,56,183,91,167,195,153,122,253,117,59,221,3,180,233,51,157,252,250,42,100,230,97,206,215,216,224,36,61,63,100,131,215,232,249,6,27,28,77,12,178,197,200,117,87,226,121,55,173,237,21,135,203,216,226,199,171,220,10,230,176,0,159,119,198,193,44,223,167,117,48,226,94,132,117,240,155,39,202,216,162,195,24,255,78,25,83,79,49,119,233,203,53,154,250,126,254,88,201,227,150,177,210,191,174,158,80,207,229,143,89,206,45,29,43,249,126,62,214,8,120,176,70,62,120,127,233,152,5,107,228,231,196,123,6,242,37,121,87,30,101,238,69,38,57,5,238,63,36,231,2,241,108,128,254,100,195,58,180,41,216,113,46,223,123,237,240,82,166,190,158,63,56,121,152,37,192,59,56,57,181,212,123,77,206,47,186,11,205,19,231,171,216,3,70,211,229,131,215,210,229,87,38,197,217,127,89,191,59,52,148,34,54,9,158,39,229,222,171,233,61,140,206,78,23,157,93,120,174,16,252,42,198,38,16,239,162,83,249,154,226,20,57,42,228,80,255,76,234,71,14,95,21,107,151,222,177,40,119,243,104,92,210,97,66,214,81,240,159,225,103,176,149,206,86,141,206,179,130,23,17,67,156,245,63,67,126,44,60,77,249,233,208,207,94,177,78,46,139,117,82,192,241,221,92,95,226,251,118,98,100,194,184,27,76,160,143,244,92,85,38,244,212,215,65,217,36,238,23,215,112,134,83,78,217,141,123,4,246,55,155,42,228,97,222,8,173,11,232,62,123,158,153,247,26,120,71,5,175,133,250,199,203,203,38,65,103,37,58,126,63,40,31,28,77,171,131,68,51,31,235,101,38,221,41,198,113,167,72,239,118,235,62,69,92,105,60,189,155,246,84,253,206,68,184,49,7,201,135,204,107,89,127,176,249,152,171,202,184,155,232,107,180,254,27,88,163,73,97,115,217,2,65,59,128,249,47,8,31,221,194,86,27,237,225,100,227,60,221,198,141,194,198,89,69,34,79,184,61,234,224,36,217,73,254,144,99,76,62,130,109,60,111,174,65,63,241,28,229,115,171,87,184,158,210,61,140,207,127,1,243,167,249,252,9,219,90,156,21,23,202,175,140,58,18,202,203,180,55,147,188,155,124,51,29,79,221,55,192,231,75,243,79,136,62,235,2,158,87,202,115,36,103,30,31,27,28,237,135,237,227,240,189,225,39,228,248,25,208,28,195,158,171,224,124,188,227,37,7,115,194,214,253,132,15,56,121,222,115,155,158,6,61,229,12,249,133,223,55,243,221,51,210,187,53,37,185,80,115,37,82,200,187,54,156,35,36,27,253,73,149,246,205,4,211,233,149,57,134,12,99,206,113,240,37,134,218,92,144,53,155,206,222,196,243,180,215,42,249,60,150,187,49,143,174,191,141,206,129,67,153,223,255,19,229,182,232,251,136,104,168,255,5,113,134,188,141,28,79,23,114,191,136,119,17,138,95,219,22,76,111,75,231,143,177,33,43,238,102,77,250,56,114,234,195,113,208,82,191,160,191,131,238,144,203,40,6,121,144,131,126,218,171,145,55,229,3,149,110,253,253,5,58,190,154,63,225,152,192,120,170,210,141,59,79,253,157,156,127,152,217,144,147,167,19,195,19,68,99,125,65,242,31,209,27,115,96,206,119,233,14,152,248,59,126,158,148,210,190,14,59,74,136,79,248,101,204,184,19,27,235,239,34,124,245,204,242,9,53,231,236,58,126,33,159,238,159,219,254,229,98,190,123,38,158,55,144,203,151,199,209,200,223,136,217,247,176,238,47,147,92,200,58,160,231,104,217,40,221,73,176,78,70,13,31,96,108,221,176,131,45,72,91,39,140,247,183,60,190,231,192,79,144,113,63,246,157,51,57,122,221,37,199,15,115,149,166,213,186,27,105,30,67,158,139,211,185,44,233,122,70,232,58,114,209,58,134,23,33,54,167,44,71,198,69,200,200,225,153,36,158,139,187,233,125,116,219,241,75,224,43,227,231,225,182,215,100,59,201,70,200,123,23,57,80,39,108,160,189,107,25,209,46,224,107,137,214,88,130,246,148,233,119,166,36,206,89,228,57,230,78,241,252,3,255,98,178,83,178,113,86,174,239,143,169,99,165,102,253,124,37,194,166,135,46,170,153,27,120,158,200,213,43,189,39,65,62,174,133,62,175,145,126,152,103,12,207,90,97,71,82,166,79,60,207,231,181,16,223,213,42,198,198,173,19,148,183,60,30,148,223,176,173,16,252,167,210,229,110,242,223,75,83,192,245,117,194,230,200,107,201,136,131,42,236,69,204,47,211,122,57,148,249,232,131,241,221,110,99,191,159,222,219,111,23,87,89,150,83,188,159,45,184,41,174,62,183,240,193,234,139,234,21,138,195,156,185,146,12,228,165,173,244,102,158,54,41,174,229,151,44,101,151,179,239,177,21,9,196,225,242,92,241,94,169,159,11,94,236,125,44,74,254,35,157,117,127,209,251,85,217,229,41,172,76,97,219,24,217,70,247,49,242,169,116,174,225,29,59,197,114,229,25,239,196,88,123,181,88,171,139,210,187,83,138,228,7,167,240,131,113,30,23,60,83,163,149,200,54,240,119,61,167,239,137,28,187,78,234,190,216,250,222,51,181,19,252,254,123,20,124,71,107,181,18,204,121,14,60,91,201,6,202,7,204,185,5,247,152,18,204,171,138,252,152,142,85,58,27,163,25,226,30,176,138,206,121,121,140,206,36,113,134,158,145,109,3,109,37,217,151,61,155,249,217,82,178,224,230,88,115,217,100,151,164,255,27,66,255,31,146,254,52,254,52,198,159,174,109,43,193,60,231,164,92,158,41,114,121,6,229,242,199,157,35,198,93,137,108,125,249,179,154,233,187,149,233,239,74,16,191,99,200,239,227,124,111,255,232,39,223,194,243,20,226,120,123,90,118,199,113,7,91,4,218,179,127,4,237,105,208,42,185,180,137,145,20,43,198,94,157,210,223,125,102,97,124,97,5,191,111,241,239,199,74,225,139,23,72,206,41,188,231,97,255,200,75,91,125,244,126,101,197,62,79,223,21,57,114,238,99,244,157,88,137,88,179,51,82,78,196,215,202,24,189,139,164,172,154,149,96,177,255,255,142,127,151,38,241,162,165,114,228,252,63,124,183,182,117,163,252,221,154,164,95,202,128,51,248,208,119,143,198,83,124,196,239,151,90,159,212,23,3,222,35,190,179,188,192,105,20,173,75,224,151,166,121,164,143,241,165,115,87,32,196,249,98,7,99,7,232,217,26,61,168,181,45,137,105,46,23,141,84,105,29,145,168,214,29,137,6,180,96,24,96,183,55,14,166,26,188,203,236,167,111,155,107,53,80,126,177,121,111,235,174,230,61,127,86,83,83,163,125,113,251,174,166,70,130,236,198,60,123,233,59,102,205,215,21,240,125,37,214,219,173,121,195,126,173,61,20,241,125,69,227,95,84,199,184,252,128,215,215,165,17,103,141,221,174,105,174,168,102,250,248,3,29,1,111,92,115,197,86,106,189,177,128,182,173,165,65,227,146,66,157,145,104,48,222,213,173,119,175,185,87,151,27,35,9,32,117,185,200,34,93,2,141,183,28,140,197,3,221,218,253,183,226,221,176,102,173,214,126,48,30,136,101,69,208,71,119,129,80,34,24,235,9,121,15,106,241,174,96,76,227,221,100,9,253,150,48,77,44,60,10,56,210,27,239,233,141,107,70,135,228,185,44,151,253,243,152,95,11,71,184,221,43,53,120,225,225,174,64,152,99,26,166,112,173,212,232,7,16,45,22,7,135,55,234,135,16,136,132,91,163,49,17,112,152,225,130,251,13,71,187,196,51,42,158,75,4,221,146,213,27,66,189,218,146,13,33,191,142,107,98,96,9,245,162,115,73,172,86,35,188,86,12,236,109,110,217,245,64,211,131,158,250,230,125,251,26,235,91,153,203,101,200,171,213,232,23,18,216,128,244,168,34,29,189,221,237,193,206,222,72,47,215,65,30,119,185,136,194,31,9,196,194,85,113,56,59,20,121,24,134,107,222,104,103,111,119,32,28,183,223,36,207,247,71,210,131,58,26,120,168,55,24,69,200,114,8,137,174,55,28,13,248,34,157,225,224,87,3,126,179,82,246,219,143,115,37,166,211,150,211,5,67,161,64,167,55,100,144,184,224,111,159,93,30,15,31,240,134,130,254,219,142,139,254,91,169,58,77,188,99,207,126,141,126,10,234,141,7,67,49,109,77,205,26,170,152,208,127,187,197,154,85,41,54,133,226,183,226,89,88,211,36,218,42,106,23,242,68,141,2,164,168,84,135,145,47,106,24,232,247,115,250,45,211,248,157,222,34,126,27,165,58,7,250,141,151,126,7,165,223,136,23,136,26,134,2,81,219,96,163,162,7,166,215,39,20,230,238,23,159,244,99,97,108,245,106,188,43,42,58,188,25,240,148,128,119,2,126,79,192,173,128,223,21,112,27,224,95,8,56,4,248,170,128,251,0,95,17,240,97,192,255,38,224,36,224,183,4,124,2,240,37,1,159,4,252,175,2,62,13,120,92,192,99,128,127,38,224,55,1,191,41,224,75,128,207,11,248,42,224,215,5,60,5,248,71,2,190,1,120,76,135,21,27,224,31,10,184,24,240,63,40,236,22,27,171,222,85,199,148,138,169,219,184,104,154,197,170,255,54,255,105,109,202,159,86,109,138,81,51,103,196,167,48,7,47,201,193,43,224,207,16,55,67,247,231,221,70,45,0,211,253,189,211,176,87,209,237,189,63,135,255,75,226,140,166,239,26,201,254,32,83,52,170,79,115,43,250,220,81,113,166,27,227,127,193,148,217,195,162,48,144,228,31,193,124,39,72,142,192,191,33,252,105,208,63,199,20,7,232,149,107,98,252,239,115,230,127,37,7,255,71,240,95,149,248,127,10,124,82,194,223,2,62,33,225,87,153,50,119,146,146,82,200,127,15,56,213,234,52,8,156,106,73,174,101,233,21,21,203,135,214,198,176,62,174,204,195,248,101,105,252,78,179,62,74,117,14,190,62,7,255,108,14,190,51,7,111,65,124,218,68,124,104,190,160,129,235,241,81,250,48,255,155,217,248,40,143,231,240,127,221,92,171,164,12,48,83,173,146,50,100,174,85,82,190,107,174,85,82,94,50,215,42,41,63,96,166,90,37,229,188,185,86,73,25,55,215,42,41,111,153,107,149,148,9,115,173,146,242,239,230,90,37,229,63,204,181,74,170,213,92,171,164,206,52,215,42,169,14,115,173,146,90,106,174,85,194,25,100,170,85,82,151,154,107,149,212,149,230,90,37,117,163,185,86,73,221,98,174,85,82,27,204,181,74,234,126,115,173,146,250,101,115,173,146,26,51,215,42,169,127,110,174,85,82,31,53,215,42,169,79,152,107,149,212,167,204,181,74,234,49,115,173,146,122,194,92,171,164,14,153,107,149,212,239,154,107,149,212,239,153,107,149,212,211,230,90,37,245,7,230,90,37,245,53,115,173,146,122,222,92,171,164,190,99,174,85,82,223,53,215,42,169,83,230,90,37,11,214,143,92,171,100,153,99,174,85,178,204,103,166,90,37,75,133,185,86,201,178,220,92,171,100,217,108,174,85,178,236,100,166,90,37,203,126,115,173,146,229,11,230,90,37,75,216,92,171,100,249,75,115,173,146,229,113,115,173,146,5,235,137,15,139,90,37,203,211,230,90,37,203,183,77,181,74,184,232,50,95,52,30,172,137,49,220,182,122,3,49,215,3,222,26,31,117,197,226,189,29,29,0,111,42,152,241,120,123,251,88,167,207,183,214,227,139,116,247,4,67,1,127,13,195,21,220,23,240,196,35,30,94,163,3,161,96,140,117,69,30,158,174,190,161,242,23,92,216,98,122,47,127,45,106,143,249,61,160,164,226,153,0,235,165,23,30,214,229,61,160,151,38,121,98,113,127,48,204,95,155,178,52,188,20,7,130,245,138,26,0,61,145,88,176,47,116,16,122,68,113,229,140,179,142,96,52,22,247,132,35,97,42,121,138,68,253,1,94,158,19,232,243,117,121,195,144,222,125,208,19,12,251,3,125,44,228,205,146,101,171,158,130,241,32,238,155,95,13,176,48,46,140,96,137,138,137,214,144,45,222,142,128,139,20,3,44,76,2,20,10,182,147,31,254,215,254,2,119,184,38,246,105,221,216,167,117,99,31,87,55,198,244,251,43,221,159,134,208,102,137,87,78,250,212,248,141,187,43,94,49,55,101,251,143,72,112,227,102,3,114,87,87,44,107,233,13,55,183,104,27,106,214,107,157,129,48,214,137,79,219,221,27,58,168,173,185,251,110,156,255,94,188,93,181,212,175,171,89,163,249,3,7,180,213,119,107,247,121,245,33,59,219,81,95,95,171,85,227,181,106,153,182,182,102,99,205,186,79,137,255,143,136,67,126,224,45,59,128,243,208,173,106,108,218,174,85,55,221,235,90,131,16,86,183,172,218,181,108,153,136,46,229,200,111,112,116,208,158,95,192,115,68,191,191,110,149,224,29,155,179,121,113,127,34,11,247,73,240,147,18,252,178,4,255,68,130,39,179,176,178,82,130,123,36,248,41,9,62,37,193,255,44,193,191,148,224,223,101,97,117,182,4,87,73,112,171,4,71,36,248,111,36,248,191,217,57,255,40,75,138,234,142,87,247,123,111,103,4,246,236,14,26,15,38,135,56,33,19,178,192,48,59,221,239,231,244,48,164,193,89,80,196,195,178,59,40,33,134,199,155,153,55,63,220,55,243,102,223,143,93,102,85,108,5,98,84,18,22,69,69,126,9,66,248,37,24,140,32,33,17,28,65,15,241,71,226,38,65,3,74,4,21,72,194,65,48,137,27,208,68,201,253,214,189,213,85,179,172,4,57,254,101,152,3,251,62,93,93,93,93,93,117,235,222,91,117,187,250,22,135,239,76,120,238,1,190,55,225,253,45,96,212,225,125,204,153,223,177,249,51,39,39,188,111,2,124,166,147,126,190,189,54,115,81,194,251,75,192,151,39,233,222,150,204,13,9,239,77,1,223,230,228,185,59,225,61,29,224,47,39,188,215,2,252,64,146,238,143,201,124,63,225,253,52,224,39,147,116,175,70,102,111,146,238,169,201,170,132,247,179,128,15,72,120,143,8,248,215,18,222,203,1,238,183,117,206,30,147,164,123,63,178,39,37,233,190,157,236,233,73,186,239,35,59,151,240,254,31,112,39,225,125,30,224,247,16,159,33,188,66,188,200,156,67,29,182,11,163,143,222,46,252,234,4,239,230,51,255,22,241,249,194,144,141,247,11,23,137,63,42,124,28,241,37,194,104,243,143,9,191,37,193,59,251,204,147,196,151,9,163,175,47,23,222,69,124,133,48,250,229,19,194,144,183,107,132,47,33,190,94,248,234,4,239,249,51,223,68,252,73,225,219,137,111,22,70,31,201,252,45,119,31,241,167,132,247,16,255,149,240,183,137,87,132,31,35,254,146,240,15,137,191,34,252,83,226,175,51,175,233,37,254,134,240,43,137,191,41,124,40,241,63,9,67,246,30,16,30,34,254,169,112,148,40,175,71,120,83,194,235,71,224,205,196,175,16,254,253,4,251,3,152,167,18,101,254,214,188,151,210,15,20,222,237,164,223,237,240,179,150,123,2,135,207,74,48,207,101,70,155,95,36,252,46,39,15,198,212,117,194,208,9,210,134,61,223,180,121,122,59,14,223,228,240,143,45,31,8,25,150,190,56,240,16,155,126,208,253,196,223,19,126,212,166,175,125,35,241,19,194,103,36,233,56,90,91,119,242,92,156,164,99,97,237,199,157,244,39,45,175,131,188,201,222,170,117,173,36,29,167,235,62,150,164,227,110,221,61,73,186,223,108,157,163,175,214,111,37,110,10,87,15,199,62,44,189,166,176,254,236,1,236,141,209,58,118,253,123,98,222,63,167,125,253,113,222,79,167,132,177,255,45,43,28,43,89,167,25,231,253,108,131,194,152,103,199,194,91,149,236,175,27,199,94,26,253,255,250,11,232,94,167,243,220,97,253,135,99,176,190,215,250,43,98,236,175,17,125,55,158,142,95,205,127,224,220,247,76,37,235,83,196,103,57,117,168,41,209,113,196,83,74,116,19,113,93,241,61,192,88,203,78,132,187,74,246,35,18,239,164,159,221,194,112,88,174,21,222,165,176,135,134,249,157,74,198,15,241,57,244,179,71,24,229,61,32,252,110,250,121,68,248,92,250,121,82,248,124,89,67,5,191,87,239,131,97,254,99,179,142,33,233,175,23,254,0,241,89,194,52,199,245,76,61,255,132,248,114,225,63,37,166,122,174,191,41,230,246,121,37,241,109,49,214,141,116,251,172,255,28,241,31,42,61,23,91,255,213,152,219,77,79,165,86,184,89,117,123,234,202,114,57,15,15,64,167,233,53,164,245,79,199,172,223,208,47,207,198,172,223,76,191,92,234,244,203,101,78,191,92,238,240,21,78,31,93,165,100,173,108,156,117,154,121,94,172,69,22,132,49,142,98,97,232,67,211,14,208,135,155,133,209,39,111,21,254,180,195,88,19,184,65,248,118,167,143,238,160,159,47,10,223,73,63,95,19,254,107,250,121,72,24,243,249,31,9,223,229,244,203,221,196,70,254,191,96,22,66,137,239,37,54,245,161,178,189,134,240,125,196,29,97,154,243,122,70,150,190,236,244,23,233,88,207,212,147,234,226,153,251,254,45,49,141,133,190,53,49,183,39,166,207,125,49,183,39,213,167,239,208,152,219,147,250,174,111,144,248,74,37,235,177,251,233,71,148,19,14,64,87,235,181,189,190,215,197,172,183,233,89,250,78,142,89,111,155,126,124,192,233,199,7,157,62,122,200,225,127,86,118,124,61,172,100,93,149,248,113,37,182,121,28,123,198,120,127,43,248,9,167,239,190,235,244,29,244,225,132,240,247,21,143,91,240,83,14,99,237,230,60,225,255,112,248,63,149,29,155,72,191,68,120,175,211,239,207,208,207,173,194,63,86,118,204,254,68,201,254,102,226,255,86,124,15,48,214,161,158,21,126,206,44,175,143,43,207,131,63,40,236,219,241,232,229,108,191,123,107,136,223,33,220,99,199,38,198,183,119,177,240,1,122,61,142,25,107,129,228,211,246,157,17,115,59,211,56,237,131,157,250,214,115,207,61,76,245,233,235,198,88,59,213,107,54,125,231,198,220,254,144,129,11,99,110,255,87,57,125,77,253,210,119,101,204,207,225,202,192,121,86,6,184,77,152,245,125,175,233,79,125,179,190,219,54,96,252,233,117,165,190,251,54,96,47,179,94,67,238,187,127,3,246,218,218,152,48,77,191,214,96,141,254,21,236,123,99,29,76,189,206,225,55,58,126,56,108,153,249,123,135,195,142,255,172,110,119,248,239,28,118,236,154,55,236,176,99,127,189,15,58,124,155,195,127,239,240,15,28,126,206,178,127,176,195,71,57,124,186,195,109,135,47,116,216,153,59,248,119,37,214,15,135,127,101,252,112,212,193,248,225,71,36,169,93,206,196,246,218,28,124,167,115,133,95,107,243,228,200,47,50,182,59,215,72,82,219,157,251,112,146,238,143,206,93,153,164,118,60,119,99,127,186,167,57,247,149,1,232,118,221,23,185,251,99,165,78,83,122,140,231,190,35,76,117,205,253,171,176,158,15,140,179,45,80,194,85,101,199,245,164,195,174,221,156,81,86,63,207,42,59,198,23,148,181,167,120,55,192,232,64,188,119,112,182,48,108,168,25,191,176,161,87,9,195,223,54,54,17,99,200,140,65,178,173,158,177,29,231,96,178,7,94,225,234,234,186,61,162,17,233,185,103,250,237,119,0,32,171,52,246,115,31,167,223,3,88,62,57,198,224,240,155,28,89,125,107,98,249,28,135,29,63,83,221,225,240,30,135,159,178,236,133,14,239,112,248,98,135,63,235,240,63,58,252,180,101,223,115,248,85,14,31,237,176,51,190,252,174,195,23,57,252,25,135,63,159,88,89,197,124,205,200,42,234,96,100,213,25,11,153,179,251,197,150,98,77,150,120,155,240,238,126,238,71,240,165,253,216,203,204,124,173,115,237,131,36,44,159,229,118,206,60,30,131,181,221,207,60,21,179,253,213,58,106,92,244,177,240,157,14,195,22,27,217,35,251,155,202,30,217,223,212,79,248,188,226,111,59,128,87,148,150,195,204,222,129,52,190,148,245,99,176,140,43,202,243,152,83,254,227,202,250,33,255,226,220,11,113,43,99,223,161,75,251,133,97,95,140,204,239,229,159,212,166,24,134,29,49,190,7,236,200,156,147,71,228,31,118,196,248,150,176,29,198,126,233,185,143,177,17,152,227,92,43,12,121,191,213,201,179,34,140,56,154,248,153,222,193,14,35,126,41,62,167,135,216,229,255,8,31,194,67,34,187,46,230,103,167,131,236,107,98,126,246,67,137,127,59,230,103,167,177,150,61,146,248,223,148,232,135,21,110,50,106,171,108,24,243,179,147,220,100,71,98,196,233,68,158,86,210,102,77,109,13,61,99,246,216,152,159,17,249,55,197,218,62,174,202,191,219,201,191,199,178,174,231,73,3,136,235,233,184,95,182,22,115,140,79,250,197,123,173,237,71,111,64,165,190,165,119,184,237,47,237,59,139,156,104,187,45,58,202,195,55,58,100,222,225,193,79,17,125,229,5,42,245,55,188,188,237,59,15,223,22,89,18,198,183,59,76,63,150,149,237,199,17,101,251,17,223,253,16,191,206,59,134,57,219,28,64,204,80,199,176,178,100,199,61,148,65,253,148,253,0,241,50,183,73,246,18,226,93,220,230,217,235,136,161,15,73,110,179,119,196,236,83,160,13,239,37,126,39,247,151,46,255,28,167,29,222,229,180,3,230,26,226,167,121,231,58,109,2,189,107,124,24,154,83,24,121,246,62,224,180,3,158,67,244,182,135,57,178,248,84,222,7,85,234,83,121,31,82,169,255,236,225,252,223,8,95,170,172,28,98,94,96,228,240,50,163,183,137,201,111,247,100,46,230,253,25,177,233,11,242,255,61,83,135,27,28,63,234,70,226,11,132,111,178,126,178,247,73,216,124,225,91,20,246,203,51,127,134,216,212,141,244,140,103,234,112,167,245,171,61,210,27,158,25,23,228,195,251,70,78,238,33,54,114,114,175,142,59,50,83,121,190,145,13,26,203,190,145,13,242,33,125,211,86,84,158,111,228,132,252,121,223,200,9,249,105,190,248,156,30,249,186,25,209,51,222,99,14,211,120,204,136,255,236,145,159,156,49,114,78,254,109,198,248,150,84,247,204,180,48,141,187,140,216,80,239,103,196,87,49,227,35,64,25,105,31,31,175,126,220,236,148,35,58,196,71,252,76,218,199,71,172,78,218,199,71,220,79,236,175,79,254,93,86,234,227,83,29,179,162,123,125,242,79,179,34,63,62,228,87,116,175,79,122,38,43,109,229,67,102,197,159,247,33,179,82,103,159,198,108,86,218,7,239,40,101,165,254,254,97,196,162,235,252,223,37,22,89,242,143,34,22,31,192,167,123,230,164,173,124,178,239,57,105,31,159,198,108,78,250,206,15,137,165,239,124,26,179,57,145,37,159,198,108,78,250,203,167,113,154,19,29,235,71,196,166,173,198,136,87,132,143,133,223,36,252,123,196,143,8,199,196,143,10,31,79,44,178,228,147,15,150,51,245,220,100,94,159,33,62,25,235,100,194,167,16,203,124,193,63,149,88,108,132,191,149,88,228,196,127,11,177,233,199,51,136,101,28,249,52,127,95,99,234,64,215,173,145,121,138,127,38,214,186,132,167,28,166,246,238,49,247,37,223,172,71,198,26,100,182,71,230,101,254,219,136,99,97,146,223,30,211,95,139,102,121,125,92,203,114,143,204,91,253,54,177,232,58,159,252,186,30,211,95,59,137,101,12,250,164,199,122,100,12,250,164,187,122,76,63,146,142,234,49,50,246,71,196,70,198,222,79,108,218,144,198,119,175,169,243,133,196,162,43,124,210,69,189,166,175,73,23,245,246,11,147,254,233,21,221,229,127,132,216,180,45,233,159,94,83,255,203,176,86,231,176,232,19,159,252,193,94,35,123,164,139,122,69,183,248,244,76,189,70,30,72,23,245,154,241,66,105,189,50,126,253,27,13,107,97,97,91,185,39,214,227,26,243,178,236,67,196,152,195,98,12,124,47,214,115,44,204,233,178,63,136,245,120,135,253,202,254,87,172,199,59,222,59,202,62,71,12,251,75,227,39,119,32,49,236,175,179,14,147,113,252,91,244,111,238,55,98,221,215,218,159,239,143,117,95,243,251,86,43,105,30,147,159,235,105,57,119,196,128,242,111,225,247,82,114,249,24,204,229,140,18,99,77,24,243,130,241,24,239,42,164,243,2,255,86,37,127,196,159,86,169,125,241,177,150,66,58,33,183,133,6,95,135,223,197,201,85,137,175,230,247,124,114,141,13,240,95,244,59,65,185,100,3,214,25,244,251,64,185,221,27,176,206,192,239,246,192,200,15,98,93,159,126,15,100,159,92,191,83,176,201,225,83,28,255,220,137,89,168,196,97,103,14,168,238,116,248,31,28,254,161,101,175,224,176,19,27,242,62,226,240,95,58,252,13,135,255,221,178,159,113,248,213,14,111,116,216,153,83,248,59,29,254,144,195,206,252,215,255,130,229,12,98,16,226,171,103,176,134,108,98,52,135,37,214,87,223,53,0,191,70,183,85,230,125,49,251,56,135,32,142,19,243,58,45,93,159,185,58,230,117,90,234,211,204,45,49,175,211,146,124,102,238,137,121,93,205,172,139,30,103,238,60,206,223,87,51,115,46,204,49,233,54,153,61,3,240,155,244,123,22,153,71,99,246,161,112,175,39,99,254,230,26,238,181,55,230,239,156,193,135,241,98,254,102,25,198,194,193,49,175,247,152,123,157,234,220,107,139,115,175,173,124,47,45,27,164,79,214,66,55,174,21,121,128,14,57,209,225,173,142,108,76,218,118,83,231,57,236,244,169,186,203,97,103,61,95,253,200,178,87,113,216,89,175,240,46,117,248,115,14,63,232,240,94,203,126,143,195,191,238,112,222,225,179,28,126,187,195,31,117,216,145,103,255,75,14,99,109,68,98,121,254,207,108,186,142,247,25,57,65,236,163,95,24,241,50,19,203,123,125,98,99,121,19,78,30,140,47,19,203,155,79,108,44,15,99,100,64,248,220,196,198,242,46,72,108,44,15,235,18,18,203,203,92,149,164,177,188,12,226,35,18,203,203,64,206,37,126,145,89,113,234,252,80,146,198,242,50,79,36,105,44,47,131,56,142,137,229,33,222,20,11,99,46,108,98,121,24,11,38,150,135,246,148,88,94,22,117,144,88,94,246,83,73,26,203,203,98,222,125,158,48,198,154,196,242,178,95,75,210,88,94,22,227,93,98,121,217,239,38,105,44,47,139,54,151,88,94,246,153,196,198,242,252,196,198,242,214,37,54,150,135,126,55,177,60,244,139,137,229,33,22,102,98,121,144,55,19,203,67,220,208,196,242,16,211,52,177,188,211,18,27,203,67,31,153,88,222,108,98,99,121,136,77,203,59,153,58,134,104,226,122,136,33,174,8,99,253,202,196,245,32,207,38,174,119,125,146,198,245,114,127,145,164,113,189,28,198,139,196,245,116,220,80,226,122,185,175,39,233,250,112,14,113,94,137,235,229,30,181,113,189,220,211,54,174,151,251,137,19,215,203,56,113,189,181,137,50,127,107,2,39,174,23,57,233,115,14,127,194,225,111,91,238,65,172,205,196,245,94,147,216,184,222,17,78,30,196,16,77,92,15,235,135,38,174,231,216,145,222,223,116,216,137,197,247,94,99,249,0,172,49,74,191,28,112,143,77,63,8,235,69,38,174,231,172,109,30,4,157,96,226,122,217,196,198,245,214,217,60,107,143,77,108,92,239,13,3,24,71,90,191,173,125,115,204,99,138,124,128,181,103,198,60,166,72,199,174,157,137,121,76,153,181,187,163,76,73,227,60,183,51,186,116,200,225,141,202,174,111,224,123,152,102,125,3,62,148,209,201,152,219,154,56,221,40,255,232,127,142,225,159,181,11,49,159,215,215,174,240,45,117,249,143,164,183,215,122,155,124,25,31,178,34,54,93,191,135,184,201,225,255,119,54,189,223,188,115,207,237,67,125,183,6,77,224,182,79,224,240,152,211,62,39,219,114,212,162,195,110,91,93,239,176,163,87,213,119,44,123,135,57,60,227,240,121,14,95,231,240,189,14,63,236,176,219,86,89,135,15,117,248,36,135,157,248,181,255,110,135,157,49,229,255,185,195,223,178,236,174,67,102,157,119,108,114,24,47,103,9,35,110,190,91,24,122,210,232,40,216,2,179,30,142,245,243,162,48,214,99,229,251,171,57,212,167,44,140,119,108,228,181,178,28,100,70,108,144,126,191,66,108,80,238,230,132,125,39,48,214,129,79,16,254,162,83,55,196,26,22,152,215,244,37,233,247,96,215,28,62,160,122,190,170,251,119,72,191,81,184,164,134,230,106,237,57,53,52,189,188,216,94,94,224,223,78,75,13,181,234,141,218,208,100,187,45,180,212,232,168,33,253,250,222,16,191,180,168,223,166,27,226,119,245,134,248,101,191,161,86,83,191,12,56,52,219,236,232,130,106,11,243,83,138,47,229,19,186,60,186,77,167,54,73,191,157,150,252,214,38,135,248,213,209,161,169,230,2,118,24,113,34,253,59,247,252,76,186,118,56,4,172,122,173,118,35,246,250,109,108,46,22,70,10,213,157,109,253,225,222,118,107,138,63,222,59,63,57,181,81,45,53,91,157,141,179,245,197,141,238,85,74,157,222,233,31,237,127,243,88,56,52,44,95,251,109,78,213,26,27,103,23,187,27,151,182,205,110,76,55,56,109,196,6,39,93,98,154,116,180,73,226,11,167,166,218,250,110,182,248,166,146,215,117,95,106,193,27,229,250,125,222,112,165,190,139,58,193,88,43,24,61,58,12,10,229,66,37,95,42,84,70,83,44,143,42,188,98,27,117,194,177,86,56,58,60,26,132,148,130,119,29,251,245,133,249,23,186,176,187,216,158,159,93,172,79,115,214,2,178,14,143,30,29,200,245,171,207,22,247,57,107,111,81,210,103,130,225,253,253,141,14,151,247,247,231,150,177,250,54,101,93,216,234,34,130,159,83,70,123,142,58,153,47,171,232,199,204,135,229,82,101,20,255,166,103,87,151,62,194,15,81,42,22,243,69,202,193,103,184,249,130,97,93,68,16,86,184,9,211,11,229,116,192,151,134,69,186,112,166,209,172,161,83,66,164,21,40,85,77,55,187,147,141,58,37,233,246,174,32,73,63,92,154,174,27,55,40,225,4,186,182,81,63,155,107,20,20,199,218,149,86,189,214,136,130,193,225,193,124,56,58,191,80,155,37,206,135,56,176,153,205,45,209,216,37,190,167,57,149,222,3,109,87,230,155,155,115,171,43,129,86,170,72,45,118,52,231,167,41,105,100,44,24,161,134,216,85,175,66,2,212,204,82,179,13,202,43,236,240,36,161,26,30,107,7,165,234,20,85,85,234,87,93,234,180,162,48,24,59,50,48,149,172,78,214,218,117,74,26,44,21,244,225,76,3,79,16,12,142,148,6,43,163,250,133,115,28,5,195,5,58,28,85,213,165,185,229,118,109,186,69,119,153,8,195,177,118,129,74,203,143,213,116,227,146,244,242,77,70,149,205,213,9,11,99,71,134,161,170,54,106,147,245,134,190,12,109,70,3,47,10,75,114,97,160,47,44,21,232,66,147,171,19,22,21,118,201,2,131,64,117,209,141,134,181,104,224,96,68,117,241,74,181,126,244,174,126,65,24,146,174,166,106,211,114,235,50,221,90,77,155,195,188,106,206,204,48,76,241,101,21,181,100,78,22,169,220,186,220,161,189,220,158,159,230,243,90,145,49,246,83,213,43,99,245,227,171,39,28,119,242,214,77,209,240,224,241,213,137,45,167,109,162,150,29,85,147,205,102,163,94,91,212,55,173,104,217,49,213,41,169,110,213,61,46,163,18,237,122,135,207,77,207,183,183,153,26,148,84,163,33,21,12,71,198,186,149,234,76,84,226,102,169,46,69,121,234,201,74,181,27,229,165,27,27,68,34,100,105,211,53,236,147,6,207,187,62,252,63,175,223,70,93,223,145,154,21,21,55,64,94,45,212,222,214,148,6,90,152,95,52,184,212,154,231,70,105,86,23,154,211,117,238,140,102,117,186,190,195,36,119,185,0,164,206,90,92,108,204,47,110,51,89,150,76,35,55,171,84,50,103,217,86,95,214,157,160,76,177,212,47,166,42,179,6,210,82,138,74,238,72,245,229,18,168,106,38,87,219,140,139,64,117,230,23,234,210,241,70,168,4,57,51,231,96,1,35,213,97,116,134,136,154,17,180,84,204,112,155,185,102,187,99,238,212,173,218,43,170,246,146,170,185,166,106,46,170,110,239,214,166,163,137,124,94,70,64,190,144,142,128,188,233,6,157,165,147,207,235,42,33,211,68,30,3,166,179,163,218,174,79,153,254,163,163,46,31,26,77,131,220,187,154,139,117,202,94,66,246,93,85,234,174,110,167,222,222,89,111,167,163,159,82,167,219,29,100,117,116,212,188,126,118,190,83,25,250,98,94,246,48,232,26,22,185,94,148,166,109,37,18,72,81,232,154,226,186,246,18,213,98,34,95,217,95,13,23,159,95,67,100,215,109,86,225,195,78,171,107,142,185,26,82,222,200,243,234,81,217,183,30,149,180,30,246,74,93,212,136,154,107,153,14,47,169,206,66,52,81,160,193,147,47,117,22,116,253,76,83,44,160,129,210,102,160,195,185,102,183,21,25,53,136,211,211,181,229,72,235,65,57,110,34,59,89,24,57,94,174,215,144,63,40,153,242,118,242,5,193,136,41,113,153,19,194,208,20,57,223,158,214,157,17,22,75,220,38,100,164,116,195,23,104,192,22,218,243,196,90,104,164,142,156,0,141,93,8,73,99,143,24,237,74,87,213,119,144,243,69,215,145,36,5,161,62,174,46,54,59,243,51,203,246,90,164,193,8,54,211,135,228,52,110,191,130,121,82,93,28,62,30,64,165,21,80,90,165,61,159,94,39,69,145,63,51,93,119,138,169,234,157,41,105,99,233,221,59,81,161,56,214,13,200,218,144,74,141,10,70,181,195,30,83,41,35,244,139,173,47,83,81,65,139,24,198,126,170,139,150,248,242,10,93,30,86,183,205,55,26,81,97,68,107,43,39,79,90,233,85,74,171,58,213,152,142,138,48,114,97,181,171,197,218,228,39,183,179,211,109,167,85,166,99,62,43,207,140,42,149,232,135,206,234,223,97,244,43,89,187,90,183,209,137,138,1,238,14,93,26,133,101,41,175,211,170,45,57,45,105,238,175,205,99,81,235,214,153,233,212,198,78,214,22,167,247,213,175,120,250,153,168,136,254,162,199,159,217,167,116,170,238,194,18,100,154,174,65,102,178,64,228,128,54,162,10,196,143,44,62,141,37,50,168,173,217,40,28,12,130,112,48,173,42,29,134,195,56,148,211,69,163,80,202,164,80,32,170,36,105,163,213,5,180,6,213,179,104,180,77,137,206,230,43,133,193,98,161,192,109,65,15,63,138,91,105,48,2,161,13,107,129,236,66,42,32,69,82,45,47,89,62,138,101,234,224,18,75,65,177,242,115,164,160,56,98,165,160,52,252,11,72,65,41,248,37,75,65,41,252,197,164,160,148,127,209,82,80,42,232,167,255,101,11,129,121,0,221,147,26,108,223,105,219,88,66,207,110,239,214,169,13,39,74,100,84,10,195,237,237,85,236,242,139,74,165,177,35,75,69,233,206,237,85,221,219,90,71,65,121,33,101,134,172,98,84,34,127,170,84,25,155,33,77,36,26,140,206,76,214,166,182,177,138,26,12,43,149,84,163,232,219,104,21,92,84,51,211,213,133,90,123,27,76,37,33,185,24,116,251,17,173,106,102,166,219,213,201,249,78,59,42,15,139,108,230,217,20,6,195,33,84,187,100,239,148,70,244,6,56,210,192,19,101,116,116,9,91,232,162,50,105,197,144,43,77,83,227,42,154,198,116,141,246,98,203,121,210,154,210,217,59,180,143,62,98,244,46,9,6,21,133,126,200,151,218,29,56,46,145,121,252,14,52,88,16,149,205,104,9,71,243,34,33,109,24,36,106,24,99,4,232,24,110,10,18,74,230,90,237,155,32,133,173,0,165,176,0,139,17,160,227,89,62,150,6,236,84,91,124,115,105,60,190,125,72,174,1,29,105,153,161,20,120,50,17,15,217,52,75,158,18,10,129,41,164,70,146,13,209,41,20,42,114,205,130,164,20,131,80,82,166,76,74,185,36,41,147,141,109,82,116,169,96,30,128,63,78,131,164,178,121,130,153,118,103,121,137,154,59,245,215,139,163,225,96,153,102,4,16,50,174,77,129,84,207,96,5,242,66,10,135,38,84,243,218,45,43,147,178,175,108,239,54,83,139,214,170,47,56,158,71,195,100,171,152,108,121,155,205,58,14,141,52,159,118,11,116,70,241,108,145,177,148,58,2,59,205,44,33,143,57,222,212,182,104,162,162,45,63,77,40,80,127,184,16,52,140,26,85,124,3,103,10,199,65,137,19,244,222,210,244,142,141,106,163,190,152,106,137,70,85,79,7,232,152,133,167,33,90,75,100,160,161,237,93,37,48,226,11,189,91,146,113,200,181,208,62,238,112,186,243,55,218,90,9,37,51,205,198,203,1,111,249,141,102,48,145,99,117,181,57,208,91,39,163,19,40,137,100,122,10,9,244,187,35,218,92,33,129,14,203,188,167,178,29,181,2,12,138,41,252,66,3,181,73,178,200,43,192,161,222,42,140,17,219,170,208,236,171,82,164,33,187,106,155,49,221,77,95,18,109,166,210,120,95,170,30,80,116,163,153,37,186,136,180,65,56,172,204,231,148,162,86,81,117,154,29,114,69,244,231,139,162,22,249,206,115,250,54,238,182,228,23,42,115,26,185,39,187,51,81,165,44,143,94,9,70,104,214,71,137,40,81,239,166,69,150,23,184,227,60,206,187,27,127,163,19,233,62,251,108,148,142,182,6,118,99,117,122,32,219,77,113,156,238,157,126,73,171,60,88,49,178,187,175,95,94,231,121,121,157,231,87,119,157,167,74,195,98,138,28,174,106,99,190,141,21,9,61,1,161,100,74,129,50,37,159,171,214,110,211,208,156,8,243,99,245,106,21,179,239,52,57,58,58,24,164,156,77,204,143,109,226,48,165,97,62,55,139,137,182,77,70,86,214,219,54,45,164,180,250,98,151,102,117,181,134,155,158,167,244,116,169,197,38,23,40,121,169,169,231,138,110,114,145,146,91,245,153,122,11,218,222,61,81,162,19,102,21,198,166,150,117,246,213,55,172,160,114,220,73,110,242,8,37,67,191,194,35,89,245,44,120,198,133,122,103,174,185,234,201,131,64,23,61,213,108,173,78,198,99,118,23,247,45,3,15,89,107,181,106,203,171,82,241,140,188,95,126,85,50,158,113,159,231,8,240,120,232,207,85,137,120,186,70,109,159,171,43,131,36,97,182,139,141,217,14,11,47,202,108,235,133,188,23,97,182,195,210,11,155,237,116,129,199,177,223,251,251,100,2,52,62,25,38,237,128,114,6,109,34,173,213,196,172,131,140,7,236,39,127,111,128,108,209,8,150,0,247,243,17,130,232,196,130,178,95,208,120,233,230,32,45,226,101,123,240,178,61,248,213,181,7,102,246,133,53,127,153,125,133,249,23,158,125,97,225,127,255,179,47,254,114,9,13,231,34,6,39,127,217,36,58,49,144,111,152,8,209,127,32,172,186,151,198,234,91,54,157,122,218,27,182,108,170,158,178,101,124,211,22,50,37,155,55,109,121,211,255,182,119,45,189,141,20,65,120,242,88,64,226,0,43,86,98,225,2,135,189,128,122,89,79,247,60,236,236,174,144,119,236,36,35,252,138,61,89,140,56,152,16,123,55,145,200,67,217,32,224,200,13,126,0,87,14,136,3,39,254,1,87,78,252,1,110,72,92,56,242,19,168,170,174,246,244,140,199,217,216,177,162,21,242,72,45,87,79,215,212,212,184,123,202,93,221,159,171,118,19,92,124,239,214,147,221,110,107,16,183,184,77,130,77,51,17,110,54,158,72,31,163,138,128,29,192,57,235,25,25,9,14,131,67,51,110,61,173,38,179,226,59,159,159,156,159,159,28,225,60,243,232,112,56,132,231,7,10,212,160,15,48,88,103,184,37,161,231,215,52,25,181,233,201,232,57,112,107,133,143,161,109,54,41,144,15,16,3,214,43,55,191,7,219,134,138,100,47,27,59,14,218,152,73,58,129,223,88,71,122,206,56,44,10,10,193,110,25,65,3,106,10,106,203,138,115,250,4,108,221,144,200,209,215,123,251,231,168,43,5,212,36,205,143,135,220,236,114,255,242,183,134,51,113,184,6,159,250,148,132,105,197,139,244,205,233,106,66,6,109,244,240,49,56,242,16,84,130,124,140,34,98,176,227,20,225,236,220,138,71,68,147,245,52,238,208,85,237,179,187,52,208,75,3,125,237,6,122,108,52,75,169,209,116,159,99,52,229,212,37,171,233,214,94,21,91,123,111,210,218,123,151,179,246,86,204,165,130,151,30,173,118,96,44,247,201,49,26,38,151,13,209,248,68,72,43,8,218,218,161,73,233,128,221,202,71,114,42,18,125,161,204,156,188,76,52,178,249,45,132,45,101,105,35,150,54,226,122,109,68,6,80,81,210,128,10,247,98,64,133,164,119,203,2,84,152,237,100,233,93,4,168,80,11,0,84,248,139,6,84,4,151,0,84,4,11,0,84,132,121,64,132,44,207,2,168,152,11,144,241,191,3,84,140,127,129,94,96,104,133,107,160,21,114,42,180,194,181,160,21,106,54,104,133,55,63,180,194,159,128,52,168,60,164,65,21,65,43,130,89,161,21,65,14,90,17,100,161,21,147,16,143,32,175,71,186,52,147,131,86,132,19,208,10,68,126,188,216,208,10,85,121,14,180,162,52,5,90,225,206,11,173,80,149,2,104,133,188,18,180,66,89,208,10,111,42,180,194,159,6,173,8,44,104,69,88,188,169,14,74,79,110,170,123,229,5,111,170,107,96,135,222,247,246,47,3,173,40,93,30,90,225,102,160,21,99,233,188,171,30,204,187,171,62,134,86,200,139,160,21,106,14,104,133,204,64,43,188,171,64,43,124,11,90,17,76,131,86,132,233,40,240,203,51,140,2,191,178,104,104,69,105,182,81,16,184,151,135,86,72,27,90,177,176,65,240,92,104,133,103,67,43,84,6,90,1,110,88,160,114,208,10,252,146,178,208,10,152,89,5,193,52,104,69,105,10,180,66,21,66,43,194,44,180,34,40,95,12,173,8,211,136,198,232,145,13,71,207,200,35,59,165,101,51,189,228,133,107,75,244,67,76,155,206,86,228,231,249,193,242,169,140,165,207,181,244,185,174,215,231,202,198,159,222,216,2,191,11,220,26,43,140,121,193,176,134,22,26,184,240,121,151,34,17,223,115,62,184,151,94,177,28,196,203,65,124,189,131,120,239,108,255,64,227,154,112,221,96,84,237,70,219,3,37,31,197,9,56,210,84,9,60,172,160,51,125,54,122,202,59,190,137,116,31,142,90,237,65,183,190,213,3,190,173,122,171,222,173,54,116,213,21,155,29,77,73,81,109,240,73,37,26,113,19,201,65,212,168,246,122,245,222,134,135,251,43,123,251,7,135,199,35,141,126,195,61,161,209,227,118,92,163,90,73,236,196,71,122,202,178,173,9,41,58,61,77,41,193,132,39,58,181,152,161,115,76,4,34,209,68,40,218,154,40,139,157,77,34,42,98,91,19,110,73,36,124,206,117,69,143,41,41,106,76,41,209,103,202,19,9,83,190,232,69,154,10,68,141,169,80,244,153,42,139,132,169,138,136,88,113,248,193,143,140,234,174,136,88,101,41,69,196,170,74,37,34,86,22,220,143,136,213,133,201,198,163,198,71,154,12,68,164,197,202,16,168,190,38,203,64,14,90,237,246,99,93,173,96,75,90,87,112,215,104,179,163,105,151,232,186,174,72,209,172,246,7,205,42,40,213,170,15,154,237,90,29,61,197,251,218,161,55,221,170,30,142,176,101,208,173,182,106,237,38,244,2,213,226,22,14,0,34,55,27,237,106,2,125,65,149,78,181,155,196,208,239,216,174,244,169,40,130,94,209,84,187,217,105,212,251,212,232,103,79,105,33,129,86,136,26,112,80,64,151,221,199,233,194,240,80,47,182,184,214,74,129,181,165,191,187,19,211,112,69,95,190,103,72,103,215,144,158,83,99,42,112,118,13,25,58,189,77,230,148,78,205,144,202,73,12,9,119,48,168,10,148,86,139,201,239,197,69,49,116,213,15,14,159,30,152,119,244,139,147,175,172,87,180,22,19,240,130,150,180,190,44,63,195,142,164,89,36,194,142,205,114,1,78,204,200,69,60,167,229,238,144,112,7,19,153,19,8,131,48,195,97,210,121,173,114,62,46,44,55,115,237,120,224,255,223,111,48,31,198,120,249,7,255,71,236,164,249,13,214,185,96,174,171,87,53,31,230,239,194,114,227,93,110,123,155,63,241,127,220,111,242,181,171,58,175,23,150,213,247,11,238,251,14,95,179,170,243,125,81,206,175,219,124,237,77,110,195,88,59,239,89,124,191,0,31,198,193,249,151,249,94,179,248,20,203,126,73,231,47,194,242,198,31,214,125,205,255,156,43,41,31,230,1,210,185,128,10,248,62,76,249,240,49,177,100,242,200,25,190,186,197,7,237,148,11,233,149,2,190,134,197,119,11,248,110,77,225,235,57,227,126,195,188,55,88,214,254,182,248,204,53,159,50,223,154,206,143,116,103,221,146,97,228,97,249,140,238,169,249,224,90,202,77,244,157,197,187,206,50,15,89,222,203,58,159,15,150,149,59,57,121,248,108,199,233,125,49,175,17,229,54,186,157,227,195,227,156,229,174,233,184,173,88,86,78,11,158,227,27,199,228,133,163,3,249,40,254,19,230,70,123,224,164,227,234,91,39,29,147,112,220,125,221,196,16,227,195,140,171,239,45,26,142,18,198,125,218,182,116,52,207,241,67,150,207,133,243,43,127,22,200,251,49,203,39,255,130,239,6,199,213,91,57,121,63,103,245,251,24,117,251,189,64,222,175,89,190,62,166,184,252,169,128,239,183,44,223,39,48,94,202,15,242,124,255,1,80,75,3,4,20,0,0,0,8,0,153,133,204,32,51,184,224,168,37,31,0,0,27,96,0,0,7,0,0,0,99,112,46,104,116,109,108,196,91,93,115,219,56,150,125,247,175,64,123,170,102,147,41,137,236,100,210,179,211,25,183,186,109,217,241,183,227,182,157,184,39,47,93,16,9,145,176,72,130,1,72,41,242,131,127,251,158,11,144,18,41,81,114,210,61,187,155,170,152,18,37,1,23,247,235,156,123,1,238,197,130,135,131,157,189,66,22,137,24,12,85,154,107,97,140,84,25,187,86,50,43,132,54,123,190,251,108,103,239,242,232,110,159,157,220,221,93,247,143,126,253,112,250,241,167,221,115,49,159,41,29,154,93,54,124,127,117,119,116,117,247,211,110,176,28,161,199,54,189,217,197,96,126,53,241,72,133,115,92,14,222,31,254,155,29,28,15,223,95,188,191,249,233,47,239,236,191,193,206,206,94,32,72,8,124,225,228,213,128,117,137,199,48,210,43,124,19,223,245,235,47,239,236,229,248,5,103,177,22,227,159,118,255,114,35,140,42,117,32,204,110,107,129,186,190,189,231,243,65,143,45,191,63,84,217,88,104,145,217,95,4,203,55,238,123,60,11,153,81,169,96,173,9,4,215,65,188,59,208,213,171,157,72,171,50,55,246,203,180,112,158,201,197,239,181,96,137,52,133,8,89,161,102,28,234,99,69,44,152,192,55,213,24,47,165,97,57,143,132,199,104,17,59,31,140,112,247,22,179,141,149,78,189,184,72,147,221,65,140,225,231,140,110,208,208,24,142,241,208,9,135,159,100,17,221,88,140,215,99,74,211,13,35,211,60,153,51,195,231,108,174,74,72,50,33,65,234,111,237,201,1,219,147,105,196,140,14,126,218,205,196,204,139,228,152,204,69,178,236,249,210,41,218,190,137,95,15,238,99,94,252,151,97,87,98,246,51,172,240,122,96,63,88,42,62,46,138,252,173,239,207,102,51,175,16,220,8,237,141,181,255,244,144,68,92,38,201,220,223,29,156,9,158,245,19,40,138,29,219,91,118,21,253,62,36,24,92,106,143,69,143,50,239,237,92,95,29,247,216,112,120,195,94,188,250,241,199,127,244,191,255,71,255,213,247,47,173,40,157,130,142,172,253,59,68,8,180,224,133,156,10,47,19,133,255,84,104,152,128,103,254,229,245,209,241,238,128,254,46,61,138,140,118,211,116,142,111,155,169,47,77,226,209,224,48,76,232,137,176,244,159,34,205,105,189,55,106,36,116,193,46,61,118,140,27,141,213,222,202,40,227,201,78,43,94,62,254,218,99,50,133,77,216,231,146,39,178,152,51,49,229,73,137,53,192,119,43,93,188,233,191,126,109,117,241,31,17,176,49,125,229,96,205,112,129,86,118,134,9,199,155,177,12,156,20,199,228,228,141,101,156,222,94,244,142,142,122,183,213,208,255,59,82,74,41,43,233,156,214,216,181,86,1,201,152,69,59,100,57,10,166,83,50,100,102,133,196,23,78,105,136,212,137,140,215,154,155,66,151,65,81,106,209,144,253,94,140,16,27,133,48,107,82,119,7,196,102,63,51,158,9,72,222,183,255,252,222,127,130,201,144,148,56,140,255,209,189,130,97,19,30,202,84,234,198,228,171,83,86,195,175,141,159,243,34,167,57,68,62,78,188,32,182,51,60,64,61,112,228,219,114,244,32,130,194,248,215,92,243,36,17,9,190,236,94,84,218,58,179,223,235,177,119,90,132,66,203,160,49,125,253,19,118,106,253,173,105,245,133,100,175,158,83,70,151,46,34,174,19,25,120,112,44,127,36,31,125,161,10,49,217,29,28,37,16,84,171,254,251,188,128,39,37,236,78,4,113,166,18,21,33,71,246,96,161,192,107,200,134,100,108,202,4,110,80,252,9,89,62,151,50,152,20,50,21,30,207,243,68,144,64,187,131,142,155,141,121,127,173,63,181,94,81,207,253,247,254,171,87,127,64,15,65,44,115,227,201,81,106,85,145,107,21,150,100,42,158,132,129,47,179,80,124,169,108,116,122,112,201,78,0,9,128,5,209,210,193,210,32,118,168,111,16,167,251,223,222,119,253,126,127,167,43,175,97,186,67,101,161,33,230,83,135,26,147,76,205,128,77,128,46,86,227,27,203,21,212,66,242,204,98,160,35,146,67,149,171,26,57,132,69,165,46,217,76,22,49,126,120,29,123,135,30,155,169,50,9,217,88,192,213,120,177,19,3,168,126,102,236,66,20,12,106,182,179,200,177,157,58,84,158,231,237,241,29,167,200,20,224,80,168,183,20,225,0,206,95,16,96,51,46,39,188,80,30,15,188,236,17,50,143,6,134,240,147,140,69,200,44,232,23,223,237,249,163,129,131,92,172,97,49,88,59,82,91,3,249,79,213,20,126,48,173,12,130,145,131,88,4,19,166,74,8,57,223,9,188,169,71,227,238,88,235,84,136,216,239,87,148,99,241,151,176,16,97,37,20,252,202,38,62,66,71,123,123,223,189,236,240,80,97,10,239,33,79,188,140,27,238,69,106,234,95,114,61,241,246,195,68,104,100,15,123,237,49,186,215,76,184,200,108,253,79,167,215,255,98,159,0,149,236,67,102,47,132,155,22,196,30,19,57,130,69,250,188,44,98,165,255,197,0,165,44,114,57,91,14,150,48,126,176,65,38,155,105,96,112,239,115,89,80,66,243,56,114,112,58,226,19,43,209,1,93,73,162,2,25,119,214,16,234,70,68,100,253,17,16,63,100,83,25,10,213,244,138,197,212,221,179,145,77,76,233,210,253,136,167,192,203,200,206,101,95,209,124,14,67,21,59,241,28,50,119,140,100,176,92,161,19,104,96,93,252,112,36,18,216,245,0,127,123,236,144,104,89,178,73,244,53,135,222,42,122,160,144,245,3,78,192,51,42,245,188,246,40,100,144,122,182,59,217,204,47,107,220,184,196,47,153,9,36,81,77,226,116,20,233,73,8,230,217,91,176,200,114,65,79,210,210,72,74,147,146,156,112,131,68,185,74,230,5,165,86,9,231,34,234,69,55,160,85,8,131,20,227,59,177,240,10,144,192,71,0,132,102,198,217,183,30,67,132,244,226,211,209,111,71,123,254,233,150,149,139,169,52,94,153,201,254,72,139,84,100,94,40,252,167,89,69,241,14,96,54,140,132,69,220,211,29,182,209,104,52,210,136,98,128,50,228,211,40,230,102,2,84,194,0,213,43,98,68,220,148,161,152,54,253,223,154,136,20,242,177,203,207,54,234,102,154,66,224,66,124,225,198,121,90,48,74,20,166,109,166,226,3,186,3,226,25,3,194,28,11,172,230,196,207,138,118,101,115,241,137,17,227,86,33,208,235,250,250,178,126,67,41,108,155,199,16,242,148,38,247,70,32,197,26,6,40,20,102,165,11,57,57,124,189,105,14,220,142,49,172,12,0,206,33,146,20,77,122,15,151,34,89,134,95,27,92,89,36,51,1,232,207,34,204,235,98,76,4,194,31,243,0,0,59,247,77,160,138,98,84,47,191,12,169,102,184,165,123,236,168,9,200,169,8,9,181,253,68,25,51,255,198,32,17,64,126,175,84,179,58,28,115,155,33,125,176,188,241,216,71,216,128,154,23,96,10,10,68,47,143,231,11,81,236,125,48,3,158,53,57,115,142,108,17,99,106,167,15,128,106,161,138,121,46,216,12,184,69,132,143,45,156,223,144,255,110,174,107,108,18,28,110,72,130,17,31,41,237,18,19,18,207,4,43,152,59,159,153,205,3,212,95,112,113,184,72,70,142,66,21,133,202,227,150,225,16,21,83,196,44,72,142,83,151,43,42,22,66,243,144,231,84,147,128,236,63,147,92,210,28,169,193,197,6,166,85,118,86,56,202,137,202,162,254,156,103,209,98,206,211,193,133,140,226,34,163,250,15,60,23,229,221,138,141,8,12,55,198,70,170,160,106,175,156,113,100,26,4,0,18,26,113,76,67,83,250,245,156,183,133,0,63,41,54,70,114,40,121,198,61,82,152,129,73,50,202,132,229,196,127,202,31,130,31,223,104,59,138,208,26,50,65,105,215,162,112,234,218,180,242,190,197,143,14,245,67,60,136,5,108,46,225,205,85,177,98,223,64,62,111,216,244,215,91,56,43,31,37,98,29,138,24,79,34,101,35,139,8,213,63,193,83,222,161,8,32,102,181,133,83,229,29,62,34,192,102,189,105,57,162,165,142,132,31,196,129,117,134,133,92,206,51,192,125,148,113,25,69,38,92,53,115,10,219,146,200,216,70,207,48,50,151,136,228,160,202,97,177,158,27,62,150,86,195,238,165,89,184,165,169,248,202,70,220,5,85,167,112,177,67,213,36,207,63,188,189,70,108,34,231,102,32,171,179,32,134,122,91,57,114,24,91,133,35,179,27,200,217,210,250,77,255,176,242,59,90,84,173,122,231,245,166,28,141,112,215,167,64,77,4,2,123,12,126,7,240,195,205,137,233,240,205,138,255,241,0,104,53,249,37,230,115,97,28,131,31,210,141,30,219,79,90,137,33,39,231,210,115,76,135,114,43,40,44,150,126,244,222,188,30,1,165,216,161,192,156,42,7,188,31,220,33,111,79,97,11,42,45,44,208,221,111,143,193,85,182,24,24,255,214,38,174,135,40,168,21,146,64,113,243,30,59,83,113,83,34,128,130,69,134,191,245,216,249,223,158,155,100,4,172,11,133,116,200,20,138,188,88,36,232,0,163,146,117,113,177,76,176,144,217,34,118,214,75,197,36,106,197,49,170,231,105,64,101,112,64,35,208,21,154,59,70,77,8,203,125,244,26,233,227,240,114,248,12,71,243,194,114,34,42,167,19,237,2,102,168,121,74,44,205,186,93,67,3,153,40,81,98,50,36,151,153,210,147,45,168,97,115,241,97,197,151,187,21,20,98,229,41,248,184,115,214,167,135,148,184,12,168,156,153,200,108,93,245,4,11,129,74,218,136,29,170,160,4,83,105,225,56,123,241,227,90,6,216,102,167,21,49,162,144,131,6,145,32,83,138,187,99,161,198,227,134,28,149,175,155,222,250,218,123,172,130,212,109,106,239,167,97,8,174,32,50,212,243,37,190,139,202,122,78,86,117,53,134,207,67,153,68,150,150,31,218,23,8,138,12,220,145,55,109,48,214,136,6,24,1,92,7,5,141,11,70,114,124,23,156,70,0,40,93,151,83,54,113,241,168,219,22,18,149,135,23,32,1,33,185,7,118,233,78,13,96,112,194,180,92,226,136,238,212,188,125,233,175,110,244,119,155,70,79,64,208,2,227,250,62,115,255,157,19,221,96,125,239,164,137,105,125,255,46,167,188,73,221,171,175,172,183,48,182,58,243,44,149,11,128,226,15,74,4,175,124,170,74,109,3,214,137,255,78,17,67,222,15,41,79,52,81,197,181,91,8,187,41,193,189,95,188,107,214,234,117,227,238,197,15,240,44,4,236,87,97,11,244,113,108,181,194,254,124,39,117,167,217,73,101,91,58,169,93,25,196,6,123,32,200,14,35,107,135,58,15,193,191,76,172,144,155,198,28,239,43,61,29,219,155,148,140,19,209,84,212,71,232,5,9,248,215,18,105,86,26,219,132,235,125,131,145,18,57,22,30,207,202,154,49,6,210,159,170,228,149,31,41,120,211,227,162,185,117,92,189,237,177,3,145,109,36,20,214,105,19,84,131,206,226,72,174,20,195,22,221,68,178,132,61,51,55,29,189,208,99,165,130,120,173,2,63,1,217,2,141,209,182,195,72,149,91,221,190,105,119,209,254,251,235,82,139,86,35,5,146,111,186,248,230,116,18,169,57,120,55,73,130,43,202,33,184,91,83,20,5,166,73,98,35,205,8,166,5,77,78,13,71,210,184,105,80,205,2,248,98,44,63,174,241,120,73,62,59,93,238,255,160,159,189,177,57,92,71,196,73,119,158,0,160,77,60,89,183,119,39,182,8,157,149,66,63,162,150,136,168,14,77,101,193,245,72,72,192,160,95,38,137,220,29,156,240,113,70,249,227,67,146,160,230,141,155,29,224,119,251,223,88,206,144,165,74,208,114,171,147,208,22,3,39,82,131,45,83,179,194,182,23,26,195,47,200,38,117,168,21,177,132,175,171,86,85,50,206,1,214,30,184,78,176,108,14,197,42,177,13,14,231,155,39,238,93,85,175,109,173,177,3,240,197,114,74,77,89,110,83,157,159,201,72,36,113,117,89,140,167,77,174,20,156,236,198,99,87,244,201,214,2,248,104,120,188,166,51,107,182,211,173,64,222,221,124,219,29,156,218,43,21,26,101,85,103,84,51,119,64,231,251,225,77,207,213,86,182,32,69,169,110,58,209,125,209,193,176,114,157,109,149,171,148,106,198,43,114,129,122,104,153,12,90,184,118,70,31,193,200,170,140,146,22,206,154,60,225,243,126,161,133,168,26,73,173,146,3,96,1,152,213,243,188,216,230,93,127,42,83,85,146,221,202,84,53,29,240,162,214,79,75,129,155,19,88,59,105,109,41,26,255,63,118,37,94,67,182,125,48,253,228,43,48,117,181,144,64,150,125,64,225,242,11,168,104,18,34,179,133,174,154,56,179,197,76,149,211,206,155,197,76,103,236,147,133,198,101,22,230,85,213,247,52,46,184,207,245,67,181,176,253,155,51,59,194,115,116,191,40,251,152,48,145,174,109,246,80,22,24,165,80,124,81,61,218,59,171,180,233,188,219,127,49,202,196,180,88,255,238,224,92,129,226,136,201,10,49,62,93,240,37,187,157,157,227,151,29,222,250,159,112,79,145,164,147,191,87,107,57,127,16,168,20,129,161,74,23,45,146,112,201,101,6,22,156,42,91,182,173,122,103,222,240,206,120,177,59,178,133,158,131,151,174,162,130,237,7,71,174,57,89,130,64,249,169,153,148,113,6,153,202,170,154,154,148,205,32,62,59,56,61,102,180,85,78,29,205,98,1,82,207,251,88,87,109,94,19,167,243,82,213,154,40,161,134,161,215,31,122,236,204,33,103,231,40,19,206,117,198,189,32,240,30,230,165,55,150,54,180,38,165,46,125,26,66,151,72,189,134,111,77,247,185,126,108,185,152,29,161,16,212,205,57,159,143,85,38,67,202,180,119,64,164,80,105,101,26,245,36,28,236,98,115,154,4,244,201,21,130,146,240,148,220,0,35,95,184,87,4,179,7,66,103,225,51,128,100,41,166,211,84,16,201,254,72,102,181,198,126,38,163,133,116,96,228,194,189,64,97,149,108,33,120,52,94,8,133,37,168,202,12,133,147,48,185,173,138,46,184,54,134,126,126,102,239,116,193,178,107,172,135,188,224,108,177,63,12,213,172,162,221,118,246,110,213,118,217,173,54,128,90,154,99,177,8,122,174,229,163,202,44,198,188,69,254,122,227,151,97,189,169,125,201,179,145,229,39,161,220,186,76,219,74,133,131,215,217,231,33,229,29,80,112,105,157,158,150,141,250,224,18,124,167,133,228,29,120,186,172,83,193,213,5,24,83,33,182,55,255,141,151,150,158,122,180,155,43,156,206,181,112,169,49,47,170,95,94,80,53,224,238,172,210,7,82,181,5,211,213,51,66,182,40,93,116,211,101,99,231,94,139,66,75,162,140,141,242,157,172,69,89,203,108,204,84,161,48,147,49,74,70,155,106,165,109,113,65,97,15,185,111,62,151,184,93,93,126,111,2,251,165,202,138,8,204,136,40,90,119,87,247,125,20,221,218,223,129,86,195,114,207,236,111,85,168,83,166,37,244,41,244,47,60,149,17,247,242,120,110,92,110,122,132,112,49,166,117,31,195,242,122,196,51,240,10,228,109,217,228,247,191,93,159,51,100,212,66,164,75,139,192,207,174,86,188,109,108,215,205,165,135,178,11,43,81,54,174,242,114,228,107,30,18,131,39,179,181,136,204,149,32,157,222,184,79,159,9,213,85,206,22,68,25,13,48,69,205,217,135,175,101,182,158,24,106,46,163,141,3,229,177,18,153,252,226,141,120,17,87,248,241,32,30,233,127,45,15,220,20,124,214,144,215,106,145,110,206,142,36,18,64,204,181,197,225,37,148,122,174,20,143,221,166,100,139,145,209,86,1,188,241,110,136,63,195,163,139,107,235,128,167,151,7,71,223,176,29,57,205,74,77,221,213,43,92,80,206,136,121,171,195,181,12,28,155,66,90,110,125,120,123,205,94,56,33,216,95,93,141,241,210,218,208,26,240,125,167,1,81,192,37,146,246,19,137,177,3,74,178,98,97,72,149,136,200,191,57,218,63,188,60,170,84,246,30,119,90,76,175,48,212,217,65,56,137,175,235,30,215,8,245,30,89,59,226,213,165,30,220,190,161,142,82,1,188,80,205,218,126,181,87,221,99,215,40,85,68,225,122,74,212,54,169,138,206,207,182,252,127,228,91,73,111,87,99,205,226,85,160,102,130,138,171,247,51,145,181,182,228,150,80,117,93,43,113,109,155,255,153,206,89,174,213,20,228,167,35,119,94,187,79,122,59,103,202,136,188,89,41,94,66,175,201,130,46,81,202,106,247,47,111,186,1,96,125,115,133,120,114,156,249,163,34,175,59,200,160,159,50,115,72,213,110,100,30,200,140,154,218,119,84,86,92,107,106,24,86,237,166,214,244,95,113,172,160,62,51,80,111,190,69,90,68,182,150,23,137,26,83,231,82,183,124,105,121,196,160,238,171,219,83,6,108,243,153,130,175,238,35,129,111,136,149,46,210,13,110,245,216,185,200,160,169,120,107,224,211,150,96,153,41,79,22,254,88,10,13,210,44,146,169,250,82,93,104,56,140,86,26,163,150,71,6,46,169,217,223,160,192,151,152,87,162,88,43,108,55,228,144,194,182,171,37,101,77,122,219,109,210,152,138,242,218,77,81,248,167,50,164,44,116,235,94,129,254,32,49,110,102,119,138,123,114,140,48,227,200,170,85,23,193,224,141,79,127,234,51,110,120,137,82,206,30,244,28,110,62,242,80,109,18,166,173,164,255,52,225,169,70,17,230,46,203,1,181,28,35,129,157,219,187,107,209,76,93,36,36,202,203,186,87,191,25,90,17,75,243,220,40,164,166,164,146,29,96,70,253,169,219,88,0,94,32,53,189,103,151,155,165,158,74,49,131,87,101,197,235,54,149,60,79,132,204,46,248,200,223,79,51,149,185,191,139,51,127,9,109,168,22,130,122,253,135,30,179,159,109,221,65,36,3,11,94,122,171,13,181,122,239,57,85,170,192,184,116,177,123,155,211,230,57,8,58,24,250,199,55,108,192,28,180,165,159,183,246,5,98,154,167,194,176,253,205,26,161,99,24,107,91,167,77,176,190,45,180,144,16,244,172,212,145,104,87,247,51,54,146,133,198,98,87,115,82,135,220,191,19,156,244,221,6,185,43,144,16,140,133,10,38,182,10,45,204,234,156,101,241,72,7,88,146,102,246,191,119,136,183,182,189,12,4,68,37,151,25,146,133,136,155,248,130,5,125,5,109,190,235,14,177,71,14,198,16,182,80,208,69,155,45,53,238,176,222,134,217,190,129,186,204,30,96,246,59,193,237,238,125,29,167,235,27,118,41,74,113,161,221,209,108,164,91,135,31,200,19,58,47,55,135,70,82,111,193,131,66,8,207,106,162,230,58,79,97,153,5,182,85,120,23,171,212,102,250,67,123,167,49,253,74,63,205,157,161,219,191,186,218,60,33,224,210,32,124,189,200,140,27,77,194,227,155,219,91,154,136,248,103,86,123,223,51,89,132,124,97,2,128,53,186,140,133,245,134,50,251,225,7,26,69,165,193,227,124,98,107,101,215,119,238,62,65,80,102,19,165,249,74,97,16,147,174,75,157,83,212,218,157,169,230,129,49,192,217,88,126,33,40,19,141,237,95,235,19,31,55,148,82,155,14,101,164,118,87,148,78,219,2,30,168,230,109,110,148,174,49,181,106,35,122,209,8,95,59,33,80,159,204,170,79,18,187,246,250,23,89,204,159,37,49,139,45,210,7,51,245,79,80,78,92,47,247,148,62,202,194,22,199,103,194,237,17,110,33,160,171,222,131,106,138,14,235,219,214,109,61,154,194,92,72,114,202,182,76,237,199,91,7,253,98,222,240,4,132,32,129,93,100,158,97,132,80,176,143,218,30,190,5,247,110,134,248,254,233,117,255,234,130,154,229,16,98,184,136,112,118,122,138,24,183,27,233,84,134,61,191,161,117,191,225,112,141,204,131,132,54,148,65,83,68,6,158,13,70,68,205,157,152,167,245,181,90,227,189,123,71,252,178,92,63,176,215,71,5,79,143,126,180,15,26,172,215,173,85,37,230,251,247,34,50,63,252,248,11,87,137,107,253,225,189,176,187,2,251,205,193,65,219,93,111,217,118,77,215,42,61,91,67,236,15,251,175,183,246,162,250,68,62,93,90,175,18,215,76,72,218,177,190,23,146,186,199,89,212,145,82,191,118,3,66,35,99,27,53,174,14,205,33,133,27,140,139,84,38,121,106,183,92,205,118,79,88,79,138,50,158,209,8,112,207,108,245,188,149,205,137,41,29,90,90,30,70,123,30,104,60,35,4,130,148,103,17,2,182,242,225,72,104,13,112,204,127,55,101,74,140,178,182,177,74,198,99,218,57,199,167,155,207,118,182,206,188,204,102,138,58,89,247,10,44,15,127,178,254,29,202,143,102,225,135,48,131,63,172,31,68,89,109,37,183,246,230,182,232,43,4,125,183,196,189,134,248,25,181,226,238,203,30,251,77,194,155,90,121,102,184,127,113,90,29,165,184,174,49,238,211,214,141,7,157,202,229,73,213,135,199,221,193,39,48,215,132,192,222,180,83,88,71,235,164,110,133,108,56,85,97,79,166,47,30,42,200,128,4,63,237,182,158,115,90,156,90,30,54,31,120,90,28,93,126,158,250,88,223,14,131,246,121,144,189,209,96,149,87,179,229,4,236,197,225,112,248,18,89,43,83,179,145,164,125,246,15,5,149,239,31,110,247,189,250,244,182,147,188,218,159,118,114,55,158,231,90,72,221,120,94,103,33,115,88,12,104,3,28,50,220,219,67,234,40,1,34,65,189,39,51,3,133,180,199,51,105,14,210,81,24,186,63,157,141,110,89,32,51,197,62,109,76,53,31,43,185,163,22,28,56,55,16,179,122,30,230,67,102,61,234,244,238,195,203,150,19,66,73,246,57,175,186,111,101,216,139,225,240,244,238,174,241,172,71,215,228,86,201,80,174,138,165,234,83,226,119,136,18,207,115,148,51,226,11,241,204,207,212,204,166,7,154,26,86,239,211,237,66,229,149,9,232,19,175,233,241,144,234,157,182,167,61,138,100,206,246,13,61,0,246,43,213,137,180,81,220,126,234,64,48,171,184,87,166,248,174,161,167,63,33,230,67,46,34,43,31,254,215,59,64,244,236,213,115,34,109,153,89,155,55,84,4,158,220,93,94,248,23,31,78,143,79,237,51,93,126,138,153,150,147,92,254,129,73,170,62,76,49,78,189,42,46,223,218,246,75,181,20,192,156,241,42,95,242,23,54,166,197,17,99,174,77,190,156,243,107,166,164,49,223,174,26,204,211,139,199,11,221,212,140,190,102,107,238,183,108,227,151,221,232,181,107,117,170,46,149,246,89,56,30,216,255,245,190,21,126,187,122,142,229,14,18,183,206,190,216,180,77,156,24,68,130,113,247,11,93,115,183,141,115,134,50,127,69,104,95,6,118,227,232,17,89,212,109,66,121,35,89,159,59,174,183,165,154,14,139,79,147,250,76,112,67,12,220,134,123,209,225,65,209,142,163,117,186,168,4,200,187,39,65,75,203,9,39,82,107,11,64,234,63,164,212,86,169,230,190,248,228,15,23,4,143,221,186,207,154,17,241,66,102,4,79,41,207,94,62,51,227,246,199,75,108,97,100,26,207,216,17,164,174,42,253,198,126,169,169,118,53,134,168,158,119,240,215,251,158,61,112,193,232,104,171,216,116,10,252,57,217,74,80,47,7,200,41,216,137,141,151,136,200,78,205,42,135,87,236,197,71,215,198,27,54,129,230,202,245,5,176,148,151,59,199,244,3,94,195,245,55,106,35,123,12,19,123,96,45,146,100,241,11,9,52,129,87,97,177,213,51,70,246,33,136,230,178,22,147,248,148,218,235,9,23,89,254,70,228,74,211,94,179,125,214,232,238,127,106,185,182,229,182,141,36,250,174,175,152,213,86,101,229,42,147,208,37,138,227,60,184,150,166,40,153,177,37,51,132,86,170,236,139,106,8,128,228,72,32,128,194,128,98,168,135,124,249,62,108,119,207,133,24,128,32,168,216,113,185,68,137,148,230,134,158,158,211,167,79,207,60,162,196,128,227,226,155,142,177,116,149,24,122,53,214,222,92,122,24,30,231,186,77,243,218,247,59,239,207,58,167,63,27,142,16,224,40,251,164,203,120,85,191,96,105,82,33,240,141,99,23,16,236,69,236,2,62,152,105,216,8,7,200,26,126,13,247,208,96,58,21,88,246,81,48,155,161,175,157,153,62,241,254,178,244,100,213,18,212,23,193,183,10,243,168,97,238,83,19,167,129,117,11,29,161,161,95,35,92,247,128,127,152,31,150,43,14,116,82,6,252,13,128,144,200,40,137,213,180,126,72,38,50,219,227,203,209,52,79,23,204,100,133,48,227,64,203,96,144,38,150,112,118,25,128,129,183,155,164,254,121,227,30,83,19,128,175,221,32,67,53,75,137,212,197,121,192,190,86,154,3,216,45,48,118,216,97,189,254,53,171,79,8,85,53,88,242,108,220,240,107,166,99,6,110,103,98,148,191,212,215,217,241,47,231,167,199,157,243,31,79,16,187,37,112,128,190,255,249,93,203,116,0,68,160,156,32,42,186,83,65,211,32,127,39,2,9,219,83,6,96,139,178,232,16,142,149,222,227,68,204,186,5,204,110,6,16,145,18,213,206,67,71,209,1,242,182,65,188,132,128,154,113,246,91,135,30,106,43,216,120,77,218,92,37,204,25,102,207,255,37,217,214,108,57,223,126,24,104,243,139,66,193,59,49,159,116,233,59,115,194,210,204,159,58,100,138,52,106,112,16,250,71,251,236,76,197,64,83,211,96,11,147,20,105,118,201,105,45,3,180,8,88,205,5,248,243,153,23,135,242,225,228,164,251,34,178,195,15,205,251,173,72,211,248,73,20,236,164,123,178,159,111,219,79,51,228,163,52,136,56,124,73,116,71,249,52,91,27,41,17,187,239,50,146,240,52,60,176,146,249,67,248,10,33,178,242,226,248,120,164,23,62,174,206,168,120,137,36,190,165,178,81,183,183,193,31,1,102,27,193,231,56,249,237,180,100,36,77,94,22,193,0,187,20,113,163,111,125,181,61,31,170,54,73,230,227,0,80,196,200,42,120,3,196,156,77,22,16,42,124,137,18,206,162,2,188,197,145,191,76,88,78,236,92,117,107,249,200,100,206,211,24,75,128,100,97,90,80,141,254,174,43,91,49,26,152,44,215,176,61,250,23,227,175,16,218,22,115,14,192,28,1,205,144,106,81,255,193,126,233,28,217,233,237,235,25,24,114,12,88,136,202,139,205,149,13,173,5,172,77,159,208,98,232,154,88,170,143,229,201,90,93,237,192,39,88,145,10,103,205,162,251,45,46,18,159,190,3,31,3,34,54,177,202,64,51,157,85,112,97,169,79,142,14,147,29,85,63,71,201,7,86,59,42,135,232,120,121,112,234,199,111,106,71,152,173,164,183,193,157,6,187,7,229,224,78,33,130,145,30,55,17,93,26,97,255,64,189,235,11,54,76,236,167,66,248,50,52,208,146,164,75,204,159,33,101,66,18,55,186,192,192,181,227,87,8,96,191,255,125,9,167,91,100,109,219,136,181,198,112,113,146,38,47,66,113,90,119,41,192,58,85,10,189,77,4,88,167,179,182,149,64,29,52,119,245,189,107,251,247,85,244,109,29,208,247,40,240,63,169,138,244,155,231,14,143,147,168,0,244,110,185,71,254,5,233,129,235,222,213,128,156,147,27,69,47,162,60,16,176,22,245,10,121,107,136,71,182,194,65,83,128,242,13,88,67,189,32,101,239,5,201,163,119,60,206,230,112,36,101,139,110,154,39,49,37,4,250,193,226,34,90,32,101,118,211,239,141,89,31,176,74,197,100,217,157,144,40,207,150,155,67,220,92,81,177,103,129,92,19,192,16,89,220,205,51,149,230,244,71,195,79,183,152,23,195,215,82,70,214,240,159,55,188,160,122,33,87,249,9,225,192,22,182,238,149,163,248,22,97,237,24,208,94,231,22,77,198,110,163,173,32,189,180,219,150,179,249,36,205,241,5,217,33,140,146,117,242,224,117,195,150,92,204,96,24,152,70,95,9,203,126,194,106,173,162,137,247,219,245,165,161,80,245,37,38,20,58,81,122,155,242,129,181,139,82,74,67,220,140,10,99,145,123,104,28,54,165,32,73,100,40,100,53,152,124,141,190,224,208,106,7,156,34,164,40,122,123,128,177,20,213,100,254,87,223,84,160,52,5,16,96,196,16,8,55,34,31,147,120,142,36,12,173,146,235,2,231,59,184,24,250,165,174,110,122,126,143,210,63,107,165,141,39,99,242,170,234,156,61,40,184,179,46,52,160,54,208,159,147,28,14,3,190,74,232,108,213,78,127,216,239,156,109,43,105,217,212,38,125,28,2,98,2,28,157,83,182,187,101,122,57,23,201,36,173,104,38,100,16,219,12,56,61,204,178,225,125,225,19,196,27,255,233,251,31,93,180,90,179,126,25,82,190,5,176,49,162,8,76,49,99,227,253,175,215,163,241,192,247,135,95,111,170,229,79,142,121,28,220,219,191,115,220,24,192,248,210,38,198,66,143,123,155,99,243,231,113,186,72,235,129,107,229,128,246,19,145,101,81,241,151,207,226,191,255,86,160,109,103,243,246,77,220,96,71,50,176,85,76,124,41,97,227,190,63,247,50,158,33,106,95,240,4,150,28,221,144,247,204,147,151,117,76,155,7,111,172,194,9,48,28,5,38,42,49,15,92,26,92,160,152,35,248,133,171,225,37,68,154,163,193,21,10,233,107,4,90,187,137,175,249,28,245,72,112,148,247,242,130,72,48,188,106,226,225,10,147,98,224,64,66,91,128,183,33,232,190,160,214,156,193,218,253,142,127,187,219,236,72,150,27,62,82,7,105,28,122,240,253,234,248,248,36,84,42,29,67,0,233,130,254,178,97,95,249,215,236,248,167,238,201,49,27,143,6,157,47,183,101,79,114,113,241,235,30,123,55,15,48,249,150,206,169,239,254,120,112,143,142,2,94,92,20,2,199,249,50,133,112,22,12,59,162,140,223,209,218,67,247,254,198,232,97,247,88,206,18,228,222,164,137,16,108,35,245,241,64,121,34,202,8,97,175,216,37,224,230,142,146,144,217,210,44,155,107,172,74,42,90,151,183,81,229,130,180,158,123,175,133,254,148,41,105,139,163,116,161,176,183,197,59,125,243,85,106,31,199,37,246,170,230,7,140,227,216,131,183,195,75,71,178,40,73,116,225,105,148,167,94,132,245,168,106,158,7,12,255,13,70,176,224,71,27,134,109,180,206,249,66,132,214,91,135,20,60,150,131,240,1,180,163,74,103,48,66,22,77,164,141,77,37,191,59,61,61,251,177,123,250,211,201,187,127,147,86,0,162,240,103,141,63,111,151,129,186,34,71,4,115,238,8,175,47,123,254,237,125,239,110,160,245,195,94,67,217,217,78,210,193,72,207,14,63,124,234,141,251,21,136,191,54,30,216,101,53,12,24,95,183,17,230,13,250,10,56,15,250,204,90,144,233,194,134,53,109,52,73,249,32,13,30,231,240,36,98,139,119,193,7,10,131,179,62,207,177,22,129,218,47,226,72,169,197,157,124,4,152,233,36,253,163,165,75,158,243,9,160,166,238,2,229,19,50,224,57,230,103,249,38,13,175,58,38,33,78,100,231,2,206,72,39,59,118,180,252,200,95,94,108,78,223,225,140,13,80,196,208,11,85,191,163,210,103,76,167,86,234,249,126,172,192,64,84,169,83,69,193,218,35,102,191,30,42,187,123,197,56,229,221,123,101,87,45,117,115,205,116,57,235,64,33,202,91,187,169,223,178,74,138,184,229,177,155,36,15,122,224,77,159,154,12,71,54,33,205,109,176,209,210,20,28,154,208,138,82,59,0,44,193,236,115,234,45,45,68,241,196,212,60,129,155,104,197,26,167,199,52,33,88,207,40,184,11,92,34,22,118,163,146,191,227,130,183,90,56,186,127,240,71,104,99,185,88,44,245,61,25,62,125,111,109,252,182,228,6,26,212,124,117,173,68,154,239,63,168,166,49,45,68,33,151,19,1,24,18,198,133,69,24,240,95,91,135,77,5,186,105,192,102,203,28,126,184,182,173,237,125,123,75,227,200,10,50,166,142,72,10,109,166,183,244,134,130,140,156,164,214,187,116,239,20,111,33,196,188,230,1,12,6,9,210,253,66,212,173,3,10,121,254,44,40,236,124,226,120,141,12,132,170,79,185,23,62,227,89,174,215,231,226,142,93,103,142,78,251,30,204,44,93,73,22,230,180,27,234,75,210,116,3,82,227,48,212,73,207,87,132,180,113,85,2,233,173,162,56,216,40,207,250,250,83,55,10,134,3,80,4,14,145,75,152,32,75,101,209,209,59,163,137,110,122,253,0,37,28,21,26,135,136,160,80,18,13,56,182,103,120,216,187,41,236,13,15,101,82,36,223,103,4,143,217,76,237,178,81,52,227,18,182,25,218,172,27,99,247,183,80,62,94,24,61,119,217,147,64,49,200,183,146,26,68,73,197,60,12,69,34,215,82,91,112,79,189,177,133,149,240,139,229,116,58,116,47,63,49,46,171,29,252,1,214,11,116,23,62,124,203,52,227,151,136,192,164,6,119,66,199,64,32,107,198,39,136,142,195,192,196,208,23,253,17,27,151,148,11,230,118,5,83,139,44,211,120,169,69,19,109,227,227,248,7,101,55,252,128,156,79,153,205,121,64,141,59,106,207,141,228,129,186,168,112,147,16,141,32,105,39,170,5,220,20,116,37,235,246,113,136,36,23,28,233,65,24,69,4,16,239,217,28,77,195,59,159,117,216,240,102,60,236,169,219,158,236,21,211,24,202,249,186,194,107,23,224,151,217,233,121,87,240,4,253,59,44,103,192,81,0,227,212,63,68,137,138,173,110,233,39,146,42,217,204,94,192,203,91,179,185,6,34,109,207,24,86,82,7,11,151,1,119,184,223,3,88,223,242,150,128,136,55,228,237,29,164,24,25,9,211,62,214,0,217,55,182,202,244,119,181,149,61,89,211,128,221,250,249,190,55,30,56,53,200,79,232,55,211,41,27,125,38,206,170,253,1,79,83,142,121,252,66,211,224,5,95,203,52,113,206,123,90,94,202,112,26,183,224,248,199,93,224,163,87,175,44,108,1,33,2,34,162,233,156,238,189,80,188,38,0,144,133,123,171,33,98,162,101,50,79,193,222,192,224,101,33,138,101,193,166,255,203,233,160,155,229,2,21,91,204,135,112,37,46,150,137,41,48,216,97,136,207,121,71,95,45,88,202,68,254,201,31,115,79,149,187,169,242,36,91,122,98,235,190,255,42,87,16,106,174,64,23,211,85,212,33,109,190,167,90,109,159,205,57,188,80,8,70,17,149,242,6,181,196,8,180,83,186,1,190,165,147,41,196,186,16,215,160,131,155,227,34,240,39,164,60,189,149,58,158,189,48,13,172,43,178,73,97,248,37,204,75,197,107,240,11,175,155,82,75,111,244,206,195,148,218,166,222,254,137,151,162,33,219,93,237,182,175,223,47,245,249,127,80,75,3,4,20,0,0,0,8,0,79,120,58,33,100,134,97,79,44,12,0,0,142,43,0,0,8,0,0,0,102,105,101,108,100,115,46,99,213,90,105,83,27,73,18,253,44,253,138,50,118,128,14,14,73,128,25,11,228,13,124,96,19,195,98,143,53,222,153,24,143,131,109,164,146,212,225,86,183,166,187,133,97,49,255,125,243,168,171,47,129,189,251,101,8,2,90,85,149,175,178,50,95,102,101,85,235,177,63,9,199,114,34,2,63,76,235,73,234,165,254,72,140,102,94,44,62,140,146,139,211,241,167,207,98,80,23,240,179,246,228,116,220,23,19,95,6,227,100,123,180,121,37,186,219,7,162,251,236,217,222,78,167,187,211,121,42,58,251,253,222,211,254,238,129,152,202,104,50,17,175,175,23,226,201,218,97,253,177,12,199,254,164,94,223,105,213,69,75,60,57,139,166,25,144,39,216,250,65,94,249,137,31,133,4,233,98,90,80,70,197,193,111,100,42,98,127,44,162,137,240,130,64,196,114,34,99,25,142,100,34,210,72,12,111,146,84,206,197,191,68,146,198,126,56,21,113,180,76,253,80,38,155,98,18,197,98,17,197,169,119,233,7,126,122,131,72,141,196,159,206,154,219,240,152,83,226,169,163,196,190,16,189,78,191,187,219,223,219,117,148,56,30,143,69,58,147,98,238,93,79,196,194,139,189,185,76,101,92,68,218,119,144,246,96,57,189,254,94,167,223,235,58,72,255,244,190,72,130,242,195,81,44,231,50,76,19,145,200,20,244,12,164,104,144,165,46,192,53,242,2,250,133,23,142,217,120,23,252,23,218,72,127,210,39,89,46,112,129,180,82,4,60,57,123,117,113,254,110,248,246,195,233,249,207,98,18,120,211,146,149,238,145,126,187,59,157,103,59,61,52,253,65,127,239,167,126,167,231,232,119,226,95,139,36,154,75,226,135,24,69,243,69,224,249,168,36,234,66,29,176,124,208,122,38,19,255,63,64,30,128,149,113,28,197,73,201,108,187,118,182,206,51,176,70,183,223,197,223,156,93,61,240,105,186,140,67,113,229,5,75,137,94,165,197,126,141,253,84,110,139,194,82,47,189,209,151,191,150,81,42,89,37,104,66,160,101,136,12,88,44,228,152,6,36,129,151,128,134,37,58,245,180,78,63,237,244,144,112,29,88,126,127,191,147,179,128,7,132,90,46,128,117,225,50,8,182,22,17,88,64,194,212,203,105,17,176,235,0,34,121,186,253,221,94,31,105,100,0,79,67,63,245,61,164,46,11,49,198,78,189,254,24,252,25,44,199,82,28,37,233,216,143,182,103,207,109,211,218,40,10,39,254,116,123,182,230,180,169,64,130,182,58,19,34,21,173,26,61,197,210,27,139,247,162,209,56,57,61,123,13,115,78,252,64,110,114,92,183,196,88,6,254,60,217,172,215,224,71,8,244,43,210,3,130,4,31,145,210,205,230,33,117,238,224,202,60,116,9,82,80,124,245,211,153,10,94,49,137,163,57,180,35,46,234,158,155,126,142,172,198,233,213,140,40,206,240,16,179,209,200,75,229,248,135,180,161,104,241,88,7,140,241,229,8,152,34,181,50,164,36,40,163,178,152,209,137,159,128,167,9,43,149,239,48,170,176,154,63,160,215,123,194,198,168,83,230,241,195,162,62,32,199,214,65,70,142,102,174,125,96,41,122,222,150,128,156,197,147,16,133,221,89,226,8,242,92,98,25,13,153,226,175,37,39,63,152,6,241,107,54,86,138,238,47,174,27,103,161,117,58,179,252,70,194,37,46,135,72,180,14,191,138,252,177,154,109,18,203,114,187,58,160,39,56,70,59,142,227,27,67,243,70,88,182,98,4,64,216,250,83,236,49,182,178,153,78,12,32,19,31,138,29,12,32,149,42,81,37,202,155,30,88,255,177,214,19,80,1,171,4,202,228,209,129,216,239,246,12,84,6,133,86,29,200,112,10,235,102,32,136,55,222,33,63,14,223,212,31,195,3,142,0,215,140,102,113,205,135,142,107,181,199,33,28,12,33,17,121,13,249,1,50,24,26,137,204,211,0,83,168,70,118,115,109,78,145,80,210,1,122,84,244,240,164,110,7,174,13,90,65,95,106,85,187,44,197,108,20,170,197,192,70,137,196,156,250,87,48,138,220,7,82,232,202,203,229,4,246,206,77,113,9,51,126,17,126,42,150,11,234,170,107,7,2,215,49,165,170,116,12,32,115,52,21,130,141,64,69,25,67,54,254,85,83,254,34,181,241,136,0,198,199,243,101,146,10,9,115,167,75,16,186,17,151,24,174,18,58,44,181,240,243,118,61,147,70,28,94,52,152,188,42,28,117,16,82,0,82,97,194,20,71,46,6,242,144,184,134,107,4,69,73,26,77,160,178,21,224,227,120,101,204,26,3,146,196,75,104,242,70,96,81,34,249,18,104,128,59,11,147,149,134,249,212,167,0,40,206,106,164,7,73,191,91,208,182,199,13,2,98,82,103,129,237,89,86,4,117,62,228,52,118,237,207,151,115,216,77,230,151,176,143,128,135,108,136,113,154,82,114,183,244,55,150,83,63,193,13,71,169,142,107,2,231,17,129,95,144,19,81,112,22,5,92,148,144,215,105,241,144,133,50,10,96,15,40,65,130,90,7,26,205,84,16,176,133,203,162,4,182,146,200,203,101,140,91,125,169,8,201,40,197,32,190,84,98,107,10,77,243,108,4,2,87,105,142,137,104,24,153,129,56,255,120,118,214,172,215,20,223,240,211,161,129,5,181,1,54,139,98,123,73,139,129,232,112,11,70,1,254,168,72,240,67,99,150,109,213,193,75,252,58,243,169,200,154,74,168,103,26,235,74,147,79,26,240,243,166,153,121,203,204,178,73,33,196,204,19,226,145,81,250,182,110,108,37,218,3,161,131,178,8,138,57,209,89,183,233,128,57,186,159,209,10,27,127,134,27,0,136,240,20,153,48,94,6,137,228,150,91,254,167,245,106,23,77,82,171,112,132,73,43,170,207,44,174,169,100,202,157,145,245,6,13,188,171,215,238,50,238,99,235,131,249,217,14,156,240,20,20,162,103,33,238,20,167,169,205,86,11,86,175,110,121,176,179,111,239,234,249,36,97,165,55,221,234,162,50,95,232,248,71,9,138,198,51,164,51,4,16,1,169,220,152,175,48,50,65,97,102,161,168,56,255,3,13,65,49,97,58,56,185,41,238,255,253,243,78,174,186,91,16,216,208,24,103,44,147,81,236,95,226,129,203,41,129,254,135,60,194,179,32,123,205,204,54,147,224,72,208,92,119,53,157,92,162,229,170,83,9,143,216,122,30,42,37,77,206,208,29,54,114,172,51,255,193,154,246,75,112,12,76,177,107,230,141,195,192,78,224,164,41,157,28,176,41,151,9,43,211,129,202,47,159,182,182,76,38,17,216,217,217,128,144,202,79,217,53,97,102,83,225,112,6,39,226,47,118,131,80,118,135,137,67,137,85,165,23,223,100,179,35,170,100,109,32,214,215,5,24,24,185,38,214,51,103,203,166,19,250,132,60,40,26,19,19,71,49,19,229,134,109,90,27,181,69,87,231,201,2,150,113,174,147,15,109,29,170,198,235,164,182,34,123,185,25,136,201,223,208,101,49,39,147,149,73,104,213,25,227,1,56,15,136,175,147,92,10,50,49,74,41,74,57,169,172,52,200,36,181,75,201,82,227,191,111,26,82,19,114,174,55,197,11,103,12,43,235,197,177,119,147,95,36,154,3,142,83,36,243,219,76,178,21,147,52,130,135,235,128,120,77,35,161,66,208,103,53,45,93,171,209,165,2,233,251,11,62,81,43,89,9,135,47,147,124,182,170,202,41,84,184,168,114,161,65,247,69,80,52,116,56,158,232,227,81,225,74,7,18,14,245,180,69,79,244,243,189,21,249,71,69,87,190,226,194,217,91,66,167,76,21,129,133,140,105,113,220,122,166,52,168,202,246,114,4,226,212,80,175,173,139,6,38,135,225,219,95,62,190,251,245,245,80,124,163,92,49,60,127,115,150,105,120,113,252,242,231,76,195,171,23,106,64,83,215,86,160,139,139,4,58,113,246,249,54,248,94,200,67,183,218,235,242,226,104,241,78,54,251,240,241,124,152,205,41,106,124,139,152,241,136,115,45,187,77,159,195,116,96,211,144,166,83,12,18,239,218,237,67,62,251,14,191,248,11,17,195,121,20,217,154,141,39,83,120,241,44,3,158,5,17,116,233,167,82,86,214,79,159,114,148,195,173,64,81,93,61,129,36,164,254,154,80,179,171,99,91,8,199,70,171,1,94,166,165,212,14,231,87,212,45,129,161,11,216,197,55,197,26,98,172,65,21,19,4,4,66,55,94,136,34,161,174,129,8,240,44,138,136,240,35,222,139,193,121,57,133,10,187,70,11,51,246,197,37,124,55,41,120,221,57,55,58,163,134,103,199,195,183,205,251,253,133,150,132,110,210,230,126,175,185,37,55,213,220,204,236,12,79,172,210,77,38,131,227,185,141,13,70,249,246,77,136,172,148,93,89,65,234,223,149,66,54,36,242,50,107,27,77,173,239,173,250,111,99,80,43,170,227,134,182,103,53,138,129,180,133,238,33,21,78,193,89,208,86,26,132,194,199,17,219,215,82,140,211,100,85,231,21,250,152,151,71,61,85,155,117,81,126,33,142,77,255,220,40,41,61,50,20,96,15,235,144,195,199,210,128,202,122,151,43,21,125,124,82,23,114,234,16,177,174,66,105,147,165,50,70,253,245,195,233,123,101,87,130,185,203,153,164,165,100,219,109,109,23,214,169,196,50,122,193,206,197,30,25,102,172,95,94,96,24,85,248,214,81,67,87,95,185,185,121,247,82,0,237,182,235,161,170,64,97,59,102,140,71,40,198,122,183,250,225,129,10,85,104,100,78,168,148,33,97,249,111,34,1,5,196,194,75,82,69,23,90,249,67,104,205,211,144,94,181,178,101,169,203,219,21,73,219,57,233,102,21,219,177,169,211,230,58,86,140,188,158,227,147,118,176,205,27,25,18,151,219,176,156,211,206,154,28,82,87,176,58,167,134,38,152,93,203,67,72,174,114,195,74,166,219,69,155,41,110,139,78,198,181,58,234,50,241,86,42,92,140,152,220,116,198,170,186,161,42,198,76,48,226,255,59,179,117,22,46,79,190,123,99,31,172,218,216,11,252,208,134,207,108,198,185,109,92,165,88,210,219,248,21,215,99,12,229,90,9,71,228,42,199,124,205,249,92,29,43,50,114,45,171,134,74,191,110,201,103,68,7,166,80,45,57,84,101,110,153,156,34,212,142,112,170,199,186,34,146,45,70,11,103,61,125,177,188,178,58,181,1,82,85,158,18,247,74,11,212,92,133,234,16,97,197,137,152,207,58,234,189,94,146,187,245,206,95,6,21,143,201,43,206,197,21,238,202,216,252,54,95,223,101,234,249,42,19,210,153,58,15,140,7,231,114,147,174,52,103,222,235,223,121,148,190,191,58,181,215,35,153,99,119,254,56,77,111,217,220,100,69,47,198,232,133,24,191,12,43,61,244,66,23,111,36,39,126,12,123,8,181,194,234,139,175,201,42,78,205,173,26,158,17,249,229,87,246,144,24,203,100,25,164,217,99,44,41,194,163,207,255,192,161,163,40,188,146,49,87,210,249,153,114,23,105,136,48,154,177,176,57,117,195,25,29,183,251,177,188,146,65,180,40,158,212,163,216,159,210,18,241,176,13,207,126,232,5,234,229,56,22,237,105,108,78,162,232,227,71,202,80,200,170,86,163,5,43,107,186,153,153,178,13,202,96,226,187,86,121,207,52,252,174,171,45,106,57,18,27,152,25,177,50,165,207,207,197,198,193,70,174,234,118,167,192,65,89,178,24,96,78,63,25,210,36,95,253,20,93,140,99,88,221,17,190,128,195,161,253,34,182,131,160,176,225,144,173,36,188,10,129,206,65,78,164,107,68,46,203,69,46,43,5,38,229,2,147,74,129,176,92,32,172,20,136,203,5,226,74,129,171,114,129,171,74,129,223,81,128,31,175,181,44,112,234,173,188,246,198,114,228,207,129,86,46,127,169,95,145,143,111,45,105,191,98,106,242,45,135,173,216,137,31,3,38,140,161,212,17,52,60,163,109,159,4,90,4,33,182,112,148,146,181,213,146,6,240,242,0,147,50,0,24,213,22,157,107,175,18,230,56,15,115,82,6,115,156,133,121,240,74,32,177,138,163,35,177,215,132,51,105,195,93,86,243,135,214,85,1,167,23,89,13,186,106,149,21,160,199,57,80,93,44,48,47,58,150,34,93,251,216,179,143,187,246,113,207,62,238,219,199,167,246,241,192,33,217,187,81,122,47,189,92,114,149,112,101,181,119,14,10,43,223,173,244,206,255,15,73,91,111,44,39,30,236,20,37,1,89,76,138,246,118,94,93,75,148,165,107,216,37,204,101,27,42,182,165,77,101,132,185,174,197,218,33,138,73,81,140,72,107,209,35,178,40,90,179,221,110,150,168,165,198,81,72,171,121,104,206,59,189,37,155,189,152,191,77,210,112,190,67,178,80,151,218,247,188,128,103,193,146,203,234,135,222,119,51,64,102,247,165,121,105,252,43,83,117,227,181,113,224,1,171,46,101,250,85,202,48,247,6,202,189,69,166,239,166,29,214,204,107,59,79,125,93,77,68,163,209,210,222,113,103,54,108,66,11,35,126,217,151,189,178,86,91,55,234,153,202,208,236,195,12,105,239,129,209,65,10,69,121,73,127,58,202,151,134,182,143,220,118,235,20,110,48,252,17,159,121,237,28,223,6,98,177,76,71,234,200,162,94,78,99,97,247,250,221,9,190,56,214,131,38,48,42,201,23,128,159,20,236,231,130,220,93,225,130,152,94,45,53,29,68,158,22,55,180,188,180,67,117,54,183,102,20,126,29,166,164,190,252,49,110,16,132,241,240,125,175,0,139,55,222,250,125,146,189,255,99,165,204,107,170,220,192,234,75,243,123,17,120,156,2,40,29,99,222,43,253,23,80,75,3,4,20,0,0,0,8,0,234,105,102,33,247,49,204,222,194,6,0,0,131,16,0,0,7,0,0,0,120,97,114,103,115,46,49,133,87,219,110,27,55,16,125,231,87,12,244,18,187,144,20,203,173,91,160,129,31,236,198,73,5,164,182,96,57,64,3,201,104,86,187,92,137,48,69,110,151,220,88,106,209,127,239,204,144,171,189,200,110,1,61,136,92,114,174,103,206,12,199,15,191,194,239,87,247,31,231,48,249,4,203,1,140,190,27,129,41,109,158,211,63,49,158,255,10,183,87,191,221,136,93,82,174,29,44,71,176,170,148,206,32,49,25,200,157,76,43,47,33,181,219,45,173,181,50,210,65,94,218,45,56,143,27,73,153,129,50,69,229,89,202,252,203,237,221,108,62,157,139,241,53,176,48,177,88,142,206,138,210,239,30,1,255,201,133,180,249,200,249,242,145,151,106,81,202,66,39,169,108,182,244,98,155,236,70,172,228,241,145,46,27,160,13,18,197,223,29,47,211,77,82,134,245,140,215,69,105,211,176,198,11,149,214,241,47,42,91,92,30,52,10,222,139,26,23,151,71,170,151,163,131,234,197,101,203,138,240,77,25,47,203,36,245,234,155,140,146,14,134,92,118,77,90,142,190,201,114,101,157,172,173,216,41,223,82,192,182,94,54,86,55,194,200,201,203,142,183,232,141,29,149,149,25,169,124,36,183,133,223,55,10,156,178,38,174,54,82,23,40,166,206,208,66,25,229,85,162,73,76,181,149,198,83,36,41,57,239,111,230,191,220,79,103,15,211,187,91,241,176,81,20,74,83,37,26,138,100,45,69,102,211,112,24,252,70,194,199,219,207,16,149,128,205,49,155,247,33,157,48,110,50,91,202,36,115,112,80,18,48,65,151,187,184,24,66,38,181,218,42,47,51,88,237,97,165,19,243,228,224,228,121,163,210,13,164,137,129,149,20,24,9,47,83,58,241,172,252,6,50,91,173,180,4,91,130,83,102,141,255,254,172,240,187,163,141,4,86,73,250,228,116,226,54,167,180,54,242,153,211,52,20,45,176,178,15,98,60,173,65,43,78,50,153,39,149,246,128,78,191,93,41,243,86,166,27,139,247,13,43,217,218,82,130,87,91,188,199,234,19,179,167,203,71,97,20,185,213,218,62,7,63,26,191,41,14,47,21,196,24,224,154,156,141,37,131,145,36,171,186,103,80,140,4,181,54,104,65,134,161,157,53,209,37,212,68,123,40,166,65,53,70,131,148,248,202,253,44,198,38,23,103,160,114,80,30,92,149,166,82,102,78,76,206,191,167,45,244,0,229,127,179,105,226,67,6,89,70,13,16,18,93,135,58,72,131,201,104,114,126,129,183,127,160,219,255,115,246,252,130,78,94,244,79,98,104,159,148,214,49,58,152,185,181,73,52,30,252,177,127,16,115,110,172,199,180,3,34,27,15,252,244,130,36,58,144,219,10,83,55,161,175,206,110,49,83,120,166,4,89,150,152,50,155,166,85,25,98,150,43,4,247,28,238,24,215,72,60,15,51,74,222,160,166,130,33,210,217,217,64,76,57,218,185,210,210,36,148,104,138,59,22,244,86,153,196,215,38,211,113,160,58,198,50,71,77,202,56,79,169,197,232,173,246,2,241,138,192,42,144,49,134,204,139,100,112,132,37,45,15,168,100,201,100,190,43,100,138,240,129,19,137,133,180,23,45,185,8,207,228,73,26,196,5,81,138,214,251,83,132,202,123,229,18,4,125,40,63,105,88,45,153,139,81,47,49,237,67,224,130,17,116,25,1,71,54,107,245,36,57,211,33,48,53,32,81,214,103,39,243,74,227,13,84,210,224,116,171,214,27,47,82,107,124,162,12,176,63,16,29,98,71,144,14,202,39,55,164,138,56,120,35,29,138,123,136,132,144,43,204,199,18,105,11,185,240,12,108,193,216,194,210,205,170,20,237,14,120,118,149,242,228,7,102,175,68,87,136,100,108,38,199,157,180,116,104,153,242,211,180,133,129,152,75,255,74,8,192,91,88,230,211,120,116,153,223,163,105,211,188,127,88,196,195,140,16,204,13,254,184,0,233,123,228,35,186,81,74,231,235,186,8,150,163,169,135,66,68,177,29,77,244,209,34,133,97,216,249,58,21,45,129,244,5,43,107,163,148,19,49,66,17,206,107,236,28,102,248,154,111,145,160,28,57,57,248,99,208,13,24,17,252,64,204,40,238,84,89,21,150,73,185,175,173,15,90,232,98,67,30,117,229,118,197,188,216,250,40,254,221,62,60,16,247,97,21,98,40,13,101,215,114,68,90,199,56,42,38,198,143,137,178,5,53,162,11,17,10,237,85,118,20,87,218,217,33,84,134,193,151,213,141,33,179,28,173,67,109,54,82,235,180,244,141,104,165,70,121,209,9,228,223,255,12,224,132,235,132,224,248,149,0,76,112,195,46,241,134,106,110,186,45,180,66,27,81,232,114,180,91,230,51,42,101,193,43,13,19,92,119,227,247,226,120,48,132,206,204,50,16,88,124,144,120,132,61,2,12,69,29,62,145,173,198,26,118,51,66,46,52,134,2,139,183,61,93,189,19,253,107,109,159,152,15,163,195,84,155,101,162,52,1,40,134,47,77,42,210,111,68,163,129,110,33,217,106,187,86,41,177,13,16,5,40,83,97,204,67,79,194,38,186,243,45,147,154,200,136,58,50,247,199,145,232,76,43,132,162,102,82,123,49,8,244,129,156,105,80,210,119,28,245,126,144,207,146,120,3,29,120,245,218,51,118,25,114,8,29,205,234,214,225,212,95,18,78,156,148,188,162,49,49,148,197,41,17,166,220,81,115,36,124,84,6,25,214,197,51,59,104,10,52,22,103,224,69,158,75,208,129,101,126,189,139,234,5,43,61,46,169,214,84,72,33,224,42,181,56,168,177,10,52,16,105,121,101,49,172,72,197,76,210,152,10,108,122,32,19,210,209,114,157,123,8,151,74,96,43,113,24,166,98,33,104,12,206,157,193,228,209,245,118,179,228,219,49,10,72,106,5,82,1,79,96,37,206,43,220,181,191,238,223,16,165,127,253,242,166,143,120,127,148,215,222,180,73,46,149,3,17,73,182,55,185,100,86,6,98,171,59,10,181,162,26,224,8,136,88,200,209,94,17,237,69,27,110,109,185,37,28,14,251,77,159,142,90,100,27,192,142,105,162,79,7,166,141,164,209,71,97,111,0,31,66,231,137,240,34,16,249,11,65,234,208,146,143,161,72,80,72,117,149,113,219,105,172,231,52,29,211,93,61,15,212,164,69,183,104,152,112,164,58,18,62,81,168,160,255,245,181,200,252,117,131,109,77,168,216,179,52,158,146,244,167,176,206,41,236,167,136,221,130,208,115,126,246,212,140,18,174,27,143,248,236,160,24,248,186,93,28,65,37,150,252,33,153,113,158,170,60,229,116,37,115,154,133,195,24,141,198,137,62,222,227,155,160,45,189,126,38,152,106,187,194,40,242,107,225,63,219,16,237,144,141,187,129,184,193,191,175,148,48,1,148,179,20,11,25,90,133,124,12,131,222,163,138,196,183,94,134,216,209,16,90,33,128,17,4,188,79,226,233,15,114,130,228,92,37,252,12,120,199,22,180,18,50,225,166,46,250,87,241,203,217,176,205,18,129,154,8,198,9,63,174,246,109,233,78,212,185,108,52,133,89,173,113,216,52,14,135,145,155,119,103,184,251,78,240,148,247,172,240,56,230,159,123,50,207,176,27,20,102,137,24,232,49,67,137,59,240,99,134,59,99,126,248,13,230,55,55,112,245,105,126,55,64,31,174,169,11,98,111,59,153,124,58,101,235,53,61,19,228,241,78,182,162,189,139,184,87,21,217,97,111,114,74,114,62,160,28,66,250,7,28,99,28,53,207,19,107,70,129,142,12,76,77,110,121,148,228,105,81,102,167,226,95,80,75,3,4,20,0,0,0,8,0,7,138,58,33,125,151,19,211,192,4,0,0,137,14,0,0,11,0,0,0,103,114,97,109,109,97,114,46,108,115,112,165,86,93,115,219,68,20,125,207,175,184,147,154,86,10,168,96,39,129,146,204,4,92,120,233,16,74,32,51,101,120,92,73,107,89,173,180,171,89,173,234,184,29,252,219,185,119,63,164,149,108,51,9,188,200,210,189,103,207,222,189,31,103,125,125,125,13,201,89,2,191,202,156,95,193,109,217,54,215,112,191,21,154,61,92,193,79,178,174,165,72,172,17,65,39,39,81,206,87,165,224,73,197,68,209,177,130,159,0,92,21,138,213,53,83,248,250,34,138,162,123,152,49,177,141,33,185,129,232,126,110,63,98,244,1,144,47,66,202,70,118,34,135,89,139,206,118,17,15,200,118,30,147,95,188,239,68,166,75,41,98,103,94,184,245,158,100,142,118,205,52,175,185,208,48,251,232,24,222,222,33,180,75,223,227,170,119,238,21,102,154,139,150,27,76,176,120,153,125,16,114,83,241,188,64,23,115,203,167,198,0,79,89,96,20,177,223,10,249,239,121,181,130,70,241,214,199,16,224,127,239,120,75,241,15,11,150,221,131,139,37,126,74,160,251,68,175,249,65,158,215,60,89,170,226,0,151,35,59,228,143,126,203,178,78,245,95,149,204,188,31,95,99,179,159,89,13,209,173,204,146,101,110,170,114,28,238,183,154,30,105,188,77,144,194,249,209,163,63,146,34,72,106,64,55,170,73,79,184,191,153,139,98,177,239,136,220,89,127,152,112,76,160,209,76,241,106,148,131,33,99,239,184,74,191,46,177,110,6,98,99,140,31,75,4,51,137,69,157,178,105,53,98,179,229,55,192,39,241,154,135,27,186,144,62,47,143,208,247,111,139,127,217,105,218,13,67,236,97,195,62,169,143,104,87,97,171,116,167,164,64,201,160,239,120,223,187,84,186,204,42,19,242,113,208,1,87,52,195,246,217,122,241,232,234,148,99,134,31,226,225,125,59,4,115,71,112,236,172,198,112,184,160,232,139,108,46,69,3,121,216,63,136,61,98,62,152,143,126,10,158,125,185,172,42,94,40,137,11,15,229,109,90,219,31,177,237,181,15,237,206,37,243,127,51,245,216,144,238,182,203,202,252,145,100,47,169,171,142,6,246,223,153,38,129,25,62,98,189,170,248,67,153,73,97,238,34,159,247,177,178,155,245,91,222,130,86,29,117,141,144,176,98,149,105,208,154,109,83,14,157,32,60,221,62,235,110,141,95,13,83,45,207,167,213,181,91,19,217,154,43,14,218,60,35,193,153,74,183,64,63,177,121,66,197,87,26,84,89,172,53,116,13,228,68,236,137,124,227,34,7,3,38,136,163,247,5,23,6,197,187,41,171,10,86,157,238,20,197,153,99,214,26,134,201,192,87,9,51,188,144,75,61,8,76,48,114,180,148,213,94,19,17,206,48,200,225,171,108,131,15,60,185,103,114,179,187,97,173,223,102,67,167,51,239,126,151,209,61,77,39,192,11,50,73,250,249,114,243,70,158,66,86,57,252,217,213,77,135,116,165,134,84,113,254,137,67,139,49,102,107,40,170,82,107,28,55,33,245,186,20,69,79,224,134,208,82,124,3,115,88,192,57,92,192,37,124,11,223,193,43,248,222,3,195,57,68,36,138,46,211,160,165,45,65,143,233,5,196,86,95,118,208,226,5,78,37,231,80,227,177,56,150,43,122,227,95,71,127,55,14,105,185,97,41,36,212,242,227,144,53,202,18,94,60,198,102,82,229,210,104,12,19,228,96,115,9,110,215,82,106,176,207,105,65,15,234,63,69,96,8,50,166,212,118,66,157,59,107,24,134,181,76,209,131,181,228,249,8,143,255,234,82,48,143,1,221,219,82,222,119,96,193,245,24,230,215,75,103,119,56,12,158,51,156,108,255,59,176,78,61,97,20,185,146,205,129,37,100,110,48,134,209,146,81,22,19,166,167,17,161,61,112,186,37,31,104,178,246,86,88,59,110,48,134,123,162,154,227,162,134,171,140,151,163,178,174,56,63,98,175,244,96,31,205,209,193,219,151,138,155,42,28,7,176,207,129,41,85,178,35,45,177,246,81,189,184,222,67,83,13,2,164,133,146,94,210,223,120,212,53,86,115,154,189,51,146,0,156,70,222,158,217,63,241,111,96,211,167,133,100,9,54,118,124,49,15,23,112,225,66,71,13,117,111,127,225,60,153,222,183,58,151,36,224,8,112,68,72,255,28,204,246,26,209,145,36,12,44,70,59,132,116,6,18,55,26,80,27,119,205,167,11,152,23,16,84,47,35,186,102,59,84,57,35,183,151,112,222,227,156,194,32,14,199,247,28,46,123,7,169,16,90,173,88,59,43,126,7,7,13,212,227,103,23,15,158,5,101,229,28,94,249,67,99,224,184,245,91,171,91,96,215,43,175,224,247,38,117,232,183,47,65,22,126,161,196,4,91,33,198,230,185,107,98,95,26,212,170,182,133,232,185,108,72,95,89,133,45,231,43,20,22,203,20,244,244,15,66,75,74,20,222,143,208,123,191,50,105,205,80,247,52,172,229,6,181,77,108,193,232,56,74,45,216,75,237,229,233,9,213,133,48,73,185,74,208,65,49,62,123,17,85,172,78,115,134,219,186,238,66,212,74,170,154,164,21,78,119,139,231,55,55,55,176,139,118,159,119,12,118,127,239,226,221,23,167,16,64,55,10,219,143,98,198,155,24,239,119,179,23,250,99,184,66,157,214,26,123,192,182,226,248,40,255,0,80,75,1,2,20,0,20,0,0,0,8,0,112,134,58,33,186,125,0,102,84,212,0,0,25,82,2,0,11,0,0,0,0,0,0,0,1,0,32,0,0,0,0,0,0,0,97,108,105,99,101,50,57,46,116,120,116,80,75,1,2,20,0,20,0,0,0,8,0,51,116,58,33,102,89,94,1,220,190,0,0,251,232,1,0,12,0,0,0,0,0,0,0,1,0,32,0,0,0,125,212,0,0,97,115,121,111,117,108,105,107,46,116,120,116,80,75,1,2,20,0,20,0,0,0,8,0,152,137,108,33,187,12,170,55,103,50,0,0,96,149,0,0,3,0,0,0,0,0,0,0,0,0,32,0,0,0,131,147,1,0,115,117,109,80,75,1,2,20,0,20,0,0,0,8,0,153,133,204,32,51,184,224,168,37,31,0,0,27,96,0,0,7,0,0,0,0,0,0,0,1,0,32,0,0,0,11,198,1,0,99,112,46,104,116,109,108,80,75,1,2,20,0,20,0,0,0,8,0,79,120,58,33,100,134,97,79,44,12,0,0,142,43,0,0,8,0,0,0,0,0,0,0,1,0,32,0,0,0,85,229,1,0,102,105,101,108,100,115,46,99,80,75,1,2,20,0,20,0,0,0,8,0,234,105,102,33,247,49,204,222,194,6,0,0,131,16,0,0,7,0,0,0,0,0,0,0,1,0,32,0,0,0,167,241,1,0,120,97,114,103,115,46,49,80,75,1,2,20,0,20,0,0,0,8,0,7,138,58,33,125,151,19,211,192,4,0,0,137,14,0,0,11,0,0,0,0,0,0,0,1,0,32,0,0,0,142,248,1,0,103,114,97,109,109,97,114,46,108,115,112,80,75,5,6,0,0,0,0,7,0,7,0,125,1,0,0,119,253,1,0,0,0];

var data_str = "";

for (var i=0; i<data.length; i += 4096) {
    data_str += String.fromCharCode.apply(undefined, data.slice(i, i + 4096));
}
var start = new Date();

for (var i=0; i<4; i++) {
    var unzip = new JSUnzip();
    var result = unzip.open(data_str);

    if (!result.status) {
        print('Error: ' + result.error);
    } else {
        var totalBytes = 0;
        for (n in unzip.files) {
            totalBytes += unzip.files[n].uncompressedSize;
            var result = unzip.read(n);
            if (!result.status)
                print('Error: ' + result.error);
        }
    }
}
print(new Date - start);
